/*********************************************************************
*                   (c) SEGGER Microcontroller GmbH                  *
*                        The Embedded Experts                        *
*                           www.segger.com                           *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : GUI_AnalogClock.c
Purpose : Showing a clock.
Literature:
Notes:
Additional information:
  Preperations:
    Works out-of-the-box.
  Expected behavior:
    This example shows a clock on the LCD. It makes use of the animation
    module of emWin.
  Sample output:
    An analog clock.
*/

#include "DIALOG.h"
#ifdef GUI_USE_EMCC
  #include "EMCC_Util.h"
#endif

/*********************************************************************
*
*       Externals
*
**********************************************************************
*/

/*********************************************************************
*
*       Types
*
**********************************************************************
*/
typedef struct {
  WM_HWIN    hWin;
  U16        Index;
  U16        LastIndex;
  U16        Destination;
  U16        NumItems;
  U8         Time;
  U8         AnimInProgress;
} ANIM_DATA;

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define BM_FACE      bmClockFace_Classic_390x390
#define BM_SECOND    bmClockHand_Second_2x210
#define BM_MINUTE    bmClockHand_Minute_24x180
#define BM_HOUR      bmClockHand_Hour_40x110

#define SCALE_LONG   35
#define SCALE_SHORT  25
#define AA_FACTOR     6

#define MSG_ANIM_SECOND    (WM_USER + 0x00)
#define MSG_ANIM_MINUTE    (WM_USER + 0x01)
#define MSG_ANIM_HOUR      (WM_USER + 0x02)
#define MSG_UPDATE_SECOND  (WM_USER + 0x03)
#define MSG_UPDATE_MINUTE  (WM_USER + 0x04)
#define MSG_UPDATE_HOUR    (WM_USER + 0x05)

#define COLOR_WHITE       GUI_MAKE_COLOR(0x00F2F2F2)
#define COLOR_LEMON       GUI_MAKE_COLOR(0x0014b6a9)
#define COLOR_BLUE        GUI_MAKE_COLOR(0x00623700)
#define COLOR_LIGHTBROWN  GUI_MAKE_COLOR(0x0090bacc)

#define COLOR_BK       COLOR_BLUE
#define COLOR_SCALE_L  COLOR_LEMON
#define COLOR_SCALE_S  COLOR_WHITE
#define COLOR_SECOND   GUI_RED
#define COLOR_MINUTE   COLOR_LEMON
#define COLOR_HOUR     COLOR_WHITE

#define SECOND 0
#define MINUTE 1
#define HOUR   2

#define TIME_START_S(x)   (60 * (x % 60))
#define TIME_START_M(x)   TIME_START_S(x)
#define TIME_START_H(x)   (300 * (x % 12))

#define TIME_ANIM      1000
#define TIME_MAX       86400
#define TIME_SECOND    1
#define TIME_MINUTE    60
#define TIME_HOUR      3600

#define ANIM_PROG_SECOND  0x01
#define ANIM_PROG_MINUTE  0x02
#define ANIM_PROG_HOUR    0x04

#ifdef GUI_USE_EMCC
  #define TIME_S   Date.Second
  #define TIME_M   Date.Minute
  #define TIME_H   Date.Hour
#else
  #define TIME_S   45
  #define TIME_M   59
  #define TIME_H   15
#endif

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static GUI_CONST_STORAGE U32 _acClockFace_Classic_390x390[] = {
#if (GUI_USE_ARGB == 1)
  0xFF7E5D0C, 0xFF7E5D0C, 0xFF7F5E0D, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF805E0F, 0xFF805F10, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 
        0xFF856417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87671B, 0xFF88681C, 0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A20, 0xFF896B20, 0xFF8A6B20, 
        0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7029, 0xFF8F7129, 0xFF8F7129, 
        0xFF8F722A, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 
        0xFF947732, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987B38, 0xFF987C38, 0xFF987C38, 
        0xFF987C39, 0xFF997D39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9B803E, 0xFF9B803E, 0xFF9C813F, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8341, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 
        0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08647, 
        0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA08647, 0xFF9D8446, 0xFF9A8145, 0xFF987F44, 0xFF957C42, 0xFF937B42, 0xFF927940, 0xFF8A733D, 0xFF786435, 0xFF6B5930, 
        0xFF60502A, 0xFF4E4123, 0xFF453A1F, 0xFF3D331B, 0xFF302916, 0xFF241E10, 0xFF211B0E, 0xFF1C180C, 0xFF16130A, 0xFF100D07, 0xFF0A0804, 0xFF030201, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF050402, 0xFF0A0804, 0xFF100D07, 0xFF16130A, 
        0xFF1C170C, 0xFF211B0E, 0xFF241E10, 0xFF302816, 0xFF3D331B, 0xFF453A1F, 0xFF4E4123, 0xFF60502A, 0xFF6B5A30, 0xFF796535, 0xFF8B733D, 0xFF917941, 0xFF937B42, 0xFF957C42, 0xFF987F44, 0xFF9A8145, 0xFF9D8446, 0xFFA08647, 0xFFA18748, 0xFFA18748, 
        0xFFA18747, 0xFFA18648, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA18647, 0xFFA08646, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 
        0xFF9F8545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8442, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8240, 0xFF9D8240, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967935, 
        0xFF967935, 0xFF967934, 0xFF957834, 0xFF957933, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 
        0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732C, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7029, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 
        0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8A6C22, 0xFF8A6C21, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6A1F, 0xFF896A1F, 0xFF896A1E, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87671B, 0xFF87671B, 
        0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846517, 0xFF846417, 0xFF846416, 0xFF846316, 0xFF836315, 0xFF836315, 0xFF836214, 0xFF826214, 0xFF826113, 0xFF826113, 0xFF826112, 0xFF816012, 0xFF816011, 
        0xFF816011, 0xFF805F10, 0xFF805F10, 0xFF805F0F, 0xFF7F5E0F, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF7F5D0D, 0xFF7E5C0C,
  0xFF7E5D0D, 0xFF7F5D0D, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF805E0F, 0xFF805F0F, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816011, 0xFF826112, 0xFF826113, 0xFF826113, 0xFF826214, 0xFF836214, 0xFF836215, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846417, 0xFF856517, 
        0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF87661A, 0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF88681C, 0xFF88681C, 0xFF88681D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 
        0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8C6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF8F7229, 
        0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91732D, 0xFF91742D, 0xFF92742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF947732, 
        0xFF957832, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987C38, 0xFF987C39, 0xFF997D39, 
        0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9B813F, 0xFF9C813F, 
        0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8141, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8545, 0xFF9F8544, 0xFF9F8544, 0xFF9F8545, 0xFF9F8546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA18646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA18647, 0xFFA18647, 
        0xFFA18747, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF967E43, 0xFF87723C, 0xFF796536, 0xFF6C5A30, 0xFF5E4E2A, 0xFF4E4223, 0xFF3F351C, 0xFF2F2815, 0xFF221D0F, 0xFF110E07, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF070603, 0xFF0E0B06, 0xFF141109, 0xFF18140B, 0xFF080704, 0xFF000000, 0xFF060502, 0xFF1F1A0E, 0xFF060502, 0xFF000000, 0xFF0E0C06, 0xFF1D180D, 0xFF000000, 0xFF000000, 0xFF100D07, 
        0xFF141109, 0xFF0D0B06, 0xFF070603, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF110E07, 0xFF221D0F, 0xFF2F2715, 0xFF3F351C, 0xFF4E4123, 0xFF5E4E2A, 0xFF6B5A30, 
        0xFF796637, 0xFF87713C, 0xFF967E43, 0xFFA18749, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08646, 0xFFA08545, 
        0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 0xFFA08544, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 
        0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 
        0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A36, 0xFF967A35, 
        0xFF967935, 0xFF967935, 0xFF957934, 0xFF967934, 0xFF957834, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947731, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF937530, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 
        0xFF92742D, 0xFF92742D, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF90712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 
        0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87681C, 
        0xFF87671B, 0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856619, 0xFF856518, 0xFF856518, 0xFF856517, 0xFF846416, 0xFF846416, 0xFF846316, 0xFF836315, 0xFF836215, 0xFF836215, 0xFF826213, 0xFF826213, 0xFF826113, 0xFF826112, 0xFF816012, 
        0xFF816011, 0xFF816011, 0xFF805F10, 0xFF805F0F, 0xFF805F0F, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF7F5D0E, 0xFF7F5D0D,
  0xFF7F5E0E, 0xFF7F5E0E, 0xFF805E0F, 0xFF805F0F, 0xFF805F0F, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826113, 0xFF836214, 0xFF836214, 0xFF836315, 0xFF846316, 0xFF846316, 0xFF846417, 0xFF846417, 0xFF856517, 0xFF856518, 
        0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF87671B, 0xFF86671B, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF88681D, 0xFF88681D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A20, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 
        0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 
        0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF957832, 0xFF957832, 0xFF957832, 
        0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 
        0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9C8140, 
        0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8445, 0xFF9F8545, 
        0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA28748, 0xFFA18748, 
        0xFF927940, 0xFF715F33, 0xFF554826, 0xFF352C18, 0xFF211C0F, 0xFF16130A, 0xFF100D07, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF201B0E, 0xFF362D18, 0xFF4A3E21, 0xFF584928, 0xFF65552E, 
        0xFF766335, 0xFF7D6939, 0xFF836E3B, 0xFF87723D, 0xFF8A743E, 0xFF8B753F, 0xFF8D7741, 0xFF917942, 0xFF977F45, 0xFF382F1A, 0xFF000000, 0xFF211C0F, 0xFFA18749, 0xFF1E190E, 0xFF000000, 0xFF4B3F22, 0xFF9A8146, 0xFF030301, 0xFF000000, 0xFF6A5930, 
        0xFF917942, 0xFF8E7741, 0xFF8B753F, 0xFF8A743E, 0xFF88723D, 0xFF836E3B, 0xFF7D6939, 0xFF766335, 0xFF65552E, 0xFF584928, 0xFF4A3E21, 0xFF352C18, 0xFF282212, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF080704, 0xFF100D07, 0xFF17130A, 0xFF211C0F, 0xFF352C18, 0xFF554726, 0xFF725F32, 0xFF927940, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA18647, 
        0xFFA08647, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8342, 0xFF9D8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF9A7D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF987B37, 0xFF977B37, 0xFF977B37, 
        0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752F, 
        0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F26, 
        0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A20, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF88681D, 
        0xFF87681C, 0xFF87671C, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846316, 0xFF846315, 0xFF836315, 0xFF836214, 0xFF836214, 0xFF826113, 0xFF826113, 0xFF826112, 
        0xFF816012, 0xFF816011, 0xFF816011, 0xFF816010, 0xFF805F10, 0xFF805F0F, 0xFF805E0E, 0xFF7F5E0E, 0xFF7F5E0D,
  0xFF7F5E0E, 0xFF7F5E0E, 0xFF805F0F, 0xFF805F10, 0xFF805F10, 0xFF816010, 0xFF816011, 0xFF816011, 0xFF826112, 0xFF826113, 0xFF826113, 0xFF836214, 0xFF836214, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856517, 0xFF856518, 0xFF856518, 
        0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691D, 0xFF89691E, 0xFF89691E, 0xFF896A1E, 0xFF896A1F, 0xFF896B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 
        0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D23, 0xFF8C6E23, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 0xFF90722A, 0xFF90722B, 0xFF90722B, 
        0xFF91732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947732, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957833, 
        0xFF957934, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 
        0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 
        0xFF9D8241, 0xFF9E8241, 0xFF9D8241, 0xFF9E8242, 0xFF9D8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9E8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08445, 0xFFA08545, 0xFFA08545, 0xFFA08545, 
        0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18646, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFFA18747, 0xFFA08647, 0xFF9F8446, 0xFF9D8346, 0xFF967E43, 0xFF776536, 0xFF514324, 0xFF272011, 0xFF060503, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF030201, 0xFF030301, 0xFF070603, 0xFF1D190D, 0xFF362D18, 0xFF514525, 0xFF6F5C32, 0xFF846E3C, 0xFF9A8246, 0xFF18140B, 0xFF040302, 0xFF736034, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF3F351D, 0xFF000000, 0xFF251F11, 0xFFA3894B, 0xFF211C0F, 0xFF000000, 0xFF534526, 0xFFA3894B, 0xFF040302, 0xFF000000, 0xFF766336, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894A, 0xFF483C21, 0xFF000000, 0xFF3F351C, 0xFF836D3B, 0xFF6E5C32, 0xFF524525, 0xFF362D18, 
        0xFF1D190D, 0xFF070603, 0xFF030301, 0xFF030201, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060503, 0xFF272011, 0xFF504424, 0xFF796535, 0xFF977E43, 0xFF9D8346, 0xFF9E8446, 0xFFA08647, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18747, 
        0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 
        0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9D8342, 0xFF9E8341, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9D8240, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 
        0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 
        0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF92752F, 
        0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 
        0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF89691E, 0xFF88691D, 0xFF88681D, 
        0xFF87681C, 0xFF87681C, 0xFF87681B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846416, 0xFF836315, 0xFF836315, 0xFF836315, 0xFF826214, 0xFF826213, 0xFF826113, 
        0xFF826112, 0xFF816012, 0xFF816011, 0xFF816011, 0xFF805F10, 0xFF805F10, 0xFF805F0F, 0xFF7F5E0E, 0xFF7F5E0E,
  0xFF7F5E0E, 0xFF805E0F, 0xFF805F10, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF836213, 0xFF836214, 0xFF836215, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846417, 0xFF856517, 0xFF856518, 0xFF856518, 0xFF866519, 
        0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D22, 
        0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E25, 0xFF8C6E25, 0xFF8D6E26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722B, 0xFF90722B, 0xFF90732B, 0xFF91732C, 
        0xFF91742C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947631, 0xFF947732, 0xFF947832, 0xFF947732, 0xFF957833, 0xFF957933, 0xFF957833, 0xFF967934, 
        0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF967A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF997E3B, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFF9F8545, 0xFFA08546, 0xFFA08545, 0xFFA08645, 0xFFA08646, 
        0xFFA08646, 0xFFA18646, 0xFFA08647, 0xFFA18647, 0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA18747, 0xFF987F44, 0xFF85703B, 0xFF746133, 0xFF5A4B28, 0xFF382F19, 0xFF17130A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF141109, 
        0xFF221C0F, 0xFF312916, 0xFF463B20, 0xFF60512C, 0xFF786537, 0xFF907941, 0xFFA2894A, 0xFFA3884A, 0xFFA3894A, 0xFFA3894B, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFF1E190E, 0xFF010100, 0xFF594B29, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 
        0xFFA38A4C, 0xFFA3894C, 0xFFA38A4B, 0xFFA3894C, 0xFFA38A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA4894C, 0xFF3F351D, 0xFF000000, 0xFF251F11, 0xFFA48A4C, 0xFF221D10, 0xFF000000, 0xFF544627, 0xFFA38A4C, 0xFF040302, 0xFF000000, 0xFF776336, 
        0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA4894C, 0xFFA38A4B, 0xFFA38A4B, 0xFFA48A4B, 0xFFA48A4B, 0xFFA4894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF312916, 0xFF000000, 0xFF4D4123, 0xFFA3894B, 0xFFA3894A, 0xFFA3894B, 0xFFA3894A, 
        0xFFA3894A, 0xFFA3894A, 0xFF917941, 0xFF786637, 0xFF61512C, 0xFF463B20, 0xFF312916, 0xFF221C0F, 0xFF141109, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF18140A, 0xFF393019, 0xFF5A4B28, 0xFF746133, 0xFF86703C, 0xFF987F44, 0xFFA18747, 
        0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA18646, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 
        0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8341, 0xFF9D8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 
        0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7D3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF987B37, 
        0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957834, 0xFF957933, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF937630, 0xFF937630, 0xFF93762F, 
        0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7128, 0xFF8E7028, 0xFF8E7028, 0xFF8E6F27, 
        0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8C6C23, 0xFF8B6D22, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691D, 
        0xFF88681D, 0xFF87681D, 0xFF87681C, 0xFF87681B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856418, 0xFF846417, 0xFF846416, 0xFF846416, 0xFF836315, 0xFF836315, 0xFF836214, 0xFF826214, 0xFF826213, 
        0xFF826113, 0xFF816112, 0xFF816011, 0xFF816011, 0xFF816011, 0xFF805F10, 0xFF805F10, 0xFF805F0F, 0xFF7F5E0E,
  0xFF805E0F, 0xFF805F0F, 0xFF806010, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826113, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836214, 0xFF836215, 0xFF846316, 0xFF846416, 0xFF846416, 0xFF856417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 
        0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88691D, 0xFF88681D, 0xFF89691D, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6A20, 0xFF8A6B20, 0xFF8B6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6D23, 0xFF8C6D24, 
        0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F712A, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732C, 0xFF91732C, 0xFF91742D, 
        0xFF91742D, 0xFF92742D, 0xFF92752D, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937530, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967935, 
        0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 
        0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18646, 0xFFA18646, 0xFFA18647, 0xFFA18647, 
        0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFF87713C, 0xFF5E4F2A, 0xFF393019, 0xFF221C0F, 0xFF110E07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF262011, 0xFF504324, 0xFF6A5A30, 0xFF7E6A39, 0xFF8B753F, 
        0xFF987F46, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894C, 0xFFA4894C, 0xFFA38A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFF2B2413, 0xFF000000, 0xFF4B3F23, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFF40361E, 0xFF000000, 0xFF252011, 0xFFA48B4D, 0xFF221C10, 0xFF000000, 0xFF544627, 0xFFA48A4D, 0xFF030301, 0xFF000000, 0xFF776438, 
        0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF1D180D, 0xFF000000, 0xFF5B4C2A, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894C, 
        0xFFA3894B, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF987F46, 0xFF8B753F, 0xFF7E6A39, 0xFF6A5A30, 0xFF4F4224, 0xFF2D2514, 0xFF070603, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF110E07, 0xFF221C0F, 0xFF393019, 
        0xFF5E4F2A, 0xFF87713C, 0xFFA18748, 0xFFA28748, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 
        0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 
        0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C39, 0xFF987C38, 
        0xFF987C38, 0xFF987B37, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 
        0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF8F712A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8F7028, 0xFF8E7028, 
        0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D23, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 
        0xFF88691D, 0xFF88681D, 0xFF88681D, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856619, 0xFF856518, 0xFF856518, 0xFF856417, 0xFF846416, 0xFF846416, 0xFF846316, 0xFF836315, 0xFF836215, 0xFF836214, 
        0xFF826213, 0xFF826113, 0xFF826112, 0xFF816012, 0xFF816011, 0xFF816011, 0xFF806011, 0xFF805F10, 0xFF805F0F,
  0xFF805F0F, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816112, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836214, 0xFF836215, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 
        0xFF86671A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6A20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 
        0xFF8C6E25, 0xFF8D6E25, 0xFF8C6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F712A, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF90732B, 0xFF91742C, 0xFF91742D, 0xFF91742D, 
        0xFF92742E, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947731, 0xFF947832, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967935, 0xFF967935, 
        0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF987D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3C, 
        0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813E, 0xFF9C803F, 0xFF9C8140, 0xFF9C813F, 0xFF9C8140, 0xFF9C8240, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8341, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8443, 0xFF9F8443, 0xFF9E8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFF9F8445, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08645, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA08647, 0xFFA08647, 0xFFA18747, 0xFFA18747, 0xFFA18747, 
        0xFFA18748, 0xFFA18748, 0xFF9D8446, 0xFF766234, 0xFF3E331C, 0xFF0D0B06, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080704, 0xFF352C18, 0xFF60512B, 0xFF151209, 0xFF010100, 0xFF6C5B32, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 
        0xFFA38A4B, 0xFFA3894B, 0xFFA4894B, 0xFFA38A4C, 0xFFA38A4C, 0xFFA3894C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 0xFF3D331C, 0xFF000000, 0xFF3F351D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 
        0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFF40361E, 0xFF000000, 0xFF262011, 0xFFA48B4D, 0xFF221C10, 0xFF000000, 0xFF534627, 0xFFA58B4E, 0xFF040302, 0xFF000000, 0xFF776538, 
        0xFFA48B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48A4D, 0xFF100E07, 0xFF030201, 0xFF675730, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA28849, 0xFFA3894A, 0xFF42371E, 0xFF000000, 0xFF251F11, 0xFF332B17, 0xFF080603, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF010100, 0xFF0E0C06, 0xFF3E331B, 0xFF766234, 0xFF9D8446, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 
        0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9C803E, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 
        0xFF987C38, 0xFF987C38, 0xFF977C38, 0xFF987B37, 0xFF977B37, 0xFF977A37, 0xFF977A36, 0xFF977A36, 0xFF977A35, 0xFF967A35, 0xFF967A35, 0xFF957934, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957832, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947631, 
        0xFF947731, 0xFF937630, 0xFF937630, 0xFF937530, 0xFF93752E, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90732B, 0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8F7128, 
        0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 
        0xFF89691E, 0xFF88691E, 0xFF88681D, 0xFF88691D, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF86671A, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846416, 0xFF836315, 0xFF836315, 0xFF836214, 
        0xFF836214, 0xFF826113, 0xFF826113, 0xFF826113, 0xFF816012, 0xFF816011, 0xFF816011, 0xFF815F10, 0xFF805F10,
  0xFF805F10, 0xFF806011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836215, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846416, 0xFF856418, 0xFF856518, 0xFF856518, 0xFF866519, 0xFF86661A, 0xFF86661A, 0xFF86671A, 
        0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6D23, 0xFF8B6D24, 0xFF8C6D24, 0xFF8C6E24, 
        0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF90732C, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 
        0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A36, 
        0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF977C38, 0xFF987C37, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B803D, 0xFF9C803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8242, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 
        0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18646, 0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF937B41, 0xFF836D3A, 
        0xFF61512B, 0xFF2E2614, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A05, 0xFF1B160C, 0xFF322A17, 0xFF5D4E2A, 0xFF8A743E, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFF2E2715, 0xFF000000, 0xFF44391F, 0xFFA38A4B, 0xFFA38A4B, 0xFFA4894C, 0xFFA4894C, 
        0xFFA48A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48B4D, 0xFF504425, 0xFF000000, 0xFF332B18, 0xFFA1884B, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4E, 
        0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFF41371E, 0xFF000000, 0xFF262012, 0xFFA58B4E, 0xFF221C10, 0xFF000000, 0xFF544627, 0xFFA58B4E, 0xFF030201, 0xFF000000, 0xFF786538, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFF9C8449, 0xFF080703, 0xFF070603, 0xFF746236, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 
        0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA38A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF1C170C, 0xFF000000, 0xFF5F502C, 0xFFA3894A, 0xFFA3894A, 0xFF89743E, 0xFF5D4E2A, 
        0xFF322A17, 0xFF1B160C, 0xFF0C0A05, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF2E2614, 0xFF60512B, 0xFF826D3A, 0xFF937B41, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 
        0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 
        0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7D3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 
        0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 
        0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF90732B, 0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 
        0xFF8F7129, 0xFF8E7027, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 
        0xFF896A1F, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF88681D, 0xFF87681C, 0xFF87671C, 0xFF87671B, 0xFF86671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846416, 0xFF836315, 0xFF836315, 
        0xFF836215, 0xFF826214, 0xFF826213, 0xFF826113, 0xFF816112, 0xFF816012, 0xFF816011, 0xFF816011, 0xFF805F10,
  0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836214, 0xFF836215, 0xFF846316, 0xFF846416, 0xFF846417, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 
        0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 
        0xFF8D6F25, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7027, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F712A, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 
        0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A35, 0xFF977A37, 0xFF977B36, 
        0xFF977B37, 0xFF977B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9B803E, 
        0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9D813F, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8242, 0xFF9E8342, 0xFF9E8443, 0xFF9E8443, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8445, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18646, 0xFFA08647, 0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFF937A41, 0xFF66552D, 0xFF3F351C, 0xFF201B0E, 0xFF010100, 
        0xFF000000, 0xFF000000, 0xFF1C180D, 0xFF443A1F, 0xFF66562E, 0xFF816C3A, 0xFF9A8247, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894C, 0xFFA38A4C, 0xFFA48A4C, 0xFF4C4023, 0xFF000000, 0xFF2C2514, 0xFFA0864A, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFF64552F, 0xFF000000, 0xFF2A2313, 0xFF9B8449, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFF443A20, 0xFF000000, 0xFF272112, 0xFFA68C4F, 0xFF231E11, 0xFF000000, 0xFF594B2A, 0xFFA58C4F, 0xFF030301, 0xFF000000, 0xFF7D6A3C, 
        0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFF8D7842, 0xFF070603, 0xFF0B0905, 0xFF816D3D, 0xFFA58B4E, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFF9B8248, 0xFF050402, 0xFF070603, 0xFF766336, 0xFFA4894C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 
        0xFFA3894B, 0xFF9A8247, 0xFF816C3A, 0xFF66562E, 0xFF44391F, 0xFF1C180D, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF201B0E, 0xFF3F351C, 0xFF66552D, 0xFF937A41, 0xFFA28748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 
        0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8341, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 
        0xFF997D3A, 0xFF997D3A, 0xFF987D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957833, 
        0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF91732B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF907129, 
        0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 
        0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF86661A, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846316, 0xFF846316, 
        0xFF836315, 0xFF836214, 0xFF836214, 0xFF826213, 0xFF826113, 0xFF826113, 0xFF816012, 0xFF816011, 0xFF816011,
  0xFF816011, 0xFF816011, 0xFF826112, 0xFF826113, 0xFF826113, 0xFF826214, 0xFF836214, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 
        0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 
        0xFF8D6F26, 0xFF8E6F27, 0xFF8E6F27, 0xFF8E7027, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 
        0xFF937630, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B37, 
        0xFF977C38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8445, 0xFF9F8544, 
        0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFF9E8446, 0xFF6A582F, 0xFF262011, 0xFF080603, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF211B0F, 
        0xFF5E4F2A, 0xFF907941, 0xFF9B8246, 0xFFA08648, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA38A4B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF756336, 0xFF000000, 0xFF1B170C, 0xFF927C44, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58A4E, 
        0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFF7C693B, 0xFF000000, 0xFF201B0F, 0xFF9A8249, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 
        0xFFA58C4F, 0xFF947D47, 0xFF887441, 0xFF816E3E, 0xFF726137, 0xFF645530, 0xFF61522F, 0xFF5D4F2C, 0xFF574A2A, 0xFF201B0F, 0xFF000000, 0xFF0D0B06, 0xFF433920, 0xFF0C0A05, 0xFF000000, 0xFF211C10, 0xFF483C22, 0xFF000000, 0xFF000000, 0xFF433920, 
        0xFF61522F, 0xFF62532F, 0xFF6E5C34, 0xFF7E6A3C, 0xFF887241, 0xFF8F7944, 0xFFA2894D, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFF806D3D, 0xFF050402, 0xFF0E0C07, 0xFF8D7843, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4F, 0xFFA58C4E, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFF796639, 0xFF020201, 0xFF120F08, 0xFF8C7541, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA3894C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA08649, 0xFF9B8246, 0xFF907941, 0xFF5D4E2A, 0xFF201B0E, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF080603, 0xFF282112, 0xFF6A582F, 0xFF9F8446, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18747, 
        0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFFA08545, 0xFF9F8544, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8341, 
        0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF9A7D3A, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF977A35, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 
        0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90732B, 0xFF90722B, 0xFF90722A, 
        0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 
        0xFF8A6B20, 0xFF8A6A1F, 0xFF896A1F, 0xFF89691F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846416, 
        0xFF846316, 0xFF836315, 0xFF836215, 0xFF836214, 0xFF826113, 0xFF826113, 0xFF826112, 0xFF816011, 0xFF816011,
  0xFF816012, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF826213, 0xFF836214, 0xFF836315, 0xFF836315, 0xFF846316, 0xFF846417, 0xFF856417, 0xFF856517, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF86671A, 0xFF87671C, 0xFF87681C, 0xFF87681C, 
        0xFF88681D, 0xFF88691D, 0xFF88691D, 0xFF886A1E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D24, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E26, 0xFF8D6F26, 
        0xFF8E7027, 0xFF8E7027, 0xFF8E7027, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF90732C, 0xFF91732C, 0xFF91732C, 0xFF92742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF92762F, 
        0xFF937630, 0xFF937631, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957933, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF987C37, 
        0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C803F, 0xFF9C813F, 
        0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9D8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 
        0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFFA18647, 0xFFA18748, 0xFF9F8546, 0xFF957C42, 0xFF796636, 0xFF3B311A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF262011, 0xFF5F502B, 0xFF977F45, 0xFFA3894B, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFF978047, 0xFF000000, 0xFF0A0804, 0xFF826D3C, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58B4F, 0xFFA58B4F, 0xFFA58C4F, 0xFFA1884D, 0xFF9D854B, 0xFF998249, 0xFF967E47, 0xFF917A45, 0xFF877241, 0xFF5A4C2B, 0xFF000000, 0xFF090704, 0xFF272112, 0xFF1B170D, 0xFF0C0A05, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF030301, 0xFF030201, 0xFF010100, 0xFF030201, 0xFF030301, 0xFF020201, 0xFF000000, 0xFF030301, 0xFF030201, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF18150B, 0xFF292213, 0xFF40361E, 0xFF362E1A, 0xFF020201, 0xFF100D07, 0xFF867140, 0xFF957E47, 0xFF988148, 0xFF9D844A, 0xFFA0884C, 
        0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFF584A29, 0xFF010100, 0xFF1E190E, 0xFFA1884B, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4B, 0xFFA3894B, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF987F45, 0xFF5E4F2B, 0xFF251F11, 0xFF0D0B06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3B311A, 0xFF7A6636, 0xFF957C42, 0xFF9F8547, 
        0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B813E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF977B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF967934, 0xFF957833, 
        0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF947630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722A, 
        0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B21, 
        0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671B, 0xFF86671A, 0xFF86661A, 0xFF85661A, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 
        0xFF846316, 0xFF836315, 0xFF836315, 0xFF836215, 0xFF826214, 0xFF826213, 0xFF826113, 0xFF826112, 0xFF816012,
  0xFF826112, 0xFF826112, 0xFF826213, 0xFF836214, 0xFF836215, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86671A, 0xFF87671A, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 
        0xFF88691D, 0xFF88691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF896B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 
        0xFF8E7027, 0xFF8E7027, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732C, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 
        0xFF947630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF977A37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 
        0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9B803F, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 
        0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8242, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8445, 0xFFA08545, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08646, 
        0xFFA08647, 0xFFA08646, 0xFFA18747, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF957C42, 0xFF6B5A30, 0xFF42371D, 0xFF141109, 0xFF000000, 0xFF000000, 0xFF1A160C, 0xFF1F1A0E, 0xFF000000, 0xFF2D2614, 0xFFA3894B, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 
        0xFFA4894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFF16130A, 0xFF000000, 0xFF6E5C34, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 
        0xFFA58C4F, 0xFFA58C4F, 0xFF9C844B, 0xFF887341, 0xFF776539, 0xFF64542F, 0xFF534627, 0xFF3F351E, 0xFF2E2616, 0xFF1A160C, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0905, 0xFF14110A, 0xFF221D10, 0xFF2A2314, 
        0xFF362D1A, 0xFF3B331C, 0xFF423820, 0xFF4C4125, 0xFF514527, 0xFF534628, 0xFF5B4D2C, 0xFF635430, 0xFF675732, 0xFF685832, 0xFF675733, 0xFF685932, 0xFF6A5A33, 0xFF685832, 0xFF685733, 0xFF685933, 0xFF685933, 0xFF675832, 0xFF665631, 0xFF645430, 
        0xFF5E502E, 0xFF564829, 0xFF514527, 0xFF4E4226, 0xFF463B21, 0xFF3C331D, 0xFF38301B, 0xFF2D2615, 0xFF231E11, 0xFF18140B, 0xFF0D0B06, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF16120A, 0xFF292213, 0xFF3B321C, 
        0xFF504326, 0xFF5F512E, 0xFF736137, 0xFF84703F, 0xFF978048, 0xFFA58C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58C4F, 0xFF39301B, 0xFF000000, 0xFF372E1A, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 
        0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF846F3C, 0xFF010100, 0xFF030201, 0xFF0E0C06, 0xFF000000, 0xFF000000, 0xFF141109, 0xFF42371E, 
        0xFF6C5B30, 0xFF957D42, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8444, 0xFF9F8343, 
        0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9D8140, 0xFF9D813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7F3C, 
        0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3A, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967A36, 0xFF967935, 0xFF967935, 0xFF967934, 
        0xFF957933, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF947630, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF90732C, 0xFF90722B, 
        0xFF90722B, 0xFF90722A, 0xFF8F7229, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 
        0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A20, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88681D, 0xFF88681D, 0xFF88681C, 0xFF87671C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF846418, 
        0xFF846417, 0xFF846316, 0xFF836315, 0xFF836315, 0xFF836214, 0xFF836214, 0xFF826213, 0xFF826113, 0xFF826112,
  0xFF826113, 0xFF826113, 0xFF836214, 0xFF836214, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856517, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF88681D, 0xFF88691D, 
        0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7027, 
        0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91732C, 0xFF91732D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947630, 
        0xFF947732, 0xFF947732, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977A37, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF987C39, 
        0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8240, 
        0xFF9D8241, 0xFF9E8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18646, 0xFFA18647, 0xFFA18647, 
        0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFF836D3A, 0xFF3E331C, 0xFF130F08, 0xFF030301, 0xFF000000, 0xFF030201, 0xFF3F351D, 0xFF7D6939, 0xFF977F44, 0xFF7C6839, 0xFF000000, 0xFF120F08, 0xFF88723E, 0xFFA48A4C, 0xFFA38A4C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFF42381F, 0xFF000000, 0xFF544728, 0xFFA68C4F, 0xFF8A7442, 0xFF645430, 
        0xFF3F351E, 0xFF231D10, 0xFF14110A, 0xFF0D0B06, 0xFF050402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF18150C, 0xFF302917, 0xFF4C4025, 0xFF62542F, 0xFF746238, 0xFF887442, 0xFF8E7945, 0xFF937D47, 0xFF968049, 0xFF9B834C, 0xFF9D854C, 
        0xFFA1894F, 0xFFA38B4F, 0xFFA58C51, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 
        0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA68D51, 0xFFA38B50, 0xFFA28A4F, 0xFF9D864D, 0xFF9B834B, 0xFF978149, 0xFF947D48, 0xFF907B46, 0xFF8A7643, 0xFF78663A, 0xFF685832, 0xFF504427, 0xFF362E1A, 0xFF201B0F, 0xFF040302, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF030201, 0xFF0B0905, 0xFF131009, 0xFF1E190E, 0xFF372F1A, 0xFF5B4D2B, 0xFF816D3E, 0xFFA1884C, 0xFFA68C50, 0xFFA2894D, 0xFF251F11, 0xFF000000, 0xFF5D4E2C, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF6A5930, 0xFF000000, 0xFF16120A, 0xFF836E3B, 0xFF7D6939, 0xFF3F351D, 0xFF030201, 0xFF000000, 
        0xFF030301, 0xFF131008, 0xFF3D341C, 0xFF846E3A, 0xFFA18848, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9C8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 
        0xFF967935, 0xFF957934, 0xFF957834, 0xFF957833, 0xFF957832, 0xFF957732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752F, 0xFF92742E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 
        0xFF91732B, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 
        0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87671C, 0xFF87671B, 0xFF87671A, 0xFF86661A, 0xFF86661A, 0xFF856519, 0xFF856518, 0xFF856518, 
        0xFF856417, 0xFF846417, 0xFF846316, 0xFF846316, 0xFF836315, 0xFF836214, 0xFF836214, 0xFF826113, 0xFF826113,
  0xFF826113, 0xFF826213, 0xFF836214, 0xFF836315, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF866619, 0xFF86671A, 0xFF86671A, 0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF89691E, 
        0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF896B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7028, 0xFF8E7028, 
        0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937731, 0xFF937631, 0xFF947731, 
        0xFF947732, 0xFF957732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 
        0xFF997E3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 
        0xFF9F8547, 0xFF9A8144, 0xFF6F5D31, 0xFF1B170C, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF1E190D, 0xFF68572F, 0xFFA18749, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF0D0B06, 0xFF000000, 0xFF685730, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 
        0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA3894D, 0xFFA0874C, 0xFF9E854B, 0xFF524527, 0xFF000000, 0xFF050402, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF010100, 0xFF050402, 0xFF070603, 0xFF19150C, 0xFF3A311C, 0xFF594B2B, 0xFF7C693C, 0xFF978149, 0xFFA78E51, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 
        0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E53, 0xFFA88E52, 0xFFA78F53, 0xFFA88F53, 0xFFA88E52, 0xFFA78F53, 0xFFA78E53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFFA88F53, 0xFFA88E53, 0xFFA88F53, 0xFFA88E52, 0xFFA78F53, 0xFFA78F53, 
        0xFFA88F52, 0xFFA88F52, 0xFFA78F52, 0xFFA78F52, 0xFFA88F53, 0xFFA78F53, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFF9D854C, 
        0xFF836F3F, 0xFF62542F, 0xFF41371F, 0xFF1F1B0F, 0xFF090704, 0xFF050402, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF16130A, 0xFF372F1A, 0xFF0D0B06, 0xFF000000, 0xFF806C3D, 0xFFA48B4E, 0xFFA48B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58B4E, 
        0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF342C18, 0xFF000000, 0xFF332B17, 0xFFA3894B, 0xFFA3894B, 0xFFA3894A, 0xFFA18749, 0xFF68572F, 
        0xFF1E190D, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF1B170C, 0xFF705D31, 0xFF9B8144, 0xFF9F8547, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C803F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967A35, 
        0xFF967935, 0xFF967934, 0xFF957934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937730, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91732D, 0xFF91742C, 
        0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E6F27, 0xFF8D6F26, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6D22, 
        0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856519, 0xFF856518, 
        0xFF856518, 0xFF846417, 0xFF846417, 0xFF846316, 0xFF836315, 0xFF836315, 0xFF836214, 0xFF826214, 0xFF826213,
  0xFF826113, 0xFF836214, 0xFF836314, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846416, 0xFF856517, 0xFF856518, 0xFF856619, 0xFF856519, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681C, 0xFF88681D, 0xFF88691E, 0xFF89691E, 
        0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8B6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8B6D24, 0xFF8C6D24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7128, 
        0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947731, 0xFF947732, 
        0xFF957732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A35, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 
        0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9B813F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF9E8446, 0xFF7C6737, 
        0xFF4C4022, 0xFF0F0D07, 0xFF000000, 0xFF010100, 0xFF231D10, 0xFF4C4022, 0xFF86703D, 0xFFA3894A, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFF473C21, 0xFF000000, 0xFF3D341C, 0xFFA1884B, 0xFFA48A4D, 0xFFA48B4D, 
        0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFF927C46, 0xFF7D693B, 0xFF645530, 0xFF42381F, 0xFF1D180D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF110E08, 0xFF241E11, 0xFF372E1A, 0xFF4F4226, 
        0xFF6C5B34, 0xFF887442, 0xFFA28A4E, 0xFFA78E51, 0xFFA78E51, 0xFFA78E51, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E53, 0xFFA78F53, 0xFFA78E52, 0xFFA88E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 
        0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E51, 0xFFA78D51, 0xFF8F7945, 0xFF726037, 0xFF554829, 0xFF3C321D, 0xFF282213, 0xFF14110A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF14110A, 0xFF39301B, 0xFF5D4F2C, 0xFF786539, 0xFF8D7743, 0xFFA38A4E, 
        0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFF917A44, 0xFF18140B, 0xFF000000, 0xFF66562F, 0xFFA48A4C, 0xFFA4894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 
        0xFFA3894A, 0xFF86703D, 0xFF4C4022, 0xFF221D0F, 0xFF010100, 0xFF000000, 0xFF100D07, 0xFF4C4022, 0xFF7B6737, 0xFF9E8446, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08645, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 
        0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 
        0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 
        0xFF967A36, 0xFF967A35, 0xFF957934, 0xFF957934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752E, 0xFF92752E, 0xFF92742E, 0xFF92742E, 0xFF91742D, 
        0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6C23, 
        0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A20, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 
        0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846316, 0xFF836315, 0xFF836315, 0xFF836214, 0xFF826214,
  0xFF836214, 0xFF836315, 0xFF836316, 0xFF846316, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681D, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 
        0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8D6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 
        0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957832, 
        0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977A37, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF997E3B, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9A7F3D, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8342, 
        0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFF9F8445, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF9D8446, 0xFF60502B, 0xFF241E10, 0xFF080603, 
        0xFF000000, 0xFF030201, 0xFF473B20, 0xFF7C6738, 0xFF977F45, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFF887340, 0xFF000000, 0xFF0D0B06, 0xFF9B8249, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58C4E, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFF816D3D, 0xFF514427, 0xFF2A2314, 0xFF18150B, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF100D07, 0xFF3B321C, 0xFF62542F, 0xFF7F6C3D, 0xFF8D7844, 0xFF9B834C, 0xFFA78E52, 0xFFA78E52, 
        0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E53, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 
        0xFFA89054, 0xFFA89054, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA88F54, 0xFFA99054, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA99054, 
        0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA98F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA78E53, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFF9E864C, 0xFF907B47, 0xFF826F3F, 0xFF6A5A33, 0xFF453B21, 0xFF1B170D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF141109, 0xFF251F11, 
        0xFF463C22, 0xFF756338, 0xFFA58B4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFF756236, 0xFF040302, 0xFF030301, 0xFF9A8348, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFF967E45, 0xFF7C6838, 0xFF473C20, 0xFF030201, 0xFF000000, 0xFF080603, 0xFF241E10, 0xFF61512B, 0xFF9F8446, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08545, 
        0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 
        0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 
        0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957732, 0xFF947731, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 
        0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F7229, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 
        0xFF8B6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691E, 0xFF88691D, 0xFF87681D, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF86661A, 
        0xFF866519, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846316, 0xFF836316, 0xFF836315, 0xFF836214,
  0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86671A, 0xFF86671A, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691E, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 
        0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 
        0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF957832, 0xFF957833, 0xFF957833, 
        0xFF957934, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 
        0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9E8443, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF9D8346, 0xFF554726, 0xFF0B0905, 0xFF000000, 0xFF000000, 0xFF0F0D07, 
        0xFF5D4E2A, 0xFF9F8548, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFF1B170D, 0xFF000000, 0xFF796739, 0xFFA58C4E, 0xFFA68C4F, 
        0xFFA68C4F, 0xFFA2894D, 0xFF7B683A, 0xFF3C331D, 0xFF050402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF302817, 0xFF665631, 0xFF98814A, 0xFFA78D52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88F52, 
        0xFFA88E53, 0xFFA88F53, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99054, 0xFFA99054, 
        0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 
        0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFF9F874D, 0xFF736238, 0xFF3E341E, 0xFF0D0B06, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF010100, 0xFF2D2615, 0xFF6C5B34, 0xFF9E854B, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA38A4D, 0xFF4C4024, 0xFF000000, 0xFF302816, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894A, 0xFF9F8448, 0xFF5D4E2A, 0xFF0F0C06, 0xFF000000, 0xFF000000, 0xFF0C0A05, 0xFF574826, 0xFF9E8446, 0xFFA18748, 0xFFA18748, 0xFFA18648, 0xFFA18647, 0xFFA18647, 0xFFA18647, 
        0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 
        0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D3A, 0xFF987D39, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF977B38, 0xFF977B37, 
        0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF93762F, 0xFF92752E, 0xFF92752E, 
        0xFF92742E, 0xFF92742D, 0xFF91742C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6D24, 
        0xFF8C6E24, 0xFF8B6D23, 0xFF8B6D22, 0xFF8B6C22, 0xFF8B6B21, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87671C, 0xFF86671A, 0xFF86671A, 0xFF86661A, 
        0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846316, 0xFF836315, 0xFF836315,
  0xFF836315, 0xFF846316, 0xFF846416, 0xFF846417, 0xFF856517, 0xFF856518, 0xFF856519, 0xFF856619, 0xFF866619, 0xFF86661A, 0xFF87671A, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 
        0xFF8A6B21, 0xFF8A6C21, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6D23, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF907229, 0xFF90722A, 
        0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 
        0xFF967934, 0xFF967934, 0xFF967A35, 0xFF977A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 
        0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA08646, 0xFFA18747, 0xFFA18747, 0xFF9F8547, 0xFF856F3B, 0xFF4F4223, 0xFF030301, 0xFF000000, 0xFF080603, 0xFF282112, 0xFF695830, 0xFFA3894A, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA4894C, 0xFFA4894C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFF524527, 0xFF000000, 0xFF322A18, 0xFF8F7844, 0xFF6B5A33, 
        0xFF362E1A, 0xFF010100, 0xFF000000, 0xFF010100, 0xFF16120A, 0xFF2A2414, 0xFF514527, 0xFF816D3E, 0xFFA78D51, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 
        0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFA99155, 0xFFA99156, 0xFFAA9155, 0xFFAA9155, 0xFFA99155, 0xFFA99055, 
        0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 
        0xFFA98F54, 0xFFA89054, 0xFFA89054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E52, 0xFFA78F52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E51, 0xFFA78E52, 0xFF8C7744, 
        0xFF5D4F2D, 0xFF322A18, 0xFF1A160D, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF292314, 0xFF5F502E, 0xFF84703F, 0xFF978048, 0xFFA0884C, 0xFF1E190E, 0xFF000000, 0xFF756337, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 
        0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894A, 0xFF68582F, 0xFF282112, 0xFF0A0904, 0xFF000000, 0xFF050402, 0xFF4E4223, 0xFF866F3C, 0xFFA08647, 0xFFA18748, 0xFFA18747, 0xFFA18647, 
        0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 
        0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E, 
        0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 
        0xFF8C6D24, 0xFF8C6D23, 0xFF8C6C23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 0xFF896A1E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF88681C, 0xFF87681C, 0xFF87671C, 0xFF86671B, 0xFF86671A, 
        0xFF86661A, 0xFF866519, 0xFF856518, 0xFF856518, 0xFF846517, 0xFF856417, 0xFF846417, 0xFF846316, 0xFF846315,
  0xFF846316, 0xFF846416, 0xFF846417, 0xFF856417, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86671A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 
        0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 0xFF90722B, 0xFF90722B, 
        0xFF90732B, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF91742E, 0xFF92752E, 0xFF92752E, 0xFF93762F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 
        0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C39, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 
        0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFF766235, 0xFF372E19, 0xFF0C0A05, 0xFF000000, 0xFF020201, 0xFF000000, 0xFF2E2715, 0xFF9F8649, 0xFFA3894B, 0xFFA3894B, 
        0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFF62532F, 0xFF000000, 0xFF040302, 0xFF0A0805, 0xFF000000, 
        0xFF000000, 0xFF2A2314, 0xFF554829, 0xFF776439, 0xFF927C47, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA78F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 
        0xFFA99054, 0xFFA99054, 0xFF957F4A, 0xFF584B2C, 0xFF54472A, 0xFF56492B, 0xFF56492B, 0xFF56492B, 0xFF56492B, 0xFF56492B, 0xFF564A2B, 0xFF56492B, 0xFF56492C, 0xFF56492C, 0xFF574A2C, 0xFF574A2C, 0xFF574A2C, 0xFF56492B, 0xFF524529, 0xFF726139, 
        0xFFA88F55, 0xFFAA9157, 0xFFAA9156, 0xFFAA9157, 0xFFAA9157, 0xFFAA9157, 0xFFAA9157, 0xFF514529, 0xFF524629, 0xFF56492B, 0xFF574B2C, 0xFF574A2C, 0xFF574A2C, 0xFF574B2C, 0xFF574B2C, 0xFF574B2C, 0xFF574A2C, 0xFF574B2C, 0xFF54482B, 0xFF524529, 
        0xFF524529, 0xFF524529, 0xFF54482A, 0xFF574A2C, 0xFF574B2C, 0xFF574A2C, 0xFF574A2C, 0xFF574A2C, 0xFF574A2C, 0xFF564A2C, 0xFF564A2C, 0xFF574A2C, 0xFF56492B, 0xFF524629, 0xFF514529, 0xFF4E4328, 0xFF514529, 0xFF52472A, 0xFF56492B, 0xFF56492B, 
        0xFF56492B, 0xFF56492B, 0xFF56492B, 0xFF56492B, 0xFF56492B, 0xFF56492B, 0xFF56492B, 0xFF55492A, 0xFF534729, 0xFF514528, 0xFF54482A, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E53, 0xFFA88F53, 0xFFA88E52, 0xFFA88E52, 
        0xFFA78E52, 0xFFA78E52, 0xFF98814A, 0xFF7D6A3D, 0xFF5F512E, 0xFF352D1A, 0xFF050402, 0xFF000000, 0xFF000000, 0xFF211C10, 0xFF3B321C, 0xFF000000, 0xFF110E08, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF68582F, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF0C0A05, 0xFF382F19, 0xFF766334, 0xFFA28748, 0xFFA18748, 
        0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8241, 0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 
        0xFF987C38, 0xFF977B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93762F, 
        0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF91732B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F25, 
        0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF88681C, 0xFF87671C, 0xFF87671B, 0xFF87671B, 
        0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846316,
  0xFF846316, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF866619, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF88691D, 0xFF88691D, 0xFF88691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 
        0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6E24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732B, 
        0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967935, 0xFF967A35, 
        0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 
        0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 
        0xFFA08546, 0xFFA08646, 0xFFA18646, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF836E3A, 0xFF261F10, 0xFF040302, 0xFF000000, 0xFF080603, 0xFF594B28, 0xFF907941, 0xFF000000, 0xFF000000, 0xFF8A743F, 0xFFA4894B, 0xFFA4894C, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFF947D46, 0xFF4C4024, 0xFF100D07, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF272113, 0xFF6B5A34, 
        0xFF98814A, 0xFFA1894E, 0xFFA58C50, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 
        0xFFA99055, 0xFFA99055, 0xFF917C49, 0xFF3E361F, 0xFF17140C, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF000000, 0xFF020201, 0xFF262013, 0xFF645532, 
        0xFFA89055, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFF3D341F, 0xFF332C1A, 0xFF0E0C07, 0xFF000000, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF19150C, 0xFF38301D, 
        0xFF413821, 0xFF3D341F, 0xFF1A160D, 0xFF000000, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF000000, 0xFF0D0B06, 0xFF362E1B, 0xFF403721, 0xFF3E351F, 0xFF403720, 0xFF2E2717, 0xFF030201, 0xFF000000, 
        0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF272113, 0xFF3E351F, 0xFF443A22, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA38A50, 0xFF9E864D, 0xFF7A683B, 0xFF372F1B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF3B311C, 0xFF847040, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894C, 0xFFA38A4B, 0xFF5C4D2A, 0xFF000000, 0xFF0A0804, 0xFF5A4C29, 0xFF070603, 0xFF000000, 0xFF040302, 0xFF262011, 0xFF836E3A, 
        0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 
        0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 
        0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967935, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 
        0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF90732C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 
        0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8B6D23, 0xFF8C6C23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF88681C, 0xFF87671C, 0xFF87671B, 
        0xFF87671B, 0xFF86661A, 0xFF866619, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416,
  0xFF846417, 0xFF846517, 0xFF856518, 0xFF856518, 0xFF866519, 0xFF866619, 0xFF86661A, 0xFF87671A, 0xFF87671B, 0xFF87681B, 0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8A6C21, 
        0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 
        0xFF91742C, 0xFF91742D, 0xFF91742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947730, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957933, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF967A35, 
        0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 
        0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08545, 
        0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF9C8346, 0xFF826D3A, 0xFF312916, 0xFF000000, 0xFF000000, 0xFF110E08, 0xFF534526, 0xFF9E8548, 0xFFA3894B, 0xFFA3894B, 0xFF39301A, 0xFF000000, 0xFF40361E, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA1894D, 0xFF957D46, 0xFF6A5A32, 0xFF251F12, 0xFF000000, 0xFF000000, 0xFF0D0B06, 0xFF211C10, 0xFF5C4E2D, 0xFF9B854B, 0xFFA78E52, 0xFFA78E52, 
        0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 
        0xFFA99155, 0xFFA99156, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFF98814C, 0xFF463C23, 0xFF0D0B06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3C341F, 0xFFA89055, 0xFFAA9257, 0xFFAB9257, 
        0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFF3A321E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF322B1A, 0xFF917C4B, 0xFFAB9258, 0xFFAB9258, 
        0xFFAA9258, 0xFFAB9258, 0xFFAB9258, 0xFF806D41, 0xFF120F09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4A4026, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFF9F8850, 0xFF342C1A, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1F1B10, 0xFF97804C, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA89054, 0xFFA98F54, 0xFFA88F54, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFFA78F52, 0xFFA88E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA68C50, 0xFF6C5B34, 0xFF2D2616, 0xFF0F0D07, 0xFF000000, 0xFF000000, 0xFF14110A, 0xFF5A4C2B, 0xFF917A45, 0xFF9E854B, 0xFFA58C4F, 
        0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFF9A8247, 0xFF231D10, 0xFF000000, 0xFF564928, 0xFFA3894B, 0xFF9F8648, 0xFF534525, 0xFF110E08, 0xFF000000, 0xFF000000, 
        0xFF312916, 0xFF826D3A, 0xFF9D8346, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 
        0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 
        0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732C, 0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F27, 
        0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C23, 0xFF8A6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87681C, 
        0xFF87671B, 0xFF87671A, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856417, 0xFF846417,
  0xFF856517, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF866619, 0xFF86661A, 0xFF87671A, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF87681D, 0xFF88691D, 0xFF89691E, 0xFF89691F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 
        0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D23, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E26, 0xFF8D6F26, 0xFF8D6F27, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 
        0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 
        0xFF977B36, 0xFF977B37, 0xFF987C37, 0xFF987C38, 0xFF997C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 
        0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFF9F8544, 0xFFA08546, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 
        0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF726033, 0xFF372E18, 0xFF000000, 0xFF000000, 0xFF231D10, 0xFF5E4F2A, 0xFF987E45, 0xFFA3894B, 0xFFA3894B, 0xFFA3894C, 0xFFA38A4B, 0xFF7D693A, 0xFF010100, 0xFF000000, 0xFF937C45, 0xFFA48A4D, 
        0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA68C4F, 0xFF988149, 0xFF6A5932, 0xFF3B321C, 0xFF0A0805, 0xFF000000, 0xFF030301, 0xFF332B19, 0xFF5E502E, 0xFF897443, 0xFFA78E51, 0xFFA78E51, 0xFFA78E52, 0xFFA88E53, 0xFFA78E53, 
        0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA88F54, 0xFFA89055, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFA99056, 0xFFAA9156, 0xFFAA9155, 0xFFAA9156, 0xFFA99156, 
        0xFFAA9157, 0xFFAA9157, 0xFFAA9257, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFF8A7546, 0xFF2A2415, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF120F09, 0xFF95804C, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 
        0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9358, 0xFFA68E56, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070603, 0xFF6B5C38, 0xFFAC9359, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 
        0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFF887546, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221D11, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAB9258, 0xFFAA9258, 0xFFAB9257, 0xFFAA9258, 0xFFAB9258, 0xFFAA9258, 
        0xFF100E08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070603, 0xFF967F4C, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA89055, 0xFFA99054, 0xFFA89055, 
        0xFFA98F54, 0xFFA89054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFFA78F52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFF947C47, 0xFF695933, 0xFF3D341E, 0xFF0E0C06, 0xFF000000, 0xFF000000, 0xFF302817, 0xFF5F502D, 
        0xFF8D7744, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFF766437, 0xFF000000, 0xFF0A0804, 0xFF9D8549, 0xFFA3894C, 0xFFA3894B, 0xFFA3894A, 0xFF987F46, 0xFF5E4F2A, 0xFF231D10, 
        0xFF000000, 0xFF000000, 0xFF372E18, 0xFF736034, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA18647, 0xFFA08646, 0xFFA08645, 0xFFA08546, 0xFFA08545, 0xFFA08444, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8343, 
        0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 
        0xFF997D39, 0xFF997D39, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947732, 0xFF947731, 
        0xFF947630, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732B, 0xFF90732B, 0xFF90722B, 0xFF90712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8F7028, 0xFF8E7028, 0xFF8E6F27, 
        0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691D, 0xFF88681D, 0xFF88681C, 
        0xFF87681C, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856517,
  0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF86671B, 0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681D, 0xFF88681D, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8C6D22, 
        0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7029, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 
        0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957834, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 
        0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 
        0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA18646, 0xFFA18647, 0xFFA18748, 
        0xFFA18748, 0xFFA18748, 0xFF86703B, 0xFF282212, 0xFF070603, 0xFF000000, 0xFF16120A, 0xFF746134, 0xFF988045, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF9A8348, 0xFF2A2313, 0xFF000000, 0xFF41371E, 0xFFA58B4E, 
        0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFF8F7944, 0xFF41371F, 0xFF120F08, 0xFF010100, 0xFF000000, 0xFF19150C, 0xFF645430, 0xFF947E48, 0xFFA0884E, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F54, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFAA9157, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFF9A844F, 0xFF252013, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0C07, 0xFF907B4B, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 
        0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC9359, 0xFFAC9459, 0xFFAC9359, 0xFFAC935A, 0xFFAC9459, 0xFFAC945A, 0xFF9A844F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF867346, 0xFFAC9359, 0xFFAB9459, 0xFFAC945A, 0xFFAC935A, 0xFFAC945A, 
        0xFFAC9359, 0xFFAC9459, 0xFFAB9359, 0xFFAC9459, 0xFF9C8651, 0xFF14110A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF594D2E, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 
        0xFF3A311E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF282214, 0xFFA18A52, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9256, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA99155, 0xFFA99055, 
        0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA89054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E53, 0xFFA78E52, 0xFFA78E52, 0xFFA38B50, 0xFF98814A, 0xFF736237, 0xFF2B2414, 0xFF000000, 0xFF000000, 
        0xFF0E0C06, 0xFF302917, 0xFF7E6B3D, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFF241F11, 0xFF000000, 0xFF544627, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF988045, 
        0xFF736034, 0xFF151209, 0xFF000000, 0xFF070603, 0xFF292212, 0xFF87703C, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 
        0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B, 
        0xFF9A7D3B, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF977B36, 0xFF967A35, 0xFF967935, 0xFF967935, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947732, 
        0xFF947732, 0xFF947630, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722B, 0xFF90712A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 
        0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691E, 0xFF88691D, 
        0xFF88681C, 0xFF87671C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF866619, 0xFF866619, 0xFF856518, 0xFF856518,
  0xFF856518, 0xFF856619, 0xFF866619, 0xFF86661A, 0xFF86671A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF896A20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 
        0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 
        0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937530, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A37, 0xFF977B37, 0xFF977B37, 
        0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 
        0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA08647, 
        0xFF937B42, 0xFF40351C, 0xFF000000, 0xFF000000, 0xFF0A0804, 0xFF5D4E2A, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFF5F512D, 0xFF020201, 0xFF0D0B06, 0xFF947E47, 
        0xFFA58C4F, 0xFF9D854B, 0xFF7E6B3C, 0xFF2A2314, 0xFF000000, 0xFF000000, 0xFF080704, 0xFF352C19, 0xFF857040, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 
        0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFA99155, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9256, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 
        0xFFAB9258, 0xFFAB9258, 0xFFAA9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFF95804D, 0xFF0E0C07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF645634, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFF39311E, 0xFF000000, 0xFF000000, 0xFF7B6A40, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFA08A54, 0xFF211D11, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF76643D, 0xFFAC9359, 0xFFAC9359, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 
        0xFF51452A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF38301C, 0xFFA48C54, 0xFFAB9258, 0xFFAA9257, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 
        0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E52, 0xFFA88F52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFF957E48, 0xFF463B22, 
        0xFF0C0A06, 0xFF010100, 0xFF000000, 0xFF18140B, 0xFF6B5A33, 0xFF9C834A, 0xFFA38A4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF7E6A3B, 0xFF000000, 0xFF0A0905, 0xFF8A7541, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 
        0xFFA3894B, 0xFFA3894B, 0xFF5D4E2A, 0xFF0A0804, 0xFF000000, 0xFF000000, 0xFF40361D, 0xFF957C42, 0xFFA08647, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF967A36, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957934, 0xFF957933, 0xFF957832, 0xFF947732, 
        0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF93752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90712A, 0xFF907229, 0xFF8F7129, 0xFF8F7129, 0xFF8E7128, 
        0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1E, 0xFF88691E, 0xFF88691D, 
        0xFF88691D, 0xFF88681C, 0xFF87681B, 0xFF87671B, 0xFF87671A, 0xFF86661A, 0xFF866619, 0xFF866519, 0xFF856518,
  0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681D, 0xFF88681D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 
        0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6E26, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF90722A, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 
        0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957732, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 
        0xFF987C38, 0xFF987C38, 0xFF987D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 
        0xFF9D8241, 0xFF9E8241, 0xFF9D8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFF8C763E, 0xFF504323, 
        0xFF060502, 0xFF000000, 0xFF1A150B, 0xFF534526, 0xFF9C8347, 0xFFA3894A, 0xFFA3894B, 0xFFA38A4B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFF988148, 0xFF120F08, 0xFF010100, 0xFF493E23, 
        0xFF5F502D, 0xFF1F1A0F, 0xFF000000, 0xFF020201, 0xFF2C2515, 0xFF5B4D2C, 0xFF978049, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99054, 
        0xFFA89055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 
        0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFF806E43, 0xFF020101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A06, 0xFF9F8853, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945B, 0xFF6E5F3A, 0xFF000000, 0xFF000000, 0xFF56492D, 0xFFAC955A, 0xFFAC945B, 0xFFAC955B, 0xFFAC955B, 0xFFAC945B, 0xFFAC955B, 0xFFAC955B, 
        0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFA18B54, 0xFF272114, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF827044, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 
        0xFF5A4D2E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF403721, 0xFFA68F55, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9157, 0xFFAA9157, 
        0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA89055, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 
        0xFFA38A4F, 0xFF6A5A33, 0xFF362E1A, 0xFF0B0905, 0xFF000000, 0xFF100D07, 0xFF504426, 0xFF806C3D, 0xFFA68C4F, 0xFF2E2716, 0xFF000000, 0xFF3A311B, 0xFFA1874C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA4894C, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894A, 0xFF9C8347, 0xFF544626, 0xFF17130A, 0xFF000000, 0xFF070603, 0xFF514424, 0xFF8C753E, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 
        0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A37, 0xFF977A36, 0xFF967A36, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957832, 
        0xFF947832, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF90712A, 0xFF8F7129, 0xFF8F7129, 
        0xFF8E7028, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 
        0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF866519,
  0xFF866619, 0xFF86661A, 0xFF86671A, 0xFF87671B, 0xFF87671B, 0xFF88681C, 0xFF88681C, 0xFF88681D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6E24, 0xFF8C6E24, 
        0xFF8C6E24, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF90732B, 0xFF91742C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 
        0xFF92752F, 0xFF937630, 0xFF947630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 
        0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8241, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF9F8547, 0xFF514424, 0xFF141009, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF715F33, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF3F351E, 0xFF000000, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF4B4024, 0xFF847140, 0xFF9F874D, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA78F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFA99155, 
        0xFFAA9156, 0xFFA99156, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAA9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 
        0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFF645635, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF302A19, 0xFFAD955B, 0xFFAD955B, 
        0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFF937F4E, 0xFF12100A, 0xFF000000, 0xFF292316, 0xFFA89059, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFA28C56, 0xFF282315, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF847145, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 
        0xFF5D5030, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF423822, 0xFFA79057, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9256, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFFA88F53, 
        0xFFA78F52, 0xFFA78E52, 0xFFA38B50, 0xFF8C7744, 0xFF5E502D, 0xFF0E0C07, 0xFF000000, 0xFF090804, 0xFF252012, 0xFF040302, 0xFF070603, 0xFF776539, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4D, 
        0xFFA48A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF967E45, 0xFF352D18, 0xFF000000, 0xFF000000, 0xFF131008, 0xFF524425, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 
        0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C803F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 
        0xFF957833, 0xFF947832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF92742E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF90712A, 0xFF8F7129, 
        0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 
        0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87681B, 0xFF87671B, 0xFF86661B, 0xFF86661A, 0xFF866619,
  0xFF866619, 0xFF86661B, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681D, 0xFF88681D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6D23, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 
        0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7029, 0xFF8F7129, 0xFF8F712A, 0xFF8F722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93752F, 
        0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 
        0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9C803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA28748, 0xFF826C39, 0xFF141109, 0xFF000000, 0xFF010100, 0xFF302816, 
        0xFF131008, 0xFF000000, 0xFF312916, 0xFFA3894B, 0xFFA38A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA48B4E, 0xFF8D7743, 0xFF292314, 0xFF000000, 0xFF000000, 0xFF0A0805, 
        0xFF554829, 0xFFA58C50, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 
        0xFFAA9156, 0xFFAA9157, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC9359, 0xFFAC9459, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAD945A, 0xFFAD945B, 0xFFAD945B, 0xFFAC955B, 0xFFAD955B, 0xFFAD945B, 0xFFA48D56, 0xFF302919, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF6B5C39, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAA945A, 0xFF302A19, 0xFF000000, 0xFF050402, 0xFFA08A55, 0xFFAD955C, 0xFFAD965C, 0xFFAD965D, 0xFFAD955C, 0xFFAE965C, 0xFFAD965C, 0xFFAD965C, 0xFFAD955C, 
        0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFA28D56, 0xFF282315, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF847146, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 
        0xFF5D5031, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF423822, 0xFFA79057, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAC935A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 
        0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA98F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88E53, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E51, 0xFF6C5B34, 0xFF141109, 0xFF000000, 0xFF000000, 0xFF070603, 0xFF746238, 0xFFA38A4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA58A4D, 
        0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFF9E8548, 0xFF0A0905, 0xFF000000, 0xFF0D0B06, 0xFF020201, 0xFF000000, 0xFF141109, 0xFF816C39, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 
        0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8544, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C8140, 0xFF9C803F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF977C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF957934, 
        0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 
        0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 
        0xFF89691F, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87681B, 0xFF87671B, 0xFF86661A, 0xFF86661A,
  0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF88681D, 0xFF88691E, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6E25, 
        0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7028, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF90712A, 0xFF8F722A, 0xFF90722A, 0xFF91722B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 
        0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957933, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 
        0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803F, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 
        0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF88713C, 0xFF3F341C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF292212, 0xFFA3894B, 
        0xFF64542E, 0xFF000000, 0xFF070503, 0xFF766437, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF9D854B, 0xFF796639, 0xFF322A18, 0xFF000000, 0xFF000000, 0xFF211C10, 0xFF5B4D2C, 0xFFA1884E, 
        0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 
        0xFFAA9257, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC9359, 0xFFAC935A, 0xFFAB945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945B, 0xFFAD945B, 0xFFAC955B, 0xFFAC955B, 0xFFAD945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFF847146, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF17140C, 0xFF9C8752, 
        0xFFAD965C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFF564A2E, 0xFF000000, 0xFF000000, 0xFF806E44, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFA38D57, 0xFF282315, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF847246, 0xFFAD965C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 
        0xFF5D5031, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF423822, 0xFFA79158, 0xFFAC945A, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAC945A, 0xFFAC9359, 0xFFAC9459, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 
        0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA88F54, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E51, 0xFF6F5E36, 0xFF2B2515, 0xFF090804, 0xFF000000, 0xFF1F1B0F, 0xFF6C5C34, 0xFF977F47, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 
        0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF483C21, 0xFF000000, 0xFF100D07, 0xFF8D7741, 0xFF746134, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3F341C, 0xFF89723D, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 
        0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 
        0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF997E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF987D39, 0xFF997C39, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF967934, 
        0xFF967934, 0xFF957834, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 
        0xFF8F722A, 0xFF8F7129, 0xFF8F7029, 0xFF8F7028, 0xFF8E7028, 0xFF8D7026, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896B20, 0xFF896A1F, 
        0xFF896A1F, 0xFF89691E, 0xFF88691D, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86661A,
  0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF88681C, 0xFF88691D, 0xFF88691D, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 
        0xFF8E6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF937630, 
        0xFF947731, 0xFF947732, 0xFF947732, 0xFF957732, 0xFF957833, 0xFF957933, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 
        0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA08647, 0xFF4E4123, 0xFF0D0B06, 0xFF000000, 0xFF1D180D, 0xFF493D21, 0xFF050402, 0xFF050402, 0xFF746135, 
        0xFFA38A4B, 0xFF282212, 0xFF000000, 0xFF282213, 0xFFA2894C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF665631, 0xFF272113, 0xFF000000, 0xFF000000, 0xFF362E1A, 0xFF766439, 0xFF9F874D, 0xFFA78E52, 0xFFA78E52, 
        0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99056, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 0xFFAB9257, 
        0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9459, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAC945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAE965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFF50452B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF51462B, 
        0xFFAD955D, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFF6F603C, 0xFF000000, 0xFF000000, 0xFF594D30, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 
        0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFA38E58, 0xFF282316, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF857347, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAE965D, 
        0xFF5D5132, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF423923, 0xFFA89159, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 
        0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 
        0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFFA78E52, 0xFFA58C51, 0xFF806D3F, 0xFF493D23, 0xFF000000, 0xFF000000, 0xFF1D180E, 0xFF554829, 0xFF9F864B, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFF87723F, 0xFF0E0B06, 0xFF000000, 0xFF4F4325, 0xFFA3894B, 0xFF544626, 0xFF000000, 0xFF120F08, 0xFF131008, 0xFF000000, 0xFF0E0C06, 0xFF4E4123, 0xFFA08547, 0xFFA18748, 0xFFA18747, 0xFFA18647, 
        0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 
        0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A36, 0xFF967A35, 
        0xFF967934, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957832, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF92742D, 0xFF91732C, 0xFF91732B, 0xFF91732B, 0xFF90722B, 
        0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F27, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6D25, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 
        0xFF896A1F, 0xFF896A1F, 0xFF896A1E, 0xFF88691E, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 0xFF87671B,
  0xFF87671B, 0xFF87681B, 0xFF88681C, 0xFF88691D, 0xFF88691D, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 
        0xFF8E6F27, 0xFF8E7028, 0xFF8F7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF947731, 0xFF947630, 
        0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF967A36, 0xFF977A37, 0xFF977B37, 0xFF987B37, 0xFF987B37, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9A7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9C8240, 0xFF9D8241, 0xFF9E8241, 0xFF9D8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9E8444, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF7B6737, 0xFF110E07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF726033, 0xFFA3894B, 0xFF262011, 0xFF000000, 0xFF2C2514, 
        0xFF9C8448, 0xFF8F7942, 0xFF000000, 0xFF000000, 0xFF6C5B33, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF766338, 0xFF16130A, 0xFF010100, 0xFF000000, 0xFF2F2817, 0xFF8F7945, 0xFFA58C50, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA98F54, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 
        0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945A, 0xFFAC945B, 0xFFAD945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955D, 0xFFAD965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE965E, 0xFF17140C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF937F4F, 0xFFAE975E, 0xFFAF975E, 0xFFAE975E, 0xFFAF975E, 0xFF907D4E, 0xFF13100A, 0xFF000000, 0xFF2A2417, 0xFFA8915B, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAE975F, 0xFFAF975F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAF975E, 0xFFAE975E, 0xFFAF975E, 0xFFA48E58, 0xFF282316, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF857347, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 
        0xFF5E5132, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF423923, 0xFFA99259, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD945B, 0xFFAC945B, 0xFFAC955B, 0xFFAC945B, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9256, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 0xFFA99155, 
        0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E52, 0xFFA78E52, 0xFFA58C51, 0xFF9A834B, 0xFF483D22, 0xFF000000, 0xFF000000, 0xFF090804, 0xFF5B4D2B, 0xFFA48A4E, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA3894D, 0xFF42381F, 0xFF000000, 0xFF0C0A05, 0xFFA1874A, 0xFF8C7641, 0xFF090804, 0xFF010100, 0xFF5A4B29, 0xFFA18749, 0xFF292212, 0xFF000000, 0xFF000000, 0xFF110E08, 0xFF7B6837, 0xFFA18748, 0xFFA18748, 
        0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 
        0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A36, 
        0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947631, 0xFF947630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF90732B, 
        0xFF90722B, 0xFF90722A, 0xFF90712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B20, 
        0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691D, 0xFF88681D, 0xFF88681D, 0xFF87671C, 0xFF87671B,
  0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 
        0xFF8E7028, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937631, 0xFF947631, 0xFF947731, 
        0xFF947832, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF977A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF917940, 0xFF4A3E21, 0xFF000000, 0xFF010100, 0xFF251F10, 0xFF211C0F, 0xFF000000, 0xFF1B170C, 0xFFA08649, 0xFF8A7440, 0xFF000000, 0xFF000000, 
        0xFF6F5D34, 0xFFA48B4D, 0xFF4D4023, 0xFF000000, 0xFF070603, 0xFF9E854B, 0xFFA2884D, 0xFF806C3D, 0xFF272113, 0xFF000000, 0xFF070603, 0xFF292214, 0xFF826E3F, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFF98814C, 0xFF4E4227, 0xFF56492B, 0xFFAA9157, 0xFFAA9257, 0xFFAB9257, 0xFFAB9258, 0xFFAA9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 
        0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE965D, 0xFFAE965E, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975E, 0xFF937F4F, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF1D1910, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFA8915B, 0xFF342D1C, 0xFF000000, 0xFF0A0905, 0xFF947F50, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 
        0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFA48E59, 0xFF292316, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF857347, 0xFFAF975F, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 
        0xFF5E5132, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF423923, 0xFFA9925A, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAD945B, 
        0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9459, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 
        0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA89054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E53, 0xFFA78E52, 0xFFA78E52, 0xFF97804A, 0xFF3B321C, 0xFF0E0C06, 0xFF000000, 0xFF121009, 0xFF705E35, 
        0xFF9A8249, 0xFFA58C4F, 0xFFA58C4F, 0xFF87713F, 0xFF000000, 0xFF000000, 0xFF756336, 0xFFA48B4D, 0xFF3D331C, 0xFF000000, 0xFF1A160C, 0xFF9B8447, 0xFF937B43, 0xFF030301, 0xFF010100, 0xFF141109, 0xFF010100, 0xFF000000, 0xFF4B3F21, 0xFF917940, 
        0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C8140, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 
        0xFF977A35, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957732, 0xFF947731, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 
        0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 
        0xFF8A6B20, 0xFF8A6A1F, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87671C,
  0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF896A1E, 0xFF896A1F, 0xFF8A6B1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7028, 
        0xFF8F7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947732, 0xFF957732, 
        0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF967A36, 0xFF967A36, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 
        0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 
        0xFFA08545, 0xFFA08645, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFF66552D, 0xFF1B160C, 0xFF000000, 0xFF16130A, 0xFF63532C, 0xFFA28849, 0xFF7D6939, 0xFF030201, 0xFF030201, 0xFF61512D, 0xFFA48A4C, 0xFF514426, 0xFF000000, 
        0xFF16130A, 0xFFA1884C, 0xFF917B44, 0xFF18140B, 0xFF000000, 0xFF342C19, 0xFF382F1B, 0xFF000000, 0xFF000000, 0xFF3A311C, 0xFF7B683B, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 
        0xFFA99055, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFA38B52, 0xFF5F5130, 0xFF19150C, 0xFF372F1C, 0xFF887545, 0xFFAB9258, 0xFFAB9258, 0xFFAB9259, 0xFFAB9358, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAD955A, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD965C, 0xFFAE965C, 0xFFAE965C, 0xFFAE965D, 0xFFAE965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 
        0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAF9760, 0xFFAF9860, 0xFF55492E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF53482D, 0xFFAF9860, 0xFFB09860, 0xFF54492E, 0xFF000000, 0xFF000000, 0xFF786842, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09960, 0xFFB09860, 0xFFB09860, 0xFFB09960, 0xFFB09860, 0xFFB09860, 0xFFB09861, 0xFFB09860, 0xFFB09860, 
        0xFFB09960, 0xFFB09860, 0xFFB09860, 0xFFB09861, 0xFFA58F5A, 0xFF292316, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF867449, 0xFFAF9860, 0xFFAF975F, 0xFFAF985F, 0xFFAF9760, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 
        0xFF5E5133, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433A24, 0xFFAA935B, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD965C, 0xFFAE965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAC955B, 0xFFAD955B, 0xFFAD945A, 0xFFAC945B, 0xFFAC945B, 0xFFAC935A, 0xFFAC9459, 0xFFAC945A, 0xFFAC9459, 0xFFAB9459, 0xFFAB9358, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 
        0xFFAA9256, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFF887342, 0xFF4B4024, 0xFF070603, 0xFF000000, 
        0xFF241E11, 0xFF675731, 0xFFA68C4F, 0xFF221D10, 0xFF000000, 0xFF372E1A, 0xFFA58B4E, 0xFF826D3D, 0xFF080703, 0xFF000000, 0xFF715F34, 0xFFA48A4C, 0xFF332B17, 0xFF000000, 0xFF1F1A0E, 0xFF8F7841, 0xFF62522C, 0xFF16120A, 0xFF000000, 0xFF1B160C, 
        0xFF65552E, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 
        0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987C37, 0xFF977B37, 0xFF977B37, 
        0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957732, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 
        0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8F7028, 0xFF8E7028, 0xFF8D6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C21, 
        0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691D, 0xFF88681D, 0xFF88681C,
  0xFF88681D, 0xFF88681D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 
        0xFF8F7028, 0xFF8F7129, 0xFF8F7229, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 
        0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 
        0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 
        0xFFA18646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF9B8144, 0xFF312916, 0xFF030201, 0xFF000000, 0xFF3E341C, 0xFF937C43, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFF3C321C, 0xFF000000, 0xFF16120A, 0xFF957E46, 0xFF9A8248, 0xFF19150B, 
        0xFF000000, 0xFF4D4124, 0xFFA58C4F, 0xFF4A3F23, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2D2615, 0xFF8B7543, 0xFFA38A4F, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 
        0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFF7E6C40, 0xFF1C180E, 0xFF000000, 0xFF594C2D, 0xFFAA9157, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAB935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAD955B, 0xFFAD945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975D, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 
        0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFF9F8A57, 0xFF1A170E, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF0D0B07, 0xFF907D4F, 0xFF766641, 0xFF000000, 0xFF000000, 0xFF5B4F32, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 
        0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFA5905B, 0xFF292416, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF867549, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 
        0xFF5E5233, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433A24, 0xFFAA935C, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAD945B, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9258, 0xFFAA9258, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9157, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA89055, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88E53, 0xFFA78E52, 0xFFA58C51, 0xFF947D47, 0xFF433920, 
        0xFF000000, 0xFF010100, 0xFF141109, 0xFF000000, 0xFF0E0C06, 0xFF84703F, 0xFFA58C4F, 0xFF2D2615, 0xFF000000, 0xFF332B18, 0xFFA48B4D, 0xFF715F35, 0xFF060502, 0xFF020201, 0xFF65552F, 0xFFA3894B, 0xFFA3894B, 0xFF937B42, 0xFF3C331B, 0xFF000000, 
        0xFF030201, 0xFF322A16, 0xFF9A8144, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 
        0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 
        0xFF91742C, 0xFF90732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 
        0xFF8A6C22, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1E, 0xFF89691E, 0xFF88681D, 0xFF88681D,
  0xFF88681D, 0xFF89691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6E24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D7027, 0xFF8E7028, 0xFF8E7028, 0xFF8E7128, 
        0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947731, 0xFF947832, 0xFF957832, 0xFF957833, 
        0xFF957934, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 
        0xFF9B7F3E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8242, 0xFF9D8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 
        0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFF9F8547, 0xFF786435, 0xFF080704, 0xFF000000, 0xFF0C0A05, 0xFF705D33, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFF9E854A, 0xFF070503, 0xFF000000, 0xFF584A29, 0xFFA58B4E, 0xFF665730, 
        0xFF010100, 0xFF000000, 0xFF4A3E23, 0xFF040302, 0xFF020201, 0xFF16120A, 0xFF736238, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA78F53, 0xFFA78F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99056, 
        0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFF98834E, 0xFF3A311D, 0xFF000000, 0xFF000000, 0xFF292315, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB935A, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 
        0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 
        0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFB09861, 0xFFB09860, 0xFFB09860, 0xFFB09861, 0xFFB09960, 0xFFB09961, 0xFFB09961, 0xFF746540, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF282316, 0xFF080704, 0xFF000000, 0xFF2C2618, 0xFFA5905B, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB09962, 0xFFB19961, 0xFFB09962, 0xFFB09961, 0xFFB19962, 0xFFB09961, 0xFFB09962, 0xFFB19961, 0xFFB09961, 
        0xFFB09962, 0xFFB09961, 0xFFB19961, 0xFFB09962, 0xFFA5905B, 0xFF292417, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF86754A, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09861, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFB09860, 
        0xFF5F5233, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433A24, 0xFFAA935C, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE975D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAC9359, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 
        0xFFAA9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E53, 0xFFA78E52, 0xFFA78E52, 
        0xFF8F7945, 0xFF282213, 0xFF030301, 0xFF000000, 0xFF1E190E, 0xFF907944, 0xFF736136, 0xFF000000, 0xFF040302, 0xFF947C46, 0xFF9D844A, 0xFF2D2615, 0xFF000000, 0xFF1E190E, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894A, 0xFF705D33, 
        0xFF0C0A05, 0xFF000000, 0xFF080704, 0xFF776435, 0xFF9F8547, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 
        0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 
        0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752F, 0xFF92742E, 0xFF92742D, 
        0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF91722B, 0xFF90722A, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7028, 0xFF8E7026, 0xFF8D6F26, 0xFF8D6E26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C22, 
        0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88681D,
  0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D22, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7128, 0xFF8F7129, 
        0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 
        0xFF967934, 0xFF967934, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B803D, 
        0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 
        0xFFA18647, 0xFFA18748, 0xFF927A41, 0xFF42371D, 0xFF000000, 0xFF000000, 0xFF40351D, 0xFF967E44, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFF665630, 0xFF000000, 0xFF000000, 0xFF8F7943, 0xFF927C46, 
        0xFF15120A, 0xFF000000, 0xFF000000, 0xFF1B170D, 0xFF5E4F2D, 0xFFA38A4F, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99056, 0xFFAA9156, 
        0xFFAA9156, 0xFF98814C, 0xFF564A2C, 0xFF0A0905, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF685935, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAB9459, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAD945B, 0xFFAC955B, 0xFFAD955B, 0xFFAD955B, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF975E, 0xFFAF975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 
        0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFF403823, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A06, 0xFF8E7C4F, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 
        0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFA5905C, 0xFF292417, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF86754A, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09960, 
        0xFF5F5234, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433A25, 0xFFAA945D, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975F, 0xFFAE975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAE965C, 0xFFAD955C, 0xFFAD955D, 0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9259, 
        0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 
        0xFFA78E52, 0xFFA78E52, 0xFF6F5E36, 0xFF2B2414, 0xFF000000, 0xFF0D0B06, 0xFF100D07, 0xFF000000, 0xFF574A29, 0xFFA58C4F, 0xFF6E5C34, 0xFF000000, 0xFF000000, 0xFF86713F, 0xFFA48B4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894A, 
        0xFF967E44, 0xFF40351D, 0xFF000000, 0xFF000000, 0xFF42371E, 0xFF937A41, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 
        0xFF9D8341, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C813E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 
        0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 
        0xFF92742E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7029, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C23, 
        0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E,
  0xFF88691E, 0xFF89691F, 0xFF8A6A20, 0xFF8A6A20, 0xFF8A6B20, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 
        0xFF90712A, 0xFF90722B, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF937631, 0xFF937631, 0xFF947732, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 
        0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8341, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18747, 
        0xFFA28748, 0xFF736034, 0xFF141109, 0xFF000000, 0xFF0F0D07, 0xFF7A6737, 0xFFA1874A, 0xFFA3894B, 0xFFA38A4B, 0xFFA3894C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFF9B8449, 0xFF272112, 0xFF000000, 0xFF1E190E, 0xFF272113, 
        0xFF000000, 0xFF000000, 0xFF5B4D2C, 0xFF98814A, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA98F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9157, 
        0xFF605331, 0xFF16130B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF504529, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAC955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 
        0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09861, 
        0xFFB09961, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFA8925D, 0xFF18150D, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF6B5D3C, 0xFFB19A63, 0xFFB19B63, 0xFFB19A63, 0xFFB19A64, 0xFFB19B63, 0xFFB19A63, 0xFFB19B63, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19B63, 0xFFB19A63, 0xFFB19A63, 
        0xFFB19B63, 0xFFB19B63, 0xFFB19A63, 0xFFB19A63, 0xFFA6905D, 0xFF292417, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF87754A, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09A62, 0xFFB19A62, 0xFFB19962, 
        0xFF5F5235, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433A25, 0xFFAB955E, 0xFFB09961, 0xFFB09860, 0xFFB09960, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAE955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 
        0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFF9D864D, 0xFF716037, 0xFF0F0D07, 0xFF000000, 0xFF030201, 0xFF574A2A, 0xFF9C834A, 0xFF0F0D07, 0xFF000000, 0xFF4D4024, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 
        0xFFA3894B, 0xFFA1874A, 0xFF7A6637, 0xFF0F0C06, 0xFF000000, 0xFF141109, 0xFF746033, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8343, 
        0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D39, 0xFF997D3A, 0xFF997C39, 
        0xFF987C39, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957832, 0xFF947832, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752F, 
        0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F7229, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 
        0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E,
  0xFF896A1E, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 
        0xFF90722B, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF967934, 0xFF957934, 0xFF967935, 
        0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 
        0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFFA18747, 0xFF9D8446, 
        0xFF4A3E21, 0xFF000000, 0xFF000000, 0xFF342B17, 0xFF9E8547, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF695832, 0xFF040302, 0xFF000000, 0xFF000000, 
        0xFF312917, 0xFF9D854C, 0xFFA78E51, 0xFFA78E52, 0xFFA78F52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA98F54, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFF8F7B49, 0xFF221D11, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080604, 0xFFAC945A, 0xFFAC945A, 0xFFAC955B, 0xFFAD945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE975D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFAF9861, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 
        0xFFB09961, 0xFFB09962, 0xFFB19961, 0xFFB09962, 0xFFB09962, 0xFFB19A62, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29A63, 0xFFB19A63, 0xFF7F6E47, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2A2517, 0xFFB29B64, 0xFFB29A64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFA7915E, 0xFF292417, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF87754B, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 
        0xFF5F5235, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433A25, 0xFFAB955E, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC9459, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99056, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F54, 
        0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFFA78F52, 0xFFA78E52, 0xFFA68D51, 0xFF483D22, 0xFF000000, 0xFF000000, 0xFF090804, 0xFF000000, 0xFF141109, 0xFF967E47, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFF9E8547, 0xFF332B17, 0xFF000000, 0xFF000000, 0xFF4A3E21, 0xFF9E8446, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 
        0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D39, 
        0xFF987D39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957832, 0xFF947832, 0xFF947732, 0xFF947631, 0xFF937631, 0xFF937630, 0xFF93762F, 0xFF92752F, 
        0xFF92752F, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7028, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 
        0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F,
  0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7029, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 
        0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752F, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF947630, 0xFF937731, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 
        0xFF967A36, 0xFF977A36, 0xFF977B36, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 
        0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF856F3B, 0xFF2D2614, 
        0xFF000000, 0xFF110E08, 0xFF5C4D29, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF9F874C, 0xFF6C5B33, 0xFF14110A, 0xFF000000, 0xFF1F1B0F, 0xFF6D5C35, 
        0xFFA78E51, 0xFFA78E51, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9256, 0xFF8F7B49, 0xFF443A23, 0xFF0E0C07, 0xFF262114, 
        0xFF322B1A, 0xFF252013, 0xFF020101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5D5031, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAE965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 
        0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09960, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19962, 
        0xFFB19962, 0xFFB09962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFAF9862, 0xFF3D3522, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF6E603D, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFA7915E, 0xFF292417, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF88764C, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB29B63, 0xFFB19B64, 0xFFB19A63, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 
        0xFF5F5335, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF443B25, 0xFFAC965F, 0xFFB19A62, 0xFFB19962, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 
        0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965C, 0xFFAD965C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAC955B, 
        0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9459, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA18951, 0xFFA99155, 0xFFA99055, 0xFFA99054, 
        0xFFA88F54, 0xFFA98F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFF887342, 0xFF2E2716, 0xFF000000, 0xFF000000, 0xFF342C19, 0xFF977F48, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894A, 0xFF5B4C29, 0xFF110E07, 0xFF000000, 0xFF2D2614, 0xFF846F3B, 0xFFA18748, 0xFFA18748, 0xFFA08647, 0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 
        0xFF997D39, 0xFF987D39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967935, 0xFF967935, 0xFF957934, 0xFF957933, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF937630, 0xFF93752F, 
        0xFF93752F, 0xFF92752E, 0xFF92742D, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F712A, 0xFF8F7128, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F25, 0xFF8C6E24, 0xFF8C6E24, 
        0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F,
  0xFF896A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7027, 0xFF8F7029, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 
        0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 
        0xFF977B36, 0xFF977B37, 0xFF977C37, 0xFF987B38, 0xFF987C39, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 
        0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8445, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFF5E4F2A, 0xFF100D07, 0xFF000000, 
        0xFF000000, 0xFF302816, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF836F3E, 0xFF2C2615, 0xFF000000, 0xFF060503, 0xFF5E502E, 0xFF98814A, 0xFFA78E52, 
        0xFFA88E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFA68E54, 0xFF4E4227, 0xFF13100A, 0xFF4F4429, 0xFF8E7A4A, 0xFFA68F56, 
        0xFFAC9359, 0xFFA28A55, 0xFF54482C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF120F09, 0xFF9A8451, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 
        0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09960, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29B65, 0xFFB29B65, 0xFFB29B65, 0xFFB29B65, 0xFFB29C65, 0xFFB19A64, 0xFF403824, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF19160E, 0xFFA28D5C, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C65, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C66, 
        0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFA8925F, 0xFF2A2417, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF88774D, 0xFFB29C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFF605336, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF443B26, 0xFFAC9660, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 
        0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF975E, 0xFFAF975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965C, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFF2F2817, 0xFF4E4327, 0xFFA38C52, 0xFFA99155, 
        0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E53, 0xFFA1884F, 0xFF705F37, 0xFF17130B, 0xFF000000, 0xFF1D180E, 0xFF6D5C34, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 
        0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF836E3B, 0xFF000000, 0xFF000000, 0xFF100D07, 0xFF5F502A, 0xFFA28748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 
        0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 
        0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967935, 0xFF957934, 0xFF957834, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 
        0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722B, 0xFF90712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7029, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 
        0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20,
  0xFF8A6A20, 0xFF8A6B20, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90722B, 0xFF90722B, 0xFF90732C, 
        0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92752F, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 
        0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF997C39, 0xFF997C39, 0xFF997D3A, 0xFF9A7D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9B7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 
        0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA08747, 0xFFA18748, 0xFF9E8446, 0xFF42371D, 0xFF010100, 0xFF000000, 0xFF2B2414, 
        0xFF0B0905, 0xFF000000, 0xFF5D4E2B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA68C4F, 0xFFA68C4F, 0xFF584A2A, 0xFF040302, 0xFF000000, 0xFF252012, 0xFF947D47, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9256, 0xFFAA9157, 0xFFAA9257, 0xFF74633B, 0xFF0D0B06, 0xFF121009, 0xFF8A7748, 0xFFAA9258, 0xFFAB9359, 0xFFAC9359, 
        0xFFAC945A, 0xFFAC945A, 0xFFA58E56, 0xFF2A2416, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF50452A, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 
        0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C64, 0xFFB29B65, 0xFFB29B65, 0xFFB39C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFF786944, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF50462E, 0xFFB39C66, 0xFFB39D66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39D66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39D66, 
        0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFA89260, 0xFF2A2418, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF88774E, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B65, 
        0xFF605436, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF443B26, 0xFFAD9761, 0xFFB29B64, 0xFFB19B63, 0xFFB19B63, 0xFFB29A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09962, 0xFFB19962, 0xFFB09961, 
        0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09960, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAE955C, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFF937E4B, 0xFF221D11, 0xFF110E08, 0xFF7D6C40, 
        0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFF9F874E, 0xFF463C22, 0xFF000000, 0xFF020201, 0xFF372F1A, 0xFF9E854C, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF382F19, 0xFF000000, 0xFF030301, 0xFF000000, 0xFF010100, 0xFF42371D, 0xFF9F8446, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 
        0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 
        0xFF997E3B, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947631, 
        0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732B, 0xFF90732B, 0xFF90722B, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 
        0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B20, 0xFF896A20,
  0xFF8A6B20, 0xFF8B6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6D22, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 
        0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF957732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 
        0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 
        0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF8C753E, 0xFF272011, 0xFF000000, 0xFF0F0C06, 0xFF6D5B31, 0xFFA3894A, 
        0xFF463B20, 0xFF000000, 0xFF0E0B06, 0xFF846F3D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF897341, 0xFF251F12, 0xFF000000, 0xFF100D07, 0xFF5F512E, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFA89056, 0xFF8C7847, 0xFF362E1B, 0xFF000000, 0xFF0F0D07, 0xFF99844F, 0xFFAB9359, 0xFFAC9359, 0xFFAC935A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFF887547, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0B06, 0xFF947F4F, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFB09860, 
        0xFFAF9860, 0xFFB09860, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19B63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFF9B8858, 0xFF070604, 0xFF000000, 
        0xFF4D432C, 0xFF231F14, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8E7C51, 0xFFB39D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 
        0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB39D67, 0xFFA99360, 0xFF2A2418, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF88774E, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 
        0xFF605436, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF443B26, 0xFFAD9761, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB19962, 
        0xFFB19962, 0xFFB09961, 0xFFB19961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC955A, 0xFFAC945A, 0xFFAC935A, 0xFFAC945A, 0xFFAC9359, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAA9258, 0xFFAB9258, 0xFFA99156, 0xFF3A311D, 0xFF000000, 
        0xFF372F1C, 0xFF8C7846, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E52, 0xFFA78E52, 0xFFA78E52, 0xFF77653A, 0xFF1B170D, 0xFF000000, 0xFF120F08, 0xFF79673A, 0xFFA2894D, 0xFFA58C4F, 0xFFA58C4E, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFF63532E, 0xFF000000, 0xFF050402, 0xFF776436, 0xFF6C5B31, 0xFF0F0C06, 0xFF000000, 0xFF272011, 0xFF8C753E, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08545, 
        0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8242, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 
        0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987D39, 0xFF987C38, 0xFF987B38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967935, 0xFF967935, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF957832, 0xFF947731, 0xFF937631, 
        0xFF937631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF91742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 
        0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B20,
  0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8D6E24, 0xFF8D6E25, 0xFF8D6E26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 
        0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 
        0xFF987C38, 0xFF987C38, 0xFF987D39, 0xFF997D39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF6C5A30, 0xFF100D07, 0xFF000000, 0xFF2E2614, 0xFF8B7540, 0xFFA3894B, 0xFFA3894B, 
        0xFF9B8248, 0xFF201B0F, 0xFF000000, 0xFF2C2514, 0xFF9E864A, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF534628, 0xFF070603, 0xFF000000, 0xFF40361F, 0xFF907B46, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFF947F4C, 0xFF463C24, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF867345, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 
        0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFF4E4329, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3B3320, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09960, 0xFFB09961, 
        0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29A64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB29C65, 0xFFB29C65, 
        0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39C66, 0xFFB39D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFAA9461, 0xFF1D1911, 0xFF000000, 0xFF2D281A, 
        0xFFAF9A65, 0xFF8D7B51, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF17140D, 0xFFAC9663, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 
        0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFA99461, 0xFF2A2518, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF89784E, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 
        0xFF605437, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF443B26, 0xFFAE9862, 0xFFB39C65, 0xFFB39C65, 0xFFB29C64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB09A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAE975F, 0xFFAE975E, 0xFFAE965E, 
        0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9257, 0xFFA08952, 0xFF131009, 
        0xFF000000, 0xFF0B0905, 0xFF4A3F25, 0xFF95804C, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF9E864D, 0xFF554829, 0xFF010100, 0xFF000000, 0xFF3F351E, 0xFF967F48, 0xFFA58C50, 
        0xFFA58B4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFF84703E, 0xFF0D0B06, 0xFF000000, 0xFF453A20, 0xFFA2884A, 0xFFA3894B, 0xFF8B753F, 0xFF2E2615, 0xFF000000, 0xFF110E07, 0xFF6C5A30, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 
        0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 
        0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987D39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 
        0xFF947731, 0xFF937731, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F26, 
        0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21,
  0xFF8B6B21, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 
        0xFF91742E, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 
        0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 
        0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFF534524, 0xFF010100, 0xFF000000, 0xFF4A3E21, 0xFFA08648, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 
        0xFFA48A4C, 0xFF907943, 0xFF050402, 0xFF000000, 0xFF504426, 0xFFA58C4E, 0xFFA58C4F, 0xFF927B45, 0xFF1B170D, 0xFF000000, 0xFF070603, 0xFF7B683B, 0xFFA58C50, 0xFFA78E52, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 
        0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFF5B4E2F, 0xFF0B0905, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF423822, 0xFFAA9259, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAD955B, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAA935B, 0xFF120F09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF817046, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09960, 0xFFB09961, 0xFFB09961, 
        0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19B63, 0xFFB19B63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29C64, 0xFFB29C65, 0xFFB29B65, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB39C66, 
        0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D67, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFF3C3523, 0xFF000000, 0xFF100E09, 0xFF917F54, 
        0xFFB49E68, 0xFFB39C67, 0xFF4B422B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4C432C, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E68, 0xFFB49E68, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB59E68, 0xFFB59E68, 0xFFB59E68, 
        0xFFB59E69, 0xFFB59E68, 0xFFB59E69, 0xFFB49E68, 0xFFA99461, 0xFF2A2518, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF89784F, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 
        0xFF615437, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF443B27, 0xFFAE9863, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19B64, 0xFFB29B63, 
        0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB19962, 0xFFB09962, 0xFFB19961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 
        0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAE955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFF473D24, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0B07, 0xFF5E502F, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFFA78E52, 0xFF8C7744, 0xFF16130B, 0xFF000000, 0xFF0E0C07, 0xFF7E6B3C, 
        0xFFA68D4F, 0xFFA58C4F, 0xFFA58C4F, 0xFF9F874B, 0xFF2A2314, 0xFF000000, 0xFF1A160C, 0xFFA1874A, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFFA08648, 0xFF4A3E21, 0xFF000000, 0xFF010100, 0xFF534625, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 
        0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8341, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957933, 0xFF957832, 0xFF957832, 
        0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 
        0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C21,
  0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7128, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732C, 0xFF91742C, 0xFF91742D, 0xFF92742D, 
        0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 
        0xFF997D39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 
        0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFF9A8145, 0xFF372E18, 0xFF000000, 0xFF070603, 0xFF6B5A30, 0xFFA3894A, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48A4D, 0xFFA48B4D, 0xFF6C5B33, 0xFF000000, 0xFF000000, 0xFF756338, 0xFF6F5E35, 0xFF020201, 0xFF010100, 0xFF2C2515, 0xFF99824A, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA99055, 
        0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFA68E54, 0xFF806E42, 0xFF16130B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF7E6D42, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE965E, 0xFF766740, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF12100A, 0xFFAF9860, 0xFFAF9960, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19961, 0xFFB19A62, 
        0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 
        0xFFB39D66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFF706341, 0xFF020101, 0xFF000000, 0xFF64573A, 0xFFB59E68, 
        0xFFB59E69, 0xFFB59F69, 0xFF9F8C5C, 0xFF13100B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0C08, 0xFF8E7D52, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59F69, 
        0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFAA9462, 0xFF2A2518, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF89784F, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 
        0xFF615537, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453C27, 0xFFAE9963, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29C64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFF39311D, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221D11, 0xFF887545, 0xFFA58D53, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88E52, 0xFFA78E52, 0xFFA78E52, 0xFF483C22, 0xFF030301, 0xFF000000, 
        0xFF4E4225, 0xFFA0874C, 0xFFA68C4F, 0xFF564928, 0xFF000000, 0xFF050402, 0xFF907A43, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894A, 0xFF6B5930, 0xFF070603, 0xFF000000, 0xFF372E19, 0xFF9B8145, 0xFFA18748, 0xFFA18647, 
        0xFFA18747, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B7F3E, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957832, 
        0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91732D, 0xFF91742C, 0xFF91732B, 0xFF90732B, 0xFF90722B, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 
        0xFF8D7027, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22,
  0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 
        0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF997C39, 
        0xFF997D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9C803E, 0xFF9C813E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF88723C, 0xFF241E10, 0xFF000000, 0xFF1B170C, 0xFF7E6939, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 
        0xFFA48B4D, 0xFFA58B4E, 0xFFA1874C, 0xFF41371F, 0xFF000000, 0xFF050402, 0xFF000000, 0xFF0E0C07, 0xFF5D4F2D, 0xFFA78E52, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 
        0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFF927D4B, 0xFF362E1C, 0xFF14110A, 0xFF38301C, 0xFF322B1A, 0xFF050402, 0xFF000000, 0xFF000000, 0xFF1A170E, 0xFF98834F, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFA68F5A, 0xFF2C2618, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5C5032, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19A64, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 
        0xFFB49D67, 0xFFB49D68, 0xFFB49D68, 0xFFB49D68, 0xFFB49D68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E69, 0xFFB49E68, 0xFFB49E69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E69, 0xFFB59E69, 0xFF9A8659, 0xFF0E0C08, 0xFF000000, 0xFF443B27, 0xFFB59F69, 0xFFB59F6A, 
        0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFF6F6140, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF342E1E, 0xFFB49E69, 0xFFB59F6A, 0xFFB5A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFAA9563, 0xFF2A2518, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8A7850, 0xFFB59E69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB59E68, 0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E69, 
        0xFF615538, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453C27, 0xFFAF9964, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29C65, 
        0xFFB29B64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 
        0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFF9A844F, 0xFF0A0905, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3D341F, 0xFF877445, 0xFFA99056, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFF746338, 0xFF1E190E, 
        0xFF000000, 0xFF2A2414, 0xFF63542F, 0xFF000000, 0xFF000000, 0xFF6A5A32, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA38A4B, 0xFFA3894A, 0xFF7E6A39, 0xFF1B160C, 0xFF000000, 0xFF241E10, 0xFF89723C, 0xFFA18748, 
        0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8242, 0xFF9E8242, 0xFF9D8240, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 
        0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 
        0xFF957833, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732D, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 
        0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6D22,
  0xFF8B6D22, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7128, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92752E, 0xFF92752E, 
        0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF987B37, 0xFF977C37, 0xFF987B38, 0xFF987C39, 0xFF997C39, 0xFF997D39, 
        0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8240, 0xFF9D8140, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8444, 0xFF9F8444, 
        0xFFA08544, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF7B6738, 0xFF0D0B06, 0xFF000000, 0xFF302916, 0xFF957E44, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 
        0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF675731, 0xFF030301, 0xFF000000, 0xFF282213, 0xFF8C7644, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 
        0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAB9258, 0xFF9A854F, 0xFF51452A, 0xFF98834F, 0xFFA78F56, 0xFFA58E56, 0xFF5C4F30, 0xFF000000, 0xFF000000, 0xFF2C2617, 0xFFAB935B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 
        0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFF7B6B43, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF17140D, 0xFF9C8756, 0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFFB19B63, 0xFFB19A63, 0xFFB19B63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 
        0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFF19160E, 0xFF000000, 0xFF282317, 0xFFAF9966, 0xFFB69F6A, 0xFFB69F6A, 
        0xFFB6A06A, 0xFFB6A06B, 0xFFB59F6A, 0xFFB69F6A, 0xFF373020, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF6C5F3F, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFAB9664, 0xFF2A2518, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8B7951, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 
        0xFF615638, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453C27, 0xFFAF9A65, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 
        0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB29B65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB29A63, 0xFFB19B63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09960, 
        0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFF53472B, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1C180E, 0xFF3D341F, 0xFF262013, 0xFF080604, 0xFF443A22, 0xFFA28A51, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF99824B, 
        0xFF4A3E24, 0xFF000000, 0xFF020201, 0xFF000000, 0xFF463B21, 0xFFA2894D, 0xFFA58B4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA48A4B, 0xFFA3894B, 0xFF967E44, 0xFF302816, 0xFF000000, 0xFF0E0C06, 0xFF7D6938, 
        0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 
        0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A35, 0xFF967934, 0xFF957934, 0xFF957934, 
        0xFF957833, 0xFF947833, 0xFF947732, 0xFF947732, 0xFF947730, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91742C, 0xFF90732C, 0xFF90722B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 
        0xFF8E7027, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23,
  0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7029, 0xFF8F7129, 0xFF8F7229, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 
        0xFF937630, 0xFF937630, 0xFF947730, 0xFF947731, 0xFF947732, 0xFF957732, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 
        0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 
        0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF66552D, 0xFF000000, 0xFF000000, 0xFF463B20, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58C4F, 0xFFA38A4E, 0xFF61522E, 0xFF000000, 0xFF000000, 0xFF413720, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 
        0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9259, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFF8D794A, 0xFF100E08, 0xFF000000, 0xFF463C25, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 
        0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09861, 0xFF2F291A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF584D31, 0xFFB19A63, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 
        0xFFB49E69, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFF393221, 0xFF000000, 0xFF0C0B07, 0xFF958357, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFA59161, 0xFF080705, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFFA49160, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFAB9664, 0xFF2A2519, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8B7A51, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB5A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 
        0xFF615639, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453C28, 0xFFB09A66, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB39D66, 
        0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB09A62, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 
        0xFFB09861, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFF96814F, 0xFF15120B, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF463C24, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFF927C4A, 0xFF231E11, 0xFF413821, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 
        0xFFA78E52, 0xFF665732, 0xFF080704, 0xFF000000, 0xFF3B321C, 0xFF9C844A, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4B, 0xFFA3894B, 0xFFA3894A, 0xFF463B1F, 0xFF000000, 0xFF000000, 
        0xFF66552E, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08645, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 
        0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 
        0xFF957834, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742C, 0xFF91742C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 
        0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8B6D23,
  0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 
        0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3A, 
        0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 
        0xFFA08645, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFFA08647, 0xFF544625, 0xFF000000, 0xFF050402, 0xFF564927, 0xFFA3894A, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 
        0xFF937C46, 0xFF3B311C, 0xFF000000, 0xFF121009, 0xFF6F5E36, 0xFFA78D51, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 
        0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFF907C4C, 0xFF120F09, 0xFF010100, 0xFF635635, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 
        0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09960, 0xFFB09960, 0xFFB09961, 0xFFA08B58, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF9A8656, 0xFFB29A64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 
        0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB49D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59E69, 
        0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFF6D6040, 0xFF020201, 0xFF000000, 0xFF64583B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06C, 0xFFB7A06C, 0xFFB6A06C, 0xFFB69F6B, 0xFF64583B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF322C1E, 0xFFB59F6B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 
        0xFFB6A16C, 0xFFB6A06C, 0xFFB6A16C, 0xFFB6A06C, 0xFFAC9665, 0xFF2A2519, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8B7A51, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB6A06A, 0xFFB59F6A, 
        0xFF625639, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453D28, 0xFFB09B66, 0xFFB59E69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB59E68, 0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 
        0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 
        0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFF50442A, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF2B2416, 0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAA9157, 0xFFA58D53, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA78E52, 0xFFA78E52, 0xFF836F3F, 0xFF221D10, 0xFF000000, 0xFF231E11, 0xFF846F3F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894A, 0xFF564827, 0xFF050402, 
        0xFF000000, 0xFF554726, 0xFFA08647, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 
        0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967935, 
        0xFF967934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 
        0xFF8F7128, 0xFF8F7028, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D23,
  0xFF8C6E24, 0xFF8C6E24, 0xFF8D6E26, 0xFF8D6F26, 0xFF8D6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF90732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92742E, 0xFF92752F, 0xFF93762F, 0xFF937630, 
        0xFF937630, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957933, 0xFF967834, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3A, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 
        0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA28748, 0xFF393019, 0xFF000000, 0xFF070603, 0xFF766436, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF806C3E, 
        0xFF1B170D, 0xFF000000, 0xFF2C2515, 0xFF907A46, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFA99156, 0xFFAA9257, 0xFF8E7949, 0xFFAA9258, 0xFFAB9258, 
        0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAD955B, 0xFFAD955B, 0xFF857347, 0xFF0C0B06, 0xFF020101, 0xFF7E6D43, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAE975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 
        0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFB19A62, 0xFF675939, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF252015, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 
        0xFFB39D66, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB69F6A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A16C, 0xFF9B895B, 0xFF0C0B07, 0xFF000000, 0xFF3A3322, 0xFFB7A16C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 
        0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFAD9867, 0xFF201C13, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF766846, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFAC9766, 0xFF2B2519, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8B7B53, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06C, 0xFFB7A06C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06B, 
        0xFF625639, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453D28, 0xFFB19C68, 0xFFB5A06A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 
        0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB19961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFF917D4D, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF050402, 0xFF9D8752, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F54, 
        0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFF9C854C, 0xFF4A3F24, 0xFF000000, 0xFF0D0B06, 0xFF60522E, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA4894B, 0xFFA3894B, 0xFF766335, 
        0xFF070603, 0xFF000000, 0xFF39301A, 0xFFA28749, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987D39, 0xFF987C39, 0xFF987B38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF967A36, 0xFF967A35, 
        0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 
        0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E26, 0xFF8C6E25, 0xFF8C6E24,
  0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7028, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 
        0xFF947631, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957933, 0xFF957834, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C37, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 
        0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 
        0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF9A8144, 0xFF211C0F, 0xFF000000, 0xFF131008, 0xFF89733E, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF6E5C35, 0xFF000000, 
        0xFF000000, 0xFF4D4125, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFA68F55, 0xFF524629, 0xFF000000, 0xFF8B7747, 0xFFAB9359, 
        0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFF78683F, 0xFF050402, 0xFF020201, 0xFF988351, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 
        0xFFB09960, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFA48F5C, 0xFF221E13, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF6F613E, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 
        0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E68, 0xFFB49E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFF1B1710, 0xFF000000, 0xFF13110B, 0xFFB6A06C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A26D, 
        0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB8A26D, 0xFFB7A26D, 0xFFB8A26D, 0xFF897851, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF19160F, 0xFFAB9766, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB8A26E, 
        0xFFB7A26E, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26D, 0xFFAD9866, 0xFF2B2619, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8B7B53, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 
        0xFF63563A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453D29, 0xFFB19C68, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB49E69, 0xFFB59E69, 
        0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D67, 0xFFB49D67, 0xFFB39D67, 0xFFB49C66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB0985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFF1D190F, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF6A5B38, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA98F54, 
        0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFF6A5A33, 0xFF000000, 0xFF000000, 0xFF4C4125, 0xFFA58B4F, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 
        0xFF88723E, 0xFF131008, 0xFF000000, 0xFF221D0F, 0xFF9A8146, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8444, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8240, 
        0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977B37, 0xFF967A36, 0xFF967A36, 
        0xFF967A35, 0xFF957934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 
        0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24,
  0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 0xFF90722A, 0xFF90722B, 0xFF90732C, 0xFF91732C, 0xFF91732D, 0xFF91742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF937631, 
        0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 
        0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18646, 
        0xFFA18747, 0xFFA18748, 0xFF8E773F, 0xFF261F11, 0xFF000000, 0xFF0F0C06, 0xFF8B7540, 0xFFA3894B, 0xFFA3894B, 0xFFA4894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFF9E854B, 0xFF4A3E23, 0xFF000000, 0xFF0C0A05, 
        0xFF6C5B34, 0xFFA78E51, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFA28B53, 0xFF76653C, 0xFF17140B, 0xFF070603, 0xFF7E6C41, 0xFFAB9358, 0xFFAB9359, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD965D, 0xFF685A37, 0xFF000000, 0xFF050402, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 
        0xFFB09961, 0xFFB09962, 0xFFB19961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFF6F613E, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1C1810, 0xFFA6905E, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 
        0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFF3E3625, 0xFF000000, 0xFF070604, 0xFF958459, 0xFFB7A26D, 0xFFB8A16D, 0xFFB8A26D, 0xFFB7A26E, 0xFFB7A26E, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFF48402B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4A412C, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFAD9867, 0xFF2A2519, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8C7B54, 0xFFB7A26E, 0xFFB7A16E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 
        0xFF62563A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453D29, 0xFFB19D68, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 
        0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB19B63, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFF695B39, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF231E13, 0xFFA28B55, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 
        0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E53, 0xFFA78E52, 0xFF887442, 0xFF18150C, 0xFF000000, 0xFF302917, 0xFF957D47, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4B, 0xFFA3894B, 
        0xFFA3894B, 0xFF8A743E, 0xFF1D190D, 0xFF000000, 0xFF262011, 0xFF8E773F, 0xFFA18748, 0xFFA18747, 0xFFA18646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8445, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 
        0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B36, 0xFF977A36, 
        0xFF977A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752F, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722A, 
        0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25,
  0xFF8D6E26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7229, 0xFF90712A, 0xFF90732B, 0xFF90732B, 0xFF91732C, 0xFF91742C, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 
        0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 
        0xFFA18748, 0xFF88713D, 0xFF1B170C, 0xFF000000, 0xFF000000, 0xFF110E07, 0xFF7E6A3A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFF977F49, 0xFF2D2615, 0xFF000000, 0xFF1D190E, 0xFF847040, 
        0xFFA78E51, 0xFFA88E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFF7C6A3F, 0xFF2E2817, 0xFF000000, 0xFF040402, 0xFF73633C, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965C, 0xFFAE965D, 0xFFAE965D, 0xFFAC945D, 0xFF554A2E, 0xFF000000, 0xFF16130C, 0xFFAF985F, 0xFFAF985F, 0xFFB09860, 0xFFB09860, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB09962, 
        0xFFB19962, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C64, 0xFFAF9963, 0xFF252115, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF65583A, 0xFFB39C67, 0xFFB49D68, 0xFFB49E67, 
        0xFFB59E68, 0xFFB59E69, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 
        0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26E, 0xFFB8A26D, 0xFF5A4F35, 0xFF000000, 0xFF020101, 0xFF5F5338, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A36F, 
        0xFFB8A36F, 0xFFB9A36F, 0xFFB8A36E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB09B69, 0xFF17150E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF6C6042, 0xFFB9A36F, 0xFFB9A370, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A36F, 
        0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFAC9868, 0xFF262117, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF897952, 0xFFB8A26F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 
        0xFF5A5036, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433B28, 0xFFB19C6A, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 
        0xFFB29B65, 0xFFB29B64, 0xFFB29A64, 0xFFB19B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFF9F8A57, 0xFF1D1910, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF030201, 0xFF6F5F3B, 0xFFAE965C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB935A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 
        0xFFA99055, 0xFFA99054, 0xFFA98F54, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFF97804A, 0xFF362E1A, 0xFF000000, 0xFF19150C, 0xFF7E6B3D, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA3894B, 0xFFA3894B, 0xFF44391F, 0xFF000000, 0xFF000000, 0xFF1B170C, 0xFF88713C, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 
        0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 
        0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 0xFF90732C, 0xFF90732B, 
        0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8F7028, 0xFF8E7028, 0xFF8D6F27, 0xFF8D6F26, 0xFF8D6F26,
  0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90732B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 
        0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 
        0xFF806B3A, 0xFF0D0B06, 0xFF000000, 0xFF3D331C, 0xFF231E10, 0xFF000000, 0xFF141109, 0xFF8B7540, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF8B7642, 0xFF0E0C07, 0xFF000000, 0xFF38301B, 0xFFA0884D, 0xFFA78E51, 
        0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFF9D8650, 0xFF342D1A, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF13100A, 0xFFA18A54, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFA9935B, 0xFF3F3722, 0xFF000000, 0xFF37301E, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19962, 
        0xFFB19A63, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFF907E52, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0906, 0xFFAA9562, 0xFFB49E68, 0xFFB49E68, 
        0xFFB49E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB7A16D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFF6D6041, 0xFF000000, 0xFF000000, 0xFF17140D, 0xFFAF9B69, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 
        0xFFB9A370, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A370, 0xFF6F6243, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A07, 0xFF917F57, 0xFFB9A370, 0xFFB9A470, 0xFFB9A370, 0xFFB9A470, 
        0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFAA9667, 0xFF1B1810, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF796B49, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 
        0xFF473E2A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3A3322, 0xFFB09C69, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 
        0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 
        0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFF635536, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF221E12, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAE965C, 0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 
        0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFFA78E51, 0xFF544728, 0xFF000000, 0xFF050402, 0xFF756338, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 
        0xFFA48A4C, 0xFF5F502B, 0xFF050402, 0xFF010100, 0xFF0D0B06, 0xFF000000, 0xFF0D0B06, 0xFF806B3A, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF977B38, 0xFF987B37, 
        0xFF977B37, 0xFF977A36, 0xFF977A35, 0xFF967935, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF93762F, 0xFF93762F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF91732B, 
        0xFF90722B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8E7128, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26,
  0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92742E, 0xFF93752E, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947832, 
        0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 
        0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8141, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18646, 0xFFA18748, 0xFFA18748, 0xFF7E6938, 
        0xFF0D0B06, 0xFF000000, 0xFF372E19, 0xFFA3894B, 0xFF9B8347, 0xFF16120A, 0xFF000000, 0xFF1C170D, 0xFF977F46, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF786539, 0xFF040302, 0xFF020201, 0xFF463C22, 0xFFA68D51, 0xFFA78E52, 0xFFA78E52, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFF9E8750, 0xFF665734, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0905, 0xFF827044, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 
        0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAF965E, 0xFFAE975E, 0xFFA7905A, 0xFF292416, 0xFF000000, 0xFF564A2F, 0xFFB09860, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 
        0xFFB19A63, 0xFFB29B63, 0xFFB19B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFF463D28, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF493F2A, 0xFFB59E69, 0xFFB59F69, 
        0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26D, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB29C6B, 0xFF61563A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF342E1F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 
        0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFB9A471, 0xFF8B7B54, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF262217, 0xFFA69365, 0xFFB9A470, 0xFFB9A471, 0xFFB9A470, 
        0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFB9A470, 0xFFA39163, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF574C34, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 
        0xFF231F15, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF242016, 0xFFAD9967, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 
        0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29A64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFA28D59, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF8F7B4D, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAC955B, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 
        0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFF6C5C34, 0xFF050402, 0xFF000000, 0xFF5E502D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 
        0xFF776438, 0xFF080703, 0xFF000000, 0xFF362E19, 0xFFA1874A, 0xFF372E19, 0xFF000000, 0xFF0D0B06, 0xFF7E6A38, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8544, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 
        0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B38, 
        0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 
        0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F722A, 0xFF8F7128, 0xFF8E7128, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26,
  0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 
        0xFF957833, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997E3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 
        0xFF9C813E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF766335, 0xFF0D0B06, 
        0xFF000000, 0xFF4A3E21, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF8C7540, 0xFF19150B, 0xFF000000, 0xFF241F11, 0xFF967F47, 0xFFA58B4E, 0xFFA58C4F, 0xFF5F502D, 0xFF040302, 0xFF030301, 0xFF60512E, 0xFFA78E51, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFA78F54, 0xFF6E5D37, 0xFF252013, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF18150D, 0xFF71613B, 0xFFAD955B, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975E, 0xFFAF975F, 0xFFA48E59, 0xFF13110A, 0xFF000000, 0xFF766740, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB39D67, 0xFFA89361, 0xFF100E09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8C7B51, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A16D, 0xFFB7A26E, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 
        0xFFB8A26E, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFF887851, 0xFF322C1E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221E14, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFBAA470, 0xFFB9A471, 
        0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA472, 0xFFBAA471, 0xFFB9A472, 0xFFB9A471, 0xFF695D40, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2E291C, 0xFF94825A, 0xFFBAA471, 0xFFBAA471, 
        0xFFBAA472, 0xFFBAA472, 0xFFBAA571, 0xFFBAA472, 0xFF584E36, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF110F0A, 0xFFA18E61, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFF8B7A53, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF746745, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB7A26E, 0xFFB7A26D, 0xFFB8A26D, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59E69, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB49D66, 
        0xFFB39C67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19B63, 0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFF3D3421, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4F452B, 
        0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD965C, 0xFFAD955C, 0xFFAD945C, 0xFFAD945B, 0xFFAC945A, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 
        0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFFA78E52, 0xFF7A683C, 0xFF121009, 0xFF000000, 0xFF453A21, 0xFFA1894C, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFF7F6B3C, 
        0xFF0C0A06, 0xFF000000, 0xFF362D19, 0xFFA0864A, 0xFFA3894B, 0xFFA3894B, 0xFF4A3E21, 0xFF000000, 0xFF0D0B06, 0xFF776435, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA08546, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 
        0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF987D39, 0xFF987C39, 0xFF987B38, 
        0xFF977B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 
        0xFF91732C, 0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7128, 0xFF8E7027, 0xFF8E7027,
  0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF90722B, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 
        0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF997E3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 
        0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF6F5C32, 0xFF080704, 0xFF000000, 
        0xFF584928, 0xFFA1874A, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFF7F6C3C, 0xFF0D0B06, 0xFF000000, 0xFF2E2716, 0xFF9F864B, 0xFF41371F, 0xFF000000, 0xFF0B0905, 0xFF816E3E, 0xFFA78E51, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA98F54, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFF8D7847, 0xFF282214, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060503, 0xFF231E13, 0xFF827044, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFA18B58, 0xFF000000, 0xFF000000, 0xFF978453, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB19B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29C65, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFF695C3C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221E14, 0xFFB39D69, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB9A36F, 
        0xFFB8A36F, 0xFFB8A26F, 0xFFA18D61, 0xFF716344, 0xFF2B261A, 0xFF080705, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF322D1F, 0xFF7D6F4C, 0xFF9E8B60, 0xFFB7A16F, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFA99667, 0xFF928259, 0xFF564C34, 0xFF060504, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0D0C08, 0xFF3B3424, 0xFF7E6F4D, 
        0xFF94835A, 0xFFA49265, 0xFF847551, 0xFF342E20, 0xFF020101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF14120C, 0xFF5D5238, 0xFF98865D, 0xFFA79365, 0xFFA49164, 0xFFA69365, 0xFF94835A, 0xFF574D35, 0xFF0E0C08, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060503, 0xFF3A3322, 0xFF867751, 0xFFA39162, 0xFFA69364, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49E67, 
        0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFF7F6E47, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF16130C, 0xFFA28C58, 
        0xFFB09860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975E, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF957F48, 0xFF1D190E, 0xFF000000, 0xFF2A2314, 0xFFA48B4F, 0xFFA68C4F, 0xFF867240, 0xFF0D0B06, 
        0xFF000000, 0xFF2D2615, 0xFF998047, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA1874A, 0xFF574927, 0xFF000000, 0xFF090804, 0xFF6F5D32, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C813E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C39, 
        0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A35, 0xFF967935, 0xFF967935, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92742E, 0xFF92742E, 0xFF91742D, 
        0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027,
  0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957934, 
        0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF9A7D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 
        0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF776335, 0xFF080704, 0xFF010100, 0xFF4B3F22, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFF716035, 0xFF030201, 0xFF000000, 0xFF0A0804, 0xFF000000, 0xFF141109, 0xFF8A7543, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA08850, 0xFF493E25, 0xFF000000, 0xFF020101, 0xFF040302, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF2D2718, 0xFF927D4E, 0xFFAB945C, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFF8F7B4F, 0xFF000000, 0xFF000000, 0xFFAF9861, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 
        0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB49E69, 0xFFB59E69, 0xFFA69260, 0xFF211D13, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF6F6141, 
        0xFFB6A06B, 0xFFB6A16C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 
        0xFFB9A370, 0xFFAF9A6A, 0xFF312B1D, 0xFF030302, 0xFF070704, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080704, 0xFF050403, 0xFF0A0906, 0xFF9A895E, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 
        0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBAA573, 0xFFB29E6E, 0xFF332D1F, 0xFF010100, 0xFF060504, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF070604, 0xFF050403, 
        0xFF030302, 0xFF020201, 0xFF040302, 0xFF080704, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF050503, 0xFF030302, 0xFF020201, 0xFF020201, 0xFF020201, 0xFF030302, 0xFF060503, 0xFF080705, 
        0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF080705, 0xFF070604, 0xFF040302, 0xFF020201, 0xFF090805, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 0xFFB49E68, 
        0xFFB49D67, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFAD9761, 0xFF201C12, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF675A39, 0xFFB09961, 
        0xFFB09861, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 
        0xFFAB9258, 0xFFAB9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFFA78E52, 0xFFA1894E, 0xFF2F2816, 0xFF000000, 0xFF14110A, 0xFF897442, 0xFF1D190E, 0xFF000000, 
        0xFF1B160C, 0xFF927B44, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFF4C3F22, 0xFF010100, 0xFF080704, 0xFF776435, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C803F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 
        0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 
        0xFF91742D, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8E7129, 0xFF8E7027,
  0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF92742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF967934, 
        0xFF967934, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 
        0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF766335, 0xFF0A0904, 0xFF000000, 0xFF524525, 0xFFA3894A, 
        0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF60512D, 0xFF000000, 0xFF000000, 0xFF262012, 0xFF907A46, 0xFFA78E51, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99055, 
        0xFFA99055, 0xFFA99055, 0xFF917B49, 0xFF1B170D, 0xFF221D11, 0xFF493E25, 0xFF655734, 0xFF6F6039, 0xFF6A5B37, 0xFF51462A, 0xFF322B1A, 0xFF14110A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF38311E, 0xFF7C6C43, 0xFFAB955D, 0xFFB09860, 0xFFB09960, 0xFFB09961, 0xFF6F613D, 0xFF000000, 0xFF12100A, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C64, 0xFFB29C65, 0xFFB39C65, 
        0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFF746543, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF211D13, 
        0xFFAB9665, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 
        0xFFB9A470, 0xFFB8A370, 0xFFB19C6B, 0xFFAD9969, 0xFFAE9969, 0xFFAE9A69, 0xFFAE9A69, 0xFFAE996A, 0xFFAE9A69, 0xFFAE9A6A, 0xFFAE9A6A, 0xFFAE9A6A, 0xFFAE9A6A, 0xFFAE9A6A, 0xFFAF9B6B, 0xFFB7A371, 0xFFBBA673, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 
        0xFFBBA673, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFB29E6D, 0xFFAF9B6B, 0xFFAF9B6B, 0xFFAF9B6C, 0xFFAF9B6B, 0xFFAF9B6C, 0xFFAF9B6B, 0xFFAF9B6C, 0xFFAF9B6B, 0xFFAF9B6C, 0xFFAF9B6B, 0xFFAF9B6C, 0xFFAF9B6C, 0xFFAF9B6C, 0xFFAF9B6C, 
        0xFFAF9B6B, 0xFFAF9B6B, 0xFFAF9B6B, 0xFFAF9B6B, 0xFFAF9B6B, 0xFFAF9B6B, 0xFFAF9B6B, 0xFFAF9B6B, 0xFFAF9A6B, 0xFFAF9A6B, 0xFFAF9A6B, 0xFFAE9A6B, 0xFFAE9A6A, 0xFFAE9A6B, 0xFFAE9A6A, 0xFFAF9A6A, 0xFFAE9A6A, 0xFFAE9A6A, 0xFFAE9A6A, 0xFFAE9A6A, 
        0xFFAE9A6A, 0xFFAE9A6A, 0xFFAE9969, 0xFFAE9969, 0xFFAE9969, 0xFFAD9969, 0xFFAD9969, 0xFFAD9968, 0xFFAD9968, 0xFFAD9968, 0xFFAE9969, 0xFFB9A470, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB7A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB5A06A, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 
        0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C64, 0xFF6C5E3D, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF201C12, 0xFFA48F5B, 0xFFB09961, 
        0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAC9359, 0xFFAB9359, 
        0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA98F54, 0xFFA89054, 0xFFA88F53, 0xFFA88E52, 0xFFA78E52, 0xFF9F874E, 0xFF3E351E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF19150C, 
        0xFF857140, 0xFFA58C4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4B, 0xFFA3894B, 0xFFA3894B, 0xFF514425, 0xFF000000, 0xFF0A0904, 0xFF786435, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 
        0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997C39, 
        0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF967833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E, 0xFF92742E, 
        0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028,
  0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732B, 0xFF91742C, 0xFF91732D, 0xFF92742D, 0xFF92752E, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967935, 
        0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 
        0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF6F5C31, 0xFF080704, 0xFF000000, 0xFF5F502B, 0xFFA3894B, 0xFFA3894B, 
        0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF988048, 0xFF231D10, 0xFF000000, 0xFF372E1A, 0xFF9B834B, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 
        0xFFAA9156, 0xFFA99156, 0xFFA08951, 0xFF857244, 0xFF9F8852, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC935A, 0xFFA79058, 0xFF937F4E, 0xFF72623C, 0xFF282215, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF060503, 0xFF272215, 0xFF73643F, 0xFFB09961, 0xFFB19962, 0xFF4F442B, 0xFF000000, 0xFF2E281A, 0xFFB19B63, 0xFFB29A64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 
        0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFF2D281A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF63573B, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 
        0xFFBAA571, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBCA674, 
        0xFFBBA774, 0xFFBCA674, 0xFFBBA674, 0xFFBCA674, 0xFFBCA774, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA774, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBCA774, 0xFFBCA774, 0xFFBCA674, 0xFFBBA674, 0xFFBBA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 
        0xFFBAA573, 0xFFBBA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 
        0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB59E69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFAA9461, 0xFF19160E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF7A6A44, 0xFFB19A62, 0xFFB19962, 
        0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA48B50, 0xFF574A2A, 0xFF000000, 0xFF000000, 0xFF6E5E35, 
        0xFFA68C50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF5F502B, 0xFF000000, 0xFF080704, 0xFF6F5D32, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 
        0xFFA08544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 
        0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 
        0xFF92742E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F7129, 0xFF8F7129,
  0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF947630, 0xFF947731, 0xFF947731, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF967934, 0xFF967934, 0xFF967A35, 
        0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3B, 0xFF997E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9B803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 
        0xFF9D8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF776435, 0xFF090804, 0xFF010100, 0xFF524525, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 
        0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF907A45, 0xFF18150B, 0xFF000000, 0xFF352D1A, 0xFFA28A4E, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 
        0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFF8C794B, 0xFF282215, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1F1B11, 0xFF917E50, 0xFF312A1B, 0xFF000000, 0xFF494029, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB39D67, 
        0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06B, 0xFFA59262, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFFAC9767, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A26F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBAA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBBA674, 0xFFBCA674, 0xFFBCA775, 0xFFBCA774, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA674, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA674, 
        0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBAA673, 0xFFBBA573, 0xFFBBA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA472, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A36F, 
        0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 
        0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D66, 0xFFB39D66, 0xFF5E5235, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2F291A, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 
        0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA68D51, 0xFF60522F, 0xFF010100, 0xFF010100, 
        0xFF7C693B, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894C, 0xFFA3894B, 0xFFA3894B, 0xFF524425, 0xFF010100, 0xFF090804, 0xFF786435, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA08646, 0xFFA08646, 
        0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8341, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C803F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 
        0xFF997D3A, 0xFF987D39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF977A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752F, 
        0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F7129, 0xFF8F7129,
  0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732B, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 
        0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF997E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA18747, 0xFF7F6938, 0xFF0D0B06, 0xFF000000, 0xFF4B3F22, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF8B7642, 0xFF1A160C, 0xFF000000, 0xFF39311C, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 
        0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFF837146, 0xFF322B1B, 0xFF0C0A06, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF000000, 0xFF635637, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 
        0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB69F6B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFF5A4F35, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF332D1F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 
        0xFFBAA573, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBCA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBDA776, 0xFFBDA876, 0xFFBCA876, 0xFFBCA875, 0xFFBCA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA876, 0xFFBCA776, 0xFFBCA776, 0xFFBCA876, 0xFFBCA876, 
        0xFFBCA776, 0xFFBCA876, 0xFFBCA776, 0xFFBCA776, 0xFFBCA875, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBCA674, 0xFFBCA674, 0xFFBBA674, 
        0xFFBBA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBBA573, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA472, 0xFFBAA571, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 
        0xFFB9A470, 0xFFB8A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFF9F8B5B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030301, 0xFFA18C5A, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFFA78E52, 0xFF5B4D2D, 0xFF040302, 
        0xFF030301, 0xFF726137, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFF4B3F22, 0xFF000000, 0xFF0E0C06, 0xFF7E6A38, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA08646, 
        0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B, 
        0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967935, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937631, 0xFF93762F, 0xFF92752F, 
        0xFF92752F, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F7129,
  0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977A36, 
        0xFF977B36, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 
        0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF806B39, 0xFF0D0B06, 0xFF000000, 0xFF584928, 0xFFA3894B, 0xFFA3894B, 0xFFA4894C, 0xFFA48A4C, 0xFFA48A4D, 
        0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF846F3F, 0xFF14110A, 0xFF000000, 0xFF544728, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9157, 0xFFAA9257, 
        0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFF87754A, 0xFF4B4129, 
        0xFF030201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1E1A11, 0xFF655839, 0xFFAE9763, 0xFFB39D65, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 
        0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26D, 0xFFA39061, 0xFF19160F, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF010100, 0xFF766846, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBBA573, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 
        0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBCA774, 0xFFBCA774, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA776, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 
        0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 
        0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA875, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBAA673, 0xFFBAA672, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 
        0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06C, 
        0xFFB6A06B, 0xFFB6A06A, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFF2D281A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5D5135, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 
        0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99056, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFF705F37, 
        0xFF030201, 0xFF050402, 0xFF6D5C34, 0xFFA68D50, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFF574927, 0xFF000000, 0xFF0D0B06, 0xFF816C3A, 0xFFA18748, 0xFFA18747, 0xFFA18647, 
        0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947732, 0xFF947631, 0xFF937630, 0xFF937630, 
        0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722A, 0xFF90722A,
  0xFF90722A, 0xFF90722B, 0xFF90732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947732, 0xFF957832, 0xFF957832, 0xFF957834, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B36, 
        0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFF88723D, 0xFF0D0B06, 0xFF000000, 0xFF4A3E21, 0xFFA1874A, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 
        0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF84703F, 0xFF0E0C07, 0xFF000000, 0xFF554729, 0xFFA68D50, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 
        0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFB09860, 0xFFB09860, 0xFFAE9760, 
        0xFFA18C59, 0xFF483F28, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF12100A, 0xFF6E613F, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 
        0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFF61563A, 0xFF020101, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF15130D, 0xFF9F8D60, 0xFFBAA470, 0xFFBAA471, 0xFFBAA471, 0xFFA39063, 0xFF363021, 0xFF867752, 0xFFBAA572, 0xFFBAA572, 0xFFBBA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBCA774, 
        0xFFBCA774, 0xFFBCA775, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 
        0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA978, 0xFFBDA977, 0xFFBDA978, 
        0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 
        0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA774, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA573, 0xFFBBA572, 0xFFBBA572, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 
        0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFF776845, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1C1810, 0xFF9D895A, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 
        0xFFB29B64, 0xFFB29B63, 0xFFB19A64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 
        0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 
        0xFF7D6A3D, 0xFF070603, 0xFF000000, 0xFF675731, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA3894B, 0xFFA3894B, 0xFFA1874A, 0xFF493D21, 0xFF000000, 0xFF0D0B06, 0xFF88723D, 0xFFA18748, 0xFFA18747, 
        0xFFA18647, 0xFFA08646, 0xFFA08645, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8242, 0xFF9E8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 
        0xFF9A7E3B, 0xFF9A7D3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 
        0xFF93762F, 0xFF92752F, 0xFF92742E, 0xFF92742E, 0xFF91732D, 0xFF91742C, 0xFF91732C, 0xFF90722B, 0xFF90722A,
  0xFF90722A, 0xFF90722C, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967935, 0xFF967935, 0xFF977A36, 0xFF977A36, 0xFF977B36, 
        0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997E3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF8E773F, 0xFF1B170C, 0xFF000000, 0xFF362D18, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 
        0xFFA58C4E, 0xFFA58C4F, 0xFF8A7441, 0xFF141109, 0xFF000000, 0xFF4D4125, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA78F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 
        0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE955D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFB09860, 0xFFAF9961, 0xFFB09861, 0xFFB09961, 
        0xFFB09A62, 0xFFB19A62, 0xFFA08B58, 0xFF3F3623, 0xFF100D08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF15130C, 0xFF786945, 0xFFA89362, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB49F6C, 0xFF15120C, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0A07, 0xFF534932, 0xFF5A5036, 0xFF2F2A1D, 0xFF090805, 0xFF4A422D, 0xFFAE9B6A, 0xFFBAA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA776, 0xFFBDA876, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 
        0xFFBDA978, 0xFFBDA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 
        0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA978, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 
        0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA675, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA573, 0xFFBAA573, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB5A06A, 0xFFB5A06A, 0xFFAA9563, 0xFF2B2619, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF625538, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 
        0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA78F53, 
        0xFFA78E52, 0xFF716037, 0xFF0A0805, 0xFF000000, 0xFF6C5B34, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFF362D18, 0xFF000000, 0xFF1C180C, 0xFF8E773F, 0xFFA18747, 
        0xFFA18747, 0xFFA08647, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 
        0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947631, 0xFF947630, 
        0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722B,
  0xFF90732B, 0xFF90732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 
        0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF9B8144, 0xFF262011, 0xFF000000, 0xFF42371E, 0xFFA3884A, 0xFFA3894B, 0xFFA4894B, 0xFFA38A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 
        0xFFA58C4F, 0xFF84703F, 0xFF141109, 0xFF000000, 0xFF5B4D2C, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9257, 0xFFAB9358, 0xFFAB9358, 
        0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 
        0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFF938052, 0xFF574C31, 0xFF14120B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221E14, 0xFF635739, 0xFFA69261, 0xFFB69F6A, 
        0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36E, 0xFFB8A36F, 0xFFB8A26F, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A370, 0xFF726546, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433C29, 0xFF97865D, 0xFFBBA673, 0xFFBBA674, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 0xFFBCA776, 
        0xFFBCA775, 0xFFBDA876, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA78, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA979, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBEA977, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA878, 0xFFBDA977, 0xFFBDA977, 
        0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA875, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBCA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 
        0xFFBBA673, 0xFFBBA573, 0xFFBBA573, 0xFFBBA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26D, 0xFFB8A26D, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFF746543, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1D1A11, 0xFFB49D67, 0xFFB49E68, 0xFFB49E67, 0xFFB49D66, 0xFFB39D66, 0xFFB39C66, 
        0xFFB39C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975F, 0xFFAE975E, 0xFFAE975D, 0xFFAE965D, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA89054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 
        0xFFA78E53, 0xFFA78E52, 0xFF756439, 0xFF070603, 0xFF040302, 0xFF6C5C34, 0xFFA68C4F, 0xFFA48B4E, 0xFFA58B4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA28849, 0xFF3E331C, 0xFF000000, 0xFF262011, 0xFF9B8244, 
        0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3C, 
        0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7D3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947832, 0xFF947732, 0xFF937731, 
        0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91732C, 0xFF91732B, 0xFF90732B,
  0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957834, 0xFF957934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977C38, 
        0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 
        0xFF9F8544, 0xFF9F8545, 0xFFA08545, 0xFFA08645, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA28748, 0xFF211C0F, 0xFF000000, 0xFF000000, 0xFF4A3E21, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 
        0xFF846F3E, 0xFF0E0C07, 0xFF000000, 0xFF5B4D2C, 0xFFA68D51, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965E, 0xFFAE965E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 
        0xFFB19A63, 0xFFB19B63, 0xFFB29B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFA89260, 0xFF383120, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF14120C, 0xFF5C5036, 
        0xFFB49E6A, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFF070604, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF231F16, 0xFF97865C, 0xFFB8A371, 0xFFBBA674, 0xFFBBA674, 0xFFBCA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBCA878, 0xFFB6A274, 0xFFB3A072, 0xFFB09D70, 0xFFB09D70, 0xFFB29F71, 0xFFB6A274, 0xFFBCA778, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 
        0xFFBDA978, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 
        0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB7A16E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB39D6A, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF958256, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB39D67, 0xFFB49D66, 
        0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 
        0xFFAE965D, 0xFFAE955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 
        0xFFA88F53, 0xFFA88E52, 0xFFA78E52, 0xFF826E3F, 0xFF070603, 0xFF000000, 0xFF695932, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF917A42, 0xFF0A0804, 0xFF000000, 0xFF211C0F, 
        0xFFA28749, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8444, 0xFF9F8343, 0xFF9E8343, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A35, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 
        0xFF937731, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732B,
  0xFF91732C, 0xFF91732C, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 
        0xFF997C39, 0xFF987D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA08647, 0xFF39301A, 0xFF000000, 0xFF0A0804, 0xFF070603, 0xFF000000, 0xFF352D18, 0xFF9F8649, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF8C7642, 
        0xFF14110A, 0xFF000000, 0xFF4D4125, 0xFFA78E52, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 
        0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFF352E1E, 0xFF000000, 0xFF0C0A06, 0xFF0C0A06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF0A0805, 0xFF6F6242, 0xFFAF9A67, 0xFFB6A06C, 0xFFB7A26D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB9A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA571, 0xFFBAA471, 0xFF282318, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF0F0D09, 0xFF706345, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 
        0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEA979, 0xFFBEAA79, 0xFFBEAA79, 0xFFBCA878, 0xFFB8A575, 0xFFB6A273, 0xFFB4A072, 0xFFAE9C6F, 0xFFA39167, 0xFF8B7C58, 0xFF716548, 
        0xFF564D37, 0xFF453E2C, 0xFF352F21, 0xFF221E16, 0xFF13110C, 0xFF090806, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF110F0B, 
        0xFF1D1A12, 0xFF322C20, 0xFF433C2B, 0xFF544B36, 0xFF6C6145, 0xFF847654, 0xFF9E8D64, 0xFFAD9A6E, 0xFFB3A072, 0xFFB6A274, 0xFFB9A476, 0xFFBBA878, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBDA876, 0xFFBCA776, 0xFFBCA875, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA775, 
        0xFFBCA674, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBAA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26F, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFF473F2A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF483F2A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 
        0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09A62, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF985F, 0xFFAF985F, 0xFFAE975F, 0xFFAE975E, 
        0xFFAE965E, 0xFFAE965D, 0xFFAD965C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 
        0xFFA88F54, 0xFFA88F53, 0xFFA78F52, 0xFFA78E52, 0xFF756439, 0xFF0A0805, 0xFF000000, 0xFF6F5E35, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFF8F7941, 0xFF120F08, 0xFF000000, 0xFF030301, 0xFF000000, 
        0xFF39301A, 0xFFA08647, 0xFFA18747, 0xFFA18747, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8342, 0xFF9E8242, 0xFF9E8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803E, 
        0xFF9B803D, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D3A, 0xFF987D39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957834, 0xFF957832, 0xFF947832, 0xFF947732, 
        0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91732D, 0xFF91732C,
  0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 
        0xFF987D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 
        0xFFA08545, 0xFFA08645, 0xFFA08647, 0xFFA08647, 0xFFA18647, 0xFFA18748, 0xFF544626, 0xFF000000, 0xFF131008, 0xFF87713D, 0xFF62522D, 0xFF030301, 0xFF000000, 0xFF312916, 0xFF957F46, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF917A45, 0xFF1A160C, 
        0xFF000000, 0xFF544729, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 
        0xFFAD945B, 0xFFAC955B, 0xFFAD955C, 0xFFAD965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFF1A170F, 0xFF000000, 0xFF5A4F34, 0xFF998758, 0xFF4B422B, 0xFF13110B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF19160E, 0xFF665A3C, 0xFF9F8C5E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFAC9969, 0xFF000000, 0xFF000000, 
        0xFF0F0D09, 0xFF514732, 0xFFA79568, 0xFFBBA674, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 
        0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA979, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFAF9C6F, 0xFF9B8A62, 0xFF867855, 0xFF726649, 0xFF5B513A, 0xFF413A2A, 0xFF2B261B, 0xFF13110C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050503, 0xFF0F0E0A, 0xFF14120D, 0xFF1A1811, 0xFF211D15, 0xFF0D0C08, 0xFF000000, 0xFF070604, 0xFF252118, 0xFF070604, 0xFF000000, 0xFF0F0E0A, 0xFF1D1A12, 0xFF000000, 0xFF000000, 0xFF040402, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0D0C08, 0xFF262218, 0xFF3B3526, 0xFF554C36, 0xFF6E6246, 0xFF827453, 0xFF968660, 0xFFAA986D, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA7A, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA876, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A370, 
        0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFF8E7E55, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0F0D09, 0xFF9F8B5D, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 
        0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE965E, 0xFFAE965E, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99054, 
        0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFF6F5F36, 0xFF050402, 0xFF070603, 0xFF776539, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4E, 0xFFA48B4D, 0xFF7B6739, 0xFF110E08, 0xFF000000, 0xFF1A160C, 0xFF67572F, 0xFF131008, 
        0xFF000000, 0xFF554626, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8341, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 
        0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 
        0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C,
  0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967A35, 0xFF977A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF997C39, 
        0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 
        0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA28748, 0xFF66552D, 0xFF000000, 0xFF070603, 0xFF89733E, 0xFFA3894B, 0xFFA38A4B, 0xFF715F34, 0xFF020201, 0xFF000000, 0xFF1F1A0E, 0xFF967F46, 0xFFA58C4F, 0xFF988048, 0xFF18150B, 0xFF000000, 
        0xFF544729, 0xFFA68D51, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 
        0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFAA9461, 0xFF100E09, 0xFF030302, 0xFF6B5E3E, 0xFFB59F6A, 0xFFB59F6A, 0xFF9B885B, 0xFF5D5136, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF16130D, 0xFF49412C, 0xFFA59163, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFB6A170, 0xFF2A251A, 0xFF000000, 0xFF433B29, 
        0xFF9A895F, 0xFFBBA774, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA979, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFA9966B, 0xFF7B6E4E, 0xFF4F4732, 0xFF2A261B, 0xFF1D1A12, 0xFF12100B, 0xFF050503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF18160F, 0xFF312C1F, 0xFF49422F, 0xFF595039, 
        0xFF050403, 0xFF0C0A07, 0xFF776B4D, 0xFF9A8A63, 0xFF9E8D66, 0xFFA39269, 0xFFA5946A, 0xFFA8976C, 0xFFB09E72, 0xFF463E2D, 0xFF000000, 0xFF272319, 0xFFBBA779, 0xFF242017, 0xFF000000, 0xFF574E38, 0xFFB09D71, 0xFF030302, 0xFF000000, 0xFF74684B, 
        0xFF9B8A64, 0xFF94845F, 0xFF897B58, 0xFF7A6D4F, 0xFF645940, 0xFF504834, 0xFF211E15, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF0F0E0A, 0xFF1A1811, 0xFF282419, 0xFF473F2D, 0xFF716548, 0xFF9E8E65, 
        0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAB79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBDA876, 
        0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA675, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBBA572, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA472, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 
        0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB19C6A, 0xFF332D1E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF574D34, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 
        0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB09A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 
        0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955D, 0xFFAD955C, 0xFFAD945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 
        0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA88E53, 0xFFA78E52, 0xFF79673B, 0xFF000000, 0xFF080704, 0xFF867240, 0xFFA68D4F, 0xFFA48B4E, 0xFFA58C4E, 0xFF726036, 0xFF0C0A06, 0xFF000000, 0xFF1B160C, 0xFF8B7540, 0xFFA3894B, 0xFF88723E, 
        0xFF070603, 0xFF000000, 0xFF66562E, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08545, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 
        0xFF9C803E, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF967A35, 0xFF967935, 0xFF967935, 0xFF957833, 0xFF957833, 0xFF957833, 
        0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D,
  0xFF92742D, 0xFF92742D, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF987C37, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 
        0xFF997E3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 
        0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF7C6737, 0xFF000000, 0xFF050402, 0xFF776436, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFF806C3C, 0xFF0A0905, 0xFF000000, 0xFF0E0C07, 0xFF7F6C3D, 0xFF231D10, 0xFF000000, 0xFF3A311C, 
        0xFFA78E51, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA98F54, 0xFFA89054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 
        0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29B65, 
        0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFF948256, 0xFF0C0B07, 0xFF060503, 0xFF81714B, 0xFFB59F6A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB09A67, 0xFF4E442D, 0xFF030302, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF423A27, 0xFF9C8A5E, 0xFFB9A471, 0xFFB9A370, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A372, 0xFF97855C, 0xFF1F1B13, 0xFF110F0A, 0xFF8C7C57, 0xFFBBA774, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA878, 
        0xFFB5A172, 0xFF827452, 0xFF453E2C, 0xFF0F0E0A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF110F0B, 0xFF383224, 0xFF60563D, 0xFF867856, 0xFFAA996E, 0xFFBFAB7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 
        0xFF0F0D09, 0xFF0B0A07, 0xFF90815D, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC0AC7D, 0xFF4E4632, 0xFF000000, 0xFF2C281C, 0xFFC1AD7D, 0xFF272319, 0xFF000000, 0xFF61583F, 0xFFC0AD7D, 0xFF040402, 0xFF000000, 0xFF8D7E5C, 
        0xFFC0AC7C, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFF5D533C, 0xFF000000, 0xFF393325, 0xFFAE9C70, 0xFF8F805C, 0xFF685D43, 0xFF413A2A, 0xFF18150F, 0xFF030302, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF050403, 0xFF352F21, 0xFF736749, 0xFFAD9A6E, 0xFFBDA979, 0xFFBDA979, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 
        0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA573, 0xFFBBA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFB8A370, 0xFFB9A471, 
        0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFF776947, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF100E09, 0xFFAC9765, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB59F69, 
        0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 
        0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD965C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 
        0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78F52, 0xFFA78E52, 0xFF695933, 0xFF020201, 0xFF030301, 0xFF8D7744, 0xFFA68C4F, 0xFF6B5B32, 0xFF000000, 0xFF000000, 0xFF221C10, 0xFF9E8549, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 
        0xFF766335, 0xFF050402, 0xFF000000, 0xFF7D6938, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8341, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 
        0xFF9B803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF967A36, 0xFF967A35, 0xFF967A34, 0xFF957934, 0xFF957833, 0xFF957833, 
        0xFF957833, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92742E, 0xFF92742D,
  0xFF91742D, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977B36, 0xFF977B37, 0xFF977B38, 0xFF987C38, 0xFF997C39, 0xFF987D39, 0xFF997D3A, 
        0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFFA08544, 0xFF9F8545, 0xFFA08546, 
        0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFF89723C, 0xFF0D0B06, 0xFF000000, 0xFF564927, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFF806B3C, 0xFF17140B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF352D19, 0xFFA78E51, 
        0xFFA78E52, 0xFFA88E52, 0xFFA78F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC935A, 0xFFAC935A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 
        0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB0985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19961, 0xFFB09A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 
        0xFFB39C66, 0xFFB39C66, 0xFFB49C67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFF81704A, 0xFF070604, 0xFF090805, 0xFF978558, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16C, 0xFF9F8C5E, 0xFF453D29, 0xFF14110B, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF252117, 0xFF61563B, 0xFF80714E, 0xFF847451, 0xFF695E41, 0xFF302A1D, 0xFF0B0906, 0xFF5D5239, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBAA676, 0xFFA29167, 0xFF897A57, 0xFF5C523A, 0xFF262218, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF16140E, 0xFF2A261B, 0xFF312C1F, 0xFF000000, 0xFF1B1811, 0xFFA7966C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFF1D1A13, 0xFF050403, 0xFF827454, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFF4D4532, 0xFF000000, 0xFF2C281C, 0xFFC1AD7E, 0xFF282319, 0xFF000000, 0xFF61573F, 0xFFC1AD7D, 0xFF030201, 0xFF000000, 0xFF8D7E5B, 
        0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFC1AD7D, 0xFF443D2C, 0xFF000000, 0xFF47402E, 0xFFC1AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFB9A678, 0xFF958660, 0xFF706448, 0xFF49422F, 0xFF2D291D, 0xFF13110C, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1A1811, 0xFF504733, 0xFF817452, 0xFF9E8D64, 0xFFB6A274, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 
        0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA774, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFA08E62, 0xFF584E36, 0xFF9C895E, 
        0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFF918057, 0xFF0A0806, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF726543, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 
        0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB19961, 0xFFB09962, 0xFFB09961, 0xFFB09861, 
        0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB935A, 0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 
        0xFFAA9156, 0xFFA99055, 0xFFA89055, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFFA78E52, 0xFF564929, 0xFF000000, 0xFF16130A, 0xFF534628, 0xFF000000, 0xFF000000, 0xFF352D19, 0xFF9C8549, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894C, 0xFFA3894B, 
        0xFFA3894B, 0xFF564827, 0xFF000000, 0xFF0E0C06, 0xFF89723D, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 
        0xFF9C813F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957833, 
        0xFF957833, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742D,
  0xFF92752E, 0xFF92752E, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 
        0xFF997E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 
        0xFFA18647, 0xFFA18748, 0xFF9A8145, 0xFF241E10, 0xFF000000, 0xFF463B20, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF8D7743, 0xFF010100, 0xFF000000, 0xFF372E1A, 0xFFA28A4E, 0xFFA78E52, 
        0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99054, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 
        0xFFAE965D, 0xFFAE975D, 0xFFAE975E, 0xFFAE975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19961, 0xFFB19962, 0xFFB19A63, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 
        0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFF6C5F3F, 0xFF030302, 0xFF0C0B07, 0xFFAE9966, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB8A26E, 0xFF99875B, 0xFF5D5238, 
        0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF574D36, 0xFFA28F64, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFF988861, 0xFF5F543C, 0xFF342E21, 0xFF17150F, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF0E0D09, 0xFF3C3627, 0xFF6B6044, 0xFF8C7D5A, 0xFFA19168, 0xFFB9A577, 0xFFB3A174, 0xFF030201, 0xFF12100C, 0xFF9E8E66, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7E, 
        0xFF312D20, 0xFF000000, 0xFF74684C, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFF4D4632, 0xFF000000, 0xFF2B271C, 0xFFC1AE7E, 0xFF28241A, 0xFF000000, 0xFF61573F, 0xFFC2AE7E, 0xFF030302, 0xFF000000, 0xFF8D7F5C, 
        0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC1AD7E, 0xFF2F2A1F, 0xFF000000, 0xFF574E38, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC0AC7C, 0xFF5E543D, 
        0xFF000000, 0xFF15130E, 0xFF463E2D, 0xFF191610, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF12100B, 0xFF2D281D, 0xFF544B36, 0xFF8D7E5B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 
        0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFAA9768, 0xFF4D442F, 0xFF13110C, 
        0xFF3A3323, 0xFF574D35, 0xFF453D2A, 0xFF0E0C08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2C271A, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 
        0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB19962, 0xFFB09961, 
        0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 
        0xFFAA9157, 0xFFA99056, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFF554829, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4A3E23, 0xFF9C844A, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA3894B, 0xFFA3894B, 0xFF463B1F, 0xFF000000, 0xFF241E10, 0xFF9C8245, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 
        0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967934, 0xFF957934, 
        0xFF957833, 0xFF957832, 0xFF947832, 0xFF947731, 0xFF947730, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92752E,
  0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF957732, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3A, 
        0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9B803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08647, 
        0xFFA18748, 0xFFA18748, 0xFF372E18, 0xFF000000, 0xFF312916, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF41371F, 0xFF000000, 0xFF262012, 0xFF9B834C, 0xFFA78E52, 0xFFA78E52, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99056, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9257, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAD965D, 
        0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D66, 0xFFB39D67, 
        0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFF584D33, 0xFF000000, 0xFF16130D, 0xFFB6A06B, 0xFFB6A16C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB7A26E, 
        0xFFB19B6B, 0xFF564C34, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2C271B, 0xFFA49265, 0xFFBAA574, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 0xFFBDA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFAF9C70, 0xFF63583F, 0xFF1A1710, 0xFF040402, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF15130D, 0xFF584E38, 0xFF9B8B63, 
        0xFFB9A577, 0xFFBCA97A, 0xFFBFAB7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7D, 0xFF1B1811, 0xFF030302, 0xFF867857, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC2AE7E, 
        0xFF4A4230, 0xFF000000, 0xFF665C43, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7E, 0xFFC1AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF4E4633, 0xFF000000, 0xFF2C281D, 0xFFC2AE7F, 0xFF28241A, 0xFF000000, 0xFF625840, 0xFFC2AE7F, 0xFF040402, 0xFF000000, 0xFF8E7F5D, 
        0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7E, 0xFF221E16, 0xFF020201, 0xFF695F45, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFF443D2C, 
        0xFF000000, 0xFF3E3828, 0xFFC0AC7C, 0xFFBBA779, 0xFFA7956B, 0xFF685D43, 0xFF221F16, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF100E0A, 0xFF504834, 0xFFA29167, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBFAA79, 0xFFBEAA79, 
        0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFA08E63, 
        0xFF252117, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF958359, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C65, 0xFFB29B65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB09962, 
        0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAC955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 
        0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFFA58C51, 0xFF4F4326, 0xFF000000, 0xFF141109, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF302816, 0xFF000000, 0xFF382F19, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08544, 0xFF9F8444, 0xFF9F8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 
        0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 
        0xFF957934, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E,
  0xFF92752E, 0xFF937630, 0xFF937630, 0xFF947730, 0xFF947731, 0xFF957732, 0xFF957832, 0xFF957833, 0xFF967934, 0xFF967935, 0xFF967935, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF9A7E3A, 0xFF9A7E3B, 
        0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18647, 
        0xFFA18748, 0xFF534525, 0xFF000000, 0xFF1B170C, 0xFF967E44, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF5F502D, 0xFF000000, 0xFF141109, 0xFF907B46, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 
        0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAB9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAB9459, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAD965C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D66, 0xFFB39D66, 0xFFB49D67, 
        0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB29D68, 0xFF453C28, 0xFF000000, 0xFF302A1C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 
        0xFFB9A470, 0xFFB9A471, 0xFF96855B, 0xFF15120C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF18150F, 0xFF756848, 0xFFBCA675, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 
        0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBAA676, 0xFFA7966A, 0xFF807251, 0xFF322D20, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0C09, 0xFF000000, 0xFF191610, 0xFF988861, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFF49412F, 0xFF000000, 0xFF695E45, 0xFFC0AC7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7E, 0xFFC1AE7E, 0xFFC1AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFF5D533D, 0xFF000000, 0xFF4F4734, 0xFFBFAB7D, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AE7F, 0xFF4E4633, 0xFF000000, 0xFF2C281D, 0xFFC2AF80, 0xFF29251B, 0xFF000000, 0xFF635941, 0xFFC2AE80, 0xFF040403, 0xFF000000, 0xFF8F815D, 
        0xFFC2AF7F, 0xFFC2AE80, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFB9A679, 0xFF191710, 0xFF030302, 0xFF7C6F51, 0xFFC2AE7F, 0xFFC1AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7E, 0xFFC1AE7F, 0xFFC2AE7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFBCA87B, 0xFF272319, 
        0xFF000000, 0xFF655A41, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFB09D71, 0xFF6F6347, 0xFF302B1E, 0xFF15120D, 0xFF030302, 0xFF000000, 0xFF000000, 0xFF201C14, 0xFF706448, 0xFFA29167, 0xFFB7A475, 0xFFBFAA7A, 0xFFBFAA79, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 
        0xFFBBA673, 0xFF716445, 0xFF1A1710, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2C271A, 0xFFAF9B6A, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 
        0xFFB09962, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC935A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 
        0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88E53, 0xFFA78E52, 0xFFA0884E, 0xFF332B18, 0xFF000000, 0xFF362E1A, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 
        0xFFA48A4C, 0xFFA3894C, 0xFFA3894B, 0xFF967E44, 0xFF1B160C, 0xFF000000, 0xFF534625, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA08545, 0xFFA08545, 0xFFA08445, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8341, 0xFF9D8241, 
        0xFF9D8241, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3B, 0xFF987D39, 0xFF987C39, 0xFF987C38, 0xFF987C37, 0xFF977B37, 0xFF977B37, 0xFF967A36, 0xFF967A35, 0xFF967935, 
        0xFF967934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF947630, 0xFF93762F, 0xFF92752F,
  0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957933, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 
        0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 
        0xFF6C5A30, 0xFF010100, 0xFF070603, 0xFF7E6A39, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF786539, 0xFF040302, 0xFF0B0905, 0xFF8A7543, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 
        0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19961, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 
        0xFFB49E68, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6B, 0xFFAC9765, 0xFF322C1D, 0xFF000000, 0xFF514730, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 
        0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFF64593D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0D09, 0xFF65593E, 0xFFB09C6D, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 
        0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFB8A475, 0xFF7D7050, 0xFF463E2C, 0xFF14120D, 0xFF000000, 0xFF000000, 0xFF0B0A07, 0xFF413A29, 0xFF73674A, 0xFF978761, 0xFF040402, 0xFF0F0D09, 0xFF9C8C65, 0xFFC1AC7C, 0xFFC1AC7D, 0xFFC1AD7D, 
        0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7E, 0xFF817454, 0xFF000000, 0xFF47402E, 0xFFBDA97C, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF7F, 0xFFC2AE80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF7F, 0xFFC2AF7F, 
        0xFF75694D, 0xFF000000, 0xFF3B3527, 0xFFA6956E, 0xFFA6956D, 0xFF9C8C67, 0xFF958663, 0xFF92835F, 0xFF92835F, 0xFF363023, 0xFF000000, 0xFF1D1A13, 0xFF938461, 0xFF1C1912, 0xFF000000, 0xFF4B4332, 0xFF9D8E68, 0xFF030202, 0xFF000000, 0xFF847758, 
        0xFFBDAA7D, 0xFFC3AF80, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3AF80, 0xFFAF9D73, 0xFF14120D, 0xFF050403, 0xFF90825F, 0xFFC2AF80, 0xFFC2AF7F, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFA6956D, 0xFF17150F, 
        0xFF000000, 0xFF8F815E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFA6956C, 0xFF7E7151, 0xFF242117, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0A07, 0xFF3B3425, 0xFF706448, 0xFFAD9B6F, 
        0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA977, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 
        0xFFBBA674, 0xFFBBA674, 0xFFA89567, 0xFF61563B, 0xFF0F0D09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF443D2A, 0xFFB4A06E, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A64, 0xFFB19A63, 
        0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9459, 0xFFAB9359, 0xFFAB9359, 
        0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF9B834C, 0xFF1F1A0F, 0xFF000000, 0xFF534728, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF7E6939, 0xFF070603, 0xFF010100, 0xFF6C5A30, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8341, 
        0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B36, 0xFF977A36, 0xFF967A36, 0xFF967935, 
        0xFF967935, 0xFF957934, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93762F,
  0xFF93762F, 0xFF937630, 0xFF947631, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957933, 0xFF957934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 
        0xFF9A7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF8C753E, 
        0xFF100D07, 0xFF000000, 0xFF6A5930, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA68C4F, 0xFF8C7742, 0xFF040302, 0xFF030301, 0xFF816D3E, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 
        0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 
        0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFA69261, 0xFF201C13, 0xFF000000, 0xFF726443, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFF716445, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF4E4530, 0xFFAD9A6C, 0xFFBBA674, 0xFFBCA775, 0xFFBCA875, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFB29F71, 0xFF5A5039, 0xFF13110C, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF231F16, 0xFF7B6D4F, 0xFFAD9B70, 0xFFB9A678, 0xFFC0AC7C, 0xFFC0AC7C, 0xFF393325, 0xFF000000, 0xFF72664A, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AD7E, 
        0xFFC1AD7E, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC1AE7F, 0xFFC2AE7F, 0xFFA9986F, 0xFF000000, 0xFF191610, 0xFFBAA87A, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFB9A77A, 0xFF9E8E68, 0xFF7F7253, 0xFF645941, 0xFF4A4231, 0xFF342F22, 
        0xFF16140F, 0xFF000000, 0xFF050403, 0xFF0F0D0A, 0xFF0E0D09, 0xFF0C0B08, 0xFF0A0907, 0xFF090806, 0xFF090806, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF080705, 0xFF000000, 0xFF000000, 0xFF040403, 0xFF0B0A07, 0xFF000000, 0xFF000000, 0xFF0D0C09, 
        0xFF15130E, 0xFF1C1912, 0xFF28241A, 0xFF3E3829, 0xFF574E39, 0xFF5B523C, 0xFF0B0A07, 0xFF060604, 0xFFA6966E, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3AF80, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFF8F815D, 0xFF090806, 
        0xFF030201, 0xFFB8A579, 0xFFC2AE7F, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFBBA879, 0xFF312C1F, 0xFF000000, 0xFF393324, 0xFF3C3627, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF0E0C09, 
        0xFF453E2C, 0xFFA39268, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFA59365, 0xFF433B29, 0xFF000000, 0xFF000000, 0xFF17150E, 0xFFAF9A6A, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 
        0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD955D, 0xFFAD965C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 
        0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF9B844C, 0xFF0F0D07, 0xFF000000, 0xFF716036, 0xFFA68D4F, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 
        0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF6A5930, 0xFF000000, 0xFF110E07, 0xFF8D753E, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 
        0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 
        0xFF967935, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630,
  0xFF937630, 0xFF937631, 0xFF947731, 0xFF947731, 0xFF947832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 
        0xFF9B7F3D, 0xFF9C803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18748, 0xFF9E8446, 0xFF272011, 
        0xFF000000, 0xFF4A3E21, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF967F48, 0xFF0E0C07, 0xFF020201, 0xFF60512E, 0xFFA78E51, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 
        0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAD955B, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 
        0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E69, 0xFFB59E69, 
        0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFF9F8B5E, 0xFF0E0C08, 0xFF000000, 0xFF907F56, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 
        0xFFBAA572, 0xFFBBA573, 0xFFB09C6C, 0xFF2C271B, 0xFF030302, 0xFF211D14, 0xFF95845C, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFB9A676, 
        0xFFA49368, 0xFF4D4431, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF0F0E0A, 0xFF443D2B, 0xFF9F8E66, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC0AD7D, 0xFF8A7C59, 0xFF000000, 0xFF383224, 0xFFBEAA7C, 0xFFC1AE7E, 0xFFC1AD7E, 
        0xFFC2AE7F, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFBFAC7E, 0xFFB5A477, 0xFF080705, 0xFF000000, 0xFF72664B, 0xFF574E39, 0xFF302B1F, 0xFF0D0C09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 
        0xFF090806, 0xFF0A0907, 0xFF0D0B08, 0xFF100E0A, 0xFF13110C, 0xFF181610, 0xFF1D1A13, 0xFF242118, 0xFF28241B, 0xFF29251B, 0xFF27231A, 0xFF28241B, 0xFF29251B, 0xFF28241B, 0xFF252118, 0xFF211D15, 0xFF1A1811, 0xFF12100C, 0xFF0F0D0A, 0xFF0F0D0A, 
        0xFF0C0B08, 0xFF0A0907, 0xFF060504, 0xFF010101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF1D1A13, 0xFF433C2C, 0xFF6B6147, 0xFF948562, 0xFFAF9D74, 0xFFB6A478, 0xFFBCA97C, 0xFFC2AF80, 0xFFC2AF80, 0xFF75694C, 0xFF000000, 
        0xFF1F1C14, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFF9E8D66, 0xFF12100C, 0xFF000000, 0xFF9B8B64, 0xFFC1AD7C, 0xFFAE9C70, 0xFF595039, 0xFF15130E, 0xFF050403, 
        0xFF000000, 0xFF000000, 0xFF383224, 0xFF998962, 0xFFB7A475, 0xFFBFAA7A, 0xFFBEAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFF8D7C57, 0xFF1B1810, 0xFF000000, 0xFF4C432E, 0xFFB7A26F, 0xFFB9A471, 0xFFB9A370, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 
        0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975D, 0xFFAE965D, 0xFFAD955D, 0xFFAD965C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC935A, 0xFFAC9359, 
        0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFF8A7644, 0xFF090704, 0xFF000000, 0xFF887341, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA48B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894A, 0xFF4A3E21, 0xFF000000, 0xFF272011, 0xFF9E8446, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFF9F8546, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C803F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF997E3A, 0xFF997D3A, 0xFF987D3A, 0xFF987C39, 0xFF987C38, 0xFF977B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 
        0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF937731, 0xFF937630,
  0xFF937630, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957834, 0xFF957934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF42371D, 0xFF000000, 
        0xFF2E2615, 0xFFA08648, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF9E854B, 0xFF2D2615, 0xFF000000, 0xFF473C22, 0xFFA78E51, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 
        0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9257, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 
        0xFFB09860, 0xFFB09960, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFF978559, 0xFF000000, 0xFF000000, 0xFFB19C69, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 
        0xFFBBA573, 0xFF98865D, 0xFF2E291C, 0xFF1E1B13, 0xFF6E6144, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFB8A475, 0xFF827452, 0xFF403929, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF302B1F, 0xFF6E6246, 0xFFAD9B6F, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFB8A578, 0xFF0C0B08, 0xFF000000, 0xFFB1A074, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFAD9C72, 0xFF8F815E, 0xFF72674B, 0xFF524A36, 0xFF302B1F, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF110F0B, 0xFF272319, 0xFF383325, 0xFF494230, 0xFF5B523D, 0xFF6D6248, 0xFF7E7154, 
        0xFF8E805E, 0xFF9C8C68, 0xFFA89770, 0xFFB4A277, 0xFFBDAA7E, 0xFFC4B182, 0xFFC4B182, 0xFFC4B082, 0xFFC4B083, 0xFFC4B182, 0xFFC4B182, 0xFFC4B182, 0xFFC4B182, 0xFFC4B183, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFB9A77A, 0xFFAF9E74, 
        0xFFA2936C, 0xFF968864, 0xFF877959, 0xFF776B4F, 0xFF645A43, 0xFF534A37, 0xFF3F392A, 0xFF2F2A1F, 0xFF1D1A13, 0xFF060604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1F1C14, 0xFF413A2B, 0xFF635941, 0xFF817355, 0xFF47402F, 0xFF000000, 
        0xFF5C533D, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7E, 0xFF796D4F, 0xFF000000, 0xFF16140E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFBAA577, 0xFF7C6F50, 
        0xFF403A29, 0xFF0D0C08, 0xFF000000, 0xFF000000, 0xFF2F2A1E, 0xFF74674A, 0xFFAE9C6F, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA472, 0xFF695D40, 0xFF15130D, 0xFF352F21, 0xFF95835A, 0xFFB8A270, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 
        0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 
        0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA89055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFF6C5B35, 0xFF000000, 0xFF0D0B06, 0xFF8C7743, 0xFFA68C4F, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA08548, 0xFF2D2614, 0xFF000000, 0xFF43381E, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997C39, 0xFF997C39, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 
        0xFF977A35, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF947832, 0xFF947731, 0xFF947731, 0xFF937630,
  0xFF947631, 0xFF947731, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A37, 0xFF977B37, 0xFF987C37, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF5E4F2A, 0xFF010100, 0xFF0F0C06, 
        0xFF8B753F, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4D, 0xFFA58C4F, 0xFFA58C4F, 0xFF4A3F23, 0xFF000000, 0xFF38301B, 0xFFA68D50, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99055, 
        0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFFAB9358, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD965C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975E, 0xFFAF985F, 0xFFB09860, 0xFFB09860, 
        0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A64, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB49E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFF82724D, 0xFF000000, 0xFF070604, 0xFFB8A36E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 
        0xFFBBA674, 0xFF94845C, 0xFF594F37, 0xFFAC996B, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFF766A4C, 0xFF231F16, 0xFF060604, 0xFF000000, 
        0xFF000000, 0xFF110F0B, 0xFF000000, 0xFF796C4E, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC0AC7D, 0xFF47402E, 0xFF000000, 0xFF685E44, 0xFFC2AF7F, 0xFFC2AF80, 
        0xFF988964, 0xFF5D543D, 0xFF2E291E, 0xFF181510, 0xFF0A0907, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0907, 0xFF332E21, 0xFF5F553F, 0xFF867859, 0xFF9F8F6A, 0xFFAA9A71, 0xFFB3A176, 0xFFBBA87C, 0xFFC2AF81, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 
        0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B183, 0xFFC4B284, 0xFFC4B184, 0xFFC5B284, 0xFFC4B184, 0xFFC5B184, 0xFFC5B183, 0xFFC5B283, 0xFFC5B283, 0xFFC5B183, 0xFFC4B184, 
        0xFFC4B183, 0xFFC4B184, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFBEAC7F, 0xFFB6A57A, 0xFFAF9E75, 0xFFA6956E, 0xFF968864, 0xFF74694E, 0xFF4C4432, 0xFF201D15, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF050403, 0xFF000000, 
        0xFF302C20, 0xFF7B6F51, 0xFFB3A276, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC0AC7E, 0xFF413B2A, 0xFF000000, 0xFF625840, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC1AD7D, 
        0xFFBCA87A, 0xFFA29269, 0xFF635940, 0xFF080705, 0xFF000000, 0xFF020201, 0xFF18150F, 0xFF5D533C, 0xFFB9A576, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBDA978, 0xFFBEA977, 0xFFBDA877, 0xFFBDA876, 
        0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA774, 0xFFBBA674, 0xFFBBA673, 0xFFA99668, 0xFF62573C, 0xFF2C271B, 0xFFA89466, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 
        0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 
        0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09962, 0xFFB09961, 0xFFB09960, 0xFFAF9860, 0xFFAF9760, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF544729, 0xFF000000, 0xFF292213, 0xFF9C844B, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF8B753F, 0xFF0F0C06, 0xFF010100, 0xFF5E4F2A, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 
        0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3A, 0xFF997D3A, 0xFF987D39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 
        0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947731, 0xFF947731,
  0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 
        0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF856F3B, 0xFF100D07, 0xFF000000, 0xFF6C5B31, 
        0xFFA3894B, 0xFFA38A4B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF6E5C34, 0xFF000000, 0xFF1E190E, 0xFFA0884D, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 
        0xFFAA9256, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC935A, 0xFFAC945B, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 
        0xFFB09962, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A64, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFF63573B, 0xFF000000, 0xFF242016, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 
        0xFFBBA774, 0xFFBCA774, 0xFFBCA775, 0xFFBCA776, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBDA978, 0xFF8D7E5A, 0xFF1C1912, 0xFF000000, 0xFF000000, 0xFF070604, 0xFF4B4430, 
        0xFFB5A274, 0xFF867857, 0xFF000000, 0xFF262218, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AD7E, 0xFF766A4D, 0xFF000000, 0xFF16140F, 0xFF4E4633, 0xFF0A0907, 
        0xFF000000, 0xFF000000, 0xFF020201, 0xFF040403, 0xFF12100C, 0xFF413B2B, 0xFF7A6E51, 0xFFAD9B73, 0xFFC4B082, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B184, 0xFFC4B183, 0xFFC5B183, 
        0xFFC5B184, 0xFFC5B184, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B184, 0xFFC5B284, 0xFFC5B284, 0xFFC4B283, 0xFFC4B184, 0xFFC4B183, 0xFFC5B183, 0xFFC4B183, 0xFFC4B183, 0xFFC0AD80, 0xFF968864, 0xFF5E553E, 0xFF27241A, 0xFF060504, 0xFF030202, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF232017, 0xFF6B6046, 0xFFAB9A71, 0xFFBFAB7E, 0xFFC1AE7F, 0xFFC3AF80, 0xFFC2AF80, 0xFFB7A578, 0xFF060604, 0xFF000000, 0xFFA8976E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7E, 0xFFC2AE7E, 0xFFC1AE7E, 0xFFC1AD7E, 
        0xFFC1AD7E, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFBEAB7C, 0xFF5B523B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0B08, 0xFF74674A, 0xFFBBA777, 0xFFBEAA79, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 
        0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFB9A471, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 
        0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 
        0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945B, 0xFFAC9459, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF352D19, 0xFF000000, 0xFF4C4125, 0xFFA68D50, 
        0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF6C5A31, 0xFF000000, 0xFF100D07, 0xFF856F3B, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9E8343, 0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997C39, 0xFF997D39, 0xFF987C39, 0xFF987B37, 0xFF977B37, 
        0xFF977B36, 0xFF977A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731,
  0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967935, 0xFF967935, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987C39, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 
        0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF9D8446, 0xFF2D2614, 0xFF000000, 0xFF39301A, 0xFFA3894A, 
        0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF806C3D, 0xFF000000, 0xFF0C0A06, 0xFF847140, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 
        0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 
        0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB5A06A, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFF423A27, 0xFF000000, 0xFF403927, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA674, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFB8A575, 0xFF847654, 0xFF2F2A1E, 0xFF000000, 0xFF000000, 0xFF191610, 0xFF534A35, 0xFFA7966C, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFB8A577, 0xFF1F1C14, 0xFF000000, 0xFF90815D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFBEAB7D, 0xFFA2926A, 0xFF7E7153, 0xFF3B3527, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0B08, 
        0xFF28241A, 0xFF463F2E, 0xFF75694E, 0xFFA4946D, 0xFFC3B082, 0xFFC4B082, 0xFFC4B183, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B183, 0xFFC5B183, 0xFFC5B184, 0xFFC4B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B385, 0xFFC5B285, 
        0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B284, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC4B184, 0xFFC5B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFBAA87C, 0xFF8B7E5D, 
        0xFF5E553F, 0xFF353023, 0xFF1A1811, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF262219, 0xFF625941, 0xFF928461, 0xFFB6A478, 0xFF8A7C5B, 0xFF000000, 0xFF2A251B, 0xFFBFAC7E, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7E, 
        0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC1AD7D, 0xFF5E543D, 0xFF000000, 0xFF221F16, 0xFF272319, 0xFF000000, 0xFF000000, 0xFF1B1811, 0xFF76694C, 0xFFB09E70, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEAA78, 0xFFBEA977, 
        0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 
        0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 
        0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 
        0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFFA38A50, 0xFF221D10, 0xFF000000, 0xFF675731, 
        0xFFA68D4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894A, 0xFF4B3F22, 0xFF000000, 0xFF2D2614, 0xFF9E8446, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7E3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 
        0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947731,
  0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 
        0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF4A3E21, 0xFF000000, 0xFF000000, 0xFF18140B, 0xFF63532D, 
        0xFFA3894C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF927C46, 0xFF1B170D, 0xFF000000, 0xFF6B5B34, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 
        0xFFAA9257, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19962, 
        0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C66, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 
        0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFF1A1710, 0xFF000000, 0xFF574D34, 0xFFB9A470, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA776, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBDA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFF887956, 0xFF2F2A1E, 0xFF040402, 0xFF000000, 0xFF0B0A07, 0xFF6D6146, 0xFFA7966B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7D, 
        0xFFC1AC7D, 0xFFC0AC7C, 0xFF695E44, 0xFF000000, 0xFF272319, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFAF9E73, 0xFF6C6247, 0xFF363023, 0xFF14120D, 0xFF000000, 0xFF000000, 0xFF070605, 0xFF3E3829, 0xFF786C50, 0xFF9D8D68, 
        0xFFB6A478, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B385, 0xFFC5B285, 0xFFC5B285, 
        0xFFC5B385, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC5B385, 0xFFC5B385, 0xFFC5B385, 0xFFC5B285, 0xFFC5B385, 0xFFC6B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 
        0xFFC5B284, 0xFFC0AE81, 0xFFA99971, 0xFF8E815F, 0xFF605640, 0xFF221F17, 0xFF000000, 0xFF000000, 0xFF060504, 0xFF262219, 0xFF1F1C14, 0xFF000000, 0xFF75694D, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AE7F, 
        0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7F, 0xFFB5A376, 0xFF080705, 0xFF000000, 0xFF958661, 0xFFB4A174, 0xFF7C6F50, 0xFF211D15, 0xFF000000, 0xFF000000, 0xFF231F16, 0xFF716549, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA979, 
        0xFFBEAA78, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA976, 0xFFBDA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A471, 
        0xFFB9A370, 0xFFB8A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 
        0xFFB39D67, 0xFFB39C65, 0xFFB39C65, 0xFFB29B65, 0xFFB29C64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFF887443, 0xFF0D0B06, 0xFF050402, 
        0xFF776539, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFF9B8247, 0xFF3E341C, 0xFF000000, 0xFF000000, 0xFF4A3E21, 0xFFA28748, 0xFFA18747, 0xFFA18747, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 
        0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987B38, 
        0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957933, 0xFF947833, 0xFF947832,
  0xFF947732, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 
        0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFF726134, 0xFF000000, 0xFF0C0A05, 0xFF131009, 0xFF000000, 0xFF010100, 
        0xFF41371E, 0xFFA0864B, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA48A4E, 0xFF3B311C, 0xFF000000, 0xFF4D4125, 0xFFA78E51, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 
        0xFFAB9258, 0xFFAB9358, 0xFFAC9359, 0xFFAB945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09861, 0xFFB09962, 0xFFB19962, 0xFFB19A62, 
        0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D68, 0xFFB59E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB6A16C, 0xFFB7A16D, 
        0xFFB7A26D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB5A06D, 0xFF000000, 0xFF000000, 0xFF443C29, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEA979, 0xFFBEAA79, 0xFFB09E70, 0xFF3A3425, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050403, 0xFFB09D71, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AC7D, 0xFFC1AD7D, 
        0xFFC1AD7D, 0xFFC1AD7E, 0xFFA19169, 0xFF15130D, 0xFF010100, 0xFF8F805D, 0xFFC2AE7F, 0xFFC2AF80, 0xFF9A8B65, 0xFF3B3527, 0xFF060604, 0xFF010101, 0xFF000000, 0xFF010101, 0xFF342F22, 0xFF857859, 0xFFBAA87C, 0xFFC1AD80, 0xFFC3B082, 0xFFC4B183, 
        0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B183, 0xFFC5B184, 0xFFC5B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B385, 0xFFC6B385, 0xFFC6B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC6B387, 0xFFC6B486, 0xFFC6B486, 0xFFC6B486, 0xFFC6B486, 0xFFC6B487, 0xFFC6B387, 0xFFC6B486, 0xFFC6B486, 0xFFC6B386, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC6B385, 0xFFC6B385, 0xFFC5B385, 0xFFC5B385, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B284, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC4B284, 0xFFC3B182, 0xFFC2AF81, 0xFFA99971, 0xFF5F563F, 0xFF14120D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF16140E, 0xFF6A5F46, 0xFFB9A77A, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF80, 
        0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF5F553E, 0xFF000000, 0xFF2E291E, 0xFFB9A679, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC0AC7C, 0xFF796D4E, 0xFF0C0B08, 0xFF000000, 0xFF010100, 0xFF1F1C14, 0xFF9B8B64, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBFAA79, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 
        0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB5A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E67, 0xFFB49D67, 
        0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB39C65, 0xFFB39B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 
        0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAB9459, 0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99056, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA78F52, 0xFFA78E52, 0xFF6B5B34, 0xFF000000, 
        0xFF1A160C, 0xFF927C45, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFF87723E, 0xFF19150B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF736034, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 
        0xFF9F8544, 0xFF9F8443, 0xFF9F8343, 0xFF9E8342, 0xFF9E8341, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 
        0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957832,
  0xFF957832, 0xFF957834, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 
        0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8341, 0xFF9E8343, 0xFF9E8343, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFF937A41, 0xFF141109, 0xFF000000, 0xFF5D4D2A, 0xFFA3894B, 0xFF39301A, 0xFF030301, 
        0xFF000000, 0xFF221D10, 0xFF877240, 0xFFA58C4E, 0xFFA58C4F, 0xFF61522E, 0xFF000000, 0xFF2C2515, 0xFFA78D51, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9257, 
        0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09861, 0xFFB09961, 0xFFB09A62, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29A64, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFF7C6D4B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF928259, 0xFFAC9869, 0xFFA49164, 0xFF7B6D4B, 0xFF80714E, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 
        0xFFBDA877, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFB09E70, 0xFF6C6145, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF373123, 0xFF887A57, 0xFF1B1811, 0xFF000000, 0xFF48402E, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 
        0xFFC1AD7E, 0xFFC2AD7E, 0xFFC2AE7F, 0xFF413A2A, 0xFF000000, 0xFF2F2A1F, 0xFF786D4F, 0xFF211E16, 0xFF000000, 0xFF000000, 0xFF100F0B, 0xFF2D281D, 0xFF6B6147, 0xFFB4A278, 0xFFC4B082, 0xFFC4B082, 0xFFC4B183, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 
        0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B385, 0xFFC5B285, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 
        0xFFC6B387, 0xFFC6B486, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 
        0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC6B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC5B385, 0xFFC6B285, 0xFFC6B385, 0xFFC5B285, 
        0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC4B283, 0xFFC4B183, 0xFFC4B183, 0xFF928462, 0xFF463F2F, 0xFF1A1711, 0xFF030302, 0xFF000000, 0xFF010101, 0xFF4D4533, 0xFF968763, 0xFFB6A478, 0xFFC3AF81, 0xFFC2AF80, 
        0xFFC3AF80, 0xFFC2AF80, 0xFFB8A679, 0xFF0C0B08, 0xFF000000, 0xFF75694D, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFB8A477, 0xFF4A4230, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF554C36, 0xFFA7966C, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 
        0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF473C22, 
        0xFF000000, 0xFF3D331D, 0xFFA3894E, 0xFFA58C4F, 0xFFA58C4F, 0xFF9F864B, 0xFF6A5931, 0xFF070603, 0xFF000000, 0xFF100D07, 0xFF66552F, 0xFF584A28, 0xFF000000, 0xFF141109, 0xFF937A41, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA08546, 0xFFA08545, 
        0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9C8240, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 
        0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957833, 0xFF947833,
  0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 
        0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA08547, 0xFF42381E, 0xFF000000, 0xFF342C17, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFF6A5931, 
        0xFF120F08, 0xFF000000, 0xFF0B0905, 0xFF5F502C, 0xFF6F5E35, 0xFF000000, 0xFF121009, 0xFF907A46, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 
        0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAE975F, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09960, 0xFFB09961, 0xFFB09A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 
        0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB9A36F, 0xFFB8A36F, 0xFFB9A370, 0xFF302B1D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060504, 0xFF262217, 0xFF0B0A07, 0xFF231F16, 0xFF887954, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 
        0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFF7B6E4E, 0xFF242017, 0xFF000000, 0xFF000000, 0xFF090806, 0xFF000000, 0xFF5C523B, 0xFFC0AC7C, 0xFF675D43, 0xFF000000, 0xFF0C0A07, 0xFF968762, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7E, 
        0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF7F, 0xFF625840, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF29251B, 0xFF685E45, 0xFF9C8C67, 0xFFC3AF81, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B284, 
        0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC6B387, 0xFFC7B387, 0xFFC7B487, 0xFFC7B487, 0xFFC7B486, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 
        0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B587, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 
        0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B386, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC5B385, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFB2A177, 0xFF847858, 0xFF4C4432, 0xFF0C0B08, 0xFF000000, 0xFF000000, 0xFF302B20, 0xFF6B6046, 0xFFB2A076, 
        0xFFC3B081, 0xFFC3AF81, 0xFF6D6247, 0xFF000000, 0xFF191710, 0xFFAB9B71, 0xFFC2AF7F, 0xFFC2AE7E, 0xFFC1AE7F, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFF6A5F45, 0xFF000000, 0xFF030201, 0xFF020201, 0xFF000000, 0xFF15130D, 0xFF655A41, 0xFFBCA879, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA875, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 
        0xFFBAA572, 0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 
        0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 
        0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78F52, 0xFFA58C51, 
        0xFF312917, 0xFF000000, 0xFF5B4D2B, 0xFFA68C4F, 0xFF907A45, 0xFF382F1A, 0xFF000000, 0xFF000000, 0xFF332B18, 0xFF86713E, 0xFFA3894B, 0xFFA3894A, 0xFF332B17, 0xFF000000, 0xFF43381E, 0xFF9F8547, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 
        0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C8140, 0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 
        0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833,
  0xFF957933, 0xFF967834, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 
        0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8445, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF786535, 0xFF000000, 0xFF0F0D07, 0xFF9E8547, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 
        0xFF917B45, 0xFF262012, 0xFF000000, 0xFF030301, 0xFF050402, 0xFF000000, 0xFF6F5E36, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 
        0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19A63, 0xFFB19A64, 0xFFB29B64, 
        0xFFB29C64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB6A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFF9E8C5F, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060504, 0xFF766949, 0xFFB29E6E, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA878, 
        0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFAF9C6F, 0xFF322C20, 0xFF020201, 0xFF000000, 0xFF090806, 0xFF8C7D5A, 0xFF766A4C, 0xFF040402, 0xFF080705, 0xFF998A63, 0xFFC1AD7D, 0xFF17150F, 0xFF000000, 0xFF413A2A, 0xFFBDAB7D, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFFC2AF80, 0xFF8C7E5C, 0xFF29251B, 0xFF060604, 0xFF000000, 0xFF000000, 0xFF3B3527, 0xFF9A8B66, 0xFFBCA97C, 0xFFC3AF81, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B183, 0xFFC5B284, 0xFFC5B184, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B284, 
        0xFFC5B385, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 
        0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 
        0xFFC8B589, 0xFFC7B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B486, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC5B285, 0xFFC6B285, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC0AC80, 0xFFB2A176, 0xFF70654B, 0xFF100F0B, 0xFF000000, 0xFF010101, 0xFF0D0C09, 
        0xFF524A37, 0xFFAB9A71, 0xFF302C20, 0xFF000000, 0xFF544B37, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFA5956C, 0xFF181610, 0xFF000000, 0xFF48412F, 0xFFA19169, 0xFF1B1811, 0xFF000000, 0xFF000000, 0xFF1E1A13, 
        0xFF9B8A63, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA875, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA573, 0xFFBBA673, 
        0xFFBBA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 
        0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 
        0xFFAE975E, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 
        0xFF8E7845, 0xFF141109, 0xFF000000, 0xFF5E502D, 0xFF1B170D, 0xFF000000, 0xFF000000, 0xFF544727, 0xFF9D8549, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF9E8547, 0xFF0F0C06, 0xFF000000, 0xFF796535, 0xFFA18748, 0xFFA18748, 0xFFA18646, 0xFFA08646, 
        0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 
        0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957833,
  0xFF957934, 0xFF967934, 0xFF967935, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C8140, 0xFF9C8240, 0xFF9D8241, 
        0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF9A8144, 0xFF080703, 0xFF000000, 0xFF7A6737, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 
        0xFFA58B4E, 0xFFA58B4E, 0xFF4C4024, 0xFF000000, 0xFF000000, 0xFF423820, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9256, 0xFFAA9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09960, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 
        0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 
        0xFFB9A36F, 0xFFB9A36F, 0xFFB9A470, 0xFF4D442E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080704, 0xFF3B3424, 0xFFAE9A6C, 0xFFBBA774, 0xFFBBA774, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 
        0xFFBEA978, 0xFFB8A475, 0xFF7E7150, 0xFF0A0906, 0xFF000000, 0xFF060604, 0xFF030201, 0xFF000000, 0xFF9D8C65, 0xFFBEAA7B, 0xFF252118, 0xFF000000, 0xFF3E3728, 0xFFC1AD7D, 0xFF988863, 0xFF000000, 0xFF000000, 0xFF938460, 0xFFBBA77A, 0xFF8D7F5D, 
        0xFF232017, 0xFF000000, 0xFF000000, 0xFF0F0D0A, 0xFF484130, 0xFFA7976E, 0xFFC3B082, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC6B285, 0xFFC6B386, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B488, 0xFFC7B588, 0xFFC8B588, 0xFFC7B589, 0xFFC7B589, 0xFFC7B589, 0xFFC7B589, 
        0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B689, 0xFFC8B689, 0xFFC8B689, 0xFFC8B689, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B689, 0xFFC8B689, 0xFFC8B689, 
        0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B589, 0xFFC8B589, 0xFFC7B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 
        0xFFC7B487, 0xFFC7B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC5B385, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B283, 0xFFC5B184, 0xFF7E7254, 0xFF252219, 0xFF070605, 
        0xFF000000, 0xFF000000, 0xFF010101, 0xFF020201, 0xFFB09F74, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC0AC7E, 0xFF5E543D, 0xFF000000, 0xFF0C0B08, 0xFFB09E72, 0xFFB7A477, 0xFF110F0B, 0xFF000000, 0xFF080705, 0xFF000000, 
        0xFF000000, 0xFF5E543C, 0xFFB3A072, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA673, 
        0xFFBBA673, 0xFFBAA573, 0xFFBAA571, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 
        0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 
        0xFFA78F52, 0xFF685832, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF120F08, 0xFF756237, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF7A6637, 0xFF000000, 0xFF080603, 0xFF9B8145, 0xFFA18748, 0xFFA18647, 0xFFA08646, 
        0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8444, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 
        0xFF997D39, 0xFF987C38, 0xFF987C37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF957934,
  0xFF957934, 0xFF967935, 0xFF967A35, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987B38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 
        0xFF9E8341, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF322916, 0xFF000000, 0xFF40351D, 0xFFA18749, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 
        0xFFA58B4E, 0xFFA58C4F, 0xFF716036, 0xFF000000, 0xFF282213, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9256, 0xFFAB9257, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 
        0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB9A36F, 
        0xFFB9A370, 0xFFB9A471, 0xFF94835A, 0xFF0D0C08, 0xFF000000, 0xFF000000, 0xFF383122, 0xFF8B7B55, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBEAA78, 0xFFBEAA79, 
        0xFF9C8C63, 0xFF413A29, 0xFF000000, 0xFF000000, 0xFF352F22, 0xFF847654, 0xFF332E21, 0xFF000000, 0xFF2B271C, 0xFFC0AC7D, 0xFF91825E, 0xFF000000, 0xFF050403, 0xFF8E805C, 0xFFC1AE7E, 0xFF504834, 0xFF000000, 0xFF1B1812, 0xFF383225, 0xFF000000, 
        0xFF000000, 0xFF232017, 0xFF665C43, 0xFFAC9B72, 0xFFC4B082, 0xFFC4B183, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B184, 0xFFC5B285, 0xFFC5B284, 0xFFC5B285, 0xFFC5B386, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B387, 
        0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC7B486, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC7B588, 0xFFC7B589, 0xFFC7B589, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B589, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68B, 0xFFC8B68A, 0xFFC8B68B, 0xFFC8B68B, 0xFFC8B68B, 0xFFC8B68A, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 
        0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC6B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC6B386, 0xFFC6B385, 0xFFC5B285, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B183, 0xFF8A7C5C, 
        0xFF463F2F, 0xFF080705, 0xFF000000, 0xFF040403, 0xFF59503B, 0xFFA0906B, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC3AF80, 0xFFA8986F, 0xFF060604, 0xFF000000, 0xFF776B4D, 0xFFC1AE7E, 0xFF554C37, 0xFF000000, 0xFF16140E, 0xFF8C7E5B, 0xFF3A3425, 
        0xFF000000, 0xFF000000, 0xFF2A261B, 0xFF897B58, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA673, 
        0xFFBBA673, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 
        0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 
        0xFFA88F52, 0xFFA78E52, 0xFF433921, 0xFF000000, 0xFF1A160C, 0xFF957F48, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA1874A, 0xFF40351D, 0xFF000000, 0xFF322A16, 0xFFA28748, 0xFFA18748, 0xFFA18647, 
        0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 
        0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF967A35, 0xFF967935, 0xFF967934,
  0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 
        0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF66552D, 0xFF030201, 0xFF0C0A05, 0xFF967E44, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58C4F, 0xFF927B46, 0xFF020201, 0xFF0E0C07, 0xFF8C7644, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE955C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 
        0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 
        0xFFB9A471, 0xFFBAA471, 0xFF231E15, 0xFF000000, 0xFF16140D, 0xFF897954, 0xFFB5A06F, 0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEA979, 0xFFBEAA79, 0xFF726648, 
        0xFF12100B, 0xFF000000, 0xFF050503, 0xFF76694B, 0xFFB6A375, 0xFFC0AC7C, 0xFF837554, 0xFF030302, 0xFF040402, 0xFF7A6D4F, 0xFFC1AD7E, 0xFF4A4230, 0xFF000000, 0xFF28241A, 0xFFC2AE7F, 0xFF73684C, 0xFF010101, 0xFF000000, 0xFF000000, 0xFF1B1812, 
        0xFF837657, 0xFFB3A277, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B184, 0xFFC5B184, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC6B487, 0xFFC7B487, 
        0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 
        0xFFC9B68B, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 
        0xFFC7B589, 0xFFC8B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC5B385, 0xFFC5B285, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 
        0xFFC0AD80, 0xFFA3936D, 0xFF4D4633, 0xFF000000, 0xFF000000, 0xFF0E0D09, 0xFF4A4231, 0xFFB5A378, 0xFFC3B081, 0xFFC3B081, 0xFF3D3728, 0xFF000000, 0xFF302B20, 0xFFBEAB7C, 0xFFA2926A, 0xFF0F0E0A, 0xFF000000, 0xFF71654A, 0xFFC1AD7D, 0xFF433C2B, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF090806, 0xFF504834, 0xFFBCA878, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBCA876, 0xFFBDA876, 0xFFBCA875, 0xFFBCA775, 0xFFBCA775, 
        0xFFBBA774, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 
        0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 
        0xFFAF985F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAA9258, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 
        0xFFA88F53, 0xFFA78F52, 0xFFA38B50, 0xFF231E11, 0xFF000000, 0xFF78663A, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF967E44, 0xFF0C0A05, 0xFF030201, 0xFF66552D, 0xFFA18748, 0xFFA18747, 
        0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 
        0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967935, 0xFF967935,
  0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8242, 
        0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF917940, 0xFF1B160C, 0xFF000000, 0xFF705F33, 0xFFA3894A, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA68C4F, 0xFF1B170D, 0xFF010100, 0xFF5D4F2D, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA98F54, 0xFFA99054, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 
        0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 
        0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 
        0xFFB09B6B, 0xFF211D14, 0xFF050403, 0xFF5C5239, 0xFFBBA673, 0xFFBBA673, 0xFFBBA774, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFB8A475, 0xFF453E2C, 0xFF000000, 
        0xFF000000, 0xFF1F1C14, 0xFFA4946A, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFF302B1F, 0xFF000000, 0xFF2B271C, 0xFFB4A176, 0xFFB5A377, 0xFF0C0A07, 0xFF000000, 0xFF1C1A13, 0xFF000000, 0xFF000000, 0xFF0C0B08, 0xFF6F6449, 0xFFC3B082, 
        0xFFC4B082, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 
        0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78C, 
        0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 
        0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC5B386, 0xFFC5B285, 0xFFC5B285, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B183, 0xFFAE9D74, 0xFF3A3427, 0xFF030202, 0xFF000000, 0xFF060504, 0xFF74684C, 0xFF8B7D5C, 0xFF000000, 0xFF020201, 0xFF8B7D5B, 0xFFC1AE7F, 0xFF4C4432, 0xFF000000, 0xFF232017, 0xFFC2AE7F, 0xFF92835F, 0xFF0A0906, 
        0xFF020201, 0xFF5A503A, 0xFF403929, 0xFF030201, 0xFF000000, 0xFF29241A, 0xFFAB996E, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB5A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 
        0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA89054, 
        0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF8C7744, 0xFF060503, 0xFF030301, 0xFF9E854C, 0xFFA68C50, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF6F5E33, 0xFF000000, 0xFF1B160C, 0xFF917940, 0xFFA18748, 
        0xFFA18747, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935,
  0xFF967A35, 0xFF977A36, 0xFF977A37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF9A7D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 
        0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA18646, 0xFFA18648, 0xFFA18748, 0xFF4A3E21, 0xFF000000, 0xFF3D341C, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 
        0xFF534628, 0xFF000000, 0xFF2B2515, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAB9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD965D, 0xFFAE975D, 0xFFAE975E, 0xFFAE975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB09A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 
        0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 
        0xFF766948, 0xFF3C3525, 0xFF9C8A60, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFF8E7F5A, 0xFF1A1710, 0xFF000000, 0xFF0B0A07, 
        0xFF5C533B, 0xFFC0AB7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFA8976E, 0xFF030201, 0xFF000000, 0xFF776B4E, 0xFFA5946C, 0xFF332E22, 0xFF000000, 0xFF000000, 0xFF1A1811, 0xFF625941, 0xFFBBA97B, 0xFFC4B082, 0xFFC4B182, 
        0xFFC4B182, 0xFFC4B183, 0xFFC4B283, 0xFFC4B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B385, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 
        0xFFC8B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 
        0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B88C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB78C, 0xFFCAB78C, 
        0xFFCAB88C, 0xFFCAB78C, 0xFFCAB78C, 0xFFCAB78C, 0xFFC9B78C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68B, 0xFFC8B68A, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B587, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC5B385, 
        0xFFC5B285, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFF928462, 0xFF3B3628, 0xFF030302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3E3829, 0xFFC3B081, 0xFF9F8E68, 0xFF000000, 0xFF000000, 0xFF9E8E67, 0xFFBEAB7D, 0xFF433C2C, 0xFF000000, 
        0xFF1D1A13, 0xFFBBA87A, 0xFFC1AD7D, 0xFF76694C, 0xFF181610, 0xFF000000, 0xFF090805, 0xFF796C4E, 0xFFBCA878, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 
        0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 
        0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF574A2A, 0xFF000000, 0xFF2B2515, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894A, 0xFF3D331B, 0xFF000000, 0xFF4B3F21, 0xFFA18748, 
        0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9C8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 
        0xFF997D3B, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35,
  0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C8140, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 
        0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18748, 0xFF7B6737, 0xFF000000, 0xFF16130A, 0xFF937C43, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF897341, 
        0xFF070603, 0xFF070603, 0xFF99814A, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 
        0xFFAE955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB29A63, 0xFFB29B63, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 
        0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFB9A471, 0xFFBAA572, 
        0xFFB7A270, 0xFFBAA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFF5F553C, 0xFF090806, 0xFF000000, 0xFF000000, 0xFF0F0D09, 
        0xFFA6956B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF6A5F45, 0xFF000000, 0xFF0F0D0A, 0xFF191610, 0xFF000000, 0xFF030302, 0xFF645A42, 0xFFAC9B72, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 
        0xFFC8B689, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B386, 0xFFC6B386, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B285, 0xFFC6B285, 0xFFC5B385, 0xFFC5B284, 0xFFBFAD80, 0xFF908261, 0xFF2E291E, 0xFF000000, 0xFF000000, 0xFF242118, 0xFF9D8E69, 0xFF252118, 0xFF000000, 0xFF574E39, 0xFFC2AF80, 0xFF8A7C5B, 0xFF000000, 0xFF000000, 
        0xFF90815E, 0xFFC2AE7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFA7956C, 0xFF3C3627, 0xFF000000, 0xFF020201, 0xFF443D2B, 0xFFBAA677, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBFAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 
        0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB7A06C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 
        0xFFB09961, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 
        0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFFA38B50, 0xFF201B0F, 0xFF000000, 0xFF5E502D, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA3894B, 0xFF937B42, 0xFF16120A, 0xFF000000, 0xFF7C6738, 
        0xFFA18748, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF967A36,
  0xFF977A36, 0xFF977A36, 0xFF987B37, 0xFF987C37, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7D3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 
        0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA08647, 0xFF110E07, 0xFF010100, 0xFF63532C, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4E, 0xFFA58C4F, 0xFF252012, 
        0xFF000000, 0xFF7B683B, 0xFFA78E51, 0xFFA78E53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9257, 0xFFAA9257, 0xFF9A844F, 0xFF3C331F, 0xFF9E8852, 0xFFAC9359, 0xFFAC945A, 0xFFAC955B, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 
        0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A16B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 
        0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA78, 0xFFB8A475, 0xFF302B1F, 0xFF000000, 0xFF000000, 0xFF4D4531, 0xFF423B2A, 0xFF000000, 
        0xFF312C20, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF988964, 0xFF060504, 0xFF000000, 0xFF000000, 0xFF373124, 0xFFAE9D73, 0xFFC4B082, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98D, 0xFFCBB98E, 0xFFCAB98E, 0xFFCBB88D, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 
        0xFFC6B387, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC5B285, 0xFFC5B284, 0xFFC5B184, 0xFFC5B284, 0xFF786C50, 0xFF060504, 0xFF000000, 0xFF010101, 0xFF000000, 0xFF191610, 0xFFA8976F, 0xFFC3B081, 0xFF221E16, 0xFF000000, 0xFF453E2D, 
        0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7E, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFF685D43, 0xFF000000, 0xFF000000, 0xFF15130D, 0xFFAA986D, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBDA877, 0xFFBDA877, 
        0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 
        0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29A64, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 
        0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 
        0xFFA99055, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF957E49, 0xFF000000, 0xFF110E08, 0xFF907A45, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF62522C, 0xFF010100, 0xFF110E08, 
        0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C803F, 0xFF9C803E, 0xFF9C803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 
        0xFF9A7E3C, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C38, 0xFF987C38, 0xFF977B38, 0xFF977B36, 0xFF967A36,
  0xFF977A36, 0xFF977B37, 0xFF977B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 
        0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFF4E4223, 0xFF000000, 0xFF282212, 0xFFA08649, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF584A2A, 0xFF000000, 
        0xFF3F361F, 0xFFA58C50, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9258, 0xFF4D4228, 0xFF2E2718, 0xFFA58D55, 0xFFAC945A, 0xFFAC945B, 0xFFAD945B, 0xFFAD955C, 0xFFAD955C, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 
        0xFFB59E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB5A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA571, 0xFFBAA571, 0xFFBAA572, 0xFFBBA673, 
        0xFFBBA673, 0xFFBBA673, 0xFFBCA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA78, 0xFF998961, 0xFF201C14, 0xFF000000, 0xFF0D0C08, 0xFF706347, 0xFFC0AB7B, 0xFFB09D71, 0xFF1B1811, 
        0xFF000000, 0xFF5D533C, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC2AE7E, 0xFFB09F73, 0xFF5C533D, 0xFF000000, 0xFF000000, 0xFF1E1B14, 0xFF7B6F51, 0xFFC4B082, 0xFFC4B082, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B284, 0xFFC5B284, 0xFFC5B285, 
        0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 
        0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB88E, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B88C, 
        0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 
        0xFFC6B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B285, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFBAA77C, 0xFF4B4432, 0xFF090806, 0xFF000000, 0xFF1A1711, 0xFF978864, 0xFF59503B, 0xFF000000, 0xFF0D0B08, 0xFFAA9970, 
        0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFF242017, 0xFF000000, 0xFF000000, 0xFF080705, 0xFF847654, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA877, 
        0xFFBDA877, 0xFFBDA877, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 
        0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 
        0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAC9359, 0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 
        0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF665632, 0xFF000000, 0xFF3A311C, 0xFFA68C50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF9F8649, 0xFF282112, 0xFF000000, 
        0xFF4F4223, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 
        0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36,
  0xFF977A37, 0xFF977B37, 0xFF987B38, 0xFF987C39, 0xFF987D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B803D, 0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 
        0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF88713C, 0xFF0D0B06, 0xFF000000, 0xFF362D18, 0xFF9D8448, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF846F3E, 0xFF040302, 0xFF100D07, 
        0xFF907B46, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFF8B7747, 0xFF000000, 0xFF615332, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAD965D, 0xFFAD965D, 
        0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 
        0xFFB59E69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 
        0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBDA978, 0xFFBEAA78, 0xFFBEAA79, 0xFF776A4B, 0xFF11100B, 0xFF000000, 0xFF232017, 0xFF95845F, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AD7D, 0xFF857856, 
        0xFF060503, 0xFF030302, 0xFF837655, 0xFFC2AE7F, 0xFFC2AF7F, 0xFF827656, 0xFF221E16, 0xFF000000, 0xFF050403, 0xFF645B42, 0xFFB3A277, 0xFFC4B182, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B285, 
        0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B58A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 
        0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB88E, 0xFFCAB98D, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 
        0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFF938562, 0xFF322D21, 0xFF000000, 0xFF0A0907, 0xFF010101, 0xFF030202, 0xFF685E45, 0xFFC2AF80, 
        0xFFC3B081, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7F, 0xFF48412F, 0xFF000000, 0xFF1E1B13, 0xFF342F22, 0xFF000000, 0xFF060503, 0xFF5C523B, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 
        0xFFBEA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26D, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A62, 
        0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 
        0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA78F53, 0xFFA48B50, 0xFF322A18, 0xFF000000, 0xFF6A5A33, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF564827, 0xFF000000, 
        0xFF0D0B06, 0xFF88723D, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 
        0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987D39, 0xFF987C38, 0xFF977B38, 0xFF977B36,
  0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 
        0xFF9F8544, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18748, 0xFFA28748, 0xFF3E341C, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF0F0D07, 0xFF685730, 0xFFA48A4D, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF9F874C, 0xFF2C2515, 0xFF000000, 0xFF60512E, 
        0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFF201B10, 0xFF050402, 0xFF76663E, 0xFFAC945B, 0xFFAC955B, 0xFFAD955B, 0xFFAE965C, 0xFFAE965D, 0xFFAE965D, 
        0xFFAF975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 
        0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFF564D37, 0xFF020201, 0xFF000000, 0xFF403929, 0xFFB5A274, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AD7D, 
        0xFF534B36, 0xFF000000, 0xFF1B1811, 0xFF9F9068, 0xFF433D2C, 0xFF010101, 0xFF000000, 0xFF2A261C, 0xFFAA9970, 0xFFC3B081, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 
        0xFFC6B386, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 
        0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88E, 0xFFCAB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCCBA90, 
        0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA90, 0xFFCCBA8F, 0xFFCBBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCAB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 
        0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC5B385, 0xFFC5B285, 0xFFC5B284, 0xFFBEAC7F, 0xFF75694E, 0xFF040403, 0xFF000000, 0xFF070605, 0xFF837657, 0xFFC3B081, 
        0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFF75694D, 0xFF030201, 0xFF050403, 0xFF7C6F50, 0xFFBEAA7B, 0xFF645A41, 0xFF000000, 0xFF000000, 0xFF332E21, 0xFFBDA879, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA979, 
        0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA472, 0xFFB9A471, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36E, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 
        0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9157, 
        0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF826E3F, 0xFF0B0905, 0xFF090704, 0xFF978048, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFF9B8248, 0xFF382F1A, 0xFF050402, 0xFF000000, 
        0xFF000000, 0xFF3E341C, 0xFFA18748, 0xFFA18748, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C37, 0xFF977B37,
  0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D39, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 
        0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF816C39, 0xFF000000, 0xFF1B170C, 0xFF3F351C, 0xFF0D0B06, 0xFF000000, 0xFF000000, 0xFF251F11, 0xFF84703E, 0xFFA3894D, 0xFFA58C4F, 0xFF6C5B33, 0xFF000000, 0xFF252012, 0xFFA78E51, 
        0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFF695A36, 0xFF020201, 0xFF080604, 0xFF7A6940, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965C, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB19B64, 0xFFB29B64, 0xFFB39B65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 
        0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFB4A172, 0xFF504732, 0xFF000000, 0xFF040402, 0xFF504733, 0xFFBEA97A, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AC7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 
        0xFFC2AE7F, 0xFF221F16, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0D0B08, 0xFF645942, 0xFFC3B081, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B283, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 
        0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88E, 0xFFCAB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 
        0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA91, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 
        0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA91, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 
        0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC6B487, 0xFFC6B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B385, 0xFFC6B385, 0xFFC5B285, 0xFFC5B284, 0xFFC5B284, 0xFFA0916C, 0xFF242118, 0xFF000000, 0xFF000000, 0xFF665C44, 
        0xFFB9A77B, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFA3936B, 0xFF16140E, 0xFF000000, 0xFF423C2B, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFC1AD7D, 0xFF776B4D, 0xFF0C0A07, 0xFF000000, 0xFF2C271C, 0xFFAA986D, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 
        0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA675, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26F, 
        0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945B, 0xFFAC935A, 0xFFAB9359, 0xFF867346, 0xFF3D341F, 0xFFA89056, 
        0xFFAA9156, 0xFFA99055, 0xFFA99155, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF483D22, 0xFF000000, 0xFF3B321C, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFF9B8349, 0xFF665630, 0xFF040302, 0xFF000000, 0xFF030301, 0xFF19150B, 
        0xFF17130A, 0xFF000000, 0xFF826D3A, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B37,
  0xFF987B38, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 
        0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFF9F8547, 0xFF151209, 0xFF000000, 0xFF61512C, 0xFFA3894A, 0xFF8A743F, 0xFF41361E, 0xFF030301, 0xFF000000, 0xFF050402, 0xFF42381F, 0xFF7E6B3C, 0xFF121009, 0xFF060503, 0xFF947C47, 0xFFA78E52, 
        0xFFA78E53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAB9257, 0xFF9D8651, 0xFF201B10, 0xFF000000, 0xFF060503, 0xFF73633C, 0xFFAC955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 
        0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59E6A, 0xFFB69F6A, 
        0xFFB69F6B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFBAA571, 0xFFBAA572, 0xFFBBA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 
        0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFAB996D, 0xFF3B3425, 0xFF000000, 0xFF080805, 0xFF726649, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AC7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFFC2AE7F, 0xFF4D4633, 0xFF000000, 0xFF000000, 0xFF322D21, 0xFF958763, 0xFFC3B082, 0xFFC4B083, 0xFFC4B183, 0xFFC4B183, 0xFFC5B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 
        0xFFC7B487, 0xFFC7B488, 0xFFC8B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B68B, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCB98F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC91, 0xFFCDBC91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC91, 0xFFCDBC91, 0xFFCDBC92, 0xFFCDBC91, 0xFFCCBC91, 0xFFCDBC91, 
        0xFFCDBC92, 0xFFCDBC91, 0xFFCDBC92, 0xFFCCBB92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCDBB90, 0xFFCCBB91, 0xFFCCBB90, 0xFFCDBA91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCBBA8F, 
        0xFFCBB98F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98D, 0xFFCBB88E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC8B68B, 0xFFC8B68B, 0xFFC9B68A, 
        0xFFC8B68A, 0xFFC8B689, 0xFFC8B58A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B386, 0xFFC5B285, 0xFFC5B285, 0xFFC5B284, 0xFFC0AD80, 0xFF655B43, 0xFF0A0907, 0xFF000000, 
        0xFF312D21, 0xFF9B8C67, 0xFFC3B081, 0xFFC3AF81, 0xFF413B2B, 0xFF000000, 0xFF221E16, 0xFFB8A579, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AD7E, 0xFFC1AD7E, 0xFF8C7E5B, 0xFF181610, 0xFF000000, 0xFF231F16, 0xFF988862, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D66, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 
        0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFF9F8953, 0xFF18150C, 0xFF685935, 
        0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78F53, 0xFFA48B50, 0xFF18140B, 0xFF030201, 0xFF7B693B, 0xFFA68C4F, 0xFF6B5B33, 0xFF221D10, 0xFF000000, 0xFF000000, 0xFF1E190E, 0xFF63532E, 0xFFA18749, 
        0xFF6F5E32, 0xFF000000, 0xFF16120A, 0xFFA18647, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803F, 0xFF9B803E, 
        0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987C38,
  0xFF987C38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3E, 0xFF9B803E, 0xFF9C813E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 
        0xFFA08546, 0xFFA08647, 0xFFA18647, 0xFFA18748, 0xFF514324, 0xFF000000, 0xFF000000, 0xFF0E0B06, 0xFF4C3F23, 0xFFA48A4C, 0xFFA48A4C, 0xFF87723F, 0xFF2D2615, 0xFF000000, 0xFF000000, 0xFF0A0804, 0xFF000000, 0xFF5E502E, 0xFFA78E52, 0xFFA78E52, 
        0xFFA88E53, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9358, 0xFF635533, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5F5132, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 
        0xFFAF985F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFA29167, 0xFF1F1C14, 0xFF000000, 0xFF13110C, 0xFF92835E, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFAF9D73, 
        0xFF322D21, 0xFF020201, 0xFF000000, 0xFF645B42, 0xFFB7A57A, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B284, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 
        0xFFC7B588, 0xFFC8B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98D, 0xFFCAB98E, 0xFFCBB98E, 
        0xFFCBB98F, 0xFFCBBA8E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBB92, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBC92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC92, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98D, 0xFFCBB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC8B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC5B285, 0xFFC5B285, 0xFFC5B285, 0xFF9E8E6A, 0xFF1B1812, 
        0xFF000000, 0xFF0D0C09, 0xFF817456, 0xFF6E6348, 0xFF000000, 0xFF0D0C09, 0xFFA5946C, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7E, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFAA986E, 0xFF2A261B, 0xFF000000, 0xFF0E0C09, 0xFF897B58, 0xFFBFAB7B, 0xFFBFAB7A, 
        0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA673, 0xFFBBA573, 0xFFBAA672, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 
        0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB39D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 
        0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFF655734, 0xFF090804, 
        0xFF9C854F, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF887342, 0xFF000000, 0xFF211C10, 0xFF251F11, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF564928, 0xFF998047, 0xFFA48A4C, 0xFF89733F, 
        0xFF251F11, 0xFF000000, 0xFF000000, 0xFF514424, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 
        0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38,
  0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 
        0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF8C763E, 0xFF141109, 0xFF010100, 0xFF18140B, 0xFF010100, 0xFF000000, 0xFF100E07, 0xFF776538, 0xFFA1884B, 0xFFA58B4E, 0xFF6C5B33, 0xFF0B0905, 0xFF000000, 0xFF1F1B0F, 0xFF978149, 0xFFA78E52, 0xFFA88E52, 
        0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFA08A52, 0xFF050402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF403722, 0xFFA9925A, 0xFFAE965C, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 
        0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39B65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 
        0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA877, 0xFFBEA977, 0xFFBEAA78, 0xFFBEAA78, 0xFFA39267, 0xFF1A1811, 0xFF000000, 0xFF020201, 0xFF6A5F44, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AD7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFA19169, 0xFF181510, 
        0xFF000000, 0xFF0E0D09, 0xFF877A59, 0xFFC4B082, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B486, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 
        0xFFC7B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 
        0xFFCBBA8F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBC92, 
        0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCEBC93, 
        0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 
        0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCBB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFFC5B285, 0xFFC6B285, 0xFFC5B285, 0xFFC5B184, 
        0xFF423C2C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF807354, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFB3A074, 0xFF2F2A1E, 0xFF000000, 0xFF070604, 0xFF857755, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 
        0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 
        0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAC935A, 0xFF96814E, 0xFF000000, 
        0xFF433922, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA68D51, 0xFF463C22, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF302916, 0xFF967F47, 0xFFA58B4E, 0xFF998147, 0xFF4F4224, 0xFF000000, 
        0xFF000000, 0xFF050402, 0xFF010100, 0xFF141109, 0xFF8C763E, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C803F, 0xFF9B803F, 
        0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38,
  0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 
        0xFFA08647, 0xFFA18647, 0xFFA08647, 0xFF504323, 0xFF000000, 0xFF372E19, 0xFFA3894B, 0xFF584A28, 0xFF17130A, 0xFF000000, 0xFF000000, 0xFF382F1A, 0xFF7E6A3B, 0xFFA0884C, 0xFF272012, 0xFF000000, 0xFF6D5C35, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 
        0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFF3A321E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF18150C, 0xFF9E8954, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975E, 0xFFAF9860, 
        0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB09A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06B, 
        0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA675, 0xFFBCA775, 0xFFBCA875, 0xFFBDA876, 0xFFBDA877, 
        0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF92835D, 0xFF17140E, 0xFF000000, 0xFF201D15, 0xFF000000, 0xFF100E0A, 0xFF8F805C, 0xFFC1AC7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC0AC7E, 0xFF766B4D, 0xFF040403, 0xFF000000, 
        0xFF353023, 0xFFAA9970, 0xFFC4B082, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B184, 0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 
        0xFFC8B689, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB78D, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 
        0xFFCCBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBC93, 
        0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCDBB92, 0xFFCCBB91, 
        0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 
        0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC6B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC5B385, 0xFFC5B284, 
        0xFFC5B284, 0xFF73674D, 0xFF0C0B08, 0xFF000000, 0xFF181610, 0xFFA1906B, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFB8A577, 0xFF423B2B, 0xFF000000, 0xFF060604, 0xFF796C4E, 
        0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBBA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 
        0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB59E68, 0xFFB49E67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 
        0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAC955C, 0xFFAC945B, 0xFFAC945A, 0xFFA18A53, 0xFF000000, 
        0xFF0C0A06, 0xFF887445, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF8F7946, 0xFF110E08, 0xFF000000, 0xFF564929, 0xFFA58C4F, 0xFF9C844A, 0xFF63532F, 0xFF15120A, 0xFF000000, 0xFF000000, 
        0xFF2E2715, 0xFF816C3B, 0xFF3B311A, 0xFF000000, 0xFF514424, 0xFFA08647, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C803F, 
        0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7D3B, 0xFF997D3A, 0xFF987D39, 0xFF987C38,
  0xFF987C39, 0xFF987D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08646, 
        0xFFA18647, 0xFFA18748, 0xFF947B42, 0xFF060502, 0xFF000000, 0xFF221D0F, 0xFF89733F, 0xFFA38A4C, 0xFF907943, 0xFF514426, 0xFF010100, 0xFF000000, 0xFF0B0905, 0xFF211C0F, 0xFF000000, 0xFF312917, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 
        0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 0xFF7A683F, 0xFF000000, 0xFF241F13, 0xFF4A3F26, 0xFF090804, 0xFF000000, 0xFF000000, 0xFF816F45, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFAF9860, 0xFFAF9860, 
        0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49E67, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A16C, 
        0xFFB7A16C, 0xFFB7A26D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 
        0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFF867855, 0xFF0F0E0A, 0xFF000000, 0xFF383224, 0xFFAB996D, 0xFF554C36, 0xFF000000, 0xFF0F0E0A, 0xFFA08F67, 0xFFC1AD7E, 0xFFC1AE7F, 0xFFC2AE7F, 0xFFBEAB7D, 0xFF4E4633, 0xFF020201, 0xFF000000, 0xFF5F563F, 
        0xFFBBA87C, 0xFFC3B182, 0xFFC4B182, 0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 0xFFC5B284, 0xFFC5B385, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B689, 
        0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA90, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD95, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD95, 0xFFCEBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 
        0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B385, 
        0xFFC5B285, 0xFFC5B284, 0xFF9F8F6A, 0xFF1B1812, 0xFF000000, 0xFF191610, 0xFF968863, 0xFFC4B082, 0xFFC3AF81, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AE7F, 0xFFC1AE7F, 0xFFC1AD7E, 0xFFC1AD7E, 0xFF312C20, 0xFF000000, 0xFF030302, 
        0xFF655B41, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA571, 0xFFBAA471, 
        0xFFB9A471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 
        0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFF6E5F39, 0xFF000000, 
        0xFF000000, 0xFF3C331F, 0xFFA99156, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF554829, 0xFF000000, 0xFF352D19, 0xFF79663A, 0xFF221D10, 0xFF000000, 0xFF000000, 0xFF1B170C, 0xFF726035, 
        0xFF9F8649, 0xFFA3894B, 0xFF564827, 0xFF000000, 0xFF060503, 0xFF937B42, 0xFFA18748, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 
        0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997C39,
  0xFF997C39, 0xFF997D39, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8445, 0xFFA08545, 0xFFA08646, 0xFFA08646, 
        0xFFA18747, 0xFFA18748, 0xFF40351C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF524526, 0xFF9E854A, 0xFFA48B4D, 0xFF8D7742, 0xFF221D10, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF9D854C, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFFA38B54, 0xFF221D11, 0xFF403721, 0xFFAC945A, 0xFFAC945B, 0xFFA48D56, 0xFF0A0805, 0xFF000000, 0xFF38301E, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 
        0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 
        0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBEA977, 
        0xFFBEA978, 0xFFBEAA78, 0xFF94845E, 0xFF0D0C08, 0xFF000000, 0xFF2D281D, 0xFFB8A577, 0xFFC0AC7C, 0xFFB9A678, 0xFF403A2A, 0xFF000000, 0xFF0E0C09, 0xFFAA996F, 0xFFC2AE7F, 0xFFBEAA7C, 0xFF353023, 0xFF000000, 0xFF000000, 0xFF807354, 0xFFC3B082, 
        0xFFC4B082, 0xFFC4B182, 0xFFC4B183, 0xFFC5B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC6B488, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBB91, 
        0xFFCDBB91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBD93, 
        0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B385, 
        0xFFC6B386, 0xFFC6B285, 0xFFC5B285, 0xFFBFAD80, 0xFF393426, 0xFF000000, 0xFF000000, 0xFF7C6F52, 0xFFC4B082, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFC1AE7E, 0xFF7A6D50, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF030302, 0xFF6D6145, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA875, 0xFFBCA775, 0xFFBCA775, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB69F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB39D67, 0xFFB39C66, 
        0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAD965C, 0xFFAD955C, 0xFFAC945B, 0xFF806E43, 0xFF0D0B07, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF867245, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFF100D07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF544727, 0xFFA0874B, 0xFFA3894C, 
        0xFF89733F, 0xFF231D10, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF40351C, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9C8240, 0xFF9C813F, 
        0xFF9C813F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D39,
  0xFF987D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C813F, 0xFF9D813F, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFFA08544, 0xFFA08546, 0xFFA08646, 0xFFA18647, 
        0xFFA18748, 0xFF86703B, 0xFF000000, 0xFF1A150B, 0xFF544626, 0xFF1D180D, 0xFF000000, 0xFF000000, 0xFF141109, 0xFF6F5E34, 0xFF9F874B, 0xFFA58C4F, 0xFF312917, 0xFF000000, 0xFF5B4D2C, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFF7B6A40, 0xFF252013, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFF71623C, 0xFF000000, 0xFF000000, 0xFFA18B56, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 
        0xFFB09962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 
        0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 
        0xFFBEAA78, 0xFF94845E, 0xFF0B0A07, 0xFF000000, 0xFF373123, 0xFFBFAB7A, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFAF9D72, 0xFF2C281D, 0xFF000000, 0xFF262219, 0xFF8F805E, 0xFF201D15, 0xFF000000, 0xFF1B1812, 0xFF9C8C67, 0xFFC3B082, 0xFFC4B082, 
        0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BE96, 0xFFD0BE96, 0xFFD0BE96, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFD0BF96, 0xFFCFBF96, 
        0xFFCFBE96, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 
        0xFFCEBD93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCAB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC6B386, 
        0xFFC6B386, 0xFFC6B386, 0xFFC5B285, 0xFFC5B284, 0xFFC1AF81, 0xFF544C38, 0xFF010101, 0xFF000000, 0xFF695F45, 0xFFC0AD7F, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFF847656, 0xFF000000, 0xFF000000, 0xFF534A35, 0xFF514934, 
        0xFF000000, 0xFF000000, 0xFF76694C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA675, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 
        0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 
        0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFF998452, 0xFF564A2E, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF18140C, 0xFFA89056, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF7D6A3D, 0xFF000000, 0xFF000000, 0xFF3B321C, 0xFF8E7843, 0xFFA58C4E, 0xFF8F7943, 0xFF4E4224, 
        0xFF000000, 0xFF000000, 0xFF050402, 0xFF2E2614, 0xFF141109, 0xFF000000, 0xFF86703C, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 
        0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A,
  0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 
        0xFFA18748, 0xFF282112, 0xFF000000, 0xFF534626, 0xFFA3894A, 0xFF947E44, 0xFF5C4E2B, 0xFF0D0B06, 0xFF000000, 0xFF000000, 0xFF2C2515, 0xFF695832, 0xFF040302, 0xFF1B170D, 0xFF98814A, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 
        0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFF9E8752, 0xFF998350, 0xFFAC945A, 0xFFAC955B, 0xFFAD955B, 0xFFAD955C, 0xFFA18A56, 0xFF19160D, 0xFF000000, 0xFF4C4129, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 
        0xFFB19962, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 
        0xFF867855, 0xFF0D0C08, 0xFF000000, 0xFF453E2C, 0xFFB8A576, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFAB9A70, 0xFF1F1B14, 0xFF000000, 0xFF030302, 0xFF000000, 0xFF2E291E, 0xFFA99970, 0xFFC3B082, 0xFFC4B182, 0xFFC4B183, 
        0xFFC5B283, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B58A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 
        0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 
        0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD95, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF96, 
        0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBF96, 0xFFD0BE96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCFBD95, 
        0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA8F, 
        0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 
        0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFFC5B386, 0xFFC6B285, 0xFFC5B284, 0xFF796D51, 0xFF010101, 0xFF000000, 0xFF4C4432, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFF938561, 0xFF0F0D0A, 0xFF000000, 0xFF3D3728, 0xFFB9A679, 0xFFC1AD7E, 
        0xFF695E44, 0xFF000000, 0xFF000000, 0xFF685D43, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA875, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A06C, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 
        0xFFB39D66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFF605233, 0xFF1A160E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF54482B, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF3B321D, 0xFF000000, 0xFF7A673A, 0xFFA2894E, 0xFF4D4124, 0xFF16120A, 0xFF000000, 
        0xFF000000, 0xFF211C0F, 0xFF6E5D32, 0xFFA3894B, 0xFF554626, 0xFF000000, 0xFF292212, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 
        0xFF9C8140, 0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A,
  0xFF997D3A, 0xFF9A7D3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8343, 0xFF9E8343, 0xFF9E8443, 0xFF9F8445, 0xFFA08545, 0xFFA08545, 0xFFA18647, 0xFFA18747, 0xFFA18747, 
        0xFF736033, 0xFF070603, 0xFF0A0804, 0xFF9C8347, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFF998147, 0xFF3E341D, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF020201, 0xFF5E4F2D, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 
        0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFFAD965C, 0xFFAE965D, 0xFFAD955C, 0xFF4F442A, 0xFF000000, 0xFF0A0905, 0xFFA8925C, 0xFFB09860, 0xFFB09961, 0xFFB09962, 
        0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 
        0xFFB8A26F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA979, 0xFF92835D, 
        0xFF0F0E0A, 0xFF000000, 0xFF373123, 0xFFB9A576, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF7F7354, 0xFF000000, 0xFF000000, 0xFF3C3627, 0xFFBFAD7F, 0xFFC4B082, 0xFFC4B083, 0xFFC4B183, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B58A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC92, 0xFFCEBC93, 
        0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD0C097, 0xFFD0C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1BF98, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD1BF98, 0xFFD0C098, 0xFFD0C098, 
        0xFFD0BF98, 0xFFD0C097, 0xFFD0BF98, 0xFFD0C097, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBF95, 0xFFCFBE96, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 
        0xFFC7B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFFC5B285, 0xFFC5B285, 0xFF968864, 0xFF0C0B08, 0xFF000000, 0xFF312C20, 0xFFBFAC7E, 0xFFC3B081, 0xFFB4A277, 0xFF16140F, 0xFF000000, 0xFF29251B, 0xFFBEAA7C, 0xFFC1AE7E, 0xFFC1AD7E, 
        0xFFBEAA7C, 0xFF645A41, 0xFF000000, 0xFF040402, 0xFF6C6145, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 
        0xFFBBA673, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A471, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB7A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F69, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 
        0xFFB39D67, 0xFFB39D66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFF89774A, 0xFF18140D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF120F09, 0xFF907B49, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF8A7644, 0xFF090704, 0xFF0E0C07, 0xFF131009, 0xFF000000, 0xFF000000, 0xFF080703, 
        0xFF6A5A32, 0xFF9E8549, 0xFFA48A4C, 0xFFA3894B, 0xFF9C8347, 0xFF0A0804, 0xFF070603, 0xFF746133, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFF9F8545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9D8341, 0xFF9D8241, 0xFF9D8141, 
        0xFF9C8140, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF997E3B, 0xFF997D3A,
  0xFF997D3A, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18747, 0xFF9C8346, 
        0xFF362D18, 0xFF000000, 0xFF5D4E2A, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58C4E, 0xFF806D3D, 0xFF1A160C, 0xFF000000, 0xFF16120A, 0xFFA28A4F, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 
        0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC935A, 0xFFAC945A, 0xFFAC955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFF827046, 0xFF090805, 0xFF030201, 0xFF6B5C3A, 0xFFB09961, 0xFFB09961, 0xFFB19962, 
        0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26D, 0xFFB8A26E, 
        0xFFB9A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA472, 0xFFBBA572, 0xFFBAA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA979, 0xFFA39267, 0xFF17140E, 
        0xFF000000, 0xFF2D281D, 0xFFBFAA7A, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7F, 0xFFC2AE7F, 0xFF827656, 0xFF000000, 0xFF000000, 0xFF504835, 0xFFC3B081, 0xFFC3B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 
        0xFFC5B285, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B588, 0xFFC7B488, 0xFFC8B589, 0xFFC7B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B88C, 0xFFCAB88C, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBD93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFCFBF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 
        0xFFD0C098, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 0xFFD1C099, 
        0xFFD1C098, 0xFFD0C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBE96, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 
        0xFFCBBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 
        0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFFC6B386, 0xFFC6B386, 0xFFC5B385, 0xFFC5B285, 0xFFC5B285, 0xFF958764, 0xFF17140F, 0xFF000000, 0xFF3A3427, 0xFFA89770, 0xFF201D15, 0xFF000000, 0xFF252118, 0xFFBAA87A, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC1AE7E, 
        0xFFC1AE7E, 0xFFC1AD7E, 0xFF504834, 0xFF000000, 0xFF060604, 0xFF857755, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB79, 0xFFBFAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 
        0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 
        0xFFB49D67, 0xFFB39D67, 0xFFB39C65, 0xFFB39C65, 0xFFB39B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFF978453, 0xFF433A24, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF060503, 0xFF040402, 0xFF000000, 0xFF4B4026, 0xFFA89056, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA58C51, 0xFF433920, 0xFF000000, 0xFF000000, 0xFF0E0C06, 0xFF473C21, 0xFFA1884C, 
        0xFFA58B4E, 0xFFA48B4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894A, 0xFF5D4D2A, 0xFF000000, 0xFF372E18, 0xFF9D8346, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8240, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF997E3A,
  0xFF997E3B, 0xFF9A7E3B, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF826D3A, 
        0xFF000000, 0xFF16120A, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA3894D, 0xFF372F1A, 0xFF000000, 0xFF736238, 0xFFA78E51, 0xFFA78E52, 0xFFA78E53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 
        0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE965D, 0xFF1F1B11, 0xFF000000, 0xFF332C1C, 0xFFAB945E, 0xFFB19962, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49E67, 0xFFB59E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 
        0xFFB8A46F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFA29167, 0xFF1A1811, 0xFF000000, 
        0xFF373123, 0xFFB8A577, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF74694C, 0xFF040403, 0xFF000000, 0xFF615840, 0xFFC1AD80, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 
        0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB88E, 
        0xFFCAB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD92, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF98, 0xFFD0C097, 0xFFD0C098, 0xFFD1C098, 0xFFD1C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 
        0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 0xFFD1C198, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD2C199, 0xFFD1C199, 0xFFD2C199, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C199, 
        0xFFD1C199, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C198, 0xFFD1C199, 0xFFD1C099, 0xFFD1C199, 0xFFD1C099, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFD0BE96, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 
        0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88E, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 
        0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC5B285, 0xFFA2926D, 0xFF252219, 0xFF000000, 0xFF0E0D09, 0xFF000000, 0xFF262219, 0xFFAC9B71, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE7F, 
        0xFFC2AE7F, 0xFFC1AE7E, 0xFFC1AD7E, 0xFF564E38, 0xFF000000, 0xFF0A0906, 0xFF8C7D5A, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 
        0xFFBBA674, 0xFFBAA573, 0xFFBAA573, 0xFFBAA571, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 
        0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29B63, 0xFFB19B63, 0xFFA18C59, 0xFF564A2F, 0xFF110F09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF15120B, 
        0xFF50452A, 0xFF76663E, 0xFF72623C, 0xFF39311E, 0xFF050402, 0xFF8E7949, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78F53, 0xFF8C7744, 0xFF070603, 0xFF070603, 0xFF736237, 0xFFA68C4F, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF151209, 0xFF000000, 0xFF826D3A, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 
        0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B,
  0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08645, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFF312916, 
        0xFF000000, 0xFF746134, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58C4E, 0xFFA58C4F, 0xFF806C3D, 0xFF000000, 0xFF2D2615, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 
        0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB935A, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFF645736, 0xFF000000, 0xFF0C0A06, 0xFF927F51, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E69, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 
        0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBDA876, 0xFFBCA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA78, 0xFFAB996D, 0xFF1E1B13, 0xFF000000, 0xFF2A261B, 
        0xFFAF9C71, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF74684C, 0xFF000000, 0xFF000000, 0xFF786C4F, 0xFFC4B082, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 
        0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C099, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 
        0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 
        0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC6B486, 0xFFC6B386, 0xFFC5B285, 0xFFC5B285, 0xFFB09F76, 0xFF2C281E, 0xFF000000, 0xFF030202, 0xFF918361, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AF80, 
        0xFFC2AE7F, 0xFFC2AE7E, 0xFFC1AE7E, 0xFFBBA879, 0xFF524935, 0xFF000000, 0xFF090806, 0xFF94845F, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA774, 
        0xFFBCA674, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 
        0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFF6F613E, 0xFF14120B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF5C5031, 0xFF9F8954, 
        0xFFAB935A, 0xFFAC945B, 0xFFAC945A, 0xFFA68E56, 0xFF423922, 0xFF2A2416, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF483D23, 0xFF000000, 0xFF4E4226, 0xFFA68D4F, 0xFFA68C4F, 
        0xFFA58C4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF736134, 0xFF000000, 0xFF322A16, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8444, 0xFF9F8544, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 
        0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF997E3B,
  0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF846E3A, 0xFF000000, 
        0xFF231D10, 0xFF988045, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF272012, 0xFF000000, 0xFF8B7543, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 
        0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAE975F, 0xFF020201, 0xFF000000, 0xFF615536, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A370, 
        0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA673, 0xFFB5A16F, 0xFFB4A06F, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA979, 0xFFB4A172, 0xFF3B3425, 0xFF000000, 0xFF000000, 0xFF060604, 
        0xFF7E7151, 0xFFBEAA7B, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7F, 0xFFC2AE7F, 0xFF72674B, 0xFF000000, 0xFF020201, 0xFF7C7052, 0xFFC4B082, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 
        0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB88E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 
        0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 
        0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1BF98, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD1C19A, 0xFFD1C19A, 0xFFD2C19A, 
        0xFFD2C19A, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 
        0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC92, 
        0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B385, 0xFFC6B385, 0xFFC5B385, 0xFFB3A178, 0xFF252219, 0xFF000000, 0xFF262219, 0xFFAE9E74, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 
        0xFFC2AF80, 0xFFC2AF7F, 0xFFC1AE7E, 0xFFC1AD7E, 0xFFB8A578, 0xFF342E21, 0xFF000000, 0xFF18150F, 0xFFA49369, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 
        0xFFBCA775, 0xFFBBA673, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26F, 0xFFB7A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F69, 0xFFB59F69, 
        0xFFB59E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB19A65, 0xFF998556, 0xFF292417, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF292316, 0xFF988452, 0xFFAE965D, 0xFFAD955C, 
        0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFA18953, 0xFF0E0C07, 0xFF71603A, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFFA58C51, 0xFF030201, 0xFF120F08, 0xFF917B46, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF988045, 0xFF231D0F, 0xFF000000, 0xFF846F3B, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8242, 
        0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7E3D, 0xFF9A7E3B,
  0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18748, 0xFFA28748, 0xFF261F11, 0xFF000000, 
        0xFF5E4E2A, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF776438, 0xFF000000, 0xFF3A311C, 0xFFA38A4F, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA98F54, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 
        0xFFAA9257, 0xFFAB9258, 0xFF806E43, 0xFF8E7A49, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFF4D432A, 0xFF000000, 0xFF14120B, 0xFFB19A63, 0xFFB29B64, 
        0xFFB29B65, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 
        0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFF473F2C, 0xFF675B40, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFF504732, 0xFF000000, 0xFF14120D, 0xFF504733, 0xFF000000, 
        0xFF000000, 0xFF665B42, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7F, 0xFFC2AE7F, 0xFF72674B, 0xFF000000, 0xFF020201, 0xFF73684C, 0xFFC4B082, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B283, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 
        0xFFC6B486, 0xFFC6B487, 0xFFC7B488, 0xFFC8B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA90, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BE96, 0xFFD0BF96, 
        0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD2C199, 0xFFD2C19A, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19B, 
        0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 
        0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C199, 0xFFD2C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C099, 
        0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBC93, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFFC5B385, 0xFFC5B285, 0xFFB3A179, 0xFF2F2A1F, 0xFF000000, 0xFF2F2B1F, 0xFFB2A076, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF80, 
        0xFFC2AF80, 0xFFC2AF80, 0xFFC1AE7F, 0xFFC2AE7E, 0xFFC1AE7E, 0xFFB6A376, 0xFF201D15, 0xFF000000, 0xFF2D291D, 0xFFB4A274, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 
        0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 0xFF978356, 0xFF4D432C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF282316, 0xFF766640, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965C, 
        0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFF6D5E39, 0xFF080704, 0xFF9F8852, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF635430, 0xFF000000, 0xFF574A2A, 0xFFA68C50, 
        0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF5E4F2A, 0xFF000000, 0xFF262011, 0xFFA18748, 0xFFA18747, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 
        0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9C813E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3B,
  0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFF766334, 0xFF040302, 0xFF110E08, 
        0xFF987F46, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF16130A, 0xFF070603, 0xFF7B683B, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 
        0xFFAB9258, 0xFFA48D54, 0xFF100D08, 0xFF75643C, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE955D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFF9C8756, 0xFF000000, 0xFF000000, 0xFF7E6E46, 0xFFB29B64, 
        0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A16B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A470, 
        0xFFBAA571, 0xFFBAA572, 0xFFBBA572, 0xFFBAA472, 0xFF3F3827, 0xFF070604, 0xFF9E8C62, 0xFFBCA776, 0xFFBCA876, 0xFFBCA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBFAA79, 0xFF564D37, 0xFF000000, 0xFF080805, 0xFF92825E, 0xFFBFAB7B, 0xFF6B6045, 
        0xFF010100, 0xFF010100, 0xFF4C4431, 0xFFBDAA7B, 0xFFC2AE7F, 0xFF7B6E51, 0xFF030302, 0xFF000000, 0xFF7E7153, 0xFFC3B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 
        0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB88E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29B, 
        0xFFD3C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39B, 0xFFD3C39C, 0xFFD2C29B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 
        0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBD94, 
        0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B385, 0xFFC5B285, 0xFFB5A479, 0xFF363124, 0xFF000000, 0xFF242018, 0xFFB8A67A, 0xFFC3B082, 0xFFC3B081, 
        0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF7F, 0xFFC2AF7F, 0xFFC1AE7E, 0xFF9F8F68, 0xFF14120D, 0xFF000000, 0xFF000000, 0xFF363023, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 
        0xFFBCA776, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA571, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB29C66, 0xFF52482F, 0xFF110F0A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0A06, 0xFF72633F, 0xFFA7905B, 0xFFAF9760, 0xFFAF975F, 0xFFAF975E, 0xFFAE975D, 0xFFAE965D, 
        0xFFAE965C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFF312A19, 0xFF4F4429, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F52, 0xFF9B834C, 0xFF1A160D, 0xFF010100, 0xFF9D854B, 
        0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF987F45, 0xFF110E07, 0xFF040302, 0xFF766334, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3C, 0xFF9A7E3C,
  0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18747, 0xFF9F8547, 0xFF372E19, 0xFF000000, 0xFF534526, 
        0xFFA3894A, 0xFFA3894C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF665630, 0xFF010100, 0xFF292214, 0xFFA68E52, 0xFFA88F52, 0xFFA88E53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 
        0xFFAB9358, 0xFF3F3620, 0xFF0E0C07, 0xFFA89158, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFAC945F, 0xFF342D1D, 0xFF000000, 0xFF211D12, 0xFFB29B64, 
        0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB8A36F, 0xFFB7A270, 
        0xFFB7A370, 0xFFB7A270, 0xFF8E7D57, 0xFF1D1A12, 0xFF000000, 0xFF584E37, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFF766A4B, 0xFF020201, 0xFF040402, 0xFF726649, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFF716549, 0xFF020201, 0xFF000000, 0xFF49412F, 0xFF857857, 0xFF000000, 0xFF000000, 0xFF7E7253, 0xFFC3B082, 0xFFC3B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B285, 0xFFC6B386, 0xFFC6B387, 0xFFC6B487, 0xFFC7B487, 
        0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 
        0xFFCDBB91, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFCFBF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 
        0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C49D, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C39D, 0xFFD4C39D, 0xFFD4C39D, 0xFFD4C39D, 
        0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B588, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFFC6B386, 0xFFC6B386, 0xFFC6B385, 0xFFC5B285, 0xFFB3A179, 0xFF27231A, 0xFF000000, 0xFF2B271D, 0xFFBAA77B, 0xFFC4B082, 
        0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AF80, 0xFF9A8A65, 0xFF14120D, 0xFF000000, 0xFF090805, 0xFF090806, 0xFF000000, 0xFF4E4632, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 
        0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB39D69, 
        0xFF897850, 0xFF14110B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF483E27, 0xFFAE9660, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC9459, 0xFF8D7949, 0xFF0B0905, 0xFF937E4C, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF5D4F2D, 0xFF000000, 0xFF433920, 
        0xFFA68C50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF524525, 0xFF000000, 0xFF382F19, 0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C,
  0xFF9A7F3C, 0xFF9B7F3E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8343, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF856F3B, 0xFF0C0A05, 0xFF080603, 0xFF9F8648, 
        0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF9E854B, 0xFF272113, 0xFF000000, 0xFF826E3F, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 
        0xFF847245, 0xFF040302, 0xFF2C2617, 0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFFAD965C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975F, 0xFFAF975F, 0xFFB09860, 0xFFAF9860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFF70613E, 0xFF000000, 0xFF000000, 0xFF907E51, 
        0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59E69, 0xFFB09A67, 0xFFA99564, 0xFFA59161, 0xFFA08D5F, 0xFF9B895D, 0xFF968459, 0xFF907F57, 0xFF897953, 0xFF7F714D, 0xFF6E6143, 0xFF564B34, 
        0xFF373121, 0xFF0E0C08, 0xFF000000, 0xFF000000, 0xFF15120D, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFF998961, 0xFF11100B, 0xFF000000, 0xFF504733, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC1AD7D, 
        0xFFC1AD7E, 0xFF827655, 0xFF0F0E0A, 0xFF000000, 0xFF000000, 0xFF010101, 0xFF685D44, 0xFFC3B081, 0xFFC3B082, 0xFFC4B183, 0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 
        0xFFC7B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C097, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 
        0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 
        0xFFD4C39D, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49E, 
        0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 
        0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88C, 
        0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B588, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFFC6B486, 0xFFC6B386, 0xFFC6B385, 0xFFC5B285, 0xFFAA9A72, 0xFF1E1B14, 0xFF000000, 0xFF453F2E, 0xFFBDAB7D, 
        0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFF8F815E, 0xFF0F0E0A, 0xFF000000, 0xFF221E16, 0xFF9D8D66, 0xFF7B6E50, 0xFF030201, 0xFF020201, 0xFF766A4C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 
        0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A06C, 0xFF928056, 0xFF3E3624, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF2F291A, 0xFF8A784D, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 
        0xFFAE965D, 0xFFAE965D, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFA18953, 0xFF0B0905, 0xFF473D24, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFF957E49, 0xFF141109, 0xFF030301, 
        0xFF917A46, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF9F8548, 0xFF070603, 0xFF0C0A05, 0xFF86703C, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8443, 0xFF9E8343, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3D,
  0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18748, 0xFFA18748, 0xFF504223, 0xFF000000, 0xFF594B28, 0xFFA3894A, 
        0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF786639, 0xFF000000, 0xFF2F2817, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFA58E55, 
        0xFF362F1C, 0xFF000000, 0xFF1C180E, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFA18C5A, 0xFF18150D, 0xFF000000, 0xFF3A3321, 
        0xFF8C7A50, 0xFF7C6C47, 0xFF706240, 0xFF64583A, 0xFF594E33, 0xFF4D432C, 0xFF433B27, 0xFF393221, 0xFF322C1D, 0xFF2D281B, 0xFF272217, 0xFF211D14, 0xFF1B1810, 0xFF15130C, 0xFF0F0E09, 0xFF0A0806, 0xFF020101, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8D7D58, 0xFFBCA875, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFB8A475, 0xFF201C14, 0xFF000000, 0xFF403929, 0xFFBEAA7A, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AC7D, 0xFFC1AD7D, 
        0xFFC1AE7F, 0xFFC2AE7F, 0xFF776B4E, 0xFF000000, 0xFF000000, 0xFF5A513B, 0xFFC3AF81, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B488, 0xFFC7B589, 
        0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 
        0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF98, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C099, 0xFFD1C199, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C59F, 0xFFD4C49F, 0xFFD5C49F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C59E, 
        0xFFD4C49E, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE96, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B385, 0xFFC5B285, 0xFFA99971, 0xFF1A1711, 0xFF000000, 0xFF4B4432, 
        0xFFC4B183, 0xFFC4B082, 0xFF7B6F51, 0xFF0C0A08, 0xFF000000, 0xFF383224, 0xFFAB9970, 0xFFC1AE7E, 0xFFC1AD7E, 0xFF62583F, 0xFF000000, 0xFF0D0C08, 0xFF9E8E65, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 
        0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA774, 0xFFA28F64, 0xFF857652, 0xFFBAA573, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFA89464, 0xFF473E29, 0xFF0A0906, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221D13, 0xFF7C6C46, 0xFFAF9963, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19961, 0xFFB09861, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 
        0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFA28B55, 0xFF18150C, 0xFF000000, 0xFF887446, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFF4F4326, 0xFF000000, 
        0xFF463C22, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF584A28, 0xFF000000, 0xFF504324, 0xFFA18748, 0xFFA18748, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8443, 
        0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D,
  0xFF9B7F3D, 0xFF9B803D, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18748, 0xFF9E8446, 0xFF030301, 0xFF080704, 0xFF9B8246, 0xFFA3894B, 
        0xFFA48A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4F, 0xFFA58B4E, 0xFF322A17, 0xFF000000, 0xFF907A45, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFF806E41, 
        0xFF000000, 0xFF000000, 0xFF020101, 0xFF3D3520, 0xFF877447, 0xFF998451, 0xFF95804F, 0xFF887649, 0xFF786840, 0xFF6B5C3A, 0xFF5C5032, 0xFF4C422A, 0xFF3E3622, 0xFF2E281A, 0xFF1F1B11, 0xFF120F0A, 0xFF080704, 0xFF010100, 0xFF000000, 0xFF000000, 
        0xFF030302, 0xFF020201, 0xFF020101, 0xFF010100, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF403827, 0xFFB6A271, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFF312C1F, 0xFF000000, 0xFF232017, 0xFFB5A275, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 
        0xFFC2AE7F, 0xFFB8A579, 0xFF15130E, 0xFF000000, 0xFF4C4532, 0xFFC3B081, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 
        0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 
        0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C49D, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59E, 
        0xFFD4C59E, 0xFFD5C59F, 0xFFD4C49F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 
        0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB88E, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B285, 0xFFC5B385, 0xFFA2926D, 0xFF12100C, 0xFF000000, 
        0xFF554D39, 0xFF7E7153, 0xFF070605, 0xFF000000, 0xFF3F3929, 0xFFB5A477, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7E, 0xFFC1AD7E, 0xFF443D2C, 0xFF000000, 0xFF15130E, 0xFFBEAA7B, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 
        0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFF887954, 0xFF070604, 0xFFAD9A6A, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFB9A470, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFF675A3D, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF675A3B, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB09962, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFF8F7B4B, 0xFF000000, 0xFF000000, 0xFF19150D, 0xFFAB9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA48B50, 0xFF010100, 
        0xFF16130B, 0xFF8F7945, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF9B8247, 0xFF0B0905, 0xFF040302, 0xFF9D8446, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8442, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D,
  0xFF9B803D, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8341, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFF9F8546, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF554726, 0xFF000000, 0xFF000000, 0xFF1B170C, 0xFF5C4D2A, 
        0xFF8F7842, 0xFFA2894C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF8C7642, 0xFF000000, 0xFF372E1A, 0xFFA58C50, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9258, 0xFFA89156, 0xFF201C10, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF91815A, 0xFFBCA776, 0xFFBCA876, 0xFFBDA877, 0xFFBDA978, 0xFFBDA978, 0xFFBEA978, 0xFF5F553C, 0xFF000000, 0xFF0E0C09, 0xFF95855F, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 
        0xFFB9A679, 0xFF252118, 0xFF000000, 0xFF3A3526, 0xFFC3B082, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 
        0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD2C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 
        0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39B, 0xFFD2C39B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD4C59E, 0xFFD4C49F, 0xFFD5C49F, 0xFFD5C59F, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 
        0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C59E, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39D, 
        0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFCFBF97, 0xFFD0BE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA90, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 0xFFC6B386, 0xFFC5B385, 0xFFC6B285, 0xFF847758, 0xFF090806, 
        0xFF000000, 0xFF000000, 0xFF020201, 0xFF4A4331, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7E, 0xFFC1AE7E, 0xFFB4A275, 0xFF231F17, 0xFF000000, 0xFF383224, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA774, 0xFF373122, 0xFF383223, 0xFFB7A271, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB19C6B, 0xFF8D7C55, 0xFF252116, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF090805, 0xFF3D3523, 0xFFA79260, 0xFFB49D68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAB935B, 0xFF847346, 0xFF0B0906, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF615332, 0xFFAA9257, 0xFFAA9156, 0xFFAA9155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF584B2A, 
        0xFF000000, 0xFF645530, 0xFFA58C50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFF9A8247, 0xFF7C6839, 0xFF372E19, 0xFF020201, 0xFF000000, 0xFF564826, 0xFFA18748, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8444, 0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9D8141, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B7F3D,
  0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF9E8446, 0xFF0B0905, 0xFF050402, 0xFF17130A, 0xFF000000, 0xFF000000, 
        0xFF110E08, 0xFF42381F, 0xFF7B683A, 0xFFA58B4E, 0xFFA58C4F, 0xFF292314, 0xFF000000, 0xFF766439, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9256, 0xFFAA9257, 0xFFAB9258, 0xFF5B4E2F, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF453D2B, 0xFFBCA776, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF8F7F5A, 0xFF090806, 0xFF000000, 0xFF6E6347, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFBBA87B, 
        0xFF3F392A, 0xFF000000, 0xFF262219, 0xFFB09F74, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 
        0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 
        0xFFCEBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C6A0, 
        0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C69F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59E, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 
        0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B385, 0xFFC5B285, 0xFF74694E, 
        0xFF000000, 0xFF000000, 0xFF534B37, 0xFFC4B182, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AD7E, 0xFF93845F, 0xFF090805, 0xFF000000, 0xFF675C42, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFAB976A, 0xFF0A0906, 0xFF3F3827, 0xFF8C7B55, 0xFF9B895F, 0xFF706344, 0xFF363021, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF393221, 0xFF86764E, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 
        0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFF9E8854, 0xFF493F26, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1A160D, 0xFF98834E, 0xFFAA9256, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78E53, 0xFF9D854D, 
        0xFF0A0805, 0xFF141109, 0xFFA68D50, 0xFFA68C4F, 0xFFA58B4E, 0xFF967F47, 0xFF5D4F2B, 0xFF282213, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A05, 0xFF9F8446, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 
        0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E,
  0xFF9B803E, 0xFF9C803F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFF60502B, 0xFF000000, 0xFF282112, 0xFF9B8347, 0xFF6C5B32, 0xFF19150B, 
        0xFF000000, 0xFF000000, 0xFF070603, 0xFF282212, 0xFF5B4C2B, 0xFF000000, 0xFF211C10, 0xFF9F874E, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFF947F4D, 0xFF080604, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF020101, 0xFFB29E6F, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFB8A475, 0xFF1A1710, 0xFF000000, 0xFF4A422F, 0xFFBFAC7B, 0xFFC0AC7C, 0xFFC1AC7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC1AD7E, 0xFF655B42, 
        0xFF000000, 0xFF070605, 0xFFA9986F, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 
        0xFFC9B78B, 0xFFCAB78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39B, 0xFFD3C29C, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A0, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C59E, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39B, 0xFFD2C29C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 
        0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 
        0xFFCBBA8F, 0xFFCBB98F, 0xFFCAB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B58A, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC6B487, 0xFFC7B386, 0xFFC6B386, 0xFFC5B385, 0xFFC6B285, 
        0xFF685E46, 0xFF000000, 0xFF0F0D0A, 0xFFB7A47A, 0xFFC4B082, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AD7E, 0xFF6D6247, 0xFF000000, 0xFF0A0906, 0xFF9B8A64, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBDA979, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFF695D41, 0xFF000000, 0xFF080705, 0xFF0B0A07, 0xFF030302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF0F0D09, 0xFF83734D, 0xFFB09A67, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB39D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 
        0xFFAF985F, 0xFFAF975E, 0xFF625535, 0xFF0A0905, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5A4D2E, 0xFFA99156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA58D51, 
        0xFF514527, 0xFF000000, 0xFF6C5B34, 0xFFA38A4E, 0xFF4B3F23, 0xFF0F0D07, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF43381F, 0xFF8B7540, 0xFF262011, 0xFF000000, 0xFF61512B, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 
        0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C803F, 0xFF9C803E,
  0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18747, 0xFF9E8445, 0xFF241E10, 0xFF000000, 0xFF695830, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 
        0xFF705F34, 0xFF221C10, 0xFF070503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5C4E2D, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9256, 0xFFAA9257, 0xFFAA9257, 0xFF3D3520, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF050403, 0xFF070604, 0xFF040402, 
        0xFF000000, 0xFF010100, 0xFF0D0B07, 0xFF0E0C08, 0xFF100E09, 0xFF12100A, 0xFF16140D, 0xFF211D13, 0xFF2D271A, 0xFF3A3322, 0xFF48402B, 0xFF564C34, 0xFF64583C, 0xFF716444, 0xFF80714E, 0xFF8B7A54, 0xFF7E704D, 0xFF332D1F, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF716446, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF443D2B, 0xFF000000, 0xFF000000, 0xFF706447, 0xFFBCA879, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF90825E, 0xFF000000, 
        0xFF000000, 0xFF978864, 0xFFC3B082, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78C, 
        0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD4C49D, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD6C6A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 
        0xFFD7C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C199, 0xFFD1C099, 
        0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 
        0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B386, 0xFFC5B385, 
        0xFFC1AE82, 0xFF433C2D, 0xFF000000, 0xFF211E16, 0xFFC0AD80, 0xFFC3B082, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AD7E, 0xFF3D3627, 0xFF000000, 0xFF262218, 0xFFBAA777, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFA89569, 0xFF201C14, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070604, 0xFF514730, 
        0xFFB7A16D, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFAB955E, 
        0xFF8C794C, 0xFF201C11, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF9A844F, 0xFFAA9157, 0xFFA99055, 0xFFA99155, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 
        0xFF857141, 0xFF0B0A05, 0xFF0B0905, 0xFF0C0A05, 0xFF000000, 0xFF010100, 0xFF0F0D07, 0xFF463B20, 0xFF977F46, 0xFFA48A4C, 0xFFA3894B, 0xFF68582F, 0xFF000000, 0xFF241E10, 0xFF9E8446, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 
        0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E,
  0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8544, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF7B6737, 0xFF080603, 0xFF0F0D07, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 
        0xFFA48B4D, 0xFFA58B4E, 0xFF786638, 0xFF352D19, 0xFF000000, 0xFF0A0805, 0xFFA1894E, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFF847144, 0xFF0A0805, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF0B0A06, 0xFF14110B, 0xFF1C190F, 0xFF252114, 0xFF2E2819, 0xFF38301F, 0xFF403824, 0xFF494029, 0xFF53482F, 0xFF5E5235, 0xFF695C3C, 0xFF746542, 0xFF7F6F49, 0xFF5A4E33, 
        0xFF000000, 0xFF050403, 0xFF9B885B, 0xFFA59260, 0xFFAE9966, 0xFFB6A16B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB8A370, 0xFFB9A471, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFF2E291C, 0xFF000000, 
        0xFF292419, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF726648, 0xFF000000, 0xFF050403, 0xFF020201, 0xFF000000, 0xFF3B3526, 0xFFA39169, 0xFFC1AD7D, 0xFFC2AE7E, 0xFFC2AE7F, 0xFF9F8F68, 0xFF090806, 0xFF000000, 
        0xFF73684C, 0xFFC3B081, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 
        0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 
        0xFFCFBE96, 0xFFD0BF96, 0xFFD0C097, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29C, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 
        0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A2, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 
        0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A3, 0xFFD7C8A3, 
        0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 
        0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 
        0xFFCCBA90, 0xFFCBBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B385, 
        0xFFC6B285, 0xFFAF9E76, 0xFF1F1C15, 0xFF000000, 0xFF4E4634, 0xFFC0AE80, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AE7F, 0xFFC1AE7E, 0xFFB7A476, 0xFF252118, 0xFF000000, 0xFF4D4532, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAA7A, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFF6D6144, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF453D29, 0xFF99875B, 0xFFB7A26D, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29A64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFF8E7B4E, 0xFF453C26, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF352D1B, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 
        0xFFA58C51, 0xFF2F2817, 0xFF000000, 0xFF040302, 0xFF2C2515, 0xFF5B4D2B, 0xFF947D46, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894A, 0xFF0F0C06, 0xFF080603, 0xFF7C6738, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08546, 0xFFA08545, 
        0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E,
  0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8341, 0xFF9E8343, 0xFF9E8343, 0xFF9E8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA18646, 0xFFA18647, 0xFF9F8547, 0xFF4C4022, 0xFF000000, 0xFF5D4E2A, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 
        0xFFA48B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF5D4F2C, 0xFF000000, 0xFF554829, 0xFFA78E51, 0xFFA78F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFF332C1A, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF060503, 0xFF322B1A, 0xFF564B2E, 0xFF75653E, 0xFF89774A, 0xFF927E4E, 0xFF968151, 0xFF9A8654, 0xFF9E8A57, 0xFFA28D59, 0xFFA7915C, 0xFFAA945F, 0xFFAF9761, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C66, 0xFFB39D67, 0xFFB39D67, 0xFF998658, 
        0xFF14110B, 0xFF000000, 0xFF726442, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA674, 0xFF665B3F, 0xFF000000, 
        0xFF887955, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF9C8C63, 0xFF12100B, 0xFF000000, 0xFF5C523B, 0xFF8A7C59, 0xFF090805, 0xFF000000, 0xFF12100B, 0xFF807454, 0xFFC2AE7F, 0xFFB3A175, 0xFF221E16, 0xFF000000, 0xFF47402F, 
        0xFFBFAD7F, 0xFFC4B182, 0xFFC4B183, 0xFFC5B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB78C, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BE96, 0xFFCFBE96, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD4C49F, 0xFFD5C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C7A3, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD8C8A4, 
        0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 
        0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB91, 
        0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB88E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 
        0xFFC6B386, 0xFFC5B385, 0xFFA3936E, 0xFF000000, 0xFF000000, 0xFF7F7355, 0xFFC4B182, 0xFFC4B082, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFBBA779, 0xFF342F22, 0xFF000000, 0xFF010100, 0xFF796D4E, 0xFFBFAB7B, 0xFFBFAB7A, 
        0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFF211D14, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF292419, 0xFF95845A, 0xFFB59F6C, 0xFFB8A36E, 0xFFB8A26E, 
        0xFFB7A26E, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB69F6A, 0xFFB59F69, 0xFFB59F68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B63, 0xFFB09962, 0xFF4D422A, 0xFF0D0C07, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0905, 0xFF5A4D2F, 0xFF8C7949, 0xFF8C7848, 0xFF413821, 0xFF000000, 0xFF74643B, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 
        0xFFA88E53, 0xFF716037, 0xFF000000, 0xFF1F1B0F, 0xFF9B834A, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF5D4E2A, 0xFF000000, 0xFF4D4122, 0xFF9F8547, 0xFFA18747, 0xFFA18646, 0xFFA08646, 0xFFA08545, 
        0xFF9F8545, 0xFF9F8444, 0xFF9F8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C803F,
  0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18748, 0xFF9B8144, 0xFF0F0D07, 0xFF030201, 0xFF9F8548, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 
        0xFFA58B4D, 0xFFA58C4F, 0xFF9E854B, 0xFF1F1A0F, 0xFF000000, 0xFFA58C50, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAB9258, 0xFF7C6A3F, 0xFF000000, 0xFF000000, 0xFF252013, 0xFF816E43, 
        0xFFAD955B, 0xFFAD965C, 0xFFAE955D, 0xFFAE975D, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49E67, 0xFFB39D67, 
        0xFF3B3422, 0xFF000000, 0xFF231F14, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFF383223, 0xFF322D1F, 
        0xFFB9A674, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFB8A475, 0xFF413A2A, 0xFF000000, 0xFF1F1C14, 0xFFBFAB7B, 0xFFC0AC7C, 0xFFB4A074, 0xFF2C281C, 0xFF000000, 0xFF000000, 0xFF494230, 0xFF4C4432, 0xFF000000, 0xFF1A1711, 0xFFBCA97C, 
        0xFFC4B082, 0xFFC4B083, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 
        0xFFCBB88D, 0xFFCBB98D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BE96, 0xFFD0BF96, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFD0C098, 0xFFD0C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59E, 0xFFD4C59F, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 
        0xFFD7C8A4, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 
        0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 
        0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB88E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B588, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 
        0xFFC6B486, 0xFFC6B386, 0xFFC5B285, 0xFF887B5B, 0xFF000000, 0xFF040403, 0xFFAE9D74, 0xFFC4B182, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC3AF80, 0xFFA2916A, 0xFF16130E, 0xFF000000, 0xFF030201, 0xFF000000, 0xFF1C1912, 0xFFAA976D, 0xFFBFAB7B, 
        0xFFBFAB7B, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFF9F8D63, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF514832, 0xFFB6A26F, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFF7C6C45, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF493F26, 0xFFA89159, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFF4C4127, 0xFF19150D, 0xFFA28B52, 0xFFAA9156, 0xFFA99156, 0xFFA99054, 0xFFA88F54, 0xFFA88F54, 
        0xFFA88F53, 0xFFA78E52, 0xFF121009, 0xFF0B0905, 0xFF806D3D, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF9F8548, 0xFF030201, 0xFF100D07, 0xFF9B8144, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 
        0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F,
  0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF6F5D31, 0xFF000000, 0xFF473C20, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 
        0xFFA58B4E, 0xFFA58C4F, 0xFF7E6B3C, 0xFF000000, 0xFF4B4024, 0xFFA78D51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFA48D55, 0xFF0F0D07, 0xFF0F0D08, 0xFF6D5E39, 0xFFAC945B, 0xFFAD955B, 
        0xFFAD955C, 0xFFAD955D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29C65, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E69, 
        0xFF776845, 0xFF020201, 0xFF0A0906, 0xFF8B7A52, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFA59266, 0xFF000000, 0xFF96855E, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF7E7150, 0xFF000000, 0xFF050503, 0xFFA4936A, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFBDAA7C, 0xFF5D533C, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF080705, 0xFFA2936B, 0xFFC4B082, 
        0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B285, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFD0C098, 0xFFD0C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 
        0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A1, 
        0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29B, 
        0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 
        0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 
        0xFFC6B487, 0xFFC6B386, 0xFFC6B385, 0xFFC5B385, 0xFF554D39, 0xFF000000, 0xFF211E16, 0xFFBCAA7D, 0xFFC4B082, 0xFFC3AF81, 0xFFBFAC7E, 0xFF71654A, 0xFF060504, 0xFF000000, 0xFF1B1811, 0xFF796C4F, 0xFF1A1711, 0xFF000000, 0xFF554C36, 0xFFC0AB7B, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFF514832, 0xFF000000, 0xFF000000, 0xFF463E2A, 0xFFBAA572, 0xFFB9A471, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFF87764C, 0xFF342D1D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF372F1D, 0xFF907C4D, 0xFFAD965D, 0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9358, 0xFF262114, 0xFF605331, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 
        0xFFA88F53, 0xFFA78E52, 0xFF6D5C35, 0xFF000000, 0xFF524527, 0xFFA48A4E, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA4894B, 0xFFA3894B, 0xFF473B20, 0xFF000000, 0xFF705D32, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 
        0xFF9F8545, 0xFF9F8445, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8341, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F,
  0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18648, 0xFFA28748, 0xFF1B170C, 0xFF010100, 0xFF7B6838, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 
        0xFFA58B4E, 0xFFA68C4F, 0xFF2A2314, 0xFF020201, 0xFF847041, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAB9257, 0xFF4A3F26, 0xFF060503, 0xFF8B7748, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 
        0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49D68, 0xFFB59E68, 0xFFB59E69, 
        0xFFB49E69, 0xFF0F0D09, 0xFF000000, 0xFF564B33, 0xFFB6A06B, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFAD996B, 0xFF817350, 0xFFBDA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFAE9C6F, 0xFF0A0906, 0xFF000000, 0xFF75694B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC2AE7F, 0xFF73674C, 0xFF000000, 0xFF000000, 0xFF817455, 0xFFC4B082, 0xFFC4B182, 
        0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 
        0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF98, 0xFFD1C098, 
        0xFFD1C198, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 
        0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A6, 0xFFD8CAA5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 
        0xFFD7C7A3, 0xFFD6C7A3, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBE94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 
        0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC5B386, 0xFFB6A47B, 0xFF252118, 0xFF000000, 0xFF4C4533, 0xFFC4B182, 0xFFB7A479, 0xFF413B2B, 0xFF020201, 0xFF000000, 0xFF3E3829, 0xFFA7966D, 0xFFC1AD7E, 0xFF9B8B65, 0xFF000000, 0xFF000000, 0xFF94845F, 
        0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA876, 0xFFA49266, 0xFF16130D, 0xFF000000, 0xFF918059, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 
        0xFFB8A36E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB6A16B, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFF9C8859, 0xFF3C3422, 0xFF0A0906, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF2A2417, 0xFF837147, 0xFFAB945C, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFF927D4B, 0xFF847143, 0xFFA99156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 
        0xFFA88F53, 0xFFA78E53, 0xFFA58C51, 0xFF0F0C07, 0xFF141109, 0xFF9F864C, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF7C6739, 0xFF010100, 0xFF1B170C, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 
        0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140,
  0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF836D3A, 0xFF000000, 0xFF231D10, 0xFF977F45, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 
        0xFFA58B4F, 0xFF8F7945, 0xFF000000, 0xFF2C2515, 0xFF9F874D, 0xFFA78E52, 0xFFA88E53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFF907B49, 0xFF0A0905, 0xFF8A7748, 0xFFAC9359, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 
        0xFFAE965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19B63, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C66, 0xFFB39D67, 0xFFB39D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 
        0xFFB59F6A, 0xFF594E34, 0xFF000000, 0xFF1E1B12, 0xFFA99564, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 
        0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBFAA79, 0xFF322C20, 0xFF000000, 0xFF352F21, 0xFFB6A374, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF242018, 0xFF000000, 0xFF4A4231, 0xFFBEAB7E, 0xFFC4B182, 0xFFC4B183, 
        0xFFC4B184, 0xFFC5B284, 0xFFC5B284, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 
        0xFFD1C199, 0xFFD2C199, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 
        0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD9CAA5, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CBA6, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA7, 
        0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9C9A6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C49F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBC93, 
        0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB88E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 
        0xFFC7B588, 0xFFC7B487, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFF9B8C68, 0xFF010101, 0xFF090806, 0xFF5D533E, 0xFF14120D, 0xFF000000, 0xFF060604, 0xFF75694D, 0xFFC1AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC0AC7D, 0xFF60563E, 0xFF000000, 0xFF110F0B, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFF5E533A, 0xFF000000, 0xFF8E7E57, 0xFFBBA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 
        0xFFB9A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFF625638, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF080704, 0xFF6F603C, 0xFFAC955E, 0xFFAF9860, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA89054, 
        0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF594C2C, 0xFF000000, 0xFF756438, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFF967E44, 0xFF221D0F, 0xFF000000, 0xFF846E3A, 0xFFA18748, 0xFFA18647, 0xFFA08646, 
        0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9C8140,
  0xFF9D8140, 0xFF9D8241, 0xFF9E8242, 0xFF9D8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF3E331C, 0xFF000000, 0xFF4C4022, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 
        0xFFA68C4F, 0xFF41371F, 0xFF000000, 0xFF5B4D2C, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFF9A8550, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59F69, 0xFFB59F69, 
        0xFFB6A06A, 0xFFAC9765, 0xFF000000, 0xFF000000, 0xFF86764F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA472, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 
        0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF7A6E4E, 0xFF020201, 0xFF080705, 0xFF8C7E5A, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC1AE7F, 0xFF635941, 0xFF000000, 0xFF191610, 0xFFAB9A72, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 
        0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBD93, 0xFFCEBD94, 0xFFCEBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 
        0xFFD1C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 
        0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 
        0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 
        0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39D, 
        0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C19A, 0xFFD2C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 
        0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 
        0xFFC7B588, 0xFFC7B488, 0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFFC5B285, 0xFF685E45, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF27231A, 0xFF998A65, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7E, 0xFFAE9C71, 0xFF201D15, 0xFF000000, 
        0xFF534A35, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 0xFFB09D6E, 0xFF13110B, 0xFF594F37, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 
        0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB6A06B, 0xFFB6A06B, 0xFFB19B67, 0xFF84734D, 0xFF1C1810, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0A06, 0xFF3F3622, 
        0xFFA38D5A, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9357, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 
        0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFF8A7543, 0xFF050402, 0xFF231D10, 0xFFA68C50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF4C4022, 0xFF000000, 0xFF3E341C, 0xFFA18748, 0xFFA18747, 0xFFA08647, 
        0xFFA08646, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140,
  0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF957D42, 0xFF131008, 0xFF030301, 0xFF86713D, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 
        0xFF988149, 0xFF120F08, 0xFF080704, 0xFF978049, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFFAB9358, 0xFFAC9359, 0xFFAC935A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 
        0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29C64, 0xFFB39C65, 0xFFB39D65, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 
        0xFFB6A06B, 0xFFB6A06B, 0xFF423A26, 0xFF000000, 0xFF2E281B, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A470, 0xFFB9A470, 0xFFBAA571, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 
        0xFFBDA978, 0xFFBEAA78, 0xFFB09E70, 0xFF232016, 0xFF000000, 0xFF050403, 0xFF524A35, 0xFFAD9B70, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFF9F8F68, 0xFF0F0E0A, 0xFF000000, 0xFF887B5A, 0xFFC4B082, 0xFFC4B082, 0xFFC4B183, 0xFFC5B184, 
        0xFFC5B284, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 
        0xFFCCBA90, 0xFFCDBB91, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 
        0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A3, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 
        0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACBA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 
        0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD95, 
        0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 
        0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B386, 0xFFC6B386, 0xFFC5B285, 0xFF3C3628, 0xFF000000, 0xFF13120D, 0xFFBBA97D, 0xFFC3B082, 0xFFC3B082, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC1AE7E, 0xFF796C4F, 0xFF000000, 
        0xFF0B0A07, 0xFF968660, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFF7F714F, 0xFF0D0B08, 0xFFAD9A6A, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 
        0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16C, 0xFFB7A16C, 0xFF8A7952, 0xFF362F1F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3D3522, 0xFF8A774C, 0xFFB19A63, 
        0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 
        0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA1884F, 0xFF2F2817, 0xFF000000, 0xFF8A7542, 0xFFA68C50, 0xFFA58B4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF86703C, 0xFF030301, 0xFF131008, 0xFF957D42, 0xFFA18748, 0xFFA18647, 
        0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241,
  0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFF6D5B31, 0xFF030301, 0xFF1E190D, 0xFFA3894A, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 
        0xFF6A5932, 0xFF010100, 0xFF342C19, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9459, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE965C, 
        0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 
        0xFFB6A06B, 0xFFB6A06C, 0xFF907E55, 0xFF000000, 0xFF000000, 0xFF9D8A5E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 
        0xFFBEA978, 0xFFBEAA79, 0xFF6C6145, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0B08, 0xFF6C6146, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF332E22, 0xFF000000, 0xFF574F3A, 0xFFC3B081, 0xFFC4B082, 0xFFC4B183, 0xFFC5B183, 0xFFC5B284, 
        0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC8B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 
        0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 
        0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD8C9A6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACAA6, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 
        0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BE97, 0xFFD0BE96, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 
        0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFFA4946F, 0xFF14120D, 0xFF000000, 0xFF817556, 0xFFC4B082, 0xFFC3B082, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AD7E, 0xFF2E2A1E, 
        0xFF000000, 0xFF413A2A, 0xFFB9A677, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFF373122, 0xFF554C34, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 
        0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFAD9867, 0xFF3F3725, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF15120C, 0xFF8A794E, 0xFFAF9962, 0xFFB29B64, 0xFFB19A63, 
        0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 
        0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88E53, 0xFF5E502E, 0xFF000000, 0xFF3D331D, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA38A4C, 0xFFA38A4C, 0xFFA3894A, 0xFF1D190D, 0xFF030301, 0xFF6C5B30, 0xFFA18748, 0xFFA18647, 
        0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8343, 0xFF9D8241, 0xFF9D8241,
  0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA08647, 0xFFA18647, 0xFF9F8547, 0xFF42371D, 0xFF000000, 0xFF68572F, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA2894D, 
        0xFF3B321C, 0xFF000000, 0xFF847140, 0xFFA78E51, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 
        0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 
        0xFFB6A06C, 0xFFB7A16C, 0xFFAA9664, 0xFF272217, 0xFF000000, 0xFF433B28, 0xFFB8A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA573, 0xFFBBA573, 0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 
        0xFFBEAA79, 0xFFB09E70, 0xFF030302, 0xFF000000, 0xFF8C7D5A, 0xFF6A5F44, 0xFF14120D, 0xFF000000, 0xFF000000, 0xFF272319, 0xFF9E8D67, 0xFF75694D, 0xFF000000, 0xFF1E1B14, 0xFFBBA97C, 0xFFC3B082, 0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 0xFFC5B284, 
        0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B589, 0xFFC8B58A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBB90, 
        0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 
        0xFFD2C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA8, 
        0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDBCCAA, 0xFFDBCDA9, 0xFFDBCCAA, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCAA, 0xFFDBCCAA, 0xFFDBCCA9, 
        0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD8CAA6, 0xFFD9C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 
        0xFFD4C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C099, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBA91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B385, 0xFF665C44, 0xFF010101, 0xFF15130E, 0xFFB3A177, 0xFFC4B082, 0xFFC3B082, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AF80, 0xFFB19E74, 0xFF5F553E, 0xFF040402, 
        0xFF000000, 0xFF000000, 0xFF92825E, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFA49266, 0xFF19160F, 0xFFA08E62, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 
        0xFFB9A470, 0xFFB8A36F, 0xFFAE9A69, 0xFF7A6C49, 0xFF0B0A06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0F0D08, 0xFF584D32, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29A63, 
        0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 
        0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF968049, 0xFF0A0805, 0xFF0F0D07, 0xFF9A834A, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF67572F, 0xFF000000, 0xFF42371D, 0xFF9F8547, 0xFFA18748, 
        0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241,
  0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18747, 0xFFA18747, 0xFF957C42, 0xFF141109, 0xFF030201, 0xFFA18749, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF957D46, 
        0xFF0A0805, 0xFF19150C, 0xFFA78E51, 0xFFA78E53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC935A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 
        0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 
        0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFF5B5036, 0xFF000000, 0xFF0A0806, 0xFFA89465, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA878, 0xFFBEA978, 
        0xFFBEAA79, 0xFF3A3425, 0xFF000000, 0xFF11100B, 0xFF998862, 0xFFC0AC7C, 0xFFAA9A6F, 0xFF524935, 0xFF0C0B08, 0xFF000000, 0xFF050403, 0xFF030302, 0xFF050403, 0xFF847757, 0xFFC3B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBB90, 0xFFCDBB91, 
        0xFFCDBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C29C, 
        0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C9A3, 0xFFD8C8A4, 
        0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCCAA, 
        0xFFDBCCAA, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAB, 
        0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CBA7, 0xFFDACAA6, 
        0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD6C7A3, 0xFFD7C7A1, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B486, 0xFFC6B386, 0xFFC1AD81, 0xFF262219, 0xFF000000, 0xFF584F3B, 0xFFC2AF81, 0xFFC3B082, 0xFFC3B082, 0xFFBCA97C, 0xFF71664A, 0xFF1F1C14, 0xFF000000, 0xFF000000, 
        0xFF1B1811, 0xFF000000, 0xFF1E1A13, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBAA574, 0xFF4F4631, 0xFF3A3424, 0xFFB8A371, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 
        0xFFB7A270, 0xFF7B6C4A, 0xFF2C271A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070604, 0xFF4A412A, 0xFF978457, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B63, 
        0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAE955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99056, 
        0xFFA99055, 0xFFA99054, 0xFFA89053, 0xFFA88F53, 0xFFA88E52, 0xFF332B19, 0xFF010100, 0xFF6A5A33, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA18749, 0xFF020201, 0xFF151209, 0xFF957C42, 0xFFA18748, 
        0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241,
  0xFF9D8241, 0xFF9E8342, 0xFF9E8443, 0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF796636, 0xFF000000, 0xFF3F351D, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF6A5A32, 
        0xFF000000, 0xFF645430, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAB9459, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 
        0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 
        0xFFB6A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFF938258, 0xFF0B0A06, 0xFF020101, 0xFF675B3E, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA776, 0xFFBCA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 
        0xFF887957, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF0E0C09, 0xFF4F4733, 0xFFBBA879, 0xFFC1AD7E, 0xFFA3936A, 0xFF413A2A, 0xFF020201, 0xFF000000, 0xFF393325, 0xFFC2AF81, 0xFFC4B082, 0xFFC4B183, 0xFFC4B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 
        0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD4C39D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 
        0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 
        0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 
        0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A1, 
        0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59E, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 
        0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B387, 0xFFC6B386, 0xFFC6B385, 0xFFA79771, 0xFF000000, 0xFF060504, 0xFFA3936D, 0xFFC4B183, 0xFF9B8B66, 0xFF2A251B, 0xFF020201, 0xFF000000, 0xFF0D0C08, 0xFF817454, 
        0xFFA3936A, 0xFF252118, 0xFF000000, 0xFF61573F, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA776, 0xFFA39165, 0xFF100E0A, 0xFF272318, 0xFF8C7C56, 0xFFA79466, 0xFF706344, 
        0xFF221E15, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2E281B, 0xFF938155, 0xFFB39C67, 0xFFB49E68, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 
        0xFFB19B63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9157, 0xFFAA9156, 
        0xFFA99156, 0xFFA99054, 0xFFA98F54, 0xFFA88F53, 0xFFA78E52, 0xFF826F40, 0xFF000000, 0xFF3D331D, 0xFFA2884E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA2894B, 0xFF3F351C, 0xFF000000, 0xFF7B6637, 0xFFA18748, 
        0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9D8241,
  0xFF9E8241, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18748, 0xFFA18748, 0xFF3B311A, 0xFF000000, 0xFF7D6939, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4E, 0xFFA68C4F, 0xFF252012, 
        0xFF030301, 0xFF947E48, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9258, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945B, 0xFFAC945B, 0xFFAD955B, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 
        0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D67, 0xFFB49E67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB5A06A, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26F, 0xFF262117, 0xFF000000, 0xFF302B1D, 0xFFB09C6B, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFB8A472, 0xFFBCA775, 0xFFBDA776, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFB8A575, 
        0xFF2F2A1E, 0xFF000000, 0xFF2C271C, 0xFF393324, 0xFF030302, 0xFF000000, 0xFF12100C, 0xFF8B7C5A, 0xFFBEAA7B, 0xFF8D7E5C, 0xFF070605, 0xFF030202, 0xFFA99970, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B283, 0xFFC5B285, 0xFFC5B385, 0xFFC6B385, 
        0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC8B588, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 
        0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 
        0xFFD4C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8CAA5, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 
        0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 
        0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDCCDAA, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 
        0xFFD5C6A0, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD95, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B385, 0xFFC5B385, 0xFF655B44, 0xFF000000, 0xFF352F23, 0xFF59503B, 0xFF000000, 0xFF000000, 0xFF050403, 0xFF433C2C, 0xFFB3A175, 0xFFC2AE7F, 
        0xFFAE9C71, 0xFF353022, 0xFF000000, 0xFF0A0906, 0xFFAC9A6F, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA774, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0D0B08, 0xFF796A47, 0xFFB6A06B, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAC955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 
        0xFFAA9156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88E53, 0xFFA78E52, 0xFF120F08, 0xFF100D07, 0xFF957E47, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894C, 0xFFA3894B, 0xFF7D6939, 0xFF000000, 0xFF3B311A, 0xFFA18748, 
        0xFFA18748, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8241,
  0xFF9E8341, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18748, 0xFFA08547, 0xFF000000, 0xFF1A150B, 0xFF957D43, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF947D46, 0xFF000000, 
        0xFF332B19, 0xFFA0884D, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 
        0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 
        0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFF7C6D4B, 0xFF000000, 0xFF050403, 0xFF918058, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFB39F6F, 0xFF594F37, 0xFFAD996B, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF857654, 
        0xFF030302, 0xFF000000, 0xFF968660, 0xFFC0AC7C, 0xFF7C6F50, 0xFF2A251B, 0xFF000000, 0xFF000000, 0xFF332E21, 0xFF29251B, 0xFF000000, 0xFF6B6147, 0xFFC4B082, 0xFFC4B182, 0xFFC4B183, 0xFFC5B183, 0xFFC5B284, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 
        0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCBBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 
        0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 
        0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8CAA6, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 
        0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDDCEAD, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAD, 
        0xFFDDCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 
        0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A1, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C097, 
        0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCBBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B387, 0xFFC6B385, 0xFFB8A67C, 0xFF211E16, 0xFF000000, 0xFF000000, 0xFF030202, 0xFF2F2A1F, 0xFF8B7E5C, 0xFFC3AF81, 0xFFB19F74, 0xFF685E44, 
        0xFF0C0B08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF584E38, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 0xFFBBA775, 0xFF19160F, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF120F0A, 0xFF554B32, 0xFFAE9966, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39B65, 0xFFB29B64, 
        0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9157, 0xFFAA9157, 
        0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF5C4E2C, 0xFF000000, 0xFF756338, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF947D44, 0xFF18140B, 0xFF010100, 0xFFA08547, 
        0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9D8342,
  0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF6A582F, 0xFF000000, 0xFF2F2715, 0xFF998046, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF4C4024, 0xFF000000, 
        0xFF5E502E, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 
        0xFFAF975F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 
        0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFF0C0A07, 0xFF000000, 0xFF2F2A1D, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFF3B3525, 0xFF201C14, 0xFFB7A473, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBEAA79, 0xFFBEA978, 0xFF2F2A1E, 
        0xFF000000, 0xFF000000, 0xFF2B271C, 0xFF8C7E5A, 0xFFC1AD7D, 0xFFB4A276, 0xFF766B4D, 0xFF0D0C08, 0xFF000000, 0xFF000000, 0xFF28241A, 0xFFBFAC7F, 0xFFC4B082, 0xFFC4B183, 0xFFC5B183, 0xFFC5B284, 0xFFC5B284, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 
        0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49E, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A3, 0xFFD7C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 
        0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 
        0xFFDDCFAD, 0xFFDCCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDECFAE, 0xFFDECFAE, 0xFFDECFAD, 0xFFDDCFAE, 0xFFDDCFAD, 
        0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDBCCAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 
        0xFFD6C7A2, 0xFFD6C6A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 
        0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 
        0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B689, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFF756A4F, 0xFF030302, 0xFF040403, 0xFF6E6349, 0xFFBDAA7D, 0xFFC4B082, 0xFF817455, 0xFF211E16, 0xFF000000, 
        0xFF000000, 0xFF332E21, 0xFF695E45, 0xFF000000, 0xFF14120D, 0xFFA8976C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA775, 0xFFBCA775, 0xFF94845D, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4F452F, 0xFF9C895C, 0xFFB8A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 
        0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAB945A, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 
        0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA78E53, 0xFF8F7946, 0xFF000000, 0xFF302917, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA08649, 0xFF332B17, 0xFF000000, 0xFF6A5930, 
        0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8342, 0xFF9E8342,
  0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08646, 0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFF272111, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF2D2614, 0xFF715F34, 0xFF9F874A, 0xFFA58B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF100D07, 0xFF0D0B06, 
        0xFF897443, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAE965C, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 
        0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 
        0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A370, 0xFFB9A470, 0xFF544B33, 0xFF000000, 0xFF000000, 0xFF1A1710, 0xFF5E533A, 0xFF221E15, 0xFF000000, 0xFF92825B, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF8C7E59, 0xFF000000, 
        0xFF040402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF403929, 0xFFB7A477, 0xFFC1AE7F, 0xFFA6956D, 0xFF000000, 0xFF000000, 0xFF8B7E5C, 0xFFC4B082, 0xFFC4B182, 0xFFC5B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 
        0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 
        0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59E, 
        0xFFD4C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD8C9A6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 
        0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDD0AE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDD0AE, 
        0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDDCFAC, 0xFFDDCEAD, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAA, 
        0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9C9A6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 
        0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 
        0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BE96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 
        0xFFCAB78C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B588, 0xFFC7B588, 0xFFC6B487, 0xFFC6B387, 0xFFC6B386, 0xFFC2AF82, 0xFF221F17, 0xFF000000, 0xFF5B523D, 0xFFAF9E74, 0xFF302B20, 0xFF000000, 0xFF000000, 0xFF060604, 
        0xFF776B4E, 0xFFC1AE7F, 0xFFC1AD7E, 0xFF242017, 0xFF000000, 0xFF61573F, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFB9A573, 0xFF47402C, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF17150E, 0xFF948259, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C65, 0xFFB29C65, 
        0xFFB29C64, 0xFFB29A64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9257, 0xFFAA9257, 
        0xFFAA9256, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF9E864D, 0xFF2C2515, 0xFF000000, 0xFFA0884D, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA3894C, 0xFF85703D, 0xFF453A20, 0xFF0C0A05, 0xFF000000, 0xFF000000, 0xFF272111, 
        0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342,
  0xFF9E8342, 0xFF9F8343, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF937A41, 0xFF080603, 0xFF030301, 0xFF1C180D, 0xFF050402, 0xFF000000, 0xFF000000, 0xFF070603, 0xFF3C321C, 0xFF726136, 0xFF6C5B34, 0xFF040302, 0xFF211C10, 
        0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC9359, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE975D, 0xFFAF975E, 0xFFAE975F, 
        0xFFAF9860, 0xFFB09860, 0xFFB09861, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 
        0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A36F, 0xFFB9A470, 0xFF9B895E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF463E2C, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA979, 0xFFBEAA79, 0xFF1C1912, 0xFF000000, 
        0xFF6C6145, 0xFF94845F, 0xFF2F2A1E, 0xFF040402, 0xFF000000, 0xFF0A0906, 0xFF786B4E, 0xFF494130, 0xFF000000, 0xFF383325, 0xFFBBA97C, 0xFFC4B082, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 
        0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 
        0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A0, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDCFAE, 
        0xFFDDCFAE, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 
        0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 
        0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9C9A6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C8A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C099, 
        0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 
        0xFFCAB88C, 0xFFC9B88C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC6B487, 0xFFC6B386, 0xFFC6B386, 0xFF908361, 0xFF000000, 0xFF060604, 0xFF000000, 0xFF000000, 0xFF13110C, 0xFF5A513B, 0xFFBDAA7C, 
        0xFFC2AF80, 0xFF9F8E68, 0xFF4B4431, 0xFF000000, 0xFF000000, 0xFF040402, 0xFFB4A174, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFF99885F, 0xFF0D0B08, 0xFF000000, 
        0xFF000000, 0xFF030302, 0xFF4B422E, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F68, 0xFFB49E68, 0xFFB49E67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 
        0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB09962, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAC9359, 0xFFAB9258, 0xFFAB9257, 
        0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA78F53, 0xFFA78E52, 0xFF55482A, 0xFF000000, 0xFF5F502D, 0xFF9E854C, 0xFF7E6B3B, 0xFF4E4225, 0xFF18140B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF131008, 0xFF020201, 0xFF080603, 
        0xFF947B41, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9E8444, 0xFF9E8342,
  0xFF9E8343, 0xFF9F8443, 0xFF9F8544, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF66562D, 0xFF030201, 0xFF241E10, 0xFF9C8348, 0xFF756236, 0xFF4F4324, 0xFF1E190E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070603, 0xFF000000, 0xFF5C4E2D, 
        0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 
        0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F69, 0xFFB69F6B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 
        0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFBAA471, 0xFFB09B6B, 0xFF14120C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF100F0A, 0xFFAE9B6C, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF766A4B, 0xFF000000, 0xFF191610, 
        0xFFA7966B, 0xFFC0AC7C, 0xFFBDA87A, 0xFF827454, 0xFF232017, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010101, 0xFF928360, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B385, 0xFFC5B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 
        0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBD93, 0xFFCEBD94, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C199, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA9, 0xFFDACCA9, 
        0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDBCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDD0AE, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 
        0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0B0, 0xFFDED1AF, 0xFFDFD1AF, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 
        0xFFDED1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDFD1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 
        0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD7C9A4, 
        0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 
        0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB88E, 
        0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B385, 0xFF403A2B, 0xFF000000, 0xFF020201, 0xFF544C38, 0xFFA2926C, 0xFFC3B081, 0xFFA8966F, 
        0xFF4E4633, 0xFF110F0B, 0xFF000000, 0xFF000000, 0xFF100E0A, 0xFF000000, 0xFF4F4733, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA976, 0xFFBCA876, 0xFFBDA875, 0xFFBCA775, 0xFF4D4530, 0xFF000000, 
        0xFF000000, 0xFF524932, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 
        0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 
        0xFFAA9257, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF7F6C3E, 0xFF090704, 0xFF110E08, 0xFF251F12, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF100D07, 0xFF40361D, 0xFF695931, 0xFF8F7841, 0xFF231E10, 0xFF030201, 
        0xFF67562E, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8343,
  0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF3F351C, 0xFF000000, 0xFF5F502B, 0xFFA3894A, 0xFFA38A4C, 0xFFA2884B, 0xFF9E864A, 0xFF8C7642, 0xFF4D4124, 0xFF120F08, 0xFF000000, 0xFF000000, 0xFF9C854B, 
        0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99156, 0xFFA99156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC955B, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 
        0xFFB09860, 0xFFB09961, 0xFFB19961, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59E6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 
        0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A371, 0xFFB9A471, 0xFFB39F6D, 0xFF352F20, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF706345, 0xFFBBA675, 0xFFBCA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFB8A475, 0xFF231F16, 0xFF000000, 0xFF534A35, 
        0xFFC0AC7C, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFBBA77A, 0xFF645A41, 0xFF040403, 0xFF000000, 0xFF373224, 0xFFC3B082, 0xFFC4B182, 0xFFC4B183, 0xFFC5B183, 0xFFC5B285, 0xFFC6B285, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 
        0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFD0BE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD1C199, 0xFFD2C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C49F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 
        0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 
        0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 
        0xFFDED1B0, 0xFFDED1B0, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD1B1, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED1AF, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 
        0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A4, 
        0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C5A1, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C19A, 
        0xFFD2C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B385, 0xFFB0A076, 0xFF020201, 0xFF000000, 0xFFB09F76, 0xFFC4B183, 0xFF695F46, 0xFF0D0B08, 
        0xFF000000, 0xFF000000, 0xFF191710, 0xFF968762, 0xFF837655, 0xFF060503, 0xFF050403, 0xFFAA986D, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFFB3A06F, 0xFF050503, 
        0xFF050403, 0xFF81724F, 0xFFBAA572, 0xFFBAA471, 0xFFB9A371, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59E68, 0xFFB49E68, 0xFFB49D68, 0xFFB39D66, 0xFFB39C66, 
        0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 0xFFAB9258, 
        0xFFAB9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA58C51, 0xFF14110A, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF372E1A, 0xFF7A6739, 0xFF9A8248, 0xFFA0874A, 0xFFA38A4C, 0xFFA3894A, 0xFF5E4F2B, 0xFF000000, 
        0xFF3F351C, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443,
  0xFF9E8343, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFF937B41, 0xFF201B0E, 0xFF000000, 0xFF987E45, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF8D7843, 0xFF080704, 0xFF272113, 0xFFA78D51, 
        0xFFA88E52, 0xFFA78F53, 0xFFA88F54, 0xFFA98F54, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAB9257, 0xFFAA9258, 0xFFAB9358, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF985F, 0xFFAF985F, 
        0xFFB09861, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19B63, 0xFFB19B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 
        0xFFB8A26F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFB6A16F, 0xFF48402C, 0xFF000000, 0xFF000000, 0xFF242016, 0xFFAC996C, 0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFF827452, 0xFF060604, 0xFF070604, 0xFFA8966C, 
        0xFFC0AC7C, 0xFFC1AC7D, 0xFFC1AD7D, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFAE9C72, 0xFF0F0E0A, 0xFF000000, 0xFFAC9B72, 0xFFC3B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 
        0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B88C, 0xFFCAB88D, 0xFFCBB88E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBE94, 0xFFCEBE95, 
        0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 
        0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 
        0xFFDBCDAA, 0xFFDBCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDED1AF, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD2B0, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFDFD2B1, 
        0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 
        0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 
        0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD2C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFFC6B386, 0xFFC3B084, 0xFF574E3A, 0xFF000000, 0xFF413B2B, 0xFF3C3628, 0xFF000000, 0xFF000000, 
        0xFF17150F, 0xFF6B6047, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFB9A779, 0xFF262219, 0xFF000000, 0xFF554C36, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA978, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBBA775, 0xFF746748, 
        0xFF000000, 0xFF7E6F4D, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26F, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB39D66, 0xFFB39C66, 
        0xFFB39C66, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 
        0xFFAA9258, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78F53, 0xFF463B21, 0xFF000000, 0xFF483D22, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4D, 0xFFA48B4C, 0xFFA48A4C, 0xFFA3894C, 0xFF977F45, 0xFF000000, 
        0xFF201B0E, 0xFF937B41, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8443,
  0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF826D3A, 0xFF010100, 0xFF211B0F, 0xFFA3894A, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF6B5A33, 0xFF000000, 0xFF6B5A34, 0xFFA78E52, 
        0xFFA78F52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9258, 0xFFAB9258, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFB09860, 
        0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 
        0xFFB8A26F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFB7A270, 0xFF514732, 0xFF000000, 0xFF000000, 0xFF786A4A, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFB9A676, 0xFF403928, 0xFF000000, 0xFF4C4330, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFC0AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE80, 0xFF524A36, 0xFF000000, 0xFF574E39, 0xFFC4B082, 0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC6B385, 0xFFC6B386, 0xFFC6B387, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 
        0xFFC8B689, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 
        0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 
        0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDCCDAA, 0xFFDCCDAB, 
        0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDD0AE, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 
        0xFFDFD2B0, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFDFD2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B1, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 
        0xFFE0D2B2, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1AF, 0xFFDED1B0, 0xFFDFD0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDECFAE, 
        0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCDAB, 0xFFDBCDA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 
        0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B488, 0xFFC7B487, 0xFFC6B486, 0xFFC6B386, 0xFF9F906B, 0xFF0F0D0A, 0xFF000000, 0xFF000000, 0xFF090906, 0xFF5D543E, 
        0xFFAC9B71, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7E, 0xFF766A4D, 0xFF000000, 0xFF1B1911, 0xFFAA986D, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 
        0xFF2A251A, 0xFF5A5037, 0xFFB9A471, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 
        0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9358, 
        0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F52, 0xFF857141, 0xFF000000, 0xFF39301B, 0xFFA58B4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF211B0F, 
        0xFF020201, 0xFF836E3A, 0xFFA28748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443,
  0xFF9E8443, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF61512B, 0xFF000000, 0xFF5E4E2A, 0xFFA3894A, 0xFFA3894C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4F, 0xFFA58C4F, 0xFF362E1A, 0xFF000000, 0xFF99824A, 0xFFA78E52, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 
        0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFB8A270, 0xFF4D442F, 0xFF000000, 0xFF2B261A, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA79, 0xFFA49369, 0xFF000000, 0xFF000000, 0xFFB3A072, 0xFFC0AC7C, 
        0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFAB9A70, 0xFF000000, 0xFF0E0D09, 0xFFA6966F, 0xFFC4B082, 0xFFC4B182, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B689, 
        0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 
        0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C199, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 
        0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B2, 
        0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 
        0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 
        0xFFDED0AE, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 
        0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 
        0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFFC6B386, 0xFFC6B386, 0xFF403A2B, 0xFF000000, 0xFF1B1912, 0xFF988A66, 0xFFC2AF81, 
        0xFFC3B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC1AE7E, 0xFF12100B, 0xFF000000, 0xFF796D4E, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBEAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA774, 
        0xFF908059, 0xFF1C1911, 0xFFAF9B6B, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A06C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 
        0xFFB39C66, 0xFFB29C65, 0xFFB29C64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 
        0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF0D0B06, 0xFF18150C, 0xFF937C46, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA38A4B, 0xFFA3894B, 0xFF5D4E2A, 
        0xFF000000, 0xFF61522C, 0xFFA18748, 0xFFA18748, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8443,
  0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF2E2614, 0xFF000000, 0xFF907941, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA3894D, 0xFF010100, 0xFF2A2314, 0xFFA1894E, 0xFFA78E52, 
        0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9358, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC955B, 0xFFAD955B, 0xFFAD955D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 
        0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB59E68, 0xFFB49E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26D, 0xFFB8A26E, 
        0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFB4A06F, 0xFF3F3827, 0xFF000000, 0xFFA89569, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFF4D4430, 0xFF000000, 0xFF231F16, 0xFFA9976D, 0xFFBCA879, 
        0xFFC1AD7D, 0xFFC1AD7D, 0xFFC2AD7E, 0xFFC2AE7F, 0xFF423C2C, 0xFF000000, 0xFF4D4533, 0xFFBFAD7F, 0xFFC4B083, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC7B587, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 
        0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 
        0xFFD0C097, 0xFFD0C098, 0xFFD0C098, 0xFFD1C199, 0xFFD2C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 
        0xFFD7C8A3, 0xFFD7C7A3, 0xFFD8C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAC, 
        0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDECFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 
        0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE1D3B3, 0xFFE1D3B3, 
        0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0B0, 0xFFDED0AF, 
        0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACBA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39D, 0xFFD3C39C, 
        0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 
        0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B58A, 0xFFC8B689, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFA0926C, 0xFF000000, 0xFF13110C, 0xFF9F906A, 0xFFC4B083, 
        0xFFC4B082, 0xFFC3B082, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7E, 0xFF75694C, 0xFF000000, 0xFF2C271C, 0xFFBCA879, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA979, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA775, 0xFFBCA775, 
        0xFFB9A572, 0xFF3C3524, 0xFF736546, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A06C, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F69, 0xFFB59F69, 0xFFB59E68, 0xFFB49E67, 0xFFB49D67, 
        0xFFB39D66, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 
        0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF493E24, 0xFF000000, 0xFF7E6B3C, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF907941, 
        0xFF000000, 0xFF2F2715, 0xFFA28748, 0xFFA18748, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444,
  0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18748, 0xFF9E8446, 0xFF000000, 0xFF1C180D, 0xFF9B8246, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF7B683A, 0xFF000000, 0xFF554829, 0xFFA58C51, 0xFFA78E52, 
        0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 
        0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 
        0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA572, 0xFFBAA572, 0xFFB29E6E, 0xFF17140E, 0xFF5A5038, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA79, 0xFFB29F71, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF433C2B, 
        0xFF857857, 0xFFB7A477, 0xFFC2AE7F, 0xFFA5956C, 0xFF0A0907, 0xFF090806, 0xFF958662, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 
        0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 
        0xFFD0C098, 0xFFD0C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A3, 
        0xFFD7C8A3, 0xFFD7C9A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDDCEAC, 0xFFDDCEAC, 
        0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 
        0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B3, 0xFFE1D3B4, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 
        0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 
        0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDA9, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 
        0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39D, 
        0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 
        0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB88E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B58A, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B386, 0xFFC6B386, 0xFF3F392A, 0xFF000000, 0xFF615841, 0xFFC2AF81, 
        0xFFC4B082, 0xFFC3B082, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFBEAB7C, 0xFF0A0906, 0xFF000000, 0xFF988862, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 
        0xFFBCA774, 0xFFB09C6D, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 
        0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE965E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC9459, 0xFFAB9359, 
        0xFFAB9359, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA98F54, 0xFFA88F53, 0xFFA88F53, 0xFF836F40, 0xFF000000, 0xFF574A2A, 0xFFA68C50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF9B8246, 
        0xFF1B170C, 0xFF010100, 0xFF9E8446, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8544, 0xFF9F8444,
  0xFF9F8444, 0xFF9F8544, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18748, 0xFF766235, 0xFF000000, 0xFF44391F, 0xFFA08649, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF3C331D, 0xFF010100, 0xFF776539, 0xFFA78E52, 0xFFA88F53, 
        0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 
        0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 
        0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 0xFF92825A, 0xFF100E0A, 0xFFA69467, 0xFFBCA775, 0xFFBCA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFF5A5039, 0xFF000000, 0xFF2B261B, 0xFF524A35, 0xFF050403, 0xFF000000, 
        0xFF060503, 0xFF252118, 0xFF685D44, 0xFF4A4331, 0xFF000000, 0xFF312C20, 0xFFC3B081, 0xFFC4B182, 0xFFC4B183, 0xFFC4B184, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 
        0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 
        0xFFDDCFAE, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 
        0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D4B5, 0xFFE2D4B5, 0xFFE1D4B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE2D4B5, 
        0xFFE1D4B5, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B1, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 
        0xFFD3C39D, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 
        0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC6B387, 0xFFC6B386, 0xFFAD9D74, 0xFF000000, 0xFF100F0B, 0xFFBCA97D, 
        0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFF8B7D5B, 0xFF353023, 0xFF060503, 0xFF000000, 0xFF312C20, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA875, 
        0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 
        0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFFAE965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 
        0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFF9E864D, 0xFF0C0A06, 0xFF221D10, 0xFFA68D50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA4894B, 0xFFA08649, 
        0xFF44391F, 0xFF000000, 0xFF766334, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8444,
  0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFF3E341C, 0xFF000000, 0xFF66562E, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF050402, 0xFF16120A, 0xFF927C47, 0xFFA78E52, 0xFFA88F53, 
        0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 
        0xFFB19962, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 
        0xFFB9A470, 0xFFB9A471, 0xFFBAA472, 0xFFBAA573, 0xFFBBA673, 0xFFB8A371, 0xFF9F8D62, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFB9A475, 0xFF13110C, 0xFF020201, 0xFF6E6247, 0xFFC0AC7C, 0xFFB5A275, 0xFF5D543C, 
        0xFF0C0B08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF958662, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 
        0xFFC9B78C, 0xFFC9B88C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBD93, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 
        0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 
        0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 
        0xFFDED0AE, 0xFFDED0AE, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 
        0xFFE1D4B5, 0xFFE2D4B4, 0xFFE1D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 
        0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE2D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 
        0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED1AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACCA8, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 
        0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB90, 
        0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B386, 0xFFC5B285, 0xFF453E2E, 0xFF000000, 0xFF766A4F, 
        0xFFC4B183, 0xFFC4B082, 0xFFC3B082, 0xFF988A65, 0xFF28241A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFFA7956B, 0xFFBFAB7C, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 
        0xFFBCA775, 0xFFBBA774, 0xFFBBA673, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49D68, 
        0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC955A, 0xFFAC945A, 0xFFAC9359, 
        0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA38A50, 0xFF39311C, 0xFF000000, 0xFFA0884D, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4B, 0xFFA3894B, 
        0xFF66562E, 0xFF000000, 0xFF3E341C, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8444,
  0xFF9F8444, 0xFF9F8545, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF0D0B06, 0xFF0C0A05, 0xFF816C3A, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF816D3D, 0xFF000000, 0xFF2A2414, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 
        0xFFA89053, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 
        0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 
        0xFFB9A471, 0xFFB9A471, 0xFFBAA571, 0xFFBAA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFF7D7050, 0xFF050403, 0xFF0F0E0A, 0xFFAD9B70, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC1AD7E, 
        0xFFB7A477, 0xFF655B42, 0xFF13110C, 0xFF000000, 0xFF232017, 0xFFC3B082, 0xFFC4B082, 0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 
        0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC94, 0xFFCFBD95, 0xFFCFBD95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 
        0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 
        0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 
        0xFFDED0AF, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE2D4B5, 
        0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D5B6, 0xFFE3D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE3D6B6, 0xFFE2D6B7, 0xFFE2D6B6, 0xFFE3D5B6, 0xFFE2D5B6, 
        0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 
        0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 
        0xFFDACBA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 
        0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCCBB91, 
        0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B488, 0xFFC7B487, 0xFFC6B486, 0xFFC6B386, 0xFF918362, 0xFF000000, 0xFF14120D, 
        0xFFB2A177, 0xFF807355, 0xFF2E2A1F, 0xFF000000, 0xFF000000, 0xFF100F0B, 0xFF3A3426, 0xFF827454, 0xFF312C1F, 0xFF000000, 0xFF524935, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA978, 0xFFBDA876, 0xFFBDA876, 
        0xFFBCA776, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 
        0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB19B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC9459, 
        0xFFAB9359, 0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF61522F, 0xFF000000, 0xFF685932, 0xFFA68C50, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 
        0xFF816C3B, 0xFF0C0A05, 0xFF0E0C06, 0xFFA28748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8544,
  0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFF87713C, 0xFF010100, 0xFF1B160C, 0xFF9A8247, 0xFFA3894C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58C4E, 0xFFA58C4F, 0xFF514427, 0xFF000000, 0xFF514527, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 
        0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 
        0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A06B, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A36F, 
        0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBAA676, 0xFF463E2C, 0xFF000000, 0xFF443D2B, 0xFFC0AC7C, 0xFFC0AD7C, 0xFFC1AD7D, 0xFFC1AD7D, 
        0xFFC1AE7F, 0xFFC2AE80, 0xFF2D281D, 0xFF000000, 0xFF8A7C5B, 0xFFC4B082, 0xFFC4B183, 0xFFC4B283, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 
        0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 
        0xFFD2C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 
        0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 
        0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B4, 0xFFE2D4B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 
        0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D7B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE3D6B6, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 
        0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCAA, 
        0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C59E, 
        0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 
        0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B386, 0xFFB8A77C, 0xFF2A261C, 0xFF000000, 
        0xFF1C1913, 0xFF000000, 0xFF000000, 0xFF1A1811, 0xFF695F45, 0xFF9B8C66, 0xFFC2AF80, 0xFFC2AE7F, 0xFF71654A, 0xFF010100, 0xFF1C1912, 0xFFB19F72, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 
        0xFFBDA776, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA472, 0xFFBAA471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 
        0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 
        0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF7D6A3D, 0xFF050402, 0xFF2C2615, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 
        0xFF9A8146, 0xFF1A160C, 0xFF010100, 0xFF89723D, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545,
  0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF5E4E2A, 0xFF000000, 0xFF322A17, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF2A2314, 0xFF000000, 0xFF816D3E, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 
        0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB19962, 
        0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB5A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 
        0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA79, 0xFFA7966A, 0xFF14120D, 0xFF000000, 0xFF9F8E66, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 
        0xFFC2AE7F, 0xFFA2926B, 0xFF000000, 0xFF201C15, 0xFFB8A57A, 0xFFC4B082, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B78C, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0C097, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D4B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D5B7, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D6B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE4D7B8, 
        0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D5B7, 0xFFE2D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D3B3, 
        0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 
        0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD4C59E, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBB92, 
        0xFFCDBB92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B589, 0xFFC8B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFF625942, 0xFF010101, 
        0xFF000000, 0xFF1B1812, 0xFF847657, 0xFFBDAB7E, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFB8A678, 0xFF070604, 0xFF060503, 0xFF847655, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA877, 0xFFBDA877, 
        0xFFBDA876, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E68, 
        0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC935A, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA98F54, 0xFFA88F54, 0xFFA88F53, 0xFF957F49, 0xFF19150C, 0xFF020201, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4B, 
        0xFFA3894B, 0xFF322A16, 0xFF000000, 0xFF5F502B, 0xFFA18748, 0xFFA18647, 0xFFA18646, 0xFFA08545, 0xFF9F8545,
  0xFFA08545, 0xFFA08546, 0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFF393019, 0xFF000000, 0xFF5D4E2A, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA58A4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF927C46, 0xFF18150B, 0xFF050402, 0xFFA78E51, 0xFFA88E52, 0xFFA78F53, 0xFFA88F53, 
        0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 
        0xFFB19A63, 0xFFB29A64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB69F6A, 0xFFB69F6B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB7A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 
        0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF807251, 0xFF000000, 0xFF231F16, 0xFFC0AB7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 
        0xFFC2AE7F, 0xFF433D2C, 0xFF000000, 0xFF625840, 0xFFC2AE80, 0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC6B285, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE94, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 
        0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C49D, 0xFFD4C49E, 0xFFD5C49E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0B0, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B4, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE2D5B7, 0xFFE3D6B6, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D6B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 
        0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D5B6, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B4, 
        0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDDD0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 
        0xFFDBCDAA, 0xFFDBCDAA, 0xFFDACCA9, 0xFFDACBA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD8CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 
        0xFFD4C59F, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29C, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C097, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 
        0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCAB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFFAB9A73, 0xFF080705, 
        0xFF0D0C09, 0xFF9E8E6A, 0xFFC4B182, 0xFFC4B082, 0xFFC3B082, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC1AE7F, 0xFF463F2D, 0xFF000000, 0xFF504834, 0xFFBCA97A, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA977, 0xFFBDA877, 
        0xFFBDA876, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFB9A571, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A26D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 
        0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19961, 0xFFB09961, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 
        0xFFAC945A, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFF2C2515, 0xFF000000, 0xFF7C6A3C, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 
        0xFFA3894B, 0xFF5D4E2A, 0xFF000000, 0xFF39301A, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08545, 0xFFA08545,
  0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFF987F44, 0xFF221C0F, 0xFF000000, 0xFF8A743E, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF7D693B, 0xFF040302, 0xFF302817, 0xFFA78E52, 0xFFA78E52, 0xFFA88E53, 0xFFA89054, 
        0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 
        0xFFB19A63, 0xFFB19B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB8A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 
        0xFFBAA471, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA78, 0xFFBEAA79, 0xFF322D20, 0xFF000000, 0xFF7B6E4F, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7E, 
        0xFFB19F74, 0xFF080705, 0xFF0D0B08, 0xFF978864, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 
        0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C199, 
        0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFDFD1B1, 
        0xFFDFD1B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE1D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D5B7, 0xFFE3D6B6, 0xFFE2D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 
        0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE4D7BA, 0xFFE5D8BA, 0xFFE5D7BA, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 
        0xFFE4D8B9, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B7, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B7, 0xFFE2D5B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE2D4B4, 
        0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 
        0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 
        0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 
        0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B88C, 0xFFC9B78B, 0xFFC8B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 0xFF3A3527, 
        0xFF000000, 0xFF645A43, 0xFFC3B082, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFA19069, 0xFF000000, 0xFF16140E, 0xFFB3A174, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 
        0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F69, 0xFFB59E69, 
        0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFF534729, 0xFF000000, 0xFF514527, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA3894B, 0xFF89733F, 0xFF000000, 0xFF221C0F, 0xFF988044, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFF9F8545,
  0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF85703B, 0xFF110E07, 0xFF080704, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4E, 0xFFA58B4E, 0xFFA68C4F, 0xFF645530, 0xFF000000, 0xFF665631, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 
        0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A370, 0xFFB9A370, 0xFFB9A471, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA877, 0xFFBDA877, 0xFFBDA978, 0xFFBEAA79, 0xFFB09C70, 0xFF000000, 0xFF0B0A07, 0xFFAD9B6F, 0xFFC0AC7C, 0xFFC1AD7C, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 
        0xFF6C6147, 0xFF000000, 0xFF2A261C, 0xFFC2AF81, 0xFFC4B183, 0xFFC4B183, 0xFFC5B184, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC8B589, 0xFFC8B58A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B88C, 0xFFCAB88D, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD2C199, 0xFFD2C19A, 
        0xFFD2C29B, 0xFFD3C39B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD2B1, 
        0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE2D5B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE4D7B9, 
        0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 
        0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D5B6, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 
        0xFFE2D5B5, 0xFFE2D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 
        0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C198, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBD93, 
        0xFFCDBC93, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFFC6B386, 0xFF9E8F6A, 
        0xFF000000, 0xFF2B261C, 0xFFB8A67B, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC3AF80, 0xFFC2AE7F, 0xFFC1AE7E, 0xFF242017, 0xFF000000, 0xFF8E7F5B, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBFAA79, 0xFFBEA978, 0xFFBDA978, 
        0xFFBDA977, 0xFFBCA876, 0xFFBCA775, 0xFFBCA774, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 
        0xFFB59E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A62, 0xFFB19A62, 0xFFB19961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD965C, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA78F53, 0xFF806D3F, 0xFF000000, 0xFF2D2616, 0xFFA68D4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA3894B, 0xFF080603, 0xFF110E07, 0xFF86703C, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08545,
  0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18748, 0xFF746133, 0xFF000000, 0xFF342C18, 0xFFA3894A, 0xFFA4894C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58C4E, 0xFFA2894D, 0xFF423820, 0xFF000000, 0xFF98814A, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA98F54, 
        0xFFA99054, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD945B, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 
        0xFFB29B63, 0xFFB29B64, 0xFFB29C65, 0xFFB29C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A370, 0xFFB9A370, 0xFFBAA471, 
        0xFFBAA572, 0xFFBBA572, 0xFFBBA673, 0xFFBCA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF63583F, 0xFF000000, 0xFF403929, 0xFFB9A678, 0xFFC0AC7C, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFBEAA7C, 
        0xFF332D21, 0xFF000000, 0xFF6D6248, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC8B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 
        0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBD93, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 
        0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 
        0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D6B6, 0xFFE2D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8B9, 
        0xFFE4D8B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 
        0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D6B6, 0xFFE2D5B6, 
        0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 
        0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCBA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8CAA6, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 
        0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 
        0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B386, 0xFFC6B385, 
        0xFF1E1B14, 0xFF000000, 0xFFA0906A, 0xFFC4B183, 0xFFC4B182, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7E, 0xFF6D6247, 0xFF000000, 0xFF403929, 0xFFC0AC7C, 0xFFC0AB7C, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 
        0xFFBDA977, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA573, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 
        0xFFB59E69, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19962, 0xFFB09962, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAC955B, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF010100, 0xFF1A160D, 0xFF967F48, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 
        0xFFA38A4C, 0xFFA3894A, 0xFF342C17, 0xFF000000, 0xFF746233, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08546,
  0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA08647, 0xFF5A4B28, 0xFF000000, 0xFF6A5830, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA0874C, 0xFF1D180E, 0xFF100D07, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 
        0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9258, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC955B, 0xFFAD955B, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF985F, 0xFFB09860, 0xFFB09960, 0xFFB19961, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A36E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 
        0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBCA774, 0xFFBCA775, 0xFFBCA875, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFF1A1710, 0xFF000000, 0xFF736749, 0xFFC0AC7C, 0xFFC0AD7C, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF9F8E68, 
        0xFF110F0B, 0xFF040403, 0xFFB6A479, 0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC6B285, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B58A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98D, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C099, 0xFFD2C199, 0xFFD2C29A, 0xFFD2C29B, 
        0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C49F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 
        0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6D9BB, 0xFFE6D9BB, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE5D9BC, 0xFFE5D9BC, 0xFFE6D9BB, 0xFFE6D9BC, 0xFFE5D9BB, 
        0xFFE5D9BB, 0xFFE5D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D5B6, 
        0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDDD0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 
        0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 
        0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 
        0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA91, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B386, 
        0xFF72674D, 0xFF000000, 0xFF574F3B, 0xFFC4B183, 0xFFC4B183, 0xFFC3B082, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFA19169, 0xFF060604, 0xFF000000, 0xFFBAA778, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA78, 0xFFBEA977, 
        0xFFBDA977, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA472, 0xFFB9A470, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F69, 
        0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39B65, 0xFFB29C64, 0xFFB29A64, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFAF9860, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAC955B, 
        0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF262012, 0xFF090704, 0xFF826E3E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58A4D, 0xFFA48A4C, 
        0xFFA38A4C, 0xFFA3894B, 0xFF66572F, 0xFF000000, 0xFF5B4C29, 0xFFA08647, 0xFFA18747, 0xFFA08646, 0xFFA08546,
  0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFF9E8446, 0xFF382F19, 0xFF000000, 0xFF262011, 0xFF4C3F23, 0xFF6F5E33, 0xFF957E46, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58C4F, 0xFF9B834A, 0xFF000000, 0xFF3B321C, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 
        0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09A62, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29C64, 0xFFB39C65, 0xFFB39C65, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 
        0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA979, 0xFF998861, 0xFF040402, 0xFF11100B, 0xFFA4936A, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC2AE7F, 0xFFC1AD7E, 0xFF776B4E, 
        0xFF000000, 0xFF3E3829, 0xFFC3B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88E, 
        0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 
        0xFFD3C39C, 0xFFD3C39D, 0xFFD3C49D, 0xFFD4C59E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFDACAA7, 0xFFDACBA7, 0xFFDACBA8, 
        0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B3, 
        0xFFE1D4B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 
        0xFFE5D9BB, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 
        0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D5B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDDCFAE, 0xFFDDCFAD, 
        0xFFDDCFAD, 0xFFDCCEAD, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A1, 
        0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCEBD95, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCEBC92, 0xFFCDBC92, 0xFFCDBC91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC6B487, 0xFFC6B386, 
        0xFFA79771, 0xFF090806, 0xFF0A0907, 0xFFC4B184, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFFB5A377, 0xFF2E2A1E, 0xFF000000, 0xFF796D4F, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE965E, 0xFFAE975D, 0xFFAD955D, 0xFFAD955C, 0xFFAD955B, 
        0xFFAC945B, 0xFFAC935A, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA89054, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF594C2C, 0xFF000000, 0xFF6D5C34, 0xFFA68C50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFF977F47, 
        0xFF746135, 0xFF4B3F22, 0xFF231D0F, 0xFF000000, 0xFF39301A, 0xFFA08547, 0xFFA18747, 0xFFA18647, 0xFFA08646,
  0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF9E8346, 0xFF17130A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF100E07, 0xFF3C321C, 0xFF6B5A32, 0xFF6C5B33, 0xFF000000, 0xFF62542F, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 
        0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29C65, 0xFFB29C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB5A06A, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA472, 
        0xFFBBA572, 0xFFBAA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFF5F553C, 0xFF010100, 0xFF000000, 0xFF201D14, 0xFF6A5F45, 0xFFAE9D71, 0xFFBEAA7D, 0xFFC1AD7E, 0xFFBEAB7D, 0xFF393426, 
        0xFF000000, 0xFF928461, 0xFFC3B082, 0xFFC4B183, 0xFFC5B283, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 
        0xFFCBB98F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 
        0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49D, 0xFFD5C59E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACCA9, 
        0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 
        0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 
        0xFFE5D9BB, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DABD, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DABD, 0xFFE6DBBD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 
        0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B8, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 
        0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD8C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A1, 
        0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39D, 0xFFD3C39B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBF96, 0xFFCFBD95, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B387, 
        0xFFBBA97F, 0xFF363125, 0xFF000000, 0xFF8C7F5E, 0xFFC4B183, 0xFFC4B182, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AF7F, 0xFFC2AE7F, 0xFF574E39, 0xFF000000, 0xFF302B1F, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFB9A471, 0xFFB9A471, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 
        0xFFAD955B, 0xFFAC9459, 0xFFAB9359, 0xFFAB9359, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA78E53, 0xFF8A7644, 0xFF000000, 0xFF4E4225, 0xFF977F49, 0xFF6D5C34, 0xFF3E341D, 0xFF15120A, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF17130A, 0xFF9D8346, 0xFFA18748, 0xFFA18647, 0xFFA08646,
  0xFFA08646, 0xFFA08647, 0xFFA18748, 0xFF967E43, 0xFF000000, 0xFF1F1A0E, 0xFF4D4123, 0xFF2C2514, 0xFF1B170C, 0xFF0B0905, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF7F6C3D, 0xFFA78E52, 0xFFA88F52, 0xFFA88F54, 0xFFA88F54, 0xFFA89055, 
        0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965C, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19B63, 
        0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 
        0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBEA977, 0xFFBEAA78, 0xFFBAA676, 0xFF332E21, 0xFF000000, 0xFF0E0C09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF302B1F, 0xFF6C6147, 0xFF887B59, 0xFF030302, 
        0xFF13110C, 0xFFBFAC7F, 0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B386, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B588, 0xFFC8B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 
        0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 
        0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C8A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFDACAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 
        0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 
        0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 
        0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE6DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DABE, 
        0xFFE7DBBE, 0xFFE7DABD, 0xFFE7DABD, 0xFFE6DABD, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE3D7B8, 
        0xFFE4D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFDFD2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 
        0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 
        0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD95, 
        0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B689, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 
        0xFFC6B386, 0xFF655B44, 0xFF000000, 0xFF3C3628, 0xFFC4B184, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFBCA97B, 0xFF9B8B66, 0xFF776B4E, 0xFF2C281D, 0xFF000000, 0xFF0D0C08, 0xFFAE9C70, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 
        0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06A, 0xFFB59F6A, 
        0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 
        0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF010100, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0905, 
        0xFF1B170C, 0xFF2C2514, 0xFF453A1F, 0xFF1B170C, 0xFF000000, 0xFF977E43, 0xFFA18748, 0xFFA18647, 0xFFA08646,
  0xFFA08646, 0xFFA08647, 0xFFA18748, 0xFF796536, 0xFF000000, 0xFF514324, 0xFFA3894B, 0xFFA08649, 0xFF937B44, 0xFF836F3D, 0xFF715F34, 0xFF524527, 0xFF322A18, 0xFF010100, 0xFF110E08, 0xFF8D7844, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 
        0xFFAA9155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 
        0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 
        0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFA29167, 0xFF17150F, 0xFF000000, 0xFF8E7F5B, 0xFF867856, 0xFF4E4632, 0xFF110F0B, 0xFF000000, 0xFF000000, 0xFF040403, 0xFF000000, 
        0xFF504835, 0xFFC2AE80, 0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B486, 0xFFC7B487, 0xFFC7B487, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCBBA90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C29C, 0xFFD3C39C, 
        0xFFD3C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 
        0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 
        0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 
        0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DBBF, 0xFFE7DBBF, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DCBF, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBF, 
        0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 
        0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 
        0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDCCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 
        0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 
        0xFFCFBD95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 
        0xFFC7B487, 0xFF968865, 0xFF0A0907, 0xFF0F0D0A, 0xFFBCAA7E, 0xFFC4B183, 0xFFA5946D, 0xFF655B43, 0xFF332D21, 0xFF0F0E0A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060604, 0xFF807453, 0xFFC0AC7B, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 
        0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A06C, 0xFFB6A06B, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB39D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19961, 0xFFB09961, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE955C, 0xFFAD955B, 
        0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9256, 0xFFAA9155, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA68D51, 0xFF272113, 0xFF000000, 0xFF16130A, 0xFF352D19, 0xFF504426, 0xFF6F5E34, 0xFF816E3C, 
        0xFF927B43, 0xFFA18749, 0xFFA3894B, 0xFF504324, 0xFF000000, 0xFF796636, 0xFFA18748, 0xFFA18647, 0xFFA08646,
  0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF514324, 0xFF000000, 0xFF6B5A30, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFF000000, 0xFF241E11, 0xFF9B834B, 0xFFA78F52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 
        0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB19961, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 
        0xFFB29B65, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D68, 0xFFB49E68, 0xFFB59E68, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 
        0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF897A57, 0xFF000000, 0xFF15130D, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFBFAB7C, 0xFFBAA77A, 0xFF91835E, 0xFF363123, 0xFF000000, 0xFF000000, 
        0xFF877959, 0xFFC4B082, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98F, 
        0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD94, 0xFFCEBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 
        0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 
        0xFFE2D5B6, 0xFFE2D6B6, 0xFFE2D6B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 
        0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DCBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 
        0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 
        0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 
        0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A3, 
        0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C49F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 
        0xFFCFBD95, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B488, 0xFFC7B487, 
        0xFFC6B486, 0xFFC2B083, 0xFF1B1812, 0xFF040403, 0xFF453E2E, 0xFF221F17, 0xFF030302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1C1A13, 0xFF73674B, 0xFF322D21, 0xFF000000, 0xFF554C37, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBEAA7A, 0xFFBEAA79, 
        0xFFBEAA78, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA776, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB39D67, 0xFFB39D66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 
        0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF4C4125, 0xFF000000, 0xFF8F7945, 0xFFA48A4F, 0xFFA48B4D, 0xFFA58B4E, 0xFFA48B4D, 
        0xFFA48A4D, 0xFFA4894B, 0xFFA3894B, 0xFF6A5930, 0xFF000000, 0xFF514424, 0xFFA18748, 0xFFA18647, 0xFFA08646,
  0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFF272111, 0xFF020201, 0xFF7E6A39, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF8A7441, 0xFF000000, 0xFF362E1A, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 
        0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAC9359, 0xFFAC9459, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9960, 0xFFB09961, 0xFFB09962, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 
        0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB49F69, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA573, 
        0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBDA978, 0xFF5B523A, 0xFF000000, 0xFF584E38, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFBEAC7D, 0xFF000000, 0xFF16140F, 
        0xFFA5956E, 0xFFC4B082, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 
        0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD4C49D, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C8A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFD9CBA7, 0xFFDACBA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 
        0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 
        0xFFE2D6B6, 0xFFE3D6B6, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 
        0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 
        0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE7DCBF, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DCBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 
        0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1AF, 
        0xFFDED0AF, 0xFFDED0AF, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 
        0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBB91, 0xFFCCBA91, 0xFFCCBA90, 0xFFCBBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 
        0xFFC7B487, 0xFFC6B386, 0xFF4B4433, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF13120D, 0xFF2E2A1F, 0xFF695F45, 0xFFA4936B, 0xFFC2AF80, 0xFFC2AE7F, 0xFF7F7253, 0xFF000000, 0xFF322D20, 0xFFB5A275, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAA79, 0xFFBEAA79, 
        0xFFBEAA78, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB09962, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD955B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF6E5E36, 0xFF000000, 0xFF705F36, 0xFFA68C50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4E, 
        0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF7D6939, 0xFF020201, 0xFF282112, 0xFFA18748, 0xFFA18647, 0xFFA08647,
  0xFFA08646, 0xFFA18747, 0xFFA28748, 0xFF060503, 0xFF141109, 0xFF8B753F, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFF645530, 0xFF000000, 0xFF4E4226, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 
        0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09960, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 
        0xFFB29C64, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 
        0xFFBBA673, 0xFFBCA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBCA878, 0xFF262218, 0xFF000000, 0xFF9B8B63, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF786C4F, 0xFF000000, 0xFF342F22, 
        0xFFC0AC7F, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC6B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 
        0xFFCCBA90, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 
        0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAB, 
        0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 
        0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE7DBBF, 0xFFE7DBBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 
        0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCCAA, 0xFFDBCCAA, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C59E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 
        0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B488, 
        0xFFC7B487, 0xFFC6B386, 0xFF958664, 0xFF000000, 0xFF13110C, 0xFF70664B, 0xFFA2926C, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFFB9A779, 0xFF000000, 0xFF0F0D09, 0xFFA7956B, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA79, 
        0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA573, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26F, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB19B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 
        0xFFAD955C, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88E53, 0xFF826E3F, 0xFF000000, 0xFF473C22, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 
        0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF8B7540, 0xFF141109, 0xFF070603, 0xFFA18748, 0xFFA18747, 0xFFA18647,
  0xFFA08647, 0xFFA18647, 0xFF927940, 0xFF000000, 0xFF221C0F, 0xFF987F45, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF3F351E, 0xFF010100, 0xFF6C5B34, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 
        0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 
        0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D68, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A26D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBBA572, 0xFFBBA573, 
        0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFB4A172, 0xFF000000, 0xFF0E0D09, 0xFFB9A576, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF3D3728, 0xFF000000, 0xFF5E553E, 
        0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B689, 0xFFC9B68A, 0xFFC8B68A, 0xFFCAB78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCBB98D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 
        0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BE96, 0xFFD0BF96, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 
        0xFFD5C59E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCEAB, 
        0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDECFAE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCBF, 
        0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC1, 0xFFE9DDC2, 0xFFE9DEC2, 
        0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DABE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BB, 
        0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCEAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49F, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBF96, 
        0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB88E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC7B588, 0xFFC7B588, 
        0xFFC7B487, 0xFFC6B386, 0xFFC6B386, 0xFF060604, 0xFF0D0B08, 0xFFA6966F, 0xFFC4B183, 0xFFC4B082, 0xFFC3B082, 0xFFC3AF80, 0xFFC3AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF2A251B, 0xFF000000, 0xFF8D7E5B, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7A, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBAA673, 0xFFBAA572, 0xFFBAA572, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB39D67, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAD965D, 0xFFAD965C, 
        0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAB935A, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF8E7946, 0xFF110E08, 0xFF1D190E, 0xFFA68D50, 0xFFA58C50, 0xFFA58C4E, 0xFFA58B4E, 
        0xFFA58B4D, 0xFFA48A4C, 0xFFA3894B, 0xFF977F45, 0xFF221C0F, 0xFF000000, 0xFF927A42, 0xFFA18747, 0xFFA18647,
  0xFFA18647, 0xFFA18747, 0xFF726033, 0xFF000000, 0xFF312916, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF231D10, 0xFF050402, 0xFF897442, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFAA9155, 
        0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAE955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 
        0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 
        0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA79, 0xFF827453, 0xFF000000, 0xFF3C3627, 0xFFBCA97A, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFB7A478, 0xFF1D1A13, 0xFF030302, 0xFF938562, 
        0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 
        0xFFCCBA91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C099, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 
        0xFFD4C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 
        0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE2D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 
        0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DCC0, 
        0xFFE8DDC1, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DEC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC2, 0xFFE9DEC2, 0xFFEADEC2, 0xFFE9DEC3, 0xFFEADEC3, 0xFFE9DEC3, 0xFFEADEC2, 0xFFEADEC2, 0xFFEADEC2, 0xFFEADEC2, 
        0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC0, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 
        0xFFE5D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD1B1, 
        0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A4, 0xFFD8C8A4, 
        0xFFD8C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 
        0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 
        0xFFC7B488, 0xFFC6B486, 0xFFC6B386, 0xFF463F2F, 0xFF000000, 0xFF897C5B, 0xFFC4B183, 0xFFC4B183, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF665C42, 0xFF000000, 0xFF5A503A, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA774, 0xFFBCA674, 0xFFBBA573, 0xFFBAA573, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09861, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 
        0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF9B834C, 0xFF241E11, 0xFF020201, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 
        0xFFA48B4D, 0xFFA48A4C, 0xFFA3894C, 0xFFA3894B, 0xFF312916, 0xFF000000, 0xFF726033, 0xFFA18747, 0xFFA18647,
  0xFFA18647, 0xFFA18747, 0xFF554826, 0xFF000000, 0xFF463B20, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF9C844A, 0xFF14110A, 0xFF070603, 0xFFA28A4E, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99055, 0xFFA99155, 0xFFA99056, 
        0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC945A, 0xFFAC945A, 0xFFAD945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29A64, 0xFFB29B65, 
        0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBBA572, 0xFFBBA673, 
        0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFF453E2C, 0xFF000000, 0xFF6A5F44, 0xFFBFAB7B, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF968762, 0xFF0D0C09, 0xFF0C0B08, 0xFFC0AD80, 
        0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B488, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B78A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 
        0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BE97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A3, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 
        0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B1, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D7B8, 
        0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC1, 0xFFE9DDC0, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFE9DDC2, 0xFFE9DDC2, 0xFFE9DDC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADEC4, 0xFFEADFC3, 0xFFEADFC4, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADEC4, 0xFFEADFC4, 0xFFEADEC3, 0xFFEADEC3, 
        0xFFEADEC3, 0xFFEADEC2, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC1, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6D9BC, 
        0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 
        0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8CAA5, 0xFFD8C9A4, 
        0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39B, 0xFFD3C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 0xFFCFBF97, 
        0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 
        0xFFC7B488, 0xFFC6B487, 0xFFC6B486, 0xFF887B5B, 0xFF000000, 0xFF544C38, 0xFFC4B283, 0xFFC4B183, 0xFFC3B082, 0xFFC3B082, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFF9C8D66, 0xFF000000, 0xFF242017, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 
        0xFFBFAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA673, 0xFFBAA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB19961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAD965D, 
        0xFFAD955C, 0xFFAC955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9258, 0xFFAB9257, 0xFFAA9256, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA68C51, 0xFF332B18, 0xFF000000, 0xFF917B45, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 
        0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF463B20, 0xFF000000, 0xFF554726, 0xFFA18748, 0xFFA18647,
  0xFFA18647, 0xFFA18748, 0xFF352C18, 0xFF010100, 0xFF60512C, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4F, 0xFF887341, 0xFF0D0B06, 0xFF19150C, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFA99156, 
        0xFFAA9157, 0xFFAA9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD945B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19B63, 0xFFB29B64, 0xFFB29C65, 
        0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16D, 0xFFB8A16E, 0xFFB8A26E, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA573, 0xFFBBA573, 
        0xFFBBA774, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA979, 0xFFBFAA79, 0xFF0F0E0A, 0xFF030302, 0xFF8C7D5A, 0xFFC0AC7C, 0xFFC1AC7D, 0xFFC0AD7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFF776B4E, 0xFF000000, 0xFF383325, 0xFFC4B082, 
        0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 0xFFC5B384, 0xFFC6B386, 0xFFC6B386, 0xFFC7B486, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B88C, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C099, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCFAC, 
        0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 
        0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC2, 
        0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 
        0xFFEADFC4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADEC2, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DBBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE7DABD, 
        0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 
        0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 
        0xFFD0BF96, 0xFFCFBE96, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B589, 0xFFC7B589, 
        0xFFC7B588, 0xFFC7B487, 0xFFC6B386, 0xFFB2A178, 0xFF000000, 0xFF1C1913, 0xFFC5B183, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFFB29F74, 0xFF110F0B, 0xFF000000, 0xFFB9A678, 0xFFC0AC7C, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 
        0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAE965D, 
        0xFFAD965C, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9256, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF483D22, 0xFF000000, 0xFF6E5D35, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 
        0xFFA48B4E, 0xFFA48A4C, 0xFFA48A4B, 0xFFA3894B, 0xFF60502B, 0xFF010100, 0xFF362D18, 0xFFA18748, 0xFFA18647,
  0xFFA18747, 0xFFA18749, 0xFF211C0F, 0xFF030201, 0xFF786537, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF776539, 0xFF050402, 0xFF3A311C, 0xFFA78E51, 0xFFA88F52, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99156, 
        0xFFAA9256, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF985F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19B63, 0xFFB29B64, 0xFFB29B65, 
        0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49E67, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 
        0xFFBCA674, 0xFFBCA775, 0xFFBCA875, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFA9966C, 0xFF000000, 0xFF16140E, 0xFFA19168, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFBEAB7D, 0xFF534B37, 0xFF000000, 0xFF756A4D, 0xFFC4B082, 
        0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC6B285, 0xFFC6B386, 0xFFC6B386, 0xFFC7B488, 0xFFC7B488, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB90, 
        0xFFCDBB92, 0xFFCDBB92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 
        0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAD, 
        0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D8B9, 
        0xFFE5D8B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE6D9BB, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 
        0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C4, 0xFFEBE0C4, 0xFFEBE0C4, 0xFFEBDFC5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 
        0xFFEBE0C4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADFC4, 0xFFEADFC4, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 
        0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 
        0xFFE0D2B1, 0xFFE0D2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 
        0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 
        0xFFCFBF96, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B689, 0xFFC8B589, 
        0xFFC7B588, 0xFFC7B487, 0xFFC6B387, 0xFFBCAA7F, 0xFF29251C, 0xFF000000, 0xFFB9A77C, 0xFFC4B183, 0xFFC4B082, 0xFFC3B082, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AE7F, 0xFFB9A679, 0xFF353023, 0xFF000000, 0xFF8C7D5B, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 
        0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBBA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB6A06C, 
        0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49D68, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAE965D, 
        0xFFAD965C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9256, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF61522F, 0xFF000000, 0xFF524527, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 
        0xFFA58B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF786436, 0xFF030201, 0xFF211C0F, 0xFFA18748, 0xFFA18747,
  0xFFA18647, 0xFF977E43, 0xFF17130A, 0xFF030301, 0xFF917941, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF645430, 0xFF000000, 0xFF594B2B, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 
        0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB39C64, 
        0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB7A270, 0xFFA29062, 0xFFB49F6F, 0xFFBBA673, 0xFFBBA673, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFF7B6E4E, 0xFF000000, 0xFF29251B, 0xFFB7A476, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFB8A579, 0xFF2D291E, 0xFF000000, 0xFFAD9C73, 0xFFC4B082, 
        0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 
        0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBD95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD1C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 
        0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 
        0xFFDDCFAE, 0xFFDECFAE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D5B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 
        0xFFE5D8BA, 0xFFE4D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC3, 
        0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 
        0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADEC4, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBE, 
        0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 
        0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED0B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA5, 
        0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39B, 0xFFD2C29B, 0xFFD1C29A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 
        0xFFC8B588, 0xFFC7B487, 0xFFC6B487, 0xFFC2AF83, 0xFF504936, 0xFF000000, 0xFF817456, 0xFFC4B183, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC2AF81, 0xFFC2AF7F, 0xFFC0AC7E, 0xFF574F39, 0xFF000000, 0xFF554C37, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 
        0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE965E, 0xFFAE965D, 
        0xFFAD965C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88E53, 0xFF78663B, 0xFF030201, 0xFF302917, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 
        0xFFA58B4E, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF917941, 0xFF030301, 0xFF17130A, 0xFF967E43, 0xFFA18747,
  0xFFA18747, 0xFF87713C, 0xFF100D07, 0xFF070603, 0xFFA3894B, 0xFFA4894B, 0xFFA38A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF534627, 0xFF000000, 0xFF7B693C, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFF847143, 
        0xFFA28B52, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAE955D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09861, 0xFFB19962, 0xFFB19962, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 
        0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A470, 0xFFB39E6D, 0xFF352F20, 0xFF9A885F, 0xFFBBA673, 0xFFBBA674, 
        0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFF504733, 0xFF000000, 0xFF3F3929, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFB2A175, 0xFF070605, 0xFF110F0B, 0xFFC4B082, 0xFFC4B082, 
        0xFFC4B184, 0xFFC5B284, 0xFFC5B284, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC7B488, 0xFFC8B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BE96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 
        0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAD, 0xFFDDCFAD, 
        0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE5D8BA, 
        0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABC, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DDC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 
        0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 
        0xFFECE1C6, 0xFFEBE0C6, 0xFFECE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DCC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 
        0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 
        0xFFE0D3B3, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 
        0xFFD0BF97, 0xFFD0BE96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 
        0xFFC8B589, 0xFFC7B488, 0xFFC6B487, 0xFFC6B486, 0xFF75694F, 0xFF000000, 0xFF474030, 0xFFC4B183, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFF786C4E, 0xFF000000, 0xFF242017, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB6A16C, 
        0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAE975F, 0xFFAE975E, 0xFFAE965D, 
        0xFFAE965C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFF917B47, 0xFF050502, 0xFF1C180D, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4E, 
        0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894A, 0xFF070603, 0xFF100D07, 0xFF88723C, 0xFFA18748,
  0xFFA18747, 0xFF796536, 0xFF080704, 0xFF1D190D, 0xFFA3894A, 0xFFA38A4C, 0xFFA38A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA1884D, 0xFF3F351E, 0xFF000000, 0xFF978149, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99155, 0xFFA99156, 0xFF0E0B07, 
        0xFF826F42, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09861, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 
        0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A470, 0xFFB9A471, 0xFFAF9A6A, 0xFF080705, 0xFF97855D, 0xFFBBA673, 0xFFBBA674, 
        0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFF2A261B, 0xFF000000, 0xFF020201, 0xFF16140E, 0xFF443D2C, 0xFF7B6E4F, 0xFFAB996F, 0xFFC2AE7F, 0xFF9B8C66, 0xFF000000, 0xFF413B2B, 0xFFC4B082, 0xFFC4B183, 
        0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 
        0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 
        0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 
        0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE8DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBDFC4, 
        0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C5, 0xFFEBE0C6, 0xFFEBE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE1C7, 0xFFEDE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFEBE0C6, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEADFC4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 
        0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBD, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BC, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B3, 
        0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDCCEAD, 0xFFDCCEAC, 0xFFDBCDAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 
        0xFFD8C9A5, 0xFFD8C9A5, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD0C098, 0xFFD0C098, 
        0xFFD0C097, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBA91, 0xFFCCBA90, 0xFFCBBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 
        0xFFC8B589, 0xFFC7B488, 0xFFC7B487, 0xFFC6B387, 0xFF918362, 0xFF0A0906, 0xFF14120D, 0xFFC4B284, 0xFFC4B183, 0xFFC3B082, 0xFFC3B082, 0xFFC3AF81, 0xFFC2AF80, 0xFFBEAB7D, 0xFF7D7052, 0xFF080705, 0xFF070604, 0xFFBBA77A, 0xFFBFAC7B, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB6A06C, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 
        0xFFAE965D, 0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA58C51, 0xFF080704, 0xFF141109, 0xFF99824A, 0xFFA58C4F, 0xFFA58C4E, 
        0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4B, 0xFFA3894A, 0xFF1D180D, 0xFF080704, 0xFF796637, 0xFFA18747,
  0xFFA18748, 0xFF6B5A30, 0xFF000000, 0xFF362D18, 0xFFA3894A, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF9D854B, 0xFF2E2616, 0xFF010100, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFF070603, 
        0xFF6E5E38, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 
        0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E69, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A471, 0xFF736646, 0xFF000000, 0xFF97865D, 0xFFBBA673, 0xFFBBA674, 
        0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFAE9C6F, 0xFF1D1A12, 0xFF000000, 0xFF100E0A, 0xFF040402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080705, 0xFF191610, 0xFF000000, 0xFF6F644A, 0xFFC4B182, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29A, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C5A0, 
        0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 
        0xFFDED0AE, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE2D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE2D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 
        0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABE, 0xFFE7DBBE, 0xFFE7DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBE0C5, 
        0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE2C7, 0xFFECE2C7, 0xFFEDE2C7, 0xFFEDE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE2C7, 0xFFEDE2C7, 0xFFEDE2C7, 0xFFECE1C7, 
        0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFEBE1C6, 0xFFECE1C6, 0xFFECE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEAE0C4, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 
        0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 
        0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 
        0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 
        0xFFD0C097, 0xFFD0BF97, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBC92, 0xFFCCBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B689, 
        0xFFC8B589, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFAA9973, 0xFF171510, 0xFF030202, 0xFFB09F76, 0xFFB5A379, 0xFFA4936D, 0xFF8F815F, 0xFF6B6046, 0xFF342E22, 0xFF090806, 0xFF000000, 0xFF000000, 0xFF040402, 0xFF978762, 0xFFC0AC7B, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBFAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB6A06C, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 
        0xFFAE965D, 0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9256, 0xFFAA9156, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFF19150C, 0xFF0E0C06, 0xFF8B7643, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF352C18, 0xFF000000, 0xFF6B5A30, 0xFFA18748,
  0xFFA18748, 0xFF5E4E2A, 0xFF000000, 0xFF524425, 0xFFA3894A, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF9A8249, 0xFF1A160C, 0xFF18150C, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFF000000, 
        0xFF463C23, 0xFFA89156, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 
        0xFFB39D66, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB7A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A370, 0xFFB19C6C, 0xFF110F0A, 0xFF080705, 0xFF97865D, 0xFFBBA673, 0xFFBBA774, 
        0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA979, 0xFF9A8A62, 0xFF12100B, 0xFF020201, 0xFF95865F, 0xFF887A58, 0xFF6C6146, 0xFF49412F, 0xFF221F16, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF958663, 0xFFC4B182, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B285, 0xFFC6B285, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B58A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 
        0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0C097, 0xFFD1C098, 0xFFD1C099, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C6A0, 
        0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 
        0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 
        0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DEC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C5, 
        0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE3C8, 0xFFEDE2C9, 0xFFEDE3C9, 0xFFEDE2C9, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C9, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE2C8, 
        0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 
        0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B5, 
        0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFD9CAA8, 0xFFD9CAA7, 
        0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 
        0xFFD0BF98, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBA91, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B68A, 0xFFC8B68A, 
        0xFFC8B589, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFFC2AF83, 0xFF242018, 0xFF000000, 0xFF312C21, 0xFF29251B, 0xFF0F0D0A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1D1A13, 0xFF090805, 0xFF020201, 0xFF76694C, 0xFFC0AC7C, 0xFFC0AB7B, 
        0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA674, 0xFFB9A473, 0xFFB8A471, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E67, 0xFFB39D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975D, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD945B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFA99157, 0xFFA89056, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88E52, 0xFF332B18, 0xFF060503, 0xFF7A673A, 0xFFA68C4F, 0xFFA58C4E, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF514425, 0xFF000000, 0xFF5E4E2A, 0xFFA18748,
  0xFFA08647, 0xFF4E4123, 0xFF000000, 0xFF6F5D32, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58C4F, 0xFF957E47, 0xFF080704, 0xFF302817, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99156, 0xFFAA9156, 0xFF020101, 
        0xFF070603, 0xFF98824E, 0xFFAB9359, 0xFFAC935A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 
        0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFF302B1D, 0xFF000000, 0xFF0A0906, 0xFF97865D, 0xFFBBA674, 0xFFBBA774, 
        0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFF867856, 0xFF050503, 0xFF110F0B, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFBDA97B, 0xFFBAA77A, 0xFFB4A276, 0xFF080705, 0xFF0B0A07, 0xFFA6966F, 0xFFC4B182, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B88C, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBB91, 
        0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0C097, 0xFFD0BF98, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 
        0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 
        0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 
        0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE8DBBE, 0xFFE8DBBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE8DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFEBE1C6, 0xFFECE1C7, 
        0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE3C9, 
        0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADEC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 
        0xFFE9DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE1D4B5, 
        0xFFE1D4B4, 0xFFE1D4B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA7, 0xFFD9CAA7, 
        0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49F, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 
        0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B68A, 0xFFC8B68A, 
        0xFFC8B689, 0xFFC7B589, 0xFFC7B587, 0xFFC7B487, 0xFFC6B487, 0xFF3B3628, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF2D281E, 0xFF615840, 0xFF8B7C5B, 0xFFAB9A70, 0xFFC1AD7E, 0xFF3B3527, 0xFF000000, 0xFF584F39, 0xFFC0AC7C, 0xFFBFAB7B, 
        0xFFBFAB7B, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBBA774, 0xFF63573D, 0xFF463E2B, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB7A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAE975E, 0xFFAE975E, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFF74643C, 0xFF423922, 0xFFA89055, 0xFFAA9156, 0xFFA99156, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF4B4025, 0xFF000000, 0xFF6C5B34, 0xFFA68C4F, 0xFFA58C4F, 
        0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF6D5C32, 0xFF000000, 0xFF4E4123, 0xFFA08647,
  0xFF9D8446, 0xFF3F341C, 0xFF000000, 0xFF846F3C, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF927B45, 0xFF000000, 0xFF4C4025, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA98F54, 0xFFA99054, 0xFFAA9156, 0xFFAA9156, 0xFF020201, 
        0xFF000000, 0xFF322B1A, 0xFFAB9258, 0xFFAC9459, 0xFFAC955B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 
        0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFAA9666, 0xFF3D3625, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865D, 0xFFBBA674, 0xFFBBA674, 
        0xFFBCA875, 0xFFBCA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFF726649, 0xFF000000, 0xFF383224, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFB8A679, 0xFF000000, 0xFF242018, 0xFFB2A076, 0xFFC4B183, 0xFFC4B183, 
        0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B486, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB92, 
        0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD5C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 
        0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCFAD, 0xFFDDCFAD, 0xFFDDD0AE, 0xFFDED0AF, 
        0xFFDFD0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 
        0xFFE6DABC, 0xFFE6DBBD, 0xFFE7DABE, 0xFFE7DBBE, 0xFFE7DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEBDFC3, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFECE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 
        0xFFECE2C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3C9, 
        0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C5, 0xFFEBE0C5, 0xFFEBDFC5, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE6DBBD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 
        0xFFE1D4B4, 0xFFE1D4B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACAA7, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59E, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD1C199, 
        0xFFD1C098, 0xFFD0BF98, 0xFFD0BE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78A, 0xFFC8B68A, 
        0xFFC8B689, 0xFFC8B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B386, 0xFF645A43, 0xFF000000, 0xFF2C271D, 0xFFA0916B, 0xFFC2AF81, 0xFFC4B082, 0xFFC3AF82, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFF60573F, 0xFF000000, 0xFF3D3728, 0xFFC0AC7C, 0xFFC0AB7C, 
        0xFFBFAB7B, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA877, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFF5D5239, 0xFF3C3625, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB7A16C, 0xFFB69F6B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAE975E, 0xFFAE975E, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAB9359, 0xFF6F5F39, 0xFF3C331F, 0xFFA89055, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA99054, 0xFFA88F53, 0xFFA78E52, 0xFF6A5A34, 0xFF000000, 0xFF5D4F2D, 0xFFA68C4F, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF846F3C, 0xFF000000, 0xFF40351C, 0xFF9D8446,
  0xFF9A8145, 0xFF2F2715, 0xFF000000, 0xFFA3884A, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58C4E, 0xFFA58C4F, 0xFF867140, 0xFF000000, 0xFF62532F, 0xFFA78E52, 0xFFA78E52, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99156, 0xFFAA9156, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF483D25, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B65, 0xFFB29C65, 0xFFB39C66, 
        0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFF8E7D55, 0xFF292419, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865D, 0xFFBBA774, 0xFFBCA774, 
        0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBEA977, 0xFFBEA978, 0xFFBCA878, 0xFF5B513A, 0xFF000000, 0xFF5F553D, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFF928460, 0xFF000000, 0xFF3A3526, 0xFFBCA97C, 0xFFC4B083, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 
        0xFFCEBC93, 0xFFCEBD93, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 
        0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AF, 
        0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE3D5B6, 0xFFE2D6B7, 0xFFE3D6B7, 0xFFE4D6B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 
        0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DCBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC4, 0xFFEADFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFECE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 
        0xFFEDE2C7, 0xFFEDE2C9, 0xFFEDE2C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE4CB, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEEE4CB, 0xFFEFE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEEE4CA, 
        0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFEDE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEBE0C4, 0xFFEADFC4, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 
        0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 
        0xFFE2D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDED1B0, 0xFFDED1AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAC, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA7, 
        0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C199, 0xFFD1C199, 
        0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B68B, 0xFFC9B68A, 
        0xFFC8B68A, 0xFFC8B588, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFF8A7D5D, 0xFF000000, 0xFF353023, 0xFFC3B082, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFF867858, 0xFF000000, 0xFF2D281D, 0xFFB6A375, 0xFFC0AC7B, 
        0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFF5D5239, 0xFF2D281B, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 
        0xFFB7A06C, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 
        0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAC9359, 0xFF574B2D, 0xFF3E3520, 0xFFA89055, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88E52, 0xFF826F40, 0xFF000000, 0xFF4F4326, 0xFFA68C50, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF9E8547, 0xFF000000, 0xFF302815, 0xFF9B8145,
  0xFF987F44, 0xFF221D0F, 0xFF000000, 0xFF2E2614, 0xFF372E19, 0xFF4B3F23, 0xFF60512C, 0xFF756336, 0xFF8A7441, 0xFF9F864B, 0xFF6C5B33, 0xFF000000, 0xFF746338, 0xFFA78E52, 0xFFA78E52, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF423922, 0xFFA99259, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29A64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 
        0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A26D, 0xFF65593C, 0xFF0C0B07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865D, 0xFFBBA674, 0xFFBCA775, 
        0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA79, 0xFFB8A575, 0xFF413A2A, 0xFF000000, 0xFF867856, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFF6E6348, 0xFF000000, 0xFF4F4735, 0xFFC4B082, 0xFFC4B183, 0xFFC4B184, 
        0xFFC5B285, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 
        0xFFCEBC93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 
        0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AF, 0xFFDED0AF, 
        0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D6B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABD, 
        0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFECE0C5, 0xFFEBE1C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 
        0xFFEDE3C8, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CC, 0xFFEFE5CB, 0xFFEFE4CB, 
        0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADEC3, 0xFFEADEC2, 
        0xFFE9DEC2, 0xFFE9DEC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 
        0xFFE2D5B5, 0xFFE2D4B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 
        0xFFDACAA7, 0xFFD9CAA6, 0xFFD8C9A6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C199, 0xFFD1C199, 
        0xFFD1C099, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 
        0xFFC8B68A, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC6B487, 0xFFB1A077, 0xFF000000, 0xFF242018, 0xFFB1A177, 0xFFC4B183, 0xFFC4B182, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AE80, 0xFFA7966D, 0xFF000000, 0xFF1F1C14, 0xFFAA986D, 0xFFC0AC7C, 
        0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA977, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFF5D5339, 0xFF16130D, 0xFFA89568, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB7A26D, 0xFFB7A16D, 
        0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE965E, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC9459, 0xFF1E1A10, 0xFF423922, 0xFFA89055, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA78F53, 0xFF957F49, 0xFF000000, 0xFF40361F, 0xFFA0884D, 0xFF8F7944, 
        0xFF796639, 0xFF64542E, 0xFF4F4325, 0xFF3B321B, 0xFF2A2313, 0xFF1D180D, 0xFF000000, 0xFF221D0F, 0xFF987F44,
  0xFF957C42, 0xFF110E07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF887442, 0xFFA78E52, 0xFFA88F52, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3A321E, 0xFFA68F58, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB19961, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 
        0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFAD9867, 0xFF3F3725, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865E, 0xFFBBA774, 0xFFBCA775, 
        0xFFBCA876, 0xFFBDA877, 0xFFBDA877, 0xFFBEA977, 0xFFBEAA79, 0xFFB6A273, 0xFF2B261B, 0xFF000000, 0xFFAA996E, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFF494130, 0xFF000000, 0xFF675D44, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 
        0xFFC5B285, 0xFFC5B286, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C6A1, 
        0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCFAC, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AE, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE7DABD, 
        0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DEC1, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC4, 0xFFEADFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C9, 
        0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEFE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 
        0xFFEFE5CC, 0xFFEFE5CB, 0xFFEFE4CB, 0xFFEEE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE1C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADEC3, 
        0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DBBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE5D9BC, 0xFFE5D9BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 
        0xFFE1D5B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 
        0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9C9A6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C6A2, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 
        0xFFD1C099, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA91, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B68A, 
        0xFFC8B68A, 0xFFC8B58A, 0xFFC8B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B386, 0xFF030202, 0xFF16140F, 0xFFA3946E, 0xFFC4B183, 0xFFC4B182, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7E, 0xFF000000, 0xFF100E0A, 0xFF9E8D66, 0xFFC0AC7C, 
        0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFF5D5239, 0xFF000000, 0xFF5D5239, 0xFFB29E6D, 0xFFB7A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB7A26D, 0xFFB7A16D, 
        0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975E, 0xFFAE975E, 
        0xFFAE965E, 0xFFAD965C, 0xFFAD955C, 0xFFAB935A, 0xFFAC945A, 0xFF615332, 0xFF000000, 0xFF453B23, 0xFFA89055, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF000000, 0xFF030301, 0xFF030201, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF000000, 0xFF110E07, 0xFF957C42,
  0xFF947B42, 0xFF060503, 0xFF1A150B, 0xFF554726, 0xFF3E341C, 0xFF342B18, 0xFF2A2313, 0xFF211B0F, 0xFF17130B, 0xFF0E0C06, 0xFF020201, 0xFF000000, 0xFF8E7945, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF211C11, 0xFF8B784A, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 
        0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB5A06B, 0xFFB49E6A, 0xFF796A47, 0xFF12100B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865E, 0xFFBBA674, 0xFFBCA775, 
        0xFFBCA776, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFB3A072, 0xFF13110C, 0xFF000000, 0xFFBFAB7B, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE80, 0xFF2C271D, 0xFF040403, 0xFF7F7354, 0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 
        0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCEBC92, 
        0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C097, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C7A1, 
        0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 
        0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 
        0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E5CC, 0xFFF0E5CD, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CC, 0xFFF0E5CD, 0xFFF0E6CC, 0xFFF0E5CC, 
        0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE2C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC3, 
        0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D6B6, 
        0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 
        0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 
        0xFFD1C099, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78B, 0xFFC8B68B, 
        0xFFC8B68A, 0xFFC8B58A, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFFC6B386, 0xFF221F17, 0xFF060604, 0xFF978865, 0xFFC4B183, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFF17150F, 0xFF030201, 0xFF938460, 0xFFC0AC7C, 
        0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFF5D5339, 0xFF000000, 0xFF000000, 0xFF2C271B, 0xFF534932, 0xFF655A3E, 0xFF6D6041, 0xFF6F6243, 0xFF6E6142, 0xFF6E6142, 0xFF6D6041, 
        0xFF6D6040, 0xFF6D6040, 0xFF6D6040, 0xFF6C5F3F, 0xFF6C5F3F, 0xFF6C5E3E, 0xFF6C5E3E, 0xFF6C5E3D, 0xFF6B5E3D, 0xFF6B5D3C, 0xFF6A5D3C, 0xFF6A5D3C, 0xFF6A5C3B, 0xFF6A5D3B, 0xFF6A5C3B, 0xFF695B3A, 0xFF695B39, 0xFF695B39, 0xFF695A38, 0xFF685A38, 
        0xFF685A38, 0xFF675936, 0xFF625434, 0xFF55492C, 0xFF332C1B, 0xFF000000, 0xFF000000, 0xFF453A23, 0xFFA89056, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF080704, 0xFF010100, 0xFF100D07, 0xFF19150C, 
        0xFF1F1A0E, 0xFF2A2313, 0xFF322B17, 0xFF3F351D, 0xFF4C3F23, 0xFF5C4D2A, 0xFF1A160C, 0xFF060503, 0xFF947B42,
  0xFF927940, 0xFF000000, 0xFF362D18, 0xFFA3894B, 0xFFA3894B, 0xFFA2884B, 0xFF9C8449, 0xFF957F46, 0xFF907A45, 0xFF8F7844, 0xFF221D10, 0xFF0B0905, 0xFF937D48, 0xFFA78E52, 0xFFA78E53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFF020101, 
        0xFF080704, 0xFF695A36, 0xFF827043, 0xFF483E26, 0xFF000000, 0xFF000000, 0xFF0E0C07, 0xFF6F603B, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 
        0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFAB9664, 0xFF393221, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865E, 0xFFBCA674, 0xFFBCA775, 
        0xFFBCA776, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFAF9C6F, 0xFF000000, 0xFF18160F, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFF1A1711, 0xFF090806, 0xFF958763, 0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 
        0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBC93, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD7C8A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCDA9, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDED0AD, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 
        0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE2D6B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DABE, 
        0xFFE7DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DDC1, 0xFFE9DDC1, 0xFFE9DEC1, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE2C7, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 
        0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF1E6CE, 0xFFF0E6CE, 0xFFF1E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CD, 
        0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFECE2C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEADFC4, 
        0xFFEADFC3, 0xFFE9DFC2, 0xFFEADEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D5B6, 
        0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 
        0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C19A, 0xFFD1C19A, 
        0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB88E, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC8B68A, 0xFFC8B58A, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC6B386, 0xFF463F2F, 0xFF000000, 0xFF897C5C, 0xFFC4B184, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE7E, 0xFF383224, 0xFF000000, 0xFF857655, 0xFFC0AC7C, 
        0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFF5D5339, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453A23, 0xFFA89055, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88E52, 0xFF1E1A0E, 0xFF100D07, 0xFF826E3E, 0xFF927B45, 
        0xFF957E47, 0xFF9C834A, 0xFFA0884B, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF352D18, 0xFF000000, 0xFF927941,
  0xFF8A733E, 0xFF000000, 0xFF4A3E21, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA68C4E, 0xFFA58C4F, 0xFF1B170D, 0xFF14110A, 0xFF968049, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9157, 0xFF020201, 
        0xFF5B4E2F, 0xFFAB9359, 0xFFAB945A, 0xFFAC945A, 0xFF7C6A41, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF52472C, 0xFFAF975F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 
        0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFF7F6E49, 0xFF040402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865E, 0xFFBCA674, 0xFFBCA775, 
        0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFA39168, 0xFF000000, 0xFF312C1F, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFB19F74, 0xFF12100C, 0xFF0D0C09, 0xFFAB9A72, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 
        0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 
        0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD9C9A5, 0xFFD8CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDECFAF, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDFD1B0, 
        0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D4B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBF, 
        0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFEDE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CB, 
        0xFFEFE4CB, 0xFFEFE5CB, 0xFFEFE5CC, 0xFFEFE5CD, 0xFFEFE5CC, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF1E6CE, 0xFFF1E6CE, 0xFFF1E6CE, 0xFFF1E7CF, 0xFFF1E6CE, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF1E7CE, 0xFFF1E7CE, 0xFFF1E6CE, 0xFFF1E6CE, 
        0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE1C7, 0xFFECE1C7, 0xFFECE0C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBDFC4, 
        0xFFEADFC3, 0xFFEADFC3, 0xFFE9DEC2, 0xFFE9DEC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B6, 
        0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD8CAA6, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 
        0xFFD1C199, 0xFFD1C099, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B68B, 
        0xFFC9B68A, 0xFFC8B589, 0xFFC8B588, 0xFFC7B588, 0xFFC7B487, 0xFFC6B386, 0xFF675D45, 0xFF000000, 0xFF776C50, 0xFFC3B083, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3B080, 0xFFC2AE80, 0xFFC2AE7F, 0xFF544C37, 0xFF000000, 0xFF726649, 0xFFC0AC7C, 
        0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89055, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF2D2616, 0xFF090804, 0xFF967F48, 0xFFA68C4F, 
        0xFFA68C4F, 0xFFA48B4E, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4B, 0xFFA3894B, 0xFF4A3E21, 0xFF000000, 0xFF8B743E,
  0xFF796535, 0xFF000000, 0xFF584928, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4F, 0xFFA68C4F, 0xFF0C0A05, 0xFF221D10, 0xFF9B834B, 0xFFA78E52, 0xFFA78E53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFF0C0A06, 
        0xFF7D6B40, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFF9A8451, 0xFF231F13, 0xFF000000, 0xFF000000, 0xFF302A1A, 0xFF9B8654, 0xFFB09861, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19A64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 
        0xFFB49D67, 0xFFB49E68, 0xFF9F8B5B, 0xFF4A412B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1F1B12, 0xFF3B3424, 0xFF312C1E, 0xFF020101, 0xFF0A0906, 0xFF97865E, 0xFFBCA774, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEAA79, 0xFFBEAA79, 0xFF8B7C58, 0xFF000000, 0xFF49422F, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFA1916A, 0xFF0D0C09, 0xFF110F0B, 0xFFBDAB7E, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 
        0xFFC6B285, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B588, 0xFFC8B588, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB88E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 
        0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA8, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B1, 
        0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DCBF, 
        0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBE0C4, 0xFFECE0C5, 0xFFECE0C6, 0xFFECE1C6, 0xFFECE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEFE4CB, 
        0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 
        0xFFF1E6CE, 0xFFF1E6CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE4CC, 0xFFEFE4CB, 0xFFEFE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C5, 
        0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC1, 0xFFE9DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 
        0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDECFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C199, 
        0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B68A, 0xFFC8B68A, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC6B486, 0xFF877A5B, 0xFF000000, 0xFF625942, 0xFFC2AF81, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFF74684B, 0xFF000000, 0xFF5D533C, 0xFFBFAB7B, 
        0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA775, 0xFF5D5339, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453A23, 0xFFA89055, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF433921, 0xFF000000, 0xFF937D47, 0xFFA58C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF574927, 0xFF000000, 0xFF796535,
  0xFF6B5930, 0xFF000000, 0xFF65542E, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4F, 0xFFA58C4F, 0xFF000000, 0xFF2A2314, 0xFF9D854D, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFF060503, 
        0xFF847245, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFA48D57, 0xFF493E27, 0xFF000000, 0xFF000000, 0xFF18150D, 0xFF837248, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 
        0xFFB49D67, 0xFF6E603F, 0xFF1B1810, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080705, 0xFF685C3F, 0xFFA99566, 0xFFBAA470, 0xFFBAA572, 0xFF665A3E, 0xFF010100, 0xFF98875E, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEAA79, 0xFFBEAA79, 0xFF716548, 0xFF000000, 0xFF645A40, 0xFFC0AC7C, 0xFFC0AC7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFF91835F, 0xFF090806, 0xFF1D1A13, 0xFFC4B082, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 
        0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 
        0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD2B0, 
        0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D6B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BB, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE8DCBE, 
        0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC3, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFECE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEFE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 
        0xFFF0E5CC, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF0E7CE, 0xFFF1E7CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF2E7CF, 0xFFF1E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E7D0, 0xFFF2E8D0, 0xFFF1E7CF, 
        0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF0E7CE, 0xFFF1E6CE, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE2C9, 0xFFEDE2C9, 0xFFEDE2C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE0C6, 0xFFEBE0C5, 
        0xFFEBE0C5, 0xFFEADFC4, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 
        0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B0, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDACCA9, 
        0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 
        0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B68B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC6B486, 0xFFA4946F, 0xFF000000, 0xFF4E4634, 0xFFC2AE82, 0xFFC4B183, 0xFFC4B083, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFF938560, 0xFF000000, 0xFF4B4331, 0xFFBEAA7B, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA775, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFF4E4226, 0xFF000000, 0xFF917A45, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA38A4B, 0xFFA3894B, 0xFF64542D, 0xFF000000, 0xFF6C5A30,
  0xFF60502A, 0xFF000000, 0xFF766335, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF000000, 0xFF362D1A, 0xFFA1894F, 0xFFA88E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFF816F42, 
        0xFFA28B53, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955D, 0xFFAE965E, 0xFF6F603C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5F5234, 0xFFB19962, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFAB9662, 
        0xFF3A3321, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF211D14, 0xFF9E8B5F, 0xFFB8A26F, 0xFFB9A370, 0xFFBAA471, 0xFFBAA572, 0xFFB09B6B, 0xFF13100B, 0xFF97865D, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFF564D37, 0xFF000000, 0xFF0F0D09, 0xFF2A261B, 0xFF433C2B, 0xFF5E543D, 0xFF786C4E, 0xFF8C7E5C, 0xFF675D44, 0xFF040403, 0xFF302B1F, 0xFFC4B082, 0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 
        0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC93, 0xFFCEBD93, 
        0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAB, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD2B0, 
        0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 
        0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC2, 0xFFEADEC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE5CB, 0xFFEFE5CC, 
        0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7D0, 0xFFF1E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF2E8D0, 
        0xFFF2E8D0, 0xFFF1E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E6CC, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFECE2C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE0C5, 
        0xFFEBDFC5, 0xFFEBDFC4, 0xFFEADFC3, 0xFFE9DEC3, 0xFFEADEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFDFD2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B68B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B486, 0xFFB6A47B, 0xFF000000, 0xFF3D3728, 0xFFC5B184, 0xFFC4B183, 0xFFC4B082, 0xFFBFAB7E, 0xFFAC9B72, 0xFF8F805D, 0xFF706449, 0xFF4A4230, 0xFF000000, 0xFF332E21, 0xFFBEAA7B, 
        0xFFC0AC7C, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA7A, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88E52, 0xFF625430, 0xFF000000, 0xFF897442, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA4894B, 0xFFA3894B, 0xFF766335, 0xFF000000, 0xFF60512B,
  0xFF4E4123, 0xFF000000, 0xFF7D6939, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4F, 0xFF947D46, 0xFF000000, 0xFF3B321C, 0xFFA38B50, 0xFFA88E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 
        0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE975E, 0xFFAF975E, 0xFF89774A, 0xFF14110A, 0xFF000000, 0xFF000000, 0xFF463D27, 0xFFA5905C, 0xFFB19B63, 0xFFB29B64, 0xFFB09963, 0xFF88764D, 0xFF110F0A, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF090805, 0xFF574C33, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFB29E6E, 0xFF2C271B, 0xFF97865D, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEA979, 0xFFBEAA79, 0xFF453E2C, 0xFF000000, 0xFF040402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF413B2B, 0xFFC4B082, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 
        0xFFC5B386, 0xFFC6B386, 0xFFC6B486, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 
        0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29A, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A2, 0xFFD7C7A2, 
        0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 
        0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 
        0xFFE8DCC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFECE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE1C7, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E5CC, 
        0xFFF0E6CD, 0xFFF0E6CD, 0xFFF1E6CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF1E7D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF2E9D1, 0xFFF2E9D1, 0xFFF3E9D1, 0xFFF2E9D2, 0xFFF2E9D2, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D0, 
        0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE2C7, 0xFFECE1C6, 0xFFECE0C5, 
        0xFFEBE0C5, 0xFFEBE0C4, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BC, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D5B6, 0xFFE2D4B6, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B2, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 
        0xFFDACCA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C19A, 
        0xFFD2C199, 0xFFD1C199, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC6B487, 0xFFBFAC81, 0xFF030202, 0xFF100F0B, 0xFF3A3527, 0xFF27231A, 0xFF100E0A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF252118, 0xFFBDA97B, 
        0xFFC0AC7C, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA776, 0xFF5D533A, 0xFF000000, 0xFF14120C, 0xFF776A49, 0xFFA99667, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16B, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFF988351, 0xFF695B38, 0xFF14110A, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA78F53, 0xFF6C5C35, 0xFF000000, 0xFF776539, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA3894C, 0xFFA3894B, 0xFF7D6938, 0xFF000000, 0xFF4E4223,
  0xFF453A1F, 0xFF000000, 0xFF836D3B, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF887341, 0xFF000000, 0xFF423820, 0xFFA58C51, 0xFFA78E52, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAB9258, 
        0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFF968352, 0xFF332C1C, 0xFF000000, 0xFF000000, 0xFF2B2518, 0xFF907D50, 0xFFA48E5C, 0xFF473E28, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF332D1E, 0xFF918056, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA571, 0xFFBAA572, 0xFFB8A371, 0xFF897954, 0xFFAD9A6B, 0xFFBCA775, 0xFFBCA875, 
        0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFF352F21, 0xFF000000, 0xFF645940, 0xFF75694B, 0xFF675C43, 0xFF584F39, 0xFF49422F, 0xFF332E21, 0xFF13110C, 0xFF000000, 0xFF574E3A, 0xFFC4B082, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 
        0xFFC5B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 
        0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39B, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C8A2, 
        0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDCCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B1, 
        0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE6D9BB, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 
        0xFFE8DCC0, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEEE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E6CD, 
        0xFFF0E6CD, 0xFFF1E6CE, 0xFFF1E7CF, 0xFFF1E7D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF3E9D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3E9D3, 0xFFF3EAD3, 0xFFF3EAD2, 0xFFF3EAD2, 0xFFF3E9D1, 0xFFF3E9D2, 0xFFF2E9D2, 
        0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3C9, 0xFFEEE2C8, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFECE1C7, 0xFFECE1C6, 
        0xFFEBE0C5, 0xFFEBE0C5, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D7B8, 
        0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B5, 0xFFE1D5B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDBCCA9, 
        0xFFDACCA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C5A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29C, 0xFFD2C29A, 
        0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B588, 0xFFC7B488, 0xFFC7B487, 0xFFC2AF83, 0xFF100E0A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF090806, 0xFF181610, 0xFF2A251B, 0xFF342F22, 0xFF403A2A, 0xFF4B4431, 0xFF020201, 0xFF15120D, 0xFFBDA97A, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA875, 0xFF5D533A, 0xFF010100, 0xFF867752, 0xFFBBA573, 0xFFBAA572, 0xFFBAA571, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 
        0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975E, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC945B, 0xFF95804E, 0xFF000000, 0xFF443A23, 0xFFA89056, 0xFFAA9257, 0xFFAA9157, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF76643A, 0xFF000000, 0xFF6B5B33, 0xFFA58D4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4B, 0xFFA3894B, 0xFF826D3C, 0xFF000000, 0xFF463B1F,
  0xFF3E341C, 0xFF000000, 0xFF88723D, 0xFFA3894B, 0xFFA38A4B, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF816D3E, 0xFF000000, 0xFF4D4125, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9256, 0xFFAA9257, 0xFFAA9257, 
        0xFFAB9358, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 0xFFAD955C, 0xFFAD965C, 0xFFAD965D, 0xFFAE965E, 0xFFAE975F, 0xFFAF975F, 0xFFAF9860, 0xFFAA945D, 0xFF5A4E31, 0xFF000000, 0xFF000000, 0xFF0C0A07, 0xFF13110A, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF726443, 0xFFB19C69, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBCA774, 0xFFBCA775, 0xFFBCA776, 
        0xFFBDA877, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA78, 0xFFBFAA7A, 0xFF221E16, 0xFF000000, 0xFF9B8A64, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFBDA97C, 0xFFBAA77A, 0xFF564D38, 0xFF000000, 0xFF6D6248, 0xFFC4B082, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 
        0xFFC6B285, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 
        0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C198, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD6C7A2, 
        0xFFD7C8A3, 0xFFD7C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 
        0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B6, 0xFFE2D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 
        0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFECE1C6, 0xFFECE2C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E5CD, 0xFFF0E6CE, 
        0xFFF1E6CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E9D2, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3EAD2, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF3EAD2, 0xFFF3E9D2, 
        0xFFF3E9D2, 0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E6CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE2C7, 0xFFECE1C6, 
        0xFFECE0C6, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC1, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D7B8, 
        0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1AF, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCCA9, 
        0xFFDACCA9, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCCBB92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B488, 0xFFC7B487, 0xFFC2B083, 0xFF221E17, 0xFF050403, 0xFF938562, 0xFFA6956E, 0xFFAE9C73, 0xFFB2A177, 0xFFB6A478, 0xFFB9A67A, 0xFFBBA87B, 0xFFB8A579, 0xFF100F0A, 0xFF070604, 0xFFBDA97B, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF1E1B13, 0xFFB5A16F, 0xFFBBA573, 0xFFBAA572, 0xFFBAA472, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A26D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFF423922, 0xFF3F3620, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA99054, 0xFFA88F53, 0xFFA88E53, 0xFF847141, 0xFF000000, 0xFF645530, 0xFFA68D50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF88723E, 0xFF000000, 0xFF3E331C,
  0xFF302816, 0xFF040302, 0xFF8A743E, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF726036, 0xFF000000, 0xFF514527, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9258, 
        0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFF665938, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF010100, 0xFF262116, 0xFFA28E5F, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16D, 0xFFB8A16E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA79, 0xFFBEAA79, 0xFF13110C, 0xFF050503, 0xFF9E8D66, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF514935, 0xFF000000, 0xFF7A6E51, 0xFFC4B082, 0xFFC5B183, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC7B587, 0xFFC7B589, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 
        0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C198, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 
        0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFE0D2B2, 
        0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DDC0, 
        0xFFE9DDC1, 0xFFE9DDC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C6, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF1E6CE, 
        0xFFF1E7CE, 0xFFF1E7CF, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF4EAD4, 0xFFF4EAD4, 0xFFF4EAD4, 0xFFF4EAD4, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF3EAD3, 
        0xFFF3E9D2, 0xFFF2E9D2, 0xFFF3E9D1, 0xFFF2E9D1, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CB, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE1C6, 
        0xFFECE1C6, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC0, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 
        0xFFDBCCA9, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 
        0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B587, 0xFFC7B487, 0xFFC3B184, 0xFF2D281E, 0xFF000000, 0xFFBEAB7F, 0xFFC4B284, 0xFFC4B182, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AE7F, 0xFFBCA97B, 0xFF1A1711, 0xFF000000, 0xFFBCA879, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA775, 0xFF5D533A, 0xFF363021, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 0xFFB7A26D, 
        0xFFB7A26D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB39D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFF695B37, 0xFF3D341F, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF8B7644, 0xFF000000, 0xFF554829, 0xFFA68C50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA3894B, 0xFF8A743F, 0xFF030301, 0xFF312916,
  0xFF241E10, 0xFF060503, 0xFF8B7540, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF645530, 0xFF000000, 0xFF534728, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 
        0xFFAB9359, 0xFFAB9459, 0xFFAC945A, 0xFFAC945A, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFF7F6E45, 0xFF292417, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF12100A, 0xFF5F5337, 0xFFB49E68, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBCA774, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFF090806, 0xFF0F0E0A, 0xFFA39269, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFBFAB7D, 0xFF4B4331, 0xFF000000, 0xFF8B7E5D, 0xFFC4B082, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 
        0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC8B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 
        0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A3, 
        0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B2, 
        0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE5D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE9DDC0, 
        0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C7, 0xFFECE2C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEEE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CE, 0xFFF1E7CE, 
        0xFFF1E7CF, 0xFFF1E7D0, 0xFFF1E8D0, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EAD3, 0xFFF4EAD3, 
        0xFFF3EAD3, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF0E6CE, 0xFFF0E5CD, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEEE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFECE1C7, 
        0xFFECE1C6, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BC, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 
        0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D5B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCCA9, 
        0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B68A, 0xFFC8B589, 0xFFC8B588, 0xFFC7B588, 0xFFC7B487, 0xFFC3B084, 0xFF3C3628, 0xFF000000, 0xFFB7A57A, 0xFFC5B183, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFBDA97C, 0xFF28241A, 0xFF000000, 0xFFB3A175, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA776, 0xFF5D533A, 0xFF3F3827, 0xFFBBA674, 0xFFBBA672, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE965D, 0xFFAE965C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFF71603B, 0xFF3B331F, 0xFFA89056, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF8C7745, 0xFF000000, 0xFF473C22, 0xFFA68C50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA38A4C, 0xFFA3894B, 0xFF8B753F, 0xFF060503, 0xFF241E10,
  0xFF211B0E, 0xFF0D0B06, 0xFF8E7740, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF61522F, 0xFF000000, 0xFF5C4F2D, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 
        0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955C, 0xFFAD965C, 0xFFAD965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFA8915B, 0xFF413924, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF362F1F, 0xFF9A8758, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBCA774, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFF000000, 0xFF14120D, 0xFFA5946A, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC2AD7E, 0xFFC2AE7F, 0xFFBDA97C, 0xFF433C2C, 0xFF000000, 0xFF958763, 0xFFC4B182, 0xFFC5B184, 0xFFC5B284, 0xFFC5B284, 
        0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B58A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD5C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A3, 
        0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDD0AE, 0xFFDED0AF, 0xFFDED0B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 
        0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC4, 0xFFEADFC4, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E7CF, 
        0xFFF2E7CF, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF4EAD4, 0xFFF4EBD5, 0xFFF4EBD5, 0xFFF5EBD5, 0xFFF5EBD5, 0xFFF5EBD5, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF5EBD5, 0xFFF4EBD5, 0xFFF5EBD5, 0xFFF4EBD4, 
        0xFFF4EAD4, 0xFFF4EAD3, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF2E9D2, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E8CF, 0xFFF1E7CF, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE5CB, 0xFFEFE4CB, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFECE1C7, 
        0xFFECE1C6, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE3D7B8, 
        0xFFE3D7B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAB, 0xFFDBCCA9, 
        0xFFDBCCA9, 0xFFDACCA8, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD2C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 
        0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B185, 0xFF443D2E, 0xFF000000, 0xFFAE9D74, 0xFFC5B283, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF7F, 0xFFBEAA7C, 0xFF2E291E, 0xFF000000, 0xFFAD9C70, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF3D3626, 0xFFBBA673, 0xFFBAA673, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A370, 0xFFB8A370, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFF6F5F3A, 0xFF3A321E, 0xFFA88F56, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F52, 0xFF8F7946, 0xFF000000, 0xFF453B21, 0xFFA68D50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFF8E7741, 0xFF0D0B06, 0xFF211C0F,
  0xFF1C180C, 0xFF141109, 0xFF917941, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF5D4E2C, 0xFF000000, 0xFF625430, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9157, 0xFFAA9257, 0xFFA89055, 
        0xFFAA9258, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAE965D, 0xFF907D4E, 0xFF18150D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF000000, 
        0xFF050403, 0xFF84744C, 0xFFB59E69, 0xFFB5A069, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA672, 0xFFBBA673, 0xFFBBA775, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFBFAB7A, 0xFF000000, 0xFF1A1811, 0xFFA8976C, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFBBA87B, 0xFF40392A, 0xFF000000, 0xFFA2926C, 0xFFC4B182, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD2C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAE, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEEE2C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE4CC, 0xFFEFE5CC, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E6CE, 0xFFF1E7CF, 
        0xFFF1E7D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3E9D3, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF5EBD5, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF5EBD5, 0xFFF4EBD4, 
        0xFFF4EBD4, 0xFFF4EAD4, 0xFFF3EAD3, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF2E9D1, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE3CB, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFECE2C7, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBDFC5, 0xFFEADFC4, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBD, 0xFFE7DABD, 0xFFE6DABC, 0xFFE5D9BC, 0xFFE5D8BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 
        0xFFE3D7B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B3, 0xFFE0D3B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDACCA9, 0xFFDACCA8, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88E, 0xFFC9B88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B68B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B285, 0xFF4E4635, 0xFF000000, 0xFFA99971, 0xFFC4B184, 0xFFC4B182, 0xFFC4B082, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFBEAA7C, 0xFF393325, 0xFF000000, 0xFFA7976D, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA977, 0xFFBDA977, 0xFFBCA776, 0xFF5D533A, 0xFF3E3727, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A26D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFF71613A, 0xFF3C331F, 0xFFA89056, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF917B47, 0xFF030301, 0xFF40361F, 0xFFA68D50, 
        0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF907941, 0xFF131008, 0xFF1D180D,
  0xFF16130A, 0xFF18140B, 0xFF967E45, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF574A2A, 0xFF000000, 0xFF675732, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFF201C10, 
        0xFF8A7647, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFA08B56, 0xFF594D30, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF3C3422, 0xFF806F49, 0xFF1D1910, 
        0xFF000000, 0xFF000000, 0xFF5A4F34, 0xFFAD9765, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBCA878, 0xFF000000, 0xFF201C14, 0xFFAE9C70, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFBEAC7D, 0xFF3D3728, 0xFF000000, 0xFFAC9B72, 0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC91, 0xFFCDBC93, 0xFFCDBD93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDCCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 
        0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFEADEC2, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE4CB, 0xFFEFE4CB, 0xFFEFE4CC, 0xFFF0E5CC, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E7CF, 0xFFF1E7CF, 
        0xFFF1E8D0, 0xFFF2E8D1, 0xFFF3E9D1, 0xFFF3E9D2, 0xFFF3EAD2, 0xFFF3EAD3, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF5EBD5, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF6ECD7, 0xFFF5ECD7, 0xFFF6EDD7, 0xFFF6ECD7, 0xFFF6ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD5, 
        0xFFF4EBD4, 0xFFF4EAD4, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E8CF, 0xFFF1E7CF, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C7, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D8BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 
        0xFFE4D7B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDECFAE, 0xFFDECFAD, 0xFFDDCFAC, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDBCDAB, 0xFFDBCCA9, 
        0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C6A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD1C098, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88C, 0xFFCAB78C, 
        0xFFC9B78B, 0xFFC9B68A, 0xFFC8B58A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B284, 0xFF574F3B, 0xFF000000, 0xFFA89870, 0xFFC5B284, 0xFFC4B182, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFF443D2C, 0xFF000000, 0xFFA08F67, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBCA876, 0xFF5D533A, 0xFF2F2A1D, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFB9A470, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A26D, 0xFFB7A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A62, 0xFFB19961, 0xFFB09961, 0xFFB09960, 0xFFAF985F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFF5D5030, 0xFF3D3520, 0xFFA89056, 0xFFAA9257, 0xFFAA9157, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF927C48, 0xFF070603, 0xFF3B321C, 0xFFA68D50, 
        0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA3894B, 0xFF967E45, 0xFF18140B, 0xFF16130A,
  0xFF100D07, 0xFF0E0C06, 0xFF554727, 0xFF5E4F2B, 0xFF5D4F2B, 0xFF5E4F2C, 0xFF5E502C, 0xFF5E502C, 0xFF62532F, 0xFF2D2615, 0xFF010100, 0xFF685932, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9157, 0xFFAA9257, 0xFF080704, 
        0xFF78673E, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAE965D, 0xFF7F6E44, 0xFF211D12, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0A06, 0xFF756641, 0xFFB09964, 0xFFB39D66, 0xFFA38E5D, 
        0xFF3C3523, 0xFF000000, 0xFF000000, 0xFF302B1C, 0xFFA49060, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFB6A274, 0xFF000000, 0xFF14120D, 0xFF6D6146, 0xFF796D4E, 0xFF7B6E4F, 0xFF766A4D, 0xFF73674B, 0xFF6E6248, 0xFF221E16, 0xFF000000, 0xFFB09E75, 0xFFC4B183, 0xFFC5B183, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B1, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D4B3, 0xFFE1D4B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE3D5B6, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFEADEC2, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEFE4CA, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E7CF, 0xFFF1E8D0, 
        0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E9D2, 0xFFF3E9D3, 0xFFF3EAD3, 0xFFF3EAD4, 0xFFF4EBD5, 0xFFF5EBD5, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF6EDD8, 0xFFF6EDD8, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF5ECD6, 0xFFF5ECD6, 
        0xFFF5ECD5, 0xFFF4EBD4, 0xFFF4EAD4, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF3E9D1, 0xFFF2E9D1, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E6CE, 0xFFF1E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE5CB, 0xFFEFE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFEDE1C8, 
        0xFFECE2C7, 0xFFECE1C6, 0xFFECE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE5D9BC, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE4D7B8, 
        0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD2C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88C, 0xFFCAB78C, 
        0xFFC9B78B, 0xFFC8B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B284, 0xFF59503C, 0xFF000000, 0xFF453E2E, 0xFF574E3A, 0xFF564D39, 0xFF564D39, 0xFF564D39, 0xFF4E4634, 0xFF4C4532, 0xFF4C4431, 0xFF1B1811, 0xFF000000, 0xFF988862, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA978, 0xFFBDA977, 0xFFBDA876, 0xFF5D533A, 0xFF191610, 0xFFAE9A6C, 0xFFBBA673, 0xFFBAA573, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFAF985F, 0xFFAF985F, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFF272114, 0xFF413822, 0xFFA89056, 0xFFAA9258, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF927C48, 0xFF0B0A05, 0xFF15120A, 0xFF352D19, 
        0xFF322A17, 0xFF2F2716, 0xFF2F2716, 0xFF302916, 0xFF302816, 0xFF302816, 0xFF2F2715, 0xFF070603, 0xFF110E07,
  0xFF090704, 0xFF000000, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF010100, 0xFF000000, 0xFF030301, 0xFF685732, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9157, 0xFFAA9257, 0xFF010100, 
        0xFF574A2D, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 0xFFAD955C, 0xFF483E26, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF342D1D, 0xFFA9935F, 0xFFB29B64, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 
        0xFFB49E68, 0xFF574C32, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF938156, 0xFFB6A16C, 0xFFB7A26D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBDA776, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFB3A072, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF020201, 0xFF020201, 0xFF020201, 0xFF020201, 0xFF020201, 0xFF000000, 0xFF000000, 0xFFB19F75, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6DABC, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C9, 0xFFEEE3C9, 0xFFEEE4C9, 0xFFEEE4CA, 0xFFEFE4CC, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF2E7D0, 
        0xFFF2E8D0, 0xFFF2E8D1, 0xFFF3E9D2, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF4EBD5, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF6EDD8, 0xFFF6EED8, 0xFFF7EED9, 0xFFF7EED8, 0xFFF7EED8, 0xFFF6EDD8, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF5ECD6, 
        0xFFF5ECD6, 0xFFF5EBD5, 0xFFF4EBD4, 0xFFF4EAD3, 0xFFF3E9D3, 0xFFF3E9D2, 0xFFF2E9D1, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF0E7CE, 0xFFF0E6CE, 0xFFF0E5CD, 0xFFF0E5CC, 0xFFEFE5CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEBDFC4, 0xFFEADFC3, 0xFFE9DEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE6DBBD, 0xFFE6DABD, 0xFFE5D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 
        0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDBCDAA, 0xFFDBCCAA, 
        0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C49F, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD0BF98, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B285, 0xFF59503C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8F805D, 
        0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF000000, 0xFF6B5F42, 0xFFBBA573, 0xFFBBA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB8A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFAF985F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFF6F5F3A, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAB9257, 0xFFAA9257, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88E53, 0xFF927C48, 0xFF0D0B06, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0804,
  0xFF020201, 0xFF030301, 0xFF17130A, 0xFF251F11, 0xFF251F11, 0xFF252011, 0xFF262011, 0xFF262012, 0xFF272112, 0xFF0D0B06, 0xFF030201, 0xFF685832, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFAA9155, 0xFFAA9157, 0xFFAA9257, 0xFF010100, 
        0xFF0E0C07, 0xFF7F6C42, 0xFF95804E, 0xFF76663E, 0xFF15120B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0F0D08, 0xFF615435, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 
        0xFFB39D66, 0xFFB59E69, 0xFF7B6C47, 0xFF0C0A07, 0xFF000000, 0xFF000000, 0xFF6C5F40, 0xFFB49F6B, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA472, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 
        0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFB09E70, 0xFF000000, 0xFF040402, 0xFF181610, 0xFF1B1811, 0xFF1C1912, 0xFF1C1912, 0xFF1C1912, 0xFF1A1711, 0xFF070605, 0xFF000000, 0xFFB19F75, 0xFFC4B183, 0xFFC4B284, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC91, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39D, 0xFFD3C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE4D6B8, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEFE4CA, 0xFFEFE5CB, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E6CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF2E8D0, 
        0xFFF2E8D1, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF4EBD4, 0xFFF5EBD5, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF6EDD7, 0xFFF6EDD8, 0xFFF6EED8, 0xFFF7EED9, 0xFFF7EED9, 0xFFF7EED9, 0xFFF7EED9, 0xFFF7EDD8, 0xFFF6EDD8, 0xFFF6EDD7, 0xFFF5ECD6, 
        0xFFF5ECD6, 0xFFF5ECD5, 0xFFF4EBD4, 0xFFF4EAD4, 0xFFF3EAD3, 0xFFF3EAD2, 0xFFF3E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF0E6CE, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 
        0xFFEDE1C7, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DABE, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 
        0xFFE3D7B8, 0xFFE3D7B7, 0xFFE3D5B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C29C, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD2C19A, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B78B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B285, 0xFF5A513C, 0xFF000000, 0xFF201D15, 0xFF2D291E, 0xFF2D281E, 0xFF2D281E, 0xFF2D281E, 0xFF2D281D, 0xFF2C281D, 0xFF2B261C, 0xFF0F0D09, 0xFF000000, 0xFF8C7E5B, 
        0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBCA876, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF3C3524, 0xFF6E6143, 0xFF847550, 0xFF8E7D56, 0xFF907F57, 0xFF907F57, 0xFF8F7E55, 0xFF8F7E55, 
        0xFF8E7E55, 0xFF8F7E54, 0xFF8E7C54, 0xFF8E7C53, 0xFF8E7C52, 0xFF8D7C51, 0xFF8D7B51, 0xFF8C7B50, 0xFF8C7A50, 0xFF8B7A4F, 0xFF8B794F, 0xFF8A784E, 0xFF8A784E, 0xFF8A784D, 0xFF8A784D, 0xFF8A774C, 0xFF89774B, 0xFF89774A, 0xFF88764A, 0xFF88754A, 
        0xFF877549, 0xFF867347, 0xFF806E44, 0xFF6F5F3B, 0xFF453C24, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAB9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF927C48, 0xFF0D0B06, 0xFF060503, 0xFF211C10, 
        0xFF201B0F, 0xFF1D190E, 0xFF1F1A0E, 0xFF1E1A0E, 0xFF1E190E, 0xFF1E190D, 0xFF1C170C, 0xFF050402, 0xFF030201,
  0xFF010100, 0xFF1B160C, 0xFF917A43, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58C4E, 0xFFA68C4F, 0xFF423820, 0xFF010100, 0xFF6A5934, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFF020201, 
        0xFF000000, 0xFF020101, 0xFF0E0C07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF37301E, 0xFF8E7B4E, 0xFFB19A62, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 
        0xFFB49E67, 0xFFB59E69, 0xFFB59F69, 0xFF928156, 0xFF242015, 0xFF000000, 0xFF000000, 0xFF443B28, 0xFFB09B69, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA472, 0xFFBAA572, 0xFFB9A372, 0xFFA08E62, 0xFFB4A06F, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFB09D70, 0xFF000000, 0xFF211D15, 0xFFA7956B, 0xFFB9A679, 0xFFBAA779, 0xFFBAA87A, 0xFFBBA87B, 0xFFB2A074, 0xFF332D21, 0xFF000000, 0xFFB09F75, 0xFFC4B082, 0xFFC4B184, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC91, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCEBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE1D3B3, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE5D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE6DABE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DDC0, 0xFFE9DDC1, 
        0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEEE4CB, 0xFFEFE5CB, 0xFFEFE5CC, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF2E8D0, 
        0xFFF2E8D1, 0xFFF3E9D1, 0xFFF3E9D3, 0xFFF3EAD3, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF5ECD7, 0xFFF6EDD8, 0xFFF6EED8, 0xFFF7EED9, 0xFFF7EED9, 0xFFF8EFDA, 0xFFF7EFDA, 0xFFF7EED9, 0xFFF7EED9, 0xFFF7EED8, 0xFFF6EDD7, 0xFFF6ECD7, 
        0xFFF5ECD6, 0xFFF5ECD5, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF3E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E6CE, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEEE4CB, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEDE3C9, 0xFFEDE2C8, 
        0xFFECE1C7, 0xFFECE1C7, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE6DBBD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BB, 0xFFE5D8BA, 0xFFE4D7B9, 
        0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAA, 0xFFDBCDAA, 
        0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD1C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC5B386, 0xFF5D543F, 0xFF000000, 0xFFA0916B, 0xFFC4B184, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFF4D4633, 0xFF000000, 0xFF8F805D, 
        0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF937D48, 0xFF0B0A05, 0xFF241E11, 0xFFA68D50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFF9E8548, 0xFF1F1A0E, 0xFF010100,
  0xFF000000, 0xFF0F0C06, 0xFF4A3E21, 0xFF483C21, 0xFF483D21, 0xFF493D22, 0xFF493E22, 0xFF493D22, 0xFF4D4124, 0xFF1A160C, 0xFF020201, 0xFF685832, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAB9257, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF685B39, 0xFFA9935D, 0xFFB19962, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 
        0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFAF9A67, 0xFF423A27, 0xFF000000, 0xFF000000, 0xFF17140E, 0xFF9C895D, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFBAA472, 0xFFBAA572, 0xFFB49F6E, 0xFF312B1E, 0xFF99885F, 0xFFBCA775, 0xFFBDA876, 
        0xFFBCA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFB29F71, 0xFF000000, 0xFF110F0B, 0xFF584E38, 0xFF61573F, 0xFF62583F, 0xFF635940, 0xFF5D533D, 0xFF524A36, 0xFF181510, 0xFF000000, 0xFFB2A076, 0xFFC4B182, 0xFFC4B184, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49D, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE5D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BC, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 
        0xFFE9DEC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE2C7, 0xFFEDE2C7, 0xFFEDE2C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEFE4CA, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF2E8D0, 
        0xFFF2E8D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF5EBD5, 0xFFF5ECD6, 0xFFF5EDD7, 0xFFF6EDD8, 0xFFF7EED8, 0xFFF7EED9, 0xFFF7EFDA, 0xFFF8EFDA, 0xFFF8EFDA, 0xFFF8EFDA, 0xFFF7EED9, 0xFFF7EED8, 0xFFF6EDD8, 0xFFF6EDD7, 
        0xFFF6ECD6, 0xFFF5ECD6, 0xFFF4EBD4, 0xFFF4EAD4, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF3E9D2, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7D0, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE2C8, 
        0xFFECE1C7, 0xFFECE1C7, 0xFFECE0C5, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 
        0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAA, 0xFFDBCDAA, 
        0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD2C29B, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD1C19A, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0BE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCBBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B285, 0xFF5A513C, 0xFF000000, 0xFF29251B, 0xFF363124, 0xFF373124, 0xFF353023, 0xFF353023, 0xFF342E22, 0xFF29251B, 0xFF272319, 0xFF0E0C09, 0xFF000000, 0xFF8F805C, 
        0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEA979, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89156, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99155, 0xFFA99054, 0xFFA88F53, 0xFFA78F53, 0xFF927C48, 0xFF0D0B06, 0xFF030201, 0xFF15120A, 
        0xFF17130B, 0xFF1A160C, 0xFF1C170D, 0xFF1C170D, 0xFF1E190E, 0xFF211C0F, 0xFF1E190E, 0xFF050402, 0xFF000000,
  0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF685733, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9157, 0xFFAA9257, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF19160E, 0xFF927F4F, 0xFFB09861, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 
        0xFFB49E67, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFF605539, 0xFF050402, 0xFF000000, 0xFF070604, 0xFF83734F, 0xFFB7A26F, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFB09B6C, 0xFF13100B, 0xFF97865E, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFB6A274, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFFB09E74, 0xFFC4B182, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B88C, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCCBB92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C099, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 
        0xFFE0D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CB, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E5CD, 0xFFF1E6CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF2E8D0, 
        0xFFF2E8D1, 0xFFF3E9D1, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF6ECD7, 0xFFF6EDD8, 0xFFF7EDD9, 0xFFF7EED9, 0xFFF8EFDA, 0xFFF8EFDA, 0xFFF8EFDB, 0xFFF8EFDA, 0xFFF7EED9, 0xFFF7EED9, 0xFFF6EED8, 0xFFF6ECD7, 
        0xFFF5ECD6, 0xFFF5ECD5, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF3E9D2, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E8CF, 0xFFF1E7CF, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE2C8, 
        0xFFECE1C7, 0xFFECE1C7, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBDFC5, 0xFFEADEC3, 0xFFEADEC2, 0xFFEADEC2, 0xFFE9DDC2, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D7B8, 
        0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C29C, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD2C19A, 0xFFD1C099, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCCBC91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88C, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC8B68B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC6B487, 0xFFC5B285, 0xFF574F3B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF958661, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFF927C48, 0xFF0D0B06, 0xFF000000, 0xFF010100, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000,
  0xFF010100, 0xFF0C0A05, 0xFF3A311A, 0xFF3C321B, 0xFF3C321C, 0xFF3D331C, 0xFF3D331C, 0xFF3D341D, 0xFF40361E, 0xFF18140B, 0xFF020201, 0xFF685832, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9157, 0xFFAA9257, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060503, 0xFF54482D, 0xFFAC955D, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 
        0xFFB49E67, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFF7A6B49, 0xFF13110B, 0xFF000000, 0xFF000000, 0xFF594F36, 0xFFAC9969, 0xFFBAA471, 0xFFBAA572, 0xFF766949, 0xFF000000, 0xFF98875E, 0xFFBCA775, 0xFFBDA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBFAA79, 0xFFBCA778, 0xFF000000, 0xFF0C0B08, 0xFF453E2C, 0xFF4D4532, 0xFF4E4632, 0xFF4E4633, 0xFF4B4331, 0xFF453E2D, 0xFF17150F, 0xFF000000, 0xFFA99870, 0xFFC4B182, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B58A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDECFAE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DEC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEFE4CA, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E6CD, 0xFFF1E6CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF2E8D0, 
        0xFFF2E8D1, 0xFFF3E9D1, 0xFFF3EAD2, 0xFFF3EAD3, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF5EBD5, 0xFFF5ECD6, 0xFFF6ECD7, 0xFFF6EDD7, 0xFFF6EED8, 0xFFF7EED9, 0xFFF7EFD9, 0xFFF8EFDA, 0xFFF8EFDA, 0xFFF7EEDA, 0xFFF7EED9, 0xFFF7EED9, 0xFFF6EDD8, 0xFFF6ECD7, 
        0xFFF5ECD6, 0xFFF5ECD5, 0xFFF4EBD5, 0xFFF4EBD4, 0xFFF4EAD3, 0xFFF3EAD2, 0xFFF3E9D2, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEDE3C9, 0xFFEDE2C8, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DABE, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE4D8BA, 0xFFE4D7B9, 
        0xFFE4D6B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B285, 0xFF544C39, 0xFF000000, 0xFF5D543E, 0xFF6F6449, 0xFF6D6248, 0xFF6D6248, 0xFF6C6247, 0xFF6B6046, 0xFF635941, 0xFF61573F, 0xFF211E15, 0xFF000000, 0xFF9E8E67, 
        0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFF937D48, 0xFF0C0A06, 0xFF141109, 0xFF5D4F2D, 
        0xFF564929, 0xFF504426, 0xFF504325, 0xFF4F4225, 0xFF4E4224, 0xFF473C20, 0xFF44391F, 0xFF0D0B06, 0xFF010100,
  0xFF050402, 0xFF1D190D, 0xFF9A8246, 0xFFA3894B, 0xFFA38A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF463C22, 0xFF000000, 0xFF6A5933, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9257, 0xFFAA9257, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF120F09, 0xFF8B784A, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09861, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 
        0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFA08D60, 0xFF2D281B, 0xFF000000, 0xFF000000, 0xFF1D1911, 0xFF4E452F, 0xFF443C29, 0xFF080705, 0xFF090805, 0xFF98875E, 0xFFBCA775, 0xFFBDA875, 
        0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBFAA79, 0xFFBFAA7A, 0xFF000000, 0xFF1D1A12, 0xFFB19F72, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF433C2C, 0xFF000000, 0xFF9D8D68, 0xFFC4B182, 0xFFC5B183, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B88C, 0xFFCBB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCEBC92, 0xFFCEBD93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D4B3, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D6B6, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE5D8B9, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 
        0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF0E7CE, 0xFFF1E7CF, 0xFFF2E8D0, 
        0xFFF2E8D1, 0xFFF2E9D1, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF4EBD4, 0xFFF5EBD5, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF6EDD7, 0xFFF6EDD8, 0xFFF6EED8, 0xFFF7EED9, 0xFFF7EED9, 0xFFF7EED9, 0xFFF7EED9, 0xFFF6EED8, 0xFFF6EDD8, 0xFFF6EDD7, 0xFFF5ECD6, 
        0xFFF5ECD6, 0xFFF5ECD5, 0xFFF4EAD4, 0xFFF4EAD4, 0xFFF3EAD3, 0xFFF3EAD2, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E6CE, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE5CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEDE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 
        0xFFECE2C7, 0xFFECE1C6, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEADEC4, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE4D8BA, 0xFFE4D7B9, 
        0xFFE4D7B8, 0xFFE3D7B7, 0xFFE3D6B6, 0xFFE3D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39B, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B185, 0xFF4A4332, 0xFF000000, 0xFFB3A178, 0xFFC5B284, 0xFFC4B182, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFF3F3829, 0xFF000000, 0xFFA7956C, 
        0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBCA876, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFF937D48, 0xFF0B0905, 0xFF2D2615, 0xFFA68D50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA38A4C, 0xFFA38A4B, 0xFF9E8547, 0xFF1C180C, 0xFF050402,
  0xFF090804, 0xFF050402, 0xFF272111, 0xFF4C4023, 0xFF4C4023, 0xFF4C4023, 0xFF4D4023, 0xFF4D4024, 0xFF514426, 0xFF221D10, 0xFF020201, 0xFF685832, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9157, 0xFFAA9257, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2F2819, 0xFFAC955B, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09960, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19B63, 0xFFB19B64, 0xFFB29B64, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 
        0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB19C6A, 0xFF3D3625, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF98875E, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAB7A, 0xFF000000, 0xFF050403, 0xFF242117, 0xFF2B261B, 0xFF2B261B, 0xFF2B261C, 0xFF2B261C, 0xFF29251B, 0xFF0E0D09, 0xFF000000, 0xFF928361, 0xFFC4B183, 0xFFC4B184, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCBB98D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCEBE95, 0xFFCFBE96, 0xFFD0BE96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCEAB, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E6CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF2E8D0, 
        0xFFF2E8D0, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF3E9D3, 0xFFF4EAD3, 0xFFF4EBD4, 0xFFF5EBD5, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF6EDD8, 0xFFF7EED8, 0xFFF7EED8, 0xFFF7EED9, 0xFFF7EED8, 0xFFF6EDD8, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF5ECD6, 
        0xFFF5ECD6, 0xFFF5EBD5, 0xFFF4EBD4, 0xFFF4EAD3, 0xFFF4EAD3, 0xFFF3E9D2, 0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEEE4CB, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 
        0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAA, 0xFFDBCDAA, 
        0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD2C09A, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCBBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B68B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC6B487, 0xFFC4B185, 0xFF413A2C, 0xFF000000, 0xFF010101, 0xFF050403, 0xFF040403, 0xFF050403, 0xFF040403, 0xFF050403, 0xFF050403, 0xFF030302, 0xFF000000, 0xFF000000, 0xFFAC9A6F, 
        0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFF5D533A, 0xFF000000, 0xFF080704, 0xFF685B40, 0xFF9E8C61, 0xFFB39E6D, 0xFFB9A471, 0xFFB9A370, 0xFFB9A370, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49C66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFAF985F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAD965D, 0xFFA58E58, 0xFF8E7A4B, 0xFF594D2F, 0xFF080604, 0xFF000000, 0xFF453B23, 0xFFA89156, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFF927C48, 0xFF0D0B06, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0804,
  0xFF100D07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF665631, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9257, 0xFFAA9257, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF463C25, 0xFFAA935A, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39D66, 0xFFB49D66, 
        0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFF4F4630, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF98875E, 0xFFBCA775, 0xFFBCA776, 
        0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBFAA7A, 0xFF030302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF857858, 0xFFC4B182, 0xFFC4B184, 0xFFC5B284, 0xFFC5B284, 
        0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCEBC92, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0C097, 0xFFD0BF98, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DEC1, 0xFFEADEC2, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3CA, 0xFFEEE4CB, 0xFFEFE5CB, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E6CD, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF2E7CF, 
        0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF3EAD3, 0xFFF4EAD4, 0xFFF4EBD5, 0xFFF4EBD5, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF6EDD8, 0xFFF6EDD8, 0xFFF6EDD8, 0xFFF6EDD8, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF5ECD6, 0xFFF5ECD6, 
        0xFFF5ECD5, 0xFFF4EBD4, 0xFFF4EAD4, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF3E9D2, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF2E7D0, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE4CC, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEADFC4, 0xFFEADFC3, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 
        0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAA, 0xFFDBCCAA, 
        0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C29C, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD2C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC3B085, 0xFF353024, 0xFF000000, 0xFF010101, 0xFF030302, 0xFF030302, 0xFF030202, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFFB2A074, 
        0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF000000, 0xFF7E6F4E, 0xFFBBA573, 0xFFBAA572, 0xFFBAA472, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E67, 0xFFB39D67, 0xFFB49D66, 0xFFB39C66, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAC945B, 0xFF897648, 0xFF000000, 0xFF453B23, 0xFFA89156, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFF927C47, 0xFF0B0905, 0xFF000000, 0xFF010100, 
        0xFF020201, 0xFF010100, 0xFF010100, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF110E07,
  0xFF16130A, 0xFF0C0A05, 0xFF554726, 0xFF5D4E2A, 0xFF5C4E2B, 0xFF5D4E2B, 0xFF5D4F2B, 0xFF5D4F2C, 0xFF61522E, 0xFF342C19, 0xFF000000, 0xFF645430, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF4D4228, 0xFFAA9259, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 
        0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A370, 0xFFB9A470, 0xFF695D40, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF98875E, 0xFFBCA775, 0xFFBCA875, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFBFAB7A, 0xFF110F0B, 0xFF030201, 0xFF62583F, 0xFF776B4D, 0xFF796D4E, 0xFF74694C, 0xFF72664A, 0xFF72674B, 0xFF332D21, 0xFF000000, 0xFF776B4F, 0xFFC4B182, 0xFFC5B283, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCDBC91, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DEC1, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C7, 0xFFECE2C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEFE4CA, 0xFFEFE4CB, 0xFFEFE5CB, 0xFFF0E5CC, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E7CF, 0xFFF1E7CF, 
        0xFFF2E8D0, 0xFFF2E8D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF5EBD4, 0xFFF5EBD5, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF6ECD6, 0xFFF5ECD7, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF6EDD7, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF4ECD6, 
        0xFFF5EBD5, 0xFFF4EBD4, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7D0, 0xFFF1E7CF, 0xFFF1E6CE, 0xFFF0E6CE, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D7B8, 
        0xFFE3D7B8, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCCAA, 
        0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B68B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC3B185, 0xFF2A261C, 0xFF030202, 0xFF8E805F, 0xFF958664, 0xFF958663, 0xFF938562, 0xFF928461, 0xFF8F805E, 0xFF8D7E5D, 0xFF8A7C5A, 0xFF13110C, 0xFF000000, 0xFFBBA779, 
        0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFF5D533A, 0xFF1C1811, 0xFFB29E6E, 0xFFBBA673, 0xFFBAA572, 0xFFBAA472, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36E, 0xFFB8A26E, 
        0xFFB7A26D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFF37301D, 0xFF403721, 0xFFA89056, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF917B47, 0xFF050502, 0xFF302817, 0xFF7F6C3C, 
        0xFF7C693B, 0xFF7B683A, 0xFF7A673A, 0xFF7C693A, 0xFF766437, 0xFF6F5E33, 0xFF63532C, 0xFF0F0D07, 0xFF17130A,
  0xFF1C170C, 0xFF141109, 0xFF907941, 0xFFA2884A, 0xFFA3894A, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58C4F, 0xFF60512E, 0xFF000000, 0xFF5E502E, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9256, 0xFFAA9257, 0xFF020201, 
        0xFF000000, 0xFF322B1A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAE955C, 0xFFAE965D, 0xFFAF975E, 0xFFAF975E, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 
        0xFFB49D68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB6A26F, 0xFF524932, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF98875E, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBFAA79, 0xFFBFAA7A, 0xFF1D1A12, 0xFF000000, 0xFF9B8A64, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC2AE7E, 0xFFC1AD7E, 0xFFC2AE80, 0xFF615740, 0xFF000000, 0xFF635942, 0xFFC4B182, 0xFFC5B183, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B387, 0xFFC6B487, 0xFFC7B488, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA91, 0xFFCCBB91, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD1C097, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD7C7A2, 0xFFD7C8A2, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAB, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D3B1, 
        0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DBBD, 0xFFE8DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DDC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEDE3C9, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E6CD, 0xFFF1E6CD, 0xFFF0E6CE, 0xFFF1E7CF, 
        0xFFF2E7D0, 0xFFF2E8D0, 0xFFF3E9D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3EAD3, 0xFFF4EBD4, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF5EBD5, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5ECD6, 0xFFF5EBD5, 0xFFF4EBD5, 
        0xFFF4EBD4, 0xFFF4EAD4, 0xFFF3EAD3, 0xFFF3E9D3, 0xFFF3E9D2, 0xFFF3E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E8CF, 0xFFF1E7CE, 0xFFF1E6CD, 0xFFF0E6CD, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFECE1C7, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEBDFC4, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 
        0xFFE3D7B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C49F, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39D, 0xFFD2C29B, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD1C099, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCCBC92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B68B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC2B083, 0xFF1B1912, 0xFF100E0A, 0xFFC0AD80, 0xFFC5B183, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFBCA97B, 0xFF13110C, 0xFF030302, 0xFFBDAA7B, 
        0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF342E20, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29C64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFF675836, 0xFF3D341F, 0xFFA89056, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF907A46, 0xFF000000, 0xFF453A21, 0xFFA68C50, 
        0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFF907941, 0xFF131008, 0xFF1D180D,
  0xFF211B0E, 0xFF0D0B06, 0xFF8E7740, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF62542F, 0xFF000000, 0xFF564829, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9157, 0xFFAA9257, 0xFF020101, 
        0xFF040402, 0xFF96814E, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 
        0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFB09B6B, 0xFF211D14, 0xFF000000, 0xFF0A0906, 0xFF98875E, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFF322C20, 0xFF000000, 0xFF94845F, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF6B6046, 0xFF000000, 0xFF534B37, 0xFFC4B082, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B689, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBD93, 0xFFCEBD93, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 
        0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE5CB, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E7CF, 
        0xFFF1E7CF, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E9D2, 0xFFF3E9D2, 0xFFF3E9D3, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF5EBD4, 0xFFF5EBD5, 0xFFF5EBD5, 0xFFF5ECD5, 0xFFF5ECD6, 0xFFF5ECD5, 0xFFF5ECD5, 0xFFF5EBD5, 0xFFF4EBD5, 0xFFF5EBD5, 0xFFF4EBD4, 
        0xFFF4EAD3, 0xFFF4EAD3, 0xFFF3E9D3, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E8D0, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE4CC, 0xFFEEE4CB, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFECE1C7, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DABE, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 
        0xFFE3D7B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCCAA, 
        0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C097, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC1AE82, 0xFF0E0D09, 0xFF1C1913, 0xFFC1AE81, 0xFFC5B283, 0xFFC4B182, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFBBA87B, 0xFF050403, 0xFF13110C, 0xFFBEAA7B, 
        0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA977, 0xFFBDA877, 0xFFBCA776, 0xFF5D533A, 0xFF3F3827, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA472, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFF71613B, 0xFF3B331F, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF8D7845, 0xFF000000, 0xFF463C22, 0xFFA68C50, 
        0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA38A4B, 0xFFA3894B, 0xFF8E7741, 0xFF0D0B06, 0xFF211C0F,
  0xFF241E10, 0xFF070603, 0xFF8A743E, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF6E5D34, 0xFF000000, 0xFF514527, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFF000000, 
        0xFF3D341F, 0xFFA89057, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 
        0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFF8E7E57, 0xFF000000, 0xFF0A0906, 0xFF98865E, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA78, 0xFFBFAA7A, 0xFF433C2B, 0xFF000000, 0xFF897B58, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE80, 0xFF786B4E, 0xFF020201, 0xFF3F392A, 0xFFC4B082, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C8A3, 
        0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD2B2, 
        0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B3, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DCBF, 0xFFE8DCC0, 0xFFE8DDC0, 
        0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E7CF, 
        0xFFF1E7CF, 0xFFF1E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF3EAD2, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EAD4, 0xFFF4EAD3, 
        0xFFF4EAD3, 0xFFF3EAD3, 0xFFF3E9D2, 0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CB, 0xFFEEE4CA, 0xFFEEE4C9, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE1C7, 
        0xFFECE1C6, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEAE0C4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE6DBBD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BC, 0xFFE5D9BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 
        0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 
        0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD4C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFBCAA7F, 0xFF000000, 0xFF2E291F, 0xFFC1AF81, 0xFFC4B184, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFB5A377, 0xFF000000, 0xFF211D15, 0xFFBDA97B, 
        0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF3D3625, 0xFFBBA674, 0xFFBBA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFF6F5F39, 0xFF3A321E, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78F52, 0xFF8B7644, 0xFF000000, 0xFF514527, 0xFFA68D50, 
        0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF8B753F, 0xFF060503, 0xFF251F10,
  0xFF302915, 0xFF040302, 0xFF89733E, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF7E6B3C, 0xFF000000, 0xFF4E4226, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9257, 0xFF040302, 
        0xFF635533, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 
        0xFFB49D68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFBAA572, 0xFF3A3324, 0xFF050503, 0xFF97875E, 0xFFBCA775, 0xFFBCA776, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFF544B36, 0xFF000000, 0xFF7A6D4F, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF857758, 0xFF060604, 0xFF2A251C, 0xFFC4B082, 0xFFC4B184, 0xFFC5B184, 0xFFC5B284, 
        0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 
        0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 
        0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFE0D2B2, 
        0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B4, 0xFFE2D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D6B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DDC0, 
        0xFFE9DDC1, 0xFFE9DDC2, 0xFFE9DEC2, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C6, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CE, 
        0xFFF1E7CF, 0xFFF1E7CF, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF3E9D1, 0xFFF3E9D2, 0xFFF3EAD2, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF4EAD3, 0xFFF4EAD4, 0xFFF4EAD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF4EBD4, 0xFFF3EAD4, 0xFFF4EAD3, 0xFFF3EAD3, 
        0xFFF3E9D2, 0xFFF3E9D2, 0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E6CE, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEDE3C8, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFECE1C6, 
        0xFFECE1C6, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADEC2, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE8DDC1, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE3D7B8, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1AF, 0xFFDED0AF, 0xFFDDD0AE, 0xFFDDCFAE, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDBCEAB, 0xFFDCCDAA, 0xFFDBCCA9, 
        0xFFDACCA9, 0xFFDACCA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCAB98E, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFB1A079, 0xFF000000, 0xFF403A2B, 0xFFC2AF82, 0xFFC4B184, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF7F, 0xFFA9986F, 0xFF000000, 0xFF2F2A1E, 0xFFBEAB7C, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF3E3727, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26D, 
        0xFFB7A26D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFF71623B, 0xFF3C331F, 0xFFA89056, 0xFFAA9257, 0xFFAA9157, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA78F52, 0xFF877342, 0xFF000000, 0xFF60522E, 0xFFA68C50, 
        0xFFA68C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF8A743E, 0xFF030301, 0xFF312916,
  0xFF3E341C, 0xFF000000, 0xFF88723D, 0xFFA3894B, 0xFFA4894B, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF887241, 0xFF000000, 0xFF463B21, 0xFFA68D51, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFF0A0905, 
        0xFF7C6940, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 
        0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFF96855C, 0xFF000000, 0xFF97875E, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA79, 0xFFBFAA79, 0xFF6C6145, 0xFF000000, 0xFF645940, 0xFFC0AC7C, 0xFFC0AD7D, 0xFFC1AE7E, 0xFFC2AE7E, 0xFFC2AE80, 0xFF978863, 0xFF0B0A07, 0xFF16140F, 0xFFC4B083, 0xFFC4B183, 0xFFC4B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC9B78A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBC91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 
        0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 
        0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 
        0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE2D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABC, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 
        0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CE, 
        0xFFF1E6CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF4EAD3, 0xFFF4EAD3, 0xFFF4EAD3, 0xFFF4EAD3, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF3E9D2, 
        0xFFF3E9D2, 0xFFF3E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEEE4CB, 0xFFEEE3CA, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE1C8, 0xFFECE1C6, 
        0xFFECE1C6, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADFC3, 0xFFE9DEC2, 0xFFE9DEC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DBBE, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D7B8, 
        0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFDFD2B2, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 
        0xFFDACCA9, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 
        0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC6B487, 0xFF9A8B68, 0xFF000000, 0xFF544C38, 0xFFC2AF82, 0xFFC4B183, 0xFFC4B082, 0xFFC4B082, 0xFFC3AF81, 0xFFC3AF81, 0xFFC2AE7F, 0xFF92835F, 0xFF000000, 0xFF473F2E, 0xFFBEAB7C, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA776, 0xFF5D533A, 0xFF322D1F, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA472, 0xFFBAA471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB39D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFF615332, 0xFF3D3520, 0xFFA89056, 0xFFAA9257, 0xFFAA9256, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88E53, 0xFF7A683C, 0xFF000000, 0xFF6A5A33, 0xFFA68C50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA3894B, 0xFF88723D, 0xFF000000, 0xFF3E331C,
  0xFF453A1F, 0xFF000000, 0xFF836E3B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF8F7944, 0xFF000000, 0xFF3C331D, 0xFFA38B50, 0xFFA88F52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFF090804, 
        0xFF877446, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975F, 0xFFAF975F, 0xFFB09860, 0xFFB09860, 0xFFB09962, 0xFFB19962, 0xFFB19A63, 0xFFB29A64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 
        0xFFB49E67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFB29E6E, 0xFF13110C, 0xFF97865D, 0xFFBCA775, 0xFFBCA875, 
        0xFFBDA877, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBFAA79, 0xFF847654, 0xFF000000, 0xFF504834, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7F, 0xFFB9A679, 0xFF928360, 0xFF0D0B08, 0xFF0F0D0A, 0xFFB9A67B, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 
        0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 
        0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49E, 0xFFD5C59E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 
        0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACBA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFE0D2B1, 
        0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE6D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 
        0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C7, 0xFFEDE1C7, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CD, 
        0xFFF0E6CD, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3EAD2, 0xFFF3EAD2, 0xFFF3EAD2, 0xFFF3EAD3, 0xFFF3EAD3, 0xFFF3EAD2, 0xFFF3E9D2, 0xFFF3EAD3, 0xFFF3E9D1, 0xFFF3E9D2, 
        0xFFF3E9D1, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE5CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFECE1C7, 0xFFECE1C6, 
        0xFFEBE0C5, 0xFFEBE0C5, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D6B8, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B5, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 
        0xFFDBCBA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 
        0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB90, 0xFFCBBA90, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC6B487, 0xFF7D7154, 0xFF000000, 0xFF28241A, 0xFF5C533E, 0xFF6D6248, 0xFF7A6D51, 0xFF887A5A, 0xFF968763, 0xFFA1906A, 0xFFAE9C72, 0xFF73674B, 0xFF000000, 0xFF584F39, 0xFFBFAC7C, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFF5D533A, 0xFF1C1911, 0xFFB29E6E, 0xFFBBA573, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975E, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFF2E2818, 0xFF413721, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99056, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F52, 0xFF6D5C35, 0xFF000000, 0xFF726137, 0xFFA68D50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF826D3C, 0xFF000000, 0xFF463B1F,
  0xFF4E4223, 0xFF000000, 0xFF7D6939, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA2894D, 0xFF000000, 0xFF38301B, 0xFFA28A4F, 0xFFA78E53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFF0E0C07, 
        0xFF897647, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 
        0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFB29E6D, 0xFF2A251A, 0xFF97865D, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA979, 0xFFBEAA79, 0xFF9E8D64, 0xFF000000, 0xFF252118, 0xFF6A5F44, 0xFF524935, 0xFF3C3627, 0xFF2B271C, 0xFF1B1811, 0xFF13110C, 0xFF010101, 0xFF0C0B08, 0xFFA5946D, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 
        0xFFC6B385, 0xFFC6B386, 0xFFC6B387, 0xFFC7B488, 0xFFC7B488, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 
        0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C199, 0xFFD2C199, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 
        0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED1AF, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFE0D2B1, 
        0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCC0, 
        0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E6CD, 
        0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E6CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF2E9D1, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3E9D2, 0xFFF3E9D1, 0xFFF2E9D2, 0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E8D0, 
        0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE5CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEDE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE1C7, 0xFFECE1C7, 0xFFECE0C6, 
        0xFFEBE0C5, 0xFFEBE0C4, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC3, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABC, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE4D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDBCCA9, 
        0xFFDACCA8, 0xFFDACBA8, 0xFFDACAA7, 0xFFD9CAA6, 0xFFD9C9A6, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCCBB92, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA90, 0xFFCBB98E, 0xFFCBB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B68B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC6B487, 0xFF59503C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010101, 0xFF070605, 0xFF0D0B08, 0xFF100F0B, 0xFF15130D, 0xFF0E0C09, 0xFF000000, 0xFF6D6247, 0xFFBFAB7B, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBEA977, 0xFFBDA877, 0xFFBCA775, 0xFF5D533A, 0xFF000000, 0xFF766949, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 
        0xFFB7A16D, 0xFFB7A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19963, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF975F, 0xFFAF975E, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC945A, 0xFF7C6B41, 0xFF000000, 0xFF453A23, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88E52, 0xFF665632, 0xFF000000, 0xFF857140, 0xFFA68C50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA38A4B, 0xFFA3894B, 0xFF7C6938, 0xFF000000, 0xFF4E4223,
  0xFF60502A, 0xFF000000, 0xFF766335, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C50, 0xFF000000, 0xFF2C2615, 0xFF9D864D, 0xFFA88E52, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFF0C0A06, 
        0xFF806E43, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB29A64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 
        0xFFB49D68, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFB19D6D, 0xFF211D14, 0xFF96865D, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFAD9A6E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF030302, 0xFF050403, 0xFF010101, 0xFF070605, 0xFF8C7E5D, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 
        0xFFC6B285, 0xFFC6B386, 0xFFC6B486, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 
        0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 
        0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD0AF, 0xFFDFD1B0, 0xFFDFD1B1, 
        0xFFE0D2B1, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE2D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 
        0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEDE3C9, 0xFFEEE3CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CB, 0xFFEFE5CC, 
        0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF1E7CE, 0xFFF1E6CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E9D1, 0xFFF2E9D1, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D1, 0xFFF2E8D0, 
        0xFFF2E8D0, 0xFFF1E8D0, 0xFFF1E7CF, 0xFFF1E6CF, 0xFFF1E7CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFEBE0C5, 
        0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D6B8, 
        0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B5, 0xFFE2D4B4, 0xFFE1D4B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C59F, 0xFFD4C49F, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C19A, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC6B487, 0xFF3B3527, 0xFF000000, 0xFF534B37, 0xFF5C533E, 0xFF433D2D, 0xFF27231A, 0xFF14120D, 0xFF090806, 0xFF060604, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF807353, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF4B432E, 0xFF847550, 0xFF9B8A5F, 0xFFA79465, 0xFFAA9667, 0xFFAA9666, 0xFFA99565, 0xFFA89564, 
        0xFFA89464, 0xFFA89463, 0xFFA79362, 0xFFA79362, 0xFFA69260, 0xFFA69160, 0xFFA59160, 0xFFA5905F, 0xFFA4905E, 0xFFA48F5E, 0xFFA48F5D, 0xFFA48E5C, 0xFFA48E5C, 0xFFA38D5B, 0xFFA28E5A, 0xFFA28D59, 0xFFA28D59, 0xFFA28C57, 0xFFA18C57, 0xFFA18B56, 
        0xFFA08B56, 0xFF9D8854, 0xFF968150, 0xFF847246, 0xFF55492C, 0xFF010100, 0xFF000000, 0xFF453B23, 0xFFA89056, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF524628, 0xFF000000, 0xFF8F7A45, 0xFFA68D50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA3894B, 0xFF766335, 0xFF000000, 0xFF61512B,
  0xFF6B592F, 0xFF000000, 0xFF65552E, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF050402, 0xFF231E11, 0xFF9B834C, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFF040302, 
        0xFF605332, 0xFFAB9359, 0xFFAB935A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 
        0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A471, 0xFFBAA572, 0xFF96855C, 0xFF020101, 0xFF97865E, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA979, 0xFFBEAA79, 0xFFB3A072, 0xFF0D0C08, 0xFF000000, 0xFF413A2A, 0xFF504834, 0xFF625840, 0xFF74694C, 0xFF827455, 0xFF988964, 0xFF2C271D, 0xFF030202, 0xFF786C50, 0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 
        0xFFC5B385, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 
        0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C69F, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B1, 
        0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 
        0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 
        0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF1E6CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E8D0, 0xFFF1E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D1, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8D0, 0xFFF2E8CF, 
        0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF1E6CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE2C7, 0xFFECE1C7, 0xFFECE0C6, 0xFFEBE0C5, 
        0xFFEBE0C4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCDA9, 0xFFDACCA8, 
        0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A6, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C49F, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29A, 0xFFD2C19A, 
        0xFFD2C199, 0xFFD1C099, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC9B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC6B487, 0xFF16140F, 0xFF0C0B08, 0xFFA0916C, 0xFFC4B184, 0xFFC4B183, 0xFFC4B082, 0xFFC3B082, 0xFFBFAC7E, 0xFFA4946C, 0xFF968762, 0xFF100F0A, 0xFF000000, 0xFF92825E, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA775, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89055, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF443A21, 0xFF000000, 0xFF937C46, 0xFFA68D50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA3894B, 0xFFA3894B, 0xFF64542D, 0xFF000000, 0xFF6C5A30,
  0xFF796535, 0xFF000000, 0xFF584928, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF18150B, 0xFF18140B, 0xFF978149, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFF010100, 
        0xFF16120B, 0xFF9A8450, 0xFFAC935A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE955C, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C66, 0xFFB39D66, 
        0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFBAA471, 0xFFBAA572, 0xFF231F15, 0xFF070604, 0xFF97865E, 0xFFBCA775, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA877, 0xFFBEA977, 0xFFBEA978, 0xFFBEAA79, 0xFFB6A273, 0xFF262218, 0xFF000000, 0xFFB09E72, 0xFFC0AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFF554C38, 0xFF000000, 0xFF5F553F, 0xFFC4B183, 0xFFC4B183, 0xFFC5B284, 
        0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 
        0xFFCEBD94, 0xFFCEBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD7C7A2, 
        0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDFD1B1, 
        0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DCBF, 
        0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEFE4CB, 
        0xFFEFE5CB, 0xFFEFE5CC, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF1E6CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 
        0xFFF1E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE4CC, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFEBE0C6, 0xFFEBDFC5, 
        0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE4D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 
        0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDACCA8, 
        0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD8CAA5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD4C59F, 0xFFD4C59E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39B, 0xFFD2C19A, 0xFFD2C19A, 
        0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC8B68A, 0xFFC8B689, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFFC5B285, 0xFF000000, 0xFF1B1812, 0xFFA99871, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFF040402, 0xFF0D0C08, 0xFF9C8C65, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBEAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89055, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA89055, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF332B19, 0xFF070603, 0xFF957F48, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF574927, 0xFF000000, 0xFF796536,
  0xFF8A743D, 0xFF000000, 0xFF4A3E21, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58C4F, 0xFFA68C4F, 0xFF292213, 0xFF0D0B06, 0xFF947D47, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFF020201, 
        0xFF000000, 0xFF050402, 0xFF423922, 0xFF685936, 0xFF7A6940, 0xFF806F44, 0xFF817044, 0xFF827045, 0xFF827146, 0xFF837146, 0xFF837147, 0xFF837148, 0xFF837248, 0xFF837249, 0xFF84734A, 0xFF85744A, 0xFF85744A, 0xFF86744B, 0xFF86744B, 0xFF86744C, 
        0xFF86754D, 0xFF86764D, 0xFF87764D, 0xFF87764E, 0xFF88774F, 0xFF887750, 0xFF887750, 0xFF897850, 0xFF897851, 0xFF897952, 0xFF897A53, 0xFF867650, 0xFF796B49, 0xFF5D5238, 0xFF14120C, 0xFF000000, 0xFF0A0906, 0xFF97865E, 0xFFBCA674, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDAA78, 0xFFBFAA79, 0xFFB8A476, 0xFF3B3526, 0xFF000000, 0xFF8F805C, 0xFFC0AD7C, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFF7B6E50, 0xFF000000, 0xFF494230, 0xFFC3B082, 0xFFC4B183, 0xFFC5B284, 
        0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB88E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 
        0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 
        0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACCA8, 0xFFDACCA8, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B1, 
        0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D5B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE8DBBE, 
        0xFFE7DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC1, 0xFFE9DEC1, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C6, 0xFFECE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEFE4CB, 
        0xFFEFE4CB, 0xFFEFE4CC, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF1E7CE, 0xFFF1E7CE, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CF, 0xFFF1E7CE, 0xFFF1E6CF, 0xFFF1E6CE, 
        0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFEFE5CC, 0xFFEFE5CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 
        0xFFEADFC3, 0xFFEADFC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 
        0xFFE2D5B6, 0xFFE2D5B6, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDED0B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDA9, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD8CAA5, 0xFFD8C9A5, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD4C59F, 0xFFD4C59E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29A, 0xFFD1C19A, 
        0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78B, 0xFFC9B68B, 
        0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFA4946F, 0xFF000000, 0xFF29241B, 0xFFB7A57A, 0xFFC4B183, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF7F, 0xFFAF9D73, 0xFF000000, 0xFF1C1912, 0xFFA7956C, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89055, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF221C10, 0xFF120F08, 0xFF988149, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA4894B, 0xFFA3894B, 0xFF4A3E21, 0xFF000000, 0xFF8B743E,
  0xFF917941, 0xFF000000, 0xFF352C18, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF41361F, 0xFF010100, 0xFF907B47, 0xFFA78E52, 0xFFA78F52, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9157, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865E, 0xFFBCA774, 0xFFBCA775, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBCA878, 0xFF554C36, 0xFF000000, 0xFF685D43, 0xFFC0AC7C, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFA0906A, 0xFF000000, 0xFF332E22, 0xFFB9A77B, 0xFFC4B183, 0xFFC5B284, 
        0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 
        0xFFCEBD94, 0xFFCEBE94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDED1AF, 0xFFDFD1B0, 
        0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBD, 
        0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 
        0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E5CD, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF1E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 0xFFF0E6CE, 
        0xFFF0E6CD, 0xFFF0E6CD, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CC, 0xFFEFE4CB, 0xFFEEE4CB, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFECE2C8, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEADFC4, 
        0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D6B6, 
        0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDACCA9, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 
        0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 
        0xFFC8B68A, 0xFFC8B58A, 0xFFC7B589, 0xFFC7B488, 0xFFC6B487, 0xFF7D7155, 0xFF000000, 0xFF393326, 0xFFC5B284, 0xFFC5B183, 0xFFC4B183, 0xFFC3B082, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFF8E7F5D, 0xFF000000, 0xFF2B261C, 0xFFB3A275, 0xFFC0AC7C, 
        0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89055, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F52, 0xFFA78E52, 0xFF100D08, 0xFF221D10, 0xFF9E864C, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894A, 0xFF352C18, 0xFF000000, 0xFF917A40,
  0xFF947B42, 0xFF050402, 0xFF282112, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFF9B8349, 0xFF8F7944, 0xFF816D3D, 0xFF362E1A, 0xFF000000, 0xFF8A7643, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865E, 0xFFBCA774, 0xFFBCA775, 
        0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFF6E6246, 0xFF000000, 0xFF403A29, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE80, 0xFFC2AE7F, 0xFF000000, 0xFF1D1A13, 0xFFAE9D73, 0xFFC4B183, 0xFFC5B284, 
        0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 
        0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A0, 0xFFD6C7A1, 
        0xFFD7C7A2, 0xFFD7C8A2, 0xFFD8C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD0B0, 
        0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 
        0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 
        0xFFEEE3CA, 0xFFEEE3CA, 0xFFEFE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E5CC, 0xFFF0E5CD, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E6CD, 0xFFF0E5CD, 0xFFF0E5CD, 0xFFF0E5CD, 0xFFF0E5CD, 0xFFF0E5CD, 0xFFF0E5CC, 
        0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CB, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEBDFC4, 0xFFEADFC3, 
        0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE8DDC1, 0xFFE8DDC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D5B6, 
        0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE0D4B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDACCA9, 0xFFDACBA8, 
        0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 
        0xFFD1C099, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBA91, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B68A, 
        0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF574F3B, 0xFF000000, 0xFF514937, 0xFFC5B284, 0xFFC4B183, 0xFFC4B182, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFF6A5F45, 0xFF000000, 0xFF393325, 0xFFBFAB7B, 0xFFC0AC7C, 
        0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89055, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF000000, 0xFF18140B, 0xFF635430, 0xFF746237, 
        0xFF7E6B3B, 0xFF8E7743, 0xFF9D8549, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF282112, 0xFF060502, 0xFF947B42,
  0xFF957C42, 0xFF110E07, 0xFF0B0905, 0xFF544626, 0xFF312916, 0xFF1F1A0E, 0xFF131009, 0xFF0A0905, 0xFF070603, 0xFF050402, 0xFF020201, 0xFF000000, 0xFF78663A, 0xFFA78E52, 0xFFA88F52, 0xFFA88F54, 0xFFA89054, 0xFFA89055, 0xFFAA9156, 0xFFAA9156, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865E, 0xFFBCA774, 0xFFBCA775, 
        0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA79, 0xFFBFAA79, 0xFF827453, 0xFF020201, 0xFF18150F, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AF80, 0xFFC2AF80, 0xFF1D1A13, 0xFF030202, 0xFFA4936D, 0xFFC4B183, 0xFFC5B184, 
        0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 
        0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A2, 
        0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDCCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABC, 0xFFE7DBBE, 
        0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DBBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C6, 0xFFECE0C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEEE3C9, 
        0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFF0E5CC, 0xFFF0E5CD, 0xFFF0E5CD, 0xFFF0E5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 
        0xFFEFE4CC, 0xFFEFE4CB, 0xFFEFE5CB, 0xFFEFE4CB, 0xFFEEE4CB, 0xFFEEE4CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADEC3, 
        0xFFEADEC2, 0xFFEADEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 
        0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 
        0xFFDACBA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C099, 
        0xFFD1C099, 0xFFD1C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBA91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC8B78B, 
        0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF322D22, 0xFF020201, 0xFF74694E, 0xFFC5B184, 0xFFC4B183, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AF80, 0xFF453E2D, 0xFF000000, 0xFF514934, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFFC0AC7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFF5D5339, 0xFF000000, 0xFF000000, 0xFF584E36, 0xFF8E7E57, 0xFFA18F61, 0xFFAA9667, 0xFFAB9867, 0xFFAB9867, 0xFFAA9765, 0xFFAA9665, 
        0xFFAA9664, 0xFFA99563, 0xFFA99563, 0xFFA89462, 0xFFA89362, 0xFFA89361, 0xFFA89361, 0xFFA89260, 0xFFA7915F, 0xFFA7915F, 0xFFA6915E, 0xFFA6905D, 0xFFA68F5C, 0xFFA58F5B, 0xFFA48E5A, 0xFFA48E5A, 0xFFA48D59, 0xFFA48D59, 0xFFA38C58, 0xFFA28C57, 
        0xFFA28C57, 0xFF9F8954, 0xFF95804F, 0xFF7E6D42, 0xFF4A4027, 0xFF000000, 0xFF000000, 0xFF453B23, 0xFFA89055, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFF9A834B, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF040302, 
        0xFF050402, 0xFF070503, 0xFF090704, 0xFF110E08, 0xFF1D180D, 0xFF332A17, 0xFF070603, 0xFF110E08, 0xFF957C42,
  0xFF987F44, 0xFF221D0F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF070603, 0xFF0B0905, 0xFF0F0D07, 0xFF100D07, 0xFF000000, 0xFF685832, 0xFFA78E52, 0xFFA78E52, 0xFFA88F54, 0xFFA88F54, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865D, 0xFFBBA674, 0xFFBCA775, 
        0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFF968660, 0xFF0F0E0A, 0xFF030302, 0xFFB9A678, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFF4D4533, 0xFF000000, 0xFF8B7E5C, 0xFFC4B183, 0xFFC5B183, 
        0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B488, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 
        0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFD0BE96, 0xFFD0BF97, 0xFFD0BF98, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C6A1, 
        0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AE, 0xFFDFD1AF, 
        0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 
        0xFFE7DBBD, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 
        0xFFEDE2C9, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE5CB, 0xFFEFE4CB, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE5CC, 0xFFEFE4CC, 0xFFEFE4CB, 
        0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE2C8, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE0C6, 0xFFECE0C5, 0xFFEBDFC5, 0xFFEAE0C4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC3, 
        0xFFE9DEC2, 0xFFE9DEC1, 0xFFE8DDC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 
        0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1AF, 0xFFDED0AF, 0xFFDDD0AE, 0xFFDDCFAE, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 
        0xFFDACBA7, 0xFFD9CAA6, 0xFFD8CAA5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 
        0xFFD1C099, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCEBD94, 0xFFCFBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 
        0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFBBAA7F, 0xFF201D16, 0xFF020201, 0xFF9A8B68, 0xFFC5B284, 0xFFC4B183, 0xFFC4B083, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AE7F, 0xFF262219, 0xFF020201, 0xFF706549, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFFBFAC7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFF5D5239, 0xFF000000, 0xFF746647, 0xFFBAA572, 0xFFBAA571, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26D, 0xFFB7A16D, 
        0xFFB7A16C, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFAF975E, 0xFFAE965E, 
        0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFF7B693F, 0xFF000000, 0xFF453A23, 0xFFA89055, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFF8A7543, 0xFF000000, 0xFF131009, 0xFF1D190E, 0xFF131009, 
        0xFF0E0C07, 0xFF0A0905, 0xFF070503, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221D0F, 0xFF987F44,
  0xFF9A8145, 0xFF2F2715, 0xFF000000, 0xFF453A1F, 0xFF4F4324, 0xFF5B4D2A, 0xFF685830, 0xFF756336, 0xFF826E3D, 0xFF8F7944, 0xFF867140, 0xFF000000, 0xFF504427, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFFA99156, 0xFFA99156, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080604, 0xFF0A0905, 0xFF0A0905, 0xFF0A0905, 0xFF0A0905, 0xFF0A0905, 0xFF0A0905, 0xFF0A0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 
        0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0906, 0xFF0B0A06, 0xFF0B0A06, 0xFF0B0A06, 0xFF0B0A06, 0xFF0B0A06, 0xFF080705, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF97865D, 0xFFBBA674, 0xFFBCA774, 
        0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEAA78, 0xFFBEAA79, 0xFFAA986D, 0xFF1A1811, 0xFF020201, 0xFF958660, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFF7C6F52, 0xFF000000, 0xFF605740, 0xFFC4B183, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78A, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC93, 
        0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 
        0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AF, 0xFFDED0AF, 
        0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABC, 
        0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE8DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFECE2C7, 
        0xFFEDE2C8, 0xFFEDE2C8, 0xFFEEE2C8, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE3CB, 0xFFEFE4CA, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEFE4CA, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEFE4CB, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEFE4CB, 
        0xFFEEE4CB, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFEBE0C6, 0xFFEBDFC5, 0xFFEADFC4, 0xFFEADFC4, 0xFFEADEC3, 0xFFEADEC3, 0xFFE9DEC2, 
        0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 
        0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 
        0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD1C099, 
        0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B68B, 0xFFC9B68A, 
        0xFFC8B68A, 0xFFC8B589, 0xFFC7B488, 0xFFC7B487, 0xFFA2936E, 0xFF13110D, 0xFF060504, 0xFFC0AD80, 0xFFC4B283, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFB09F73, 0xFF191610, 0xFF040402, 0xFF92835F, 0xFFC0AC7C, 0xFFC0AC7B, 
        0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFF5D5339, 0xFF18150E, 0xFFAC996A, 0xFFBAA572, 0xFFBAA471, 0xFFB9A371, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 
        0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39C66, 0xFFB39B65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAC9359, 0xFF2C2617, 0xFF413721, 0xFFA89055, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F52, 0xFF6F5E36, 0xFF000000, 0xFF5D4F2D, 0xFFA68C50, 0xFF9B844A, 
        0xFF8D7642, 0xFF806C3C, 0xFF736236, 0xFF6B5A31, 0xFF5A4C29, 0xFF493D21, 0xFF000000, 0xFF2F2815, 0xFF9A8145,
  0xFF9D8446, 0xFF3F351C, 0xFF000000, 0xFF836D3B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58C4E, 0xFFA58C4F, 0xFF957E47, 0xFF040302, 0xFF362E1A, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFAA9155, 0xFFAA9156, 0xFF020201, 
        0xFF000000, 0xFF362E1B, 0xFF887546, 0xFF97824F, 0xFF988350, 0xFF9A8451, 0xFF9A8451, 0xFF9A8552, 0xFF9A8552, 0xFF9A8653, 0xFF9B8654, 0xFF9B8755, 0xFF9C8756, 0xFF9C8856, 0xFF9D8957, 0xFF9D8958, 0xFF9D8958, 0xFF9E8959, 0xFF9E8A59, 0xFF9F8A59, 
        0xFF9F8B5B, 0xFFA08B5B, 0xFFA08C5C, 0xFFA18C5C, 0xFFA18D5E, 0xFFA18D5E, 0xFFA28E5F, 0xFFA28F60, 0xFFA28F60, 0xFFA28F61, 0xFFA39061, 0xFFA39062, 0xFFA18E61, 0xFF918059, 0xFF413927, 0xFF000000, 0xFF0A0906, 0xFF97865D, 0xFFBBA674, 0xFFBBA774, 
        0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFF28241A, 0xFF000000, 0xFF706448, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFA8966E, 0xFF000000, 0xFF322D21, 0xFFC4B182, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA91, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C198, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 
        0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDBCCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AF, 
        0xFFDFD0AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 
        0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFEADEC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBE0C4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFECE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFEDE1C7, 
        0xFFEDE1C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEEE4CA, 0xFFEEE3CA, 0xFFEEE3CA, 0xFFEEE3C9, 
        0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE2C9, 0xFFEDE3C9, 0xFFEDE2C9, 0xFFEDE2C8, 0xFFEDE2C7, 0xFFEDE2C7, 0xFFECE2C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEAE0C4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE1D5B5, 
        0xFFE2D4B4, 0xFFE1D4B4, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFD9CBA7, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD1C099, 
        0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF877B5C, 0xFF030202, 0xFF28241B, 0xFFC5B284, 0xFFC5B183, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFF988963, 0xFF0E0C09, 0xFF060503, 0xFFB4A275, 0xFFC0AC7C, 0xFFC0AB7B, 
        0xFFC0AB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFF5D5239, 0xFF312C1E, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A371, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 
        0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09860, 0xFFAF9860, 0xFFAF9760, 0xFFAE975E, 0xFFAE965E, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFF635533, 0xFF3D341F, 0xFFA88F55, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF534628, 0xFF000000, 0xFF685933, 0xFFA68D4F, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF836E3C, 0xFF000000, 0xFF40351C, 0xFF9D8446,
  0xFFA08647, 0xFF4E4123, 0xFF000000, 0xFF6F5C32, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA68C4F, 0xFF988148, 0xFF16130B, 0xFF201B0F, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99155, 0xFFAA9156, 0xFF000000, 
        0xFF292315, 0xFFA48D54, 0xFFAB9359, 0xFFAC9459, 0xFFAC945B, 0xFFAC955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF985E, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 
        0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFF453D2A, 0xFF050403, 0xFF97855D, 0xFFBBA674, 0xFFBBA774, 
        0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA877, 0xFFBEA979, 0xFFBEAA79, 0xFFBEAA79, 0xFF473F2D, 0xFF000000, 0xFF49422F, 0xFFC1AC7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFB5A377, 0xFF14120D, 0xFF030202, 0xFFC4B182, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B284, 0xFFC6B385, 0xFFC6B387, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBC92, 
        0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C69F, 0xFFD5C6A0, 
        0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACAA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAB, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDECFAF, 
        0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6D9BC, 
        0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DDC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADFC4, 0xFFEADFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE1C6, 0xFFECE1C7, 
        0xFFECE1C6, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C9, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3CA, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE3C9, 
        0xFFEDE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE2C7, 0xFFEDE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBDFC5, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADEC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 
        0xFFE9DDC0, 0xFFE8DDC0, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D5B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE1D4B5, 
        0xFFE1D4B4, 0xFFE1D4B4, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA7, 0xFFD9CAA7, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD8C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49F, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 
        0xFFD1C098, 0xFFD0C097, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B78C, 0xFFC8B68A, 0xFFC8B68A, 
        0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC6B386, 0xFF675D46, 0xFF000000, 0xFF0E0D09, 0xFF4A4332, 0xFF7B6F52, 0xFFAA9A72, 0xFFB8A67A, 0xFFBCA97C, 0xFFC0AC7E, 0xFFC2AF80, 0xFF7D7052, 0xFF020201, 0xFF1A1711, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AB7B, 
        0xFFBFAB7B, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFFBCA875, 0xFFBBA774, 0xFF5D5239, 0xFF3F3726, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB7A16C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF985F, 0xFFAE975E, 0xFFAE965D, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAC9459, 0xFFAB9359, 0xFF706039, 0xFF3B321E, 0xFFA89055, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF3B321D, 0xFF040302, 0xFF77653A, 0xFFA68C4F, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF6E5C32, 0xFF000000, 0xFF4E4123, 0xFFA08647,
  0xFFA18748, 0xFF5E4E2A, 0xFF000000, 0xFF524525, 0xFFA3894B, 0xFFA4894C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF9D844A, 0xFF292213, 0xFF040302, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFF040302, 
        0xFF655734, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 
        0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A470, 0xFFBAA471, 0xFFAC9969, 0xFF080705, 0xFF97865D, 0xFFBBA674, 0xFFBCA774, 
        0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFF716548, 0xFF000000, 0xFF2D291D, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC0AC7D, 0xFFAC9A70, 0xFF8F815E, 0xFF71664A, 0xFF181510, 0xFF000000, 0xFF9C8C68, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C6A0, 
        0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 
        0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 
        0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C6, 
        0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE2C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE3C9, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEEE3C9, 0xFFEEE3C9, 0xFFEDE3C9, 0xFFEDE2C8, 0xFFEDE2C9, 
        0xFFEDE2C8, 0xFFEDE1C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE2C7, 0xFFECE2C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC5, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 
        0xFFE8DDC0, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 
        0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 
        0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 
        0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA91, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 
        0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC1AF83, 0xFF423C2D, 0xFF000000, 0xFF010101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF15130E, 0xFF3A3426, 0xFF5B513B, 0xFF75694D, 0xFF48402E, 0xFF000000, 0xFF4A4230, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7B, 
        0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFFBCA674, 0xFF7B6E4C, 0xFF675B3F, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB6A16C, 0xFFB6A06B, 0xFFB5A06A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFF847043, 0xFF605231, 0xFFA88F56, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF1D190E, 0xFF0C0A06, 0xFF867240, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF514425, 0xFF000000, 0xFF5E4E2A, 0xFFA18748,
  0xFFA18747, 0xFF6C5A30, 0xFF000000, 0xFF362D18, 0xFFA3894A, 0xFFA4894C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA1884C, 0xFF3B311C, 0xFF000000, 0xFF9D854C, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA98F54, 0xFFA99055, 0xFFA99156, 0xFF0D0B06, 
        0xFF826F43, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09861, 0xFFB09A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 
        0xFFB39D66, 0xFFB39D67, 0xFFB49E67, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFB29D6C, 0xFF252117, 0xFF95855C, 0xFFBBA673, 0xFFBBA674, 
        0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA78, 0xFFBEAA79, 0xFF9E8E65, 0xFF000000, 0xFF15120D, 0xFF675C42, 0xFF504733, 0xFF2E291E, 0xFF1B1811, 0xFF090806, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5E553F, 0xFFC4B183, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B488, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCFBE94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD1C099, 0xFFD2C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD5C49E, 0xFFD5C59F, 0xFFD5C69F, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD7C9A4, 0xFFD9C9A5, 0xFFD8C9A6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDED0AE, 
        0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE2D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE5D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 
        0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBE0C5, 
        0xFFEBE0C5, 0xFFEBE0C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFEDE1C7, 0xFFECE2C7, 0xFFEDE2C7, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFEDE2C8, 0xFFECE2C7, 
        0xFFECE2C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEADFC4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 
        0xFFE8DCBF, 0xFFE8DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 
        0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C49F, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C098, 
        0xFFD0C097, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBB91, 0xFFCDBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 
        0xFFC8B589, 0xFFC7B589, 0xFFC7B487, 0xFFBBAA7F, 0xFF191711, 0xFF020201, 0xFF9A8B68, 0xFF7C7053, 0xFF4D4633, 0xFF231F17, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF000000, 0xFF7D7051, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBFAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBBA674, 0xFFBAA573, 0xFFB9A472, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB6A16C, 
        0xFFB6A06C, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAB945A, 0xFFAB9359, 0xFFAA9157, 0xFFA99057, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF0B0905, 0xFF121009, 0xFF957F48, 0xFFA68C4F, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894A, 0xFF352C18, 0xFF000000, 0xFF6B5A30, 0xFFA18748,
  0xFFA18747, 0xFF796637, 0xFF080704, 0xFF1D190D, 0xFFA3894A, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF504326, 0xFF000000, 0xFF836F3F, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFF100D08, 
        0xFF897546, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09960, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 
        0xFFB39D65, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB5A06A, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A471, 0xFFB29E6D, 0xFF302A1D, 0xFF94845C, 0xFFBBA673, 0xFFBBA674, 
        0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAB7A, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF060503, 0xFF211E16, 0xFF322D21, 0xFF020201, 0xFF242118, 0xFFC4B183, 
        0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC8B588, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFC9B88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCDBB91, 
        0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD2C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 
        0xFFD6C6A0, 0xFFD6C6A1, 0xFFD7C7A1, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 
        0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BA, 
        0xFFE5D9BB, 0xFFE5D9BC, 0xFFE6D9BC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBE, 0xFFE8DBBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DCC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBE0C4, 
        0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C5, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE2C7, 0xFFECE1C7, 0xFFECE2C7, 0xFFEDE1C7, 0xFFECE2C7, 0xFFEDE2C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 
        0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE0C6, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEADFC4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 
        0xFFE8DBBF, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B3, 
        0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 
        0xFFD9C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C19A, 0xFFD1C098, 0xFFD0C098, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBB90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 
        0xFFC8B589, 0xFFC7B487, 0xFFC7B487, 0xFFAA9B74, 0xFF000000, 0xFF2F2B20, 0xFFC5B285, 0xFFC5B284, 0xFFC4B182, 0xFFC3B082, 0xFFBBA87B, 0xFF948561, 0xFF504835, 0xFF1E1B13, 0xFF000000, 0xFF000000, 0xFFB4A174, 0xFFC0AC7D, 0xFFC0AC7B, 0xFFBFAB7B, 
        0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA571, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB6A16B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 
        0xFFAD965D, 0xFFAD955C, 0xFFAD945B, 0xFFAC945B, 0xFFAC9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFF968049, 0xFF060503, 0xFF19150C, 0xFFA68C50, 0xFFA68C4F, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894A, 0xFF1D180D, 0xFF080704, 0xFF796636, 0xFFA18748,
  0xFFA18747, 0xFF87713C, 0xFF100D07, 0xFF070603, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF5F502E, 0xFF000000, 0xFF62542F, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFF493E25, 
        0xFF957F4C, 0xFFAB9258, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFFAE965C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09861, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 
        0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A370, 0xFFB9A470, 0xFFB4A06E, 0xFF63583D, 0xFFA29064, 0xFFBBA673, 0xFFBBA674, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAB7A, 0xFF352F21, 0xFF000000, 0xFF191610, 0xFF48412F, 0xFF706549, 0xFF9B8C65, 0xFFBBA87B, 0xFFC2AF80, 0xFFA8966E, 0xFF13110D, 0xFF060504, 0xFFB6A478, 
        0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B587, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 
        0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 
        0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 
        0xFFDDD0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 
        0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DEC1, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC2, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC4, 
        0xFFEBDFC4, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFECE0C6, 0xFFEBE1C6, 0xFFECE0C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C6, 0xFFECE1C6, 0xFFECE1C7, 0xFFECE1C7, 0xFFECE1C6, 
        0xFFECE1C6, 0xFFECE1C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DDC2, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE9DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 
        0xFFE8DBBF, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE7DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 
        0xFFE0D3B3, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A1, 0xFFD5C6A1, 0xFFD6C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29C, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C098, 0xFFD0C097, 
        0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 
        0xFFC8B589, 0xFFC7B487, 0xFFC7B487, 0xFF72674D, 0xFF000000, 0xFF675D45, 0xFFC5B284, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFAE9C72, 0xFF000000, 0xFF17150F, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE965D, 0xFFAE965D, 
        0xFFAD955D, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFF7F6C3E, 0xFF030301, 0xFF2A2314, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4E, 
        0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894C, 0xFFA3894A, 0xFF060503, 0xFF100D07, 0xFF88723C, 0xFFA18748,
  0xFFA18747, 0xFF967E43, 0xFF17130A, 0xFF030301, 0xFF907941, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58C4E, 0xFFA58C4F, 0xFF736137, 0xFF030201, 0xFF41371F, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 
        0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 
        0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36E, 0xFFB8A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 
        0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAB7A, 0xFF736749, 0xFF000000, 0xFF48402E, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFBFAC7E, 0xFF242118, 0xFF030202, 0xFF817556, 
        0xFFC4B183, 0xFFC5B184, 0xFFC5B284, 0xFFC5B385, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B58A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 
        0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 
        0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 
        0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D6B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 
        0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DDC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC3, 0xFFEADFC3, 
        0xFFEADFC3, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFECE0C6, 0xFFEBE0C5, 0xFFEBE0C6, 0xFFECE0C6, 0xFFEBE0C6, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 
        0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE7DCBF, 0xFFE7DBBF, 
        0xFFE7DBBE, 0xFFE6DABD, 0xFFE7DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE2D5B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE1D3B3, 
        0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD0B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9C9A5, 
        0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 
        0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFF2D291F, 0xFF000000, 0xFF968865, 0xFFC5B284, 0xFFC4B183, 0xFFC4B082, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF7F, 0xFF75694C, 0xFF000000, 0xFF4D4532, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7A, 
        0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA472, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 
        0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19961, 0xFFB09960, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE965E, 0xFFAE965D, 
        0xFFAD955C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAB935A, 0xFFAB9358, 0xFFAB9258, 0xFFAA9258, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF665732, 0xFF000000, 0xFF4A3F24, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 
        0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF917941, 0xFF030301, 0xFF17130A, 0xFF967E43, 0xFFA18748,
  0xFFA18747, 0xFFA18748, 0xFF211C0F, 0xFF030201, 0xFF796537, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4F, 0xFF84703F, 0xFF0B0905, 0xFF201B0F, 0xFFA78E51, 0xFFA78E53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99056, 0xFFAA9156, 
        0xFFAA9256, 0xFFAB9258, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB29B63, 0xFFB29B64, 0xFFB29C65, 
        0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 
        0xFFBCA774, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFFAD9A6E, 0xFF000000, 0xFF191610, 0xFFBBA779, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFF514935, 0xFF000000, 0xFF4D4533, 
        0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC6B385, 0xFFC6B386, 0xFFC6B486, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 
        0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 
        0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCEAD, 
        0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE4D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 
        0xFFE5D8BA, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DEC1, 0xFFE9DDC2, 0xFFE9DEC2, 0xFFEADEC2, 
        0xFFEADEC3, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC5, 0xFFEBE0C5, 0xFFEBE0C4, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C5, 0xFFEBE0C4, 
        0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE8DDC1, 0xFFE8DDC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DBBF, 0xFFE7DBBF, 0xFFE7DBBF, 0xFFE7DBBD, 
        0xFFE7DBBD, 0xFFE7DABD, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B2, 0xFFE0D3B2, 
        0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD8CAA5, 0xFFD8C9A5, 
        0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD0C098, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCEBE94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B689, 0xFFC8B589, 
        0xFFC7B588, 0xFFC7B488, 0xFFBFAD81, 0xFF000000, 0xFF1A1711, 0xFFAD9C73, 0xFFC5B284, 0xFFC4B183, 0xFFC3B082, 0xFFC3B082, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFF373124, 0xFF000000, 0xFF847655, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 
        0xFFBFAB7A, 0xFFBEA979, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A06C, 
        0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 
        0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFF4E4226, 0xFF000000, 0xFF665731, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF786536, 0xFF030201, 0xFF211C0F, 0xFFA18748, 0xFFA18747,
  0xFFA18647, 0xFFA18748, 0xFF352C18, 0xFF010100, 0xFF61512C, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF978048, 0xFF131009, 0xFF090704, 0xFFA78E51, 0xFFA78F52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99156, 0xFFAA9156, 
        0xFFAA9256, 0xFFAA9258, 0xFFAB9258, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAD965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19B63, 0xFFB29B64, 0xFFB29B65, 
        0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 
        0xFFBBA774, 0xFFBCA775, 0xFFBCA875, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA78, 0xFFBFAA79, 0xFFBDA879, 0xFF1A1811, 0xFF000000, 0xFFA7956B, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFF8D7E5D, 0xFF000000, 0xFF2B261C, 
        0xFFB7A57A, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCBB88E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 
        0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDD0AE, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B8, 
        0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC2, 
        0xFFE9DEC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEADFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC4, 0xFFEBDFC5, 0xFFEBDFC4, 0xFFEBE0C4, 0xFFEADFC4, 0xFFEAE0C4, 0xFFEADFC4, 
        0xFFEBDFC4, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADEC3, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DBBF, 0xFFE7DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DABD, 
        0xFFE6DABD, 0xFFE6DABD, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 
        0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 
        0xFFD8C9A4, 0xFFD8C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD0C097, 0xFFD0BF97, 
        0xFFD0BF96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBC94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B589, 0xFFC8B589, 
        0xFFC7B588, 0xFFC7B487, 0xFF7E7355, 0xFF000000, 0xFF3C3628, 0xFFBEAB7F, 0xFFC4B184, 0xFFC4B183, 0xFFC4B082, 0xFFC3B082, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AE7F, 0xFF010100, 0xFF070604, 0xFFA4936A, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 
        0xFFBFAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA774, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 
        0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49D68, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE965D, 0xFFAE965D, 
        0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFF372E1A, 0xFF000000, 0xFF877341, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 
        0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF60502B, 0xFF010100, 0xFF362D18, 0xFFA18748, 0xFFA18747,
  0xFFA18647, 0xFFA18748, 0xFF554726, 0xFF000000, 0xFF463B20, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF1E190E, 0xFF050402, 0xFF8F7945, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 
        0xFFAA9157, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 
        0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 
        0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEA978, 0xFF504733, 0xFF000000, 0xFF685D43, 0xFFC0AC7D, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF81, 0xFF080705, 0xFF0D0B08, 
        0xFF9D8E69, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B387, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 
        0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBE94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29A, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 
        0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE2D4B4, 0xFFE2D4B5, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 
        0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC1, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADFC3, 0xFFEADEC2, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADFC3, 0xFFEADFC4, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEADFC3, 0xFFEBDEC4, 0xFFEADFC3, 0xFFEADEC3, 
        0xFFEADEC3, 0xFFEADEC2, 0xFFEADEC2, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABD, 0xFFE6DABD, 
        0xFFE6DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 
        0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9C9A5, 0xFFD8C9A4, 
        0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFCFBE96, 0xFFCFBE96, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98F, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B588, 
        0xFFC7B488, 0xFFC7B487, 0xFF393426, 0xFF000000, 0xFF645B43, 0xFFC5B284, 0xFFC4B183, 0xFFC4B182, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFF8F805D, 0xFF000000, 0xFF2A251B, 0xFFB2A073, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAA7A, 
        0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBBA774, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAD965D, 
        0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89053, 0xFFA88F53, 0xFF9D864D, 0xFF272113, 0xFF000000, 0xFFA68D50, 0xFFA68C50, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4B, 0xFFA3894B, 0xFF463B20, 0xFF000000, 0xFF564826, 0xFFA18748, 0xFFA18647,
  0xFFA18647, 0xFFA18647, 0xFF725F32, 0xFF000000, 0xFF312916, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF372F1A, 0xFF020201, 0xFF726037, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99055, 0xFFA99055, 0xFFA99156, 
        0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9459, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 
        0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 
        0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA979, 0xFFBEAA79, 0xFFBFAA7A, 0xFF817452, 0xFF000000, 0xFF211E15, 0xFFC0AC7C, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF7F, 0xFFC3AF80, 0xFF443D2D, 0xFF000000, 
        0xFF776B4F, 0xFFC3B082, 0xFFC4B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 
        0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 
        0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE0D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE2D6B6, 0xFFE3D6B8, 
        0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DDC0, 
        0xFFE9DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC3, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADEC2, 0xFFEADEC3, 0xFFEADEC3, 0xFFEADEC2, 0xFFE9DEC3, 0xFFE9DEC3, 0xFFEADEC2, 0xFFEADEC2, 0xFFEADEC2, 
        0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6D9BC, 
        0xFFE5D9BC, 0xFFE5D9BB, 0xFFE5D8BB, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE2D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 
        0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF98, 0xFFD0BF96, 
        0xFFCFBF96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 
        0xFFC7B488, 0xFFB5A47A, 0xFF14120D, 0xFF080705, 0xFF958765, 0xFFC4B284, 0xFFC4B183, 0xFFC4B183, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AE80, 0xFF494230, 0xFF000000, 0xFF4D4532, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AB7C, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A16E, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06B, 
        0xFFB6A06A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAD965D, 
        0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99155, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF917B47, 0xFF16120A, 0xFF16120A, 0xFFA68D50, 0xFFA68C50, 0xFFA58C4E, 0xFFA58B4E, 
        0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF312916, 0xFF000000, 0xFF726033, 0xFFA18747, 0xFFA18647,
  0xFFA18647, 0xFFA18747, 0xFF927940, 0xFF000000, 0xFF221C0F, 0xFF977F45, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF5B4D2B, 0xFF000000, 0xFF554829, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99055, 
        0xFFAA9256, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC935A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29A64, 0xFFB29B64, 
        0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A470, 0xFFBAA572, 0xFFBAA572, 0xFFBBA672, 
        0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA79, 0xFFBFAA79, 0xFF9E8C64, 0xFF12100B, 0xFF000000, 0xFFB09D71, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC3AF80, 0xFF928360, 0xFF000000, 
        0xFF3D3728, 0xFFC2AF81, 0xFFC4B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B88C, 0xFFCAB88D, 0xFFCBB88D, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 
        0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 
        0xFFD4C49F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAB, 0xFFDCCEAB, 
        0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D6B6, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 
        0xFFE8DCC0, 0xFFE9DCC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DEC2, 0xFFE9DDC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFEADEC2, 0xFFEADEC2, 0xFFE9DEC2, 0xFFE9DEC2, 0xFFE9DEC1, 
        0xFFE9DEC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE8DDC1, 0xFFE8DDC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE5D9BB, 
        0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B7, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD1B1, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDBCEAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8CAA5, 0xFFD8C9A4, 0xFFD8C8A4, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49F, 0xFFD4C49E, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C39B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF96, 0xFFD0BF96, 
        0xFFCFBE96, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC7B589, 0xFFC7B588, 
        0xFFC7B487, 0xFF85785A, 0xFF060604, 0xFF16140F, 0xFFC5B285, 0xFFC5B184, 0xFFC4B183, 0xFFC4B182, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AE7F, 0xFF15130D, 0xFF040402, 0xFF776B4D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBEAA79, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA875, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D66, 0xFFB39C66, 0xFFB39C66, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 
        0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFF857141, 0xFF020201, 0xFF3D341D, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4D, 
        0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFF977F45, 0xFF221C0F, 0xFF000000, 0xFF927A41, 0xFFA18748, 0xFFA18647,
  0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF070603, 0xFF141109, 0xFF8B753F, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFF816D3D, 0xFF000000, 0xFF3B321D, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 
        0xFFA99156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19B64, 0xFFB29B64, 
        0xFFB39B65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA571, 0xFFBAA572, 0xFFBBA573, 
        0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEA979, 0xFFBEAA79, 0xFFB6A274, 0xFF2D281D, 0xFF000000, 0xFF6F6347, 0xFFC0AD7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFBDAA7D, 0xFF100E0A, 
        0xFF030202, 0xFFB6A57A, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 
        0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 
        0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDCCDAA, 
        0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 
        0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DBBF, 0xFFE7DBBF, 0xFFE7DBBF, 
        0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE9DDC0, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC2, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 0xFFE9DDC1, 
        0xFFE9DDC1, 0xFFE8DDC1, 0xFFE8DDC0, 0xFFE9DDC1, 0xFFE8DDC0, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6D9BB, 0xFFE6D9BB, 0xFFE5D9BB, 
        0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 
        0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A3, 
        0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 
        0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 
        0xFFC5B285, 0xFF534B39, 0xFF000000, 0xFF353023, 0xFFB7A67B, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFF958561, 0xFF090805, 0xFF0C0B08, 0xFFA4946B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 
        0xFFBEAA79, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA675, 0xFFBBA674, 0xFFBBA573, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 
        0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF746339, 0xFF000000, 0xFF665732, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 
        0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFF8B7540, 0xFF141109, 0xFF070603, 0xFFA28749, 0xFFA18748, 0xFFA18647,
  0xFFA08646, 0xFFA18648, 0xFFA28748, 0xFF272111, 0xFF020201, 0xFF7E6A39, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA1884C, 0xFF000000, 0xFF292214, 0xFF9E864D, 0xFFA78E52, 0xFFA78F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 
        0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 
        0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 
        0xFFBBA674, 0xFFBBA674, 0xFFBCA774, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAA7A, 0xFF544B36, 0xFF000000, 0xFF302B1F, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC0AD7E, 0xFF534A37, 
        0xFF000000, 0xFF786C50, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD3C29B, 0xFFD2C39C, 0xFFD3C39C, 0xFFD4C39D, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAB, 
        0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 
        0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DABE, 0xFFE7DBBE, 0xFFE7DBBE, 
        0xFFE7DBBF, 0xFFE7DBBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE8DDC0, 0xFFE8DDC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DDC0, 0xFFE8DCC0, 0xFFE8DDC0, 
        0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DCBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE7DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 
        0xFFE4D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 
        0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACBA9, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 
        0xFFB5A57B, 0xFF242018, 0xFF000000, 0xFF050403, 0xFF1B1812, 0xFF423B2C, 0xFF7F7354, 0xFFBDA97D, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AF80, 0xFF635941, 0xFF000000, 0xFF252118, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 
        0xFFBEA979, 0xFFBDA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA573, 0xFFBAA572, 0xFFBAA472, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB69F6A, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 
        0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF55482A, 0xFF000000, 0xFF8B7643, 0xFFA68C50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4D, 
        0xFFA48A4D, 0xFFA38A4B, 0xFFA3894B, 0xFF7D6939, 0xFF020201, 0xFF282112, 0xFFA18748, 0xFFA18647, 0xFFA08647,
  0xFFA08646, 0xFFA18647, 0xFFA28748, 0xFF504424, 0xFF000000, 0xFF6B5A30, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF16130A, 0xFF14110A, 0xFF907B47, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 
        0xFFA99155, 0xFFAA9157, 0xFFAA9257, 0xFFAA9258, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 
        0xFFB29B65, 0xFFB29C65, 0xFFB39C66, 0xFFB49D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 
        0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFF8C7E59, 0xFF030302, 0xFF15120D, 0xFFA7956C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AD7F, 0xFFC0AC7E, 0xFFB9A679, 0xFF615740, 
        0xFF000000, 0xFF211D15, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B385, 0xFFC6B385, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 
        0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 
        0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDA9, 
        0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 
        0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE7DABD, 0xFFE6DABD, 0xFFE7DBBE, 
        0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBF, 0xFFE7DBBF, 0xFFE7DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCC0, 0xFFE8DCBF, 0xFFE8DCBF, 
        0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE6DABD, 0xFFE7DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE4D8BA, 
        0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED1AF, 
        0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C7A3, 
        0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 
        0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98D, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B488, 0xFFC7B487, 
        0xFF9D8F6B, 0xFF000000, 0xFF100E0A, 0xFF14120D, 0xFF010101, 0xFF000000, 0xFF000000, 0xFF070605, 0xFF423C2C, 0xFF8D7E5C, 0xFFB09E74, 0xFF383325, 0xFF000000, 0xFF685D44, 0xFFC1AC7D, 0xFFC0AC7B, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAA79, 0xFFBEAA79, 
        0xFFBEAA78, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA776, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 
        0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB39D67, 0xFFB39C66, 0xFFB29C66, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09861, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAD965D, 0xFFAD955C, 
        0xFFAD955B, 0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA78D51, 0xFF302917, 0xFF030301, 0xFF9E864C, 0xFFA68C4F, 0xFFA58B4F, 0xFFA58B4E, 0xFFA48B4D, 
        0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF6A5930, 0xFF000000, 0xFF514424, 0xFFA18748, 0xFFA18647, 0xFFA08646,
  0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF796536, 0xFF000000, 0xFF4F4224, 0xFFA2884A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA2884D, 0xFF372F1A, 0xFF000000, 0xFF826F3F, 0xFFA88E52, 0xFFA88E52, 0xFFA89054, 0xFFA89054, 0xFFA99055, 
        0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 
        0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA571, 0xFFBAA572, 
        0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFF100E0A, 0xFF030302, 0xFF7E7151, 0xFFBFAB7C, 0xFFA4936B, 0xFF827554, 0xFF423B2B, 0xFF080705, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFFA2926C, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B689, 0xFFC8B689, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 
        0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 
        0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 
        0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE8DCBF, 0xFFE7DBBF, 
        0xFFE7DCBF, 0xFFE7DBBF, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE6DABE, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BB, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D8B9, 
        0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 
        0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C9A4, 0xFFD7C8A3, 0xFFD7C7A2, 
        0xFFD7C7A2, 0xFFD6C6A1, 0xFFD5C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 
        0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 
        0xFF564F3B, 0xFF000000, 0xFF756A4F, 0xFFC5B284, 0xFF948563, 0xFF524A36, 0xFF28241B, 0xFF0B0A07, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF050403, 0xFF000000, 0xFFB19E72, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA674, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06A, 
        0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 
        0xFFAD955B, 0xFFAC945A, 0xFFAB9459, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF0A0805, 0xFF16130B, 0xFF7D6A3C, 0xFF8F7944, 0xFF9C844A, 0xFFA58B4E, 0xFFA48B4D, 
        0xFFA48A4C, 0xFFA38A4C, 0xFFA2884A, 0xFF4F4223, 0xFF000000, 0xFF796636, 0xFFA18748, 0xFFA18647, 0xFFA08646,
  0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF977E43, 0xFF000000, 0xFF2D2514, 0xFFA3894A, 0xFFA3894B, 0xFF998147, 0xFF7B6739, 0xFF574A29, 0xFF3A311B, 0xFF251F11, 0xFF0D0B06, 0xFF000000, 0xFF6A5A33, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 
        0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC935A, 0xFFAD945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19B64, 
        0xFFB29B64, 0xFFB29B65, 0xFFB29C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB5A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 
        0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAA7A, 0xFF504834, 0xFF000000, 0xFF272319, 0xFF373123, 0xFF18150F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2C281D, 
        0xFF231F17, 0xFF000000, 0xFF534A37, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B386, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B488, 0xFFC8B589, 0xFFC8B589, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 
        0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBE94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 
        0xFFDBCCA9, 0xFFDBCCAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD2B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 
        0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6DABC, 
        0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DBBD, 0xFFE7DABD, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 0xFFE7DBBE, 
        0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DABD, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE5DABC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 
        0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B5, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD2B0, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 
        0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD7C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC4B185, 
        0xFF080705, 0xFF080705, 0xFFAC9B74, 0xFFC5B284, 0xFFC4B183, 0xFFC4B082, 0xFFB7A479, 0xFF988A65, 0xFF6B6046, 0xFF262219, 0xFF000000, 0xFF000000, 0xFF2B271C, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 
        0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB69F6B, 0xFFB59F6A, 
        0xFFB59F69, 0xFFB49E69, 0xFFB49E67, 0xFFB49D68, 0xFFB39D66, 0xFFB39C66, 0xFFB39B65, 0xFFB29C65, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 
        0xFFAD945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F52, 0xFF947E48, 0xFF000000, 0xFF000000, 0xFF080704, 0xFF17130B, 0xFF241F11, 0xFF39311B, 0xFF594B29, 
        0xFF7C6839, 0xFF9C8348, 0xFFA3894B, 0xFF2C2514, 0xFF000000, 0xFF977E44, 0xFFA18748, 0xFFA18647, 0xFFA08646,
  0xFFA08646, 0xFFA08646, 0xFFA18648, 0xFF9D8346, 0xFF17130A, 0xFF080704, 0xFF4D4123, 0xFF1B170C, 0xFF060502, 0xFF020201, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF453A21, 0xFFA78E52, 0xFFA78E52, 0xFFA88F54, 0xFFA88F54, 0xFFA99055, 
        0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 
        0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA776, 0xFFBCA876, 0xFFBDA876, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAB7A, 0xFFA29167, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221F16, 0xFF6F6348, 0xFFAB9970, 0xFFC2AF80, 
        0xFF847657, 0xFF020201, 0xFF1F1C14, 0xFFB6A479, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 
        0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 
        0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 
        0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D4B4, 
        0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BC, 
        0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE7DABD, 0xFFE7DABD, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DBBD, 0xFFE7DBBE, 0xFFE7DBBD, 0xFFE7DABD, 0xFFE7DABD, 0xFFE7DBBD, 0xFFE7DABD, 0xFFE6DABD, 
        0xFFE6DABD, 0xFFE7DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D6B8, 
        0xFFE3D7B8, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE1D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 
        0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9C9A6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 
        0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE94, 
        0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFF7C7054, 
        0xFF000000, 0xFF3E382A, 0xFFBEAB7F, 0xFFC5B284, 0xFFC4B183, 0xFFC4B082, 0xFFC4B082, 0xFFC3AF81, 0xFFC1AE7F, 0xFFC2AE7F, 0xFF2F2A1E, 0xFF000000, 0xFF7E7151, 0xFFC1AC7D, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 
        0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C67, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 
        0xFFAC945B, 0xFFAC945A, 0xFFAB9459, 0xFFAB9359, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF665632, 0xFF000000, 0xFF1A160C, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 
        0xFF020201, 0xFF050402, 0xFF1C170C, 0xFF060502, 0xFF18140B, 0xFF9D8346, 0xFFA18748, 0xFFA18646, 0xFFA08646,
  0xFFA08546, 0xFFA08646, 0xFFA18747, 0xFF9F8446, 0xFF392F19, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070603, 0xFF120F08, 0xFF1E190E, 0xFF382F1A, 0xFF5E502D, 0xFF7F6B3C, 0xFF141109, 0xFF1B170D, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 
        0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9459, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29B63, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA571, 
        0xFFBAA573, 0xFFB9A472, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBFAA79, 0xFFBFAB7A, 0xFF201C14, 0xFF000000, 0xFF433C2B, 0xFFA6956B, 0xFFC1AD7D, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AF80, 
        0xFFC3AF81, 0xFF12100C, 0xFF050403, 0xFF877A5A, 0xFFC4B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 
        0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 
        0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A3, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 
        0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDD0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 
        0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE2D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 
        0xFFE5D9BB, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABD, 
        0xFFE6DABD, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6DABC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 
        0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A1, 
        0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCEBE95, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B588, 0xFFC7B488, 0xFFC7B487, 0xFF221E17, 
        0xFF000000, 0xFF766B50, 0xFFC5B284, 0xFFC5B284, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFB2A074, 0xFF000000, 0xFF0A0906, 0xFFB19F73, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA78, 0xFFBEA978, 
        0xFFBEA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBAA673, 0xFFBBA673, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A16E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB5A06A, 0xFFB59F6A, 
        0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 
        0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA99054, 0xFFA88F53, 0xFFA78E52, 0xFF332B19, 0xFF040302, 0xFF826F3F, 0xFFA68C4F, 0xFF857140, 0xFF5B4C2B, 0xFF352D19, 0xFF1E190E, 
        0xFF100E07, 0xFF070503, 0xFF000000, 0xFF000000, 0xFF39301A, 0xFF9F8547, 0xFFA18748, 0xFFA08647, 0xFFA08646,
  0xFFA08545, 0xFFA08647, 0xFFA18747, 0xFFA08647, 0xFF594B28, 0xFF000000, 0xFF2A2313, 0xFF63532D, 0xFF746336, 0xFF8C7642, 0xFFA0874B, 0xFFA58B4E, 0xFFA58C4E, 0xFFA48B4E, 0xFF39301B, 0xFF000000, 0xFF9F874D, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 
        0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C65, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 
        0xFF9F8D61, 0xFF4A422D, 0xFFBBA673, 0xFFBCA774, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAB7A, 0xFF706448, 0xFF000000, 0xFF3C3526, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AF7F, 
        0xFFC3AF80, 0xFF645942, 0xFF000000, 0xFF4C4532, 0xFFC0AD80, 0xFFC5B284, 0xFFC5B284, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB98D, 
        0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C099, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C29B, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C8A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACBA7, 0xFFDACBA8, 
        0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B2, 
        0xFFE0D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D5B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE5D8BA, 
        0xFFE5D8BB, 0xFFE5D8BA, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BC, 0xFFE5D9BB, 0xFFE6D9BB, 0xFFE6D9BB, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE5D9BC, 0xFFE6D9BC, 0xFFE6D9BC, 0xFFE6D9BB, 0xFFE6D9BB, 0xFFE6D9BB, 
        0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BC, 0xFFE5D8BB, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D5B7, 
        0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE0D4B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDDD0AE, 0xFFDDCFAE, 0xFFDDCFAD, 
        0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 
        0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 
        0xFFCEBC93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B488, 0xFFC6B487, 0xFF958765, 0xFF040403, 
        0xFF14120D, 0xFFAD9C74, 0xFFC5B284, 0xFFC4B183, 0xFFC4B183, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFF5C533C, 0xFF000000, 0xFF443D2C, 0xFFBBA879, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBDA977, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA573, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 
        0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 
        0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF070603, 0xFF16130B, 0xFF917B45, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA2884B, 
        0xFF87723F, 0xFF766336, 0xFF342C17, 0xFF000000, 0xFF5A4C28, 0xFFA08647, 0xFFA18647, 0xFFA08646, 0xFFA08545,
  0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF746133, 0xFF000000, 0xFF342B17, 0xFFA3894A, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4E, 0xFFA48B4E, 0xFF5D4E2C, 0xFF000000, 0xFF736138, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 
        0xFFA99054, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAE955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 
        0xFFB7A370, 0xFF110F0A, 0xFF6F6244, 0xFFBBA673, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA7A, 0xFFA29167, 0xFF0B0A07, 0xFF000000, 0xFFAE9C70, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFFC2AF80, 0xFFB9A67A, 0xFF000000, 0xFF090806, 0xFFB3A177, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 
        0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD8C8A4, 0xFFD7C9A4, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 
        0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD0AF, 0xFFDFD1B0, 0xFFDFD2B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 
        0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE2D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D8B9, 
        0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BA, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 0xFFE5D9BB, 
        0xFFE5D8BB, 0xFFE5D9BA, 0xFFE5D8BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D5B7, 0xFFE2D5B6, 
        0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 
        0xFFDCCEAC, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD5C6A1, 
        0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 
        0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF4D4634, 0xFF000000, 
        0xFF443D2D, 0xFFC5B284, 0xFFC5B184, 0xFFC4B183, 0xFFC4B182, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AE7F, 0xFF0F0D09, 0xFF020201, 0xFF796D4E, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 
        0xFFBDA977, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 
        0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09960, 0xFFAF9860, 0xFFAF985F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAD945B, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF8A7543, 0xFF000000, 0xFF272113, 0xFFA58B4F, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA3894B, 0xFF342B17, 0xFF000000, 0xFF746133, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08545,
  0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF86703C, 0xFF110E07, 0xFF080704, 0xFFA3894A, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF786539, 0xFF000000, 0xFF3E341E, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA99154, 0xFFA99056, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16B, 0xFFB7A16C, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A36F, 0xFFB9A470, 0xFFBAA471, 
        0xFFBAA572, 0xFF665A3E, 0xFF0D0C08, 0xFFAD9A6B, 0xFFBCA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA978, 0xFFBEAA79, 0xFFBEAA7A, 0xFFB7A475, 0xFF3B3426, 0xFF000000, 0xFF595039, 0xFFC0AC7D, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 
        0xFFC2AF80, 0xFFC3AF80, 0xFF4F4734, 0xFF000000, 0xFF6D6248, 0xFFC4B183, 0xFFC5B184, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 
        0xFFCBB88E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF98, 0xFFD1C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 
        0xFFD2C29B, 0xFFD3C39B, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B1, 
        0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE1D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B7, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 
        0xFFE4D7B9, 0xFFE4D7B9, 0xFFE5D8BA, 0xFFE4D8B9, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D9BA, 0xFFE5D9BA, 0xFFE5D8BB, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D9BB, 0xFFE5D8BB, 0xFFE5D8BA, 
        0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE4D7B9, 0xFFE4D8B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D6B7, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 
        0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD2B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED1AF, 0xFFDED0AF, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 
        0xFFDCCEAB, 0xFFDCCEAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8CAA5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A0, 0xFFD5C6A0, 
        0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBC93, 
        0xFFCDBC93, 0xFFCDBC91, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B488, 0xFFAD9C75, 0xFF1C1913, 0xFF000000, 
        0xFF9F8F6B, 0xFFC5B184, 0xFFC4B183, 0xFFC4B183, 0xFFC4B182, 0xFFC3B081, 0xFFC3AF80, 0xFFC3AF80, 0xFF827455, 0xFF020201, 0xFF17150F, 0xFFA8976D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 
        0xFFBDA877, 0xFFBCA775, 0xFF9D8B61, 0xFF5D533A, 0xFFBBA674, 0xFFBBA673, 0xFFBAA672, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59E69, 
        0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19B64, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF5E502E, 0xFF000000, 0xFF473C22, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 
        0xFFA48A4B, 0xFFA3894A, 0xFF080603, 0xFF110E07, 0xFF86703C, 0xFFA18747, 0xFFA18747, 0xFFA08546, 0xFFA08545,
  0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18747, 0xFF987F44, 0xFF221C0F, 0xFF000000, 0xFF8A743E, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF8D7743, 0xFF141109, 0xFF0D0B06, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 
        0xFFA89055, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAB9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAE965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 
        0xFFB29A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A16B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A470, 0xFFBAA470, 
        0xFFBAA471, 0xFF877853, 0xFF000000, 0xFF5F543A, 0xFFBBA673, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFF706448, 0xFF030201, 0xFF15130E, 0xFFB9A577, 0xFFC1AD7D, 0xFFC2AD7E, 0xFFC2AE7F, 
        0xFFC2AE80, 0xFFC2AF80, 0xFF998965, 0xFF030202, 0xFF0F0D0A, 0xFFC1AE81, 0xFFC4B183, 0xFFC5B284, 0xFFC6B385, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B488, 0xFFC8B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 
        0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 
        0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C69F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B0, 
        0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE4D7B8, 
        0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D8B9, 0xFFE4D8B9, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE4D8BA, 0xFFE4D8BA, 0xFFE5D8BA, 0xFFE5D7B9, 0xFFE4D8BA, 0xFFE4D8BA, 
        0xFFE4D8BA, 0xFFE5D7B9, 0xFFE4D8B9, 0xFFE4D8B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D7B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B7, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D4B5, 0xFFE2D4B5, 
        0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 
        0xFFDCCEAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 
        0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 
        0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFF7C7054, 0xFF000000, 0xFF302B20, 
        0xFFC5B284, 0xFFC5B184, 0xFFC4B183, 0xFFC4B083, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF7F, 0xFF3F3929, 0xFF000000, 0xFF413A2A, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA978, 0xFFBDA977, 
        0xFFBDA876, 0xFFBCA776, 0xFF211E15, 0xFF524A33, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F69, 0xFFB49E69, 
        0xFFB59E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88E53, 0xFF352D1A, 0xFF000000, 0xFF726137, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 
        0xFFA38A4B, 0xFF89733E, 0xFF000000, 0xFF221C0F, 0xFF988044, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08545,
  0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF393019, 0xFF000000, 0xFF5D4E2A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA38A4E, 0xFF251F11, 0xFF000000, 0xFF8C7744, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 
        0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975D, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 
        0xFFB19A63, 0xFFB19B64, 0xFFB19B64, 0xFFB29B65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 
        0xFFBAA471, 0xFF61563B, 0xFF000000, 0xFF0D0B08, 0xFFAA9769, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFFAD9B6E, 0xFF0E0C09, 0xFF050403, 0xFF7C6F50, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC1AE7E, 
        0xFFC2AE7F, 0xFFC2AF80, 0xFFB9A679, 0xFF342F22, 0xFF000000, 0xFF70654A, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88C, 
        0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF98, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 
        0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAC, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 
        0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE2D6B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B9, 0xFFE4D7B8, 0xFFE4D7B9, 
        0xFFE4D7B9, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 
        0xFFE1D3B4, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDBCDAA, 
        0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 
        0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C199, 0xFFD1C198, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 
        0xFFCDBB92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B58A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B487, 0xFFC6B487, 0xFF232018, 0xFF000000, 0xFF948664, 
        0xFFC5B284, 0xFFC5B183, 0xFFC4B083, 0xFFC4B182, 0xFFC3B082, 0xFFC3AF81, 0xFFC2AF80, 0xFFA4936B, 0xFF15130D, 0xFF000000, 0xFF958560, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA978, 0xFFBDA877, 
        0xFFBDA876, 0xFF706446, 0xFF0F0D09, 0xFFBAA573, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA472, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F69, 0xFFB59E69, 
        0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB09A62, 0xFFB09962, 0xFFB09961, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFF9B854C, 0xFF1D190E, 0xFF000000, 0xFFA0884D, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 
        0xFFA3894B, 0xFF5D4E2A, 0xFF000000, 0xFF39301A, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFF9F8545,
  0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF5E4F2A, 0xFF000000, 0xFF322A17, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58C4E, 0xFFA58C4F, 0xFF463C22, 0xFF000000, 0xFF5D4F2D, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB19961, 
        0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 
        0xFF928159, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF4A412D, 0xFFBCA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFF453E2C, 0xFF000000, 0xFF403A29, 0xFFBCA87A, 0xFFC1AD7D, 0xFFC1AD7E, 
        0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AF80, 0xFF73684C, 0xFF030202, 0xFF1A1711, 0xFFC0AE80, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCBB88E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C099, 
        0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C49F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD9C9A5, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D5B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE2D6B7, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE4D7B8, 0xFFE4D6B8, 0xFFE3D7B8, 0xFFE3D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE4D7B8, 0xFFE3D7B8, 0xFFE3D7B8, 
        0xFFE4D6B8, 0xFFE4D7B8, 0xFFE3D7B7, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE3D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B3, 
        0xFFE0D3B3, 0xFFE1D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 
        0xFFDBCDA9, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 
        0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF8F8261, 0xFF000000, 0xFF000000, 0xFF090806, 
        0xFF5F5640, 0xFFB5A379, 0xFFC1AE80, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC1AE7F, 0xFF73674B, 0xFF000000, 0xFF1F1C14, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAC7B, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 
        0xFFAC996B, 0xFF1E1B13, 0xFF514832, 0xFFBBA674, 0xFFBBA672, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59E69, 0xFFB59E69, 
        0xFFB49E68, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB09962, 0xFFB09961, 0xFFB09960, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88E53, 0xFF826F40, 0xFF0A0805, 0xFF1F1B0F, 0xFFA68D50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA3894B, 0xFF322A16, 0xFF000000, 0xFF5F502B, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA08545, 0xFF9F8545,
  0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF88713C, 0xFF010100, 0xFF1B160C, 0xFF9A8247, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF756438, 0xFF000000, 0xFF322A18, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 
        0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09962, 
        0xFFB19A62, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A16B, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFAC9868, 0xFF685C3F, 
        0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF94835B, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA78, 0xFFBFAA79, 0xFFBFAA79, 0xFFA39269, 0xFF000000, 0xFF0D0C08, 0xFFA29169, 0xFFC1AD7D, 0xFFC1AD7E, 
        0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFBCA97C, 0xFF17150F, 0xFF030302, 0xFF7B6F52, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC8B588, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 
        0xFFD1C199, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C69F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 
        0xFFD9C9A6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 
        0xFFE2D5B6, 0xFFE2D6B6, 0xFFE2D5B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D6B8, 0xFFE3D6B8, 0xFFE3D7B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B8, 0xFFE3D6B8, 0xFFE3D6B7, 0xFFE3D6B7, 
        0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B7, 0xFFE3D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE0D3B3, 0xFFE0D3B3, 
        0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCAA, 
        0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C6A1, 0xFFD5C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C49F, 
        0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 
        0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B488, 0xFFC6B487, 0xFF201D16, 0xFF000000, 0xFF1E1B14, 0xFF030302, 
        0xFF000000, 0xFF0A0907, 0xFF534A37, 0xFF948562, 0xFFBCA97C, 0xFFC3AF80, 0xFFC0AC7E, 0xFF221F16, 0xFF000000, 0xFF857756, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 
        0xFF6D6144, 0xFF000000, 0xFF65593E, 0xFFBBA674, 0xFFBAA673, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 
        0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09861, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965C, 0xFFAD965C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88E53, 0xFF685933, 0xFF000000, 0xFF5A4C2C, 0xFFA68D50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 
        0xFF9A8146, 0xFF1A160C, 0xFF010100, 0xFF88733D, 0xFFA18748, 0xFFA18647, 0xFFA18646, 0xFFA08545, 0xFF9F8545,
  0xFF9F8444, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF0D0B06, 0xFF0C0A05, 0xFF816C3B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4E, 0xFF010100, 0xFF1A160D, 0xFF98814A, 0xFFA78E52, 0xFFA88F53, 
        0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 
        0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFF7A6C49, 0xFF242016, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1E1A12, 0xFFBAA574, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFBFAA7A, 0xFFBFAB7A, 0xFF383224, 0xFF000000, 0xFF62583F, 0xFFC1AD7D, 0xFFC1AD7E, 
        0xFFC1AE7E, 0xFFC2AE7F, 0xFFBAA77A, 0xFF6C6147, 0xFF0E0D09, 0xFF000000, 0xFF353023, 0xFFBAA87C, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 
        0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBE94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 
        0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD7C7A1, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 
        0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFDACAA7, 0xFFD9CBA8, 0xFFDACBA8, 0xFFDBCCA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AE, 
        0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D5B5, 
        0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE2D5B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B6, 0xFFE3D6B6, 0xFFE3D6B7, 0xFFE3D6B7, 0xFFE2D6B6, 0xFFE3D5B7, 0xFFE2D5B6, 
        0xFFE2D6B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE1D4B5, 0xFFE2D4B5, 0xFFE2D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B1, 
        0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAA, 0xFFDCCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 
        0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 
        0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 
        0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA90, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFF807557, 0xFF000000, 0xFF1E1B14, 0xFFA5956F, 0xFF958563, 
        0xFF47402F, 0xFF000000, 0xFF000000, 0xFF090806, 0xFF312C20, 0xFF72674B, 0xFF827455, 0xFF000000, 0xFF1B1811, 0xFFBBA879, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFB09D6E, 
        0xFF050503, 0xFF000000, 0xFF2D281C, 0xFFBBA673, 0xFFBBA573, 0xFFBAA472, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 
        0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09960, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC9459, 
        0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA48B51, 0xFF433921, 0xFF000000, 0xFF957F48, 0xFFA68C50, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 
        0xFF816C3A, 0xFF0C0A05, 0xFF0E0C06, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFF9F8544,
  0xFF9F8444, 0xFF9F8545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF3E341C, 0xFF000000, 0xFF66562E, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA68C4F, 0xFF2D2615, 0xFF060503, 0xFF7D6A3D, 0xFFA78E52, 0xFFA88F53, 
        0xFFA98F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9157, 0xFFAA9257, 0xFFAA9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD955A, 0xFFAD955C, 0xFFAD955C, 0xFFAD965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFB09860, 0xFFB09860, 0xFFB09961, 
        0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFAA9564, 0xFF332D1E, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF685C40, 0xFFBCA775, 0xFFBDA776, 0xFFBCA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA7A, 0xFFBFAB7A, 0xFF998962, 0xFF000000, 0xFF080705, 0xFFBEAA7C, 0xFFC1AD7D, 
        0xFFBCA97B, 0xFF6C6046, 0xFF090806, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF988A66, 0xFFC4B183, 0xFFC5B284, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 
        0xFFC9B78C, 0xFFC9B88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 
        0xFFD1C099, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 
        0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCFAE, 
        0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 
        0xFFE1D4B5, 0xFFE2D4B5, 0xFFE1D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B6, 
        0xFFE2D5B6, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 
        0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCDA9, 0xFFDBCCA9, 0xFFDACCA8, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 
        0xFFD4C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBE94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 
        0xFFCCBB90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B488, 0xFFC2AF83, 0xFF2C281D, 0xFF000000, 0xFF5D543F, 0xFFC5B284, 0xFFC5B184, 
        0xFFC3B082, 0xFFAE9D75, 0xFF4F4734, 0xFF030202, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF000000, 0xFF6B6045, 0xFFBFAC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEA979, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFF383223, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF504731, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 
        0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAC9359, 
        0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFF9F874E, 0xFF16130B, 0xFF16120A, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894C, 0xFFA3894B, 
        0xFF66552E, 0xFF000000, 0xFF3E341C, 0xFFA18748, 0xFFA18747, 0xFFA18646, 0xFFA08646, 0xFF9F8545, 0xFF9F8444,
  0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF766234, 0xFF000000, 0xFF45391F, 0xFFA08649, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA68C4F, 0xFF6C5B34, 0xFF000000, 0xFF5F512E, 0xFFA78E52, 0xFFA88F52, 
        0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 
        0xFFB19961, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D66, 0xFFB49D68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFA69261, 0xFF615539, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF13110B, 0xFF332D1F, 0xFF393223, 0xFF18160F, 0xFF1B1811, 0xFFA89569, 0xFFBCA775, 0xFFBCA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFFB7A475, 0xFF2F2A1E, 0xFF000000, 0xFF5D533C, 0xFF6B6045, 
        0xFF0E0C09, 0xFF000000, 0xFF000000, 0xFF191610, 0xFF554C38, 0xFF635941, 0xFF000000, 0xFF332E22, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 
        0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BE96, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFD0C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39B, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 
        0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 
        0xFFDDD0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 
        0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE2D4B5, 0xFFE2D4B5, 0xFFE2D4B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B6, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D5B5, 0xFFE2D4B5, 
        0xFFE2D5B5, 0xFFE1D4B5, 0xFFE1D5B5, 0xFFE1D4B5, 0xFFE1D4B5, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD1B1, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDD0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDDCEAD, 0xFFDCCFAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 
        0xFFD3C39D, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCDBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB90, 
        0xFFCCBB90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFF8A7D5E, 0xFF060504, 0xFF0C0B08, 0xFFBAA87D, 0xFFC5B284, 0xFFC4B183, 
        0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFB2A076, 0xFF544B37, 0xFF0E0C09, 0xFF000000, 0xFF12110C, 0xFFA19068, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFF897A56, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3B3424, 0xFF9C8A5E, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 
        0xFFB49D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 
        0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA78F53, 0xFF8E7946, 0xFF000000, 0xFF4B3F24, 0xFFA68D50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894C, 0xFFA08649, 
        0xFF44391F, 0xFF000000, 0xFF766335, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFF9F8545, 0xFF9F8444,
  0xFF9F8444, 0xFF9F8445, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18748, 0xFF9D8446, 0xFF010100, 0xFF1C180D, 0xFF9B8246, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF9E854B, 0xFF000000, 0xFF352D1A, 0xFFA38A50, 0xFFA88E52, 
        0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAE965C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09960, 
        0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E67, 0xFFB59F69, 0xFFB59F69, 0xFF675B3C, 0xFF1C1910, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF0F0E09, 0xFF60553A, 0xFF9C895E, 0xFFBAA472, 0xFFBBA572, 0xFFA59165, 0xFF2E291C, 0xFF5F553B, 0xFFBCA775, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFF74674A, 0xFF020201, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF393325, 0xFF7C6F51, 0xFFAB9A71, 0xFFC2AF80, 0xFFB7A479, 0xFF201D15, 0xFF000000, 0xFF8B7D5C, 0xFFC4B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 
        0xFFD0BF98, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A3, 
        0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAC, 
        0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDD0AE, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE1D3B3, 
        0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 
        0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D3B4, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD0B0, 
        0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDD0AE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDDCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 
        0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39D, 
        0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBC94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 
        0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC2B184, 0xFF383326, 0xFF000000, 0xFF70654B, 0xFFC5B284, 0xFFC5B284, 0xFFC4B183, 
        0xFFC4B182, 0xFFC3B082, 0xFFC3AF81, 0xFFC2AF80, 0xFFC2AF80, 0xFF2F2A1E, 0xFF000000, 0xFF443D2C, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA977, 0xFFB4A071, 0xFF2C271B, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF13110B, 0xFF574D34, 0xFFAC9868, 0xFFB9A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 
        0xFFB39D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 
        0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88E53, 0xFF584B2B, 0xFF000000, 0xFF776539, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF9B8247, 
        0xFF1C170C, 0xFF010100, 0xFF9E8446, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444,
  0xFF9F8443, 0xFF9F8445, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF2E2614, 0xFF000000, 0xFF907941, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF292314, 0xFF050402, 0xFF9E864D, 0xFFA78E52, 
        0xFFA88F52, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9155, 0xFFAA9157, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 
        0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFF8C7A51, 0xFF19160E, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433B28, 
        0xFFA69364, 0xFFB8A26F, 0xFFB9A471, 0xFFBAA571, 0xFFBAA572, 0xFFBAA573, 0xFF95845C, 0xFF0D0C08, 0xFFAD996B, 0xFFBCA775, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFAE9B70, 0xFF17150F, 0xFF000000, 0xFF28241A, 
        0xFF9F8F67, 0xFFBAA779, 0xFFC1AE7E, 0xFFC2AF7F, 0xFFC2AF80, 0xFFC3AF80, 0xFF6D6248, 0xFF000000, 0xFF191610, 0xFFC4B183, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B487, 0xFFC6B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 
        0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 
        0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 
        0xFFDCCFAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDECFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 
        0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D4B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE1D3B4, 0xFFE1D4B4, 0xFFE1D4B4, 0xFFE1D4B3, 0xFFE1D4B4, 0xFFE1D4B3, 
        0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED1AF, 
        0xFFDED0AF, 0xFFDED0AF, 0xFFDDD0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFD9CAA7, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 
        0xFFD3C29B, 0xFFD3C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCBBA8F, 0xFFCBB98F, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFF948664, 0xFF000000, 0xFF1D1A13, 0xFFC5B285, 0xFFC5B284, 0xFFC4B183, 0xFFC4B183, 
        0xFFC4B082, 0xFFC3B081, 0xFFC2AF81, 0xFFC2AF80, 0xFF928360, 0xFF0C0A07, 0xFF000000, 0xFF988963, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA877, 0xFF7C6E4D, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF14110C, 0xFF7C6D4A, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 
        0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955D, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 
        0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFF18140B, 0xFF110F08, 0xFF8E7944, 0xFFA68C50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA3894B, 0xFFA3894B, 0xFF8F7842, 
        0xFF000000, 0xFF2F2815, 0xFFA18748, 0xFFA18748, 0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444,
  0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFF61512B, 0xFF000000, 0xFF5E4F2A, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF5F502E, 0xFF000000, 0xFF7A683B, 0xFFA78E52, 
        0xFFA88E53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC9459, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 
        0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39D66, 0xFFA18D5C, 0xFF49402A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF211D13, 0xFF8B7B54, 0xFFB8A26E, 
        0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFF473F2C, 0xFF312B1E, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFF5D533C, 0xFF000000, 0xFF272319, 
        0xFFB3A074, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF80, 0xFFB2A076, 0xFF1C1912, 0xFF010101, 0xFF70654B, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 
        0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 
        0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD5C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 
        0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 
        0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDECFAD, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED1AF, 0xFFDED1AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFE0D2B2, 
        0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE1D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 0xFFE0D3B3, 
        0xFFE1D3B3, 0xFFE1D3B2, 0xFFE0D3B2, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED1AF, 0xFFDED1AF, 0xFFDED0AF, 
        0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29C, 
        0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 
        0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68B, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B487, 0xFFC6B487, 0xFF181610, 0xFF000000, 0xFF060504, 0xFF695E46, 0xFFB6A57B, 0xFFC4B183, 0xFFC4B182, 
        0xFFC3B082, 0xFFC3AF81, 0xFFC3AF80, 0xFFBEAC7D, 0xFF4F4633, 0xFF000000, 0xFF342F22, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFB4A071, 0xFF1C1911, 0xFF000000, 0xFF020101, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF312B1D, 0xFF9A885B, 0xFFB49F6A, 0xFFB6A06C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E69, 0xFFB49D67, 0xFFB49D67, 
        0xFFB39D66, 0xFFB39C65, 0xFFB29C64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAC955B, 0xFFAD945B, 0xFFAC9459, 0xFFAC9359, 0xFFAB9358, 
        0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF937D48, 0xFF000000, 0xFF302817, 0xFFA0874D, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4B, 0xFFA3894B, 0xFF5D4E2A, 
        0xFF000000, 0xFF61512C, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8445, 0xFF9F8443,
  0xFF9E8343, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF836D3A, 0xFF010100, 0xFF211C0F, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF84703F, 0xFF000000, 0xFF372F1B, 0xFFA78E52, 
        0xFFA78E53, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 
        0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFA4905D, 0xFF5B5034, 0xFF0E0C08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1E1A12, 0xFF6D5F40, 0xFFB39D6A, 0xFFB7A26D, 0xFFB8A26E, 
        0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 0xFFAD996B, 0xFF000000, 0xFF7D6F4E, 0xFFBCA875, 0xFFBDA876, 0xFFBDA977, 0xFFBEA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFFB9A577, 0xFF0C0B08, 0xFF000000, 
        0xFF7C6F50, 0xFFC1AC7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF80, 0xFF72674B, 0xFF000000, 0xFF211E16, 0xFFB2A177, 0xFFC5B284, 0xFFC5B284, 0xFFC6B385, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 
        0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA6, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 
        0xFFDCCDAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDECFAE, 0xFFDECFAE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD2B1, 
        0xFFE0D1B1, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D3B2, 0xFFE0D2B2, 0xFFE0D3B3, 0xFFE0D3B2, 0xFFE0D3B2, 0xFFE0D3B2, 
        0xFFE0D2B2, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFDFD1B1, 0xFFDFD2B0, 0xFFDFD2B0, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 
        0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 
        0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 
        0xFFD2C29B, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFF6A6048, 0xFF000000, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF1F1C15, 0xFF756A4E, 0xFFC0AD7F, 
        0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFA7966D, 0xFF050403, 0xFF000000, 0xFFA5946B, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFF5E533A, 0xFF000000, 0xFF423A29, 0xFF6D6143, 
        0xFF594F37, 0xFF201C13, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF4E442E, 0xFF9B885C, 0xFFB5A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 
        0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC9459, 0xFFAB9359, 0xFFAB9358, 
        0xFFAA9258, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA78E53, 0xFF55482A, 0xFF000000, 0xFF534628, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894C, 0xFFA3894B, 0xFF211B0F, 
        0xFF020201, 0xFF836E3B, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8445, 0xFF9F8443,
  0xFF9E8343, 0xFF9F8443, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18747, 0xFF937B41, 0xFF201B0E, 0xFF000000, 0xFF987F45, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF988048, 0xFF211C10, 0xFF000000, 0xFFA68D50, 
        0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA98F54, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 
        0xFFB09861, 0xFFB09961, 0xFFB09962, 0xFFB19A63, 0xFFB29A63, 0xFF6F613E, 0xFF14120B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF63573A, 0xFFA79362, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 
        0xFFB8A26F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFF100E0A, 0xFF252117, 0xFFAE9B6D, 0xFFBDA876, 0xFFBDA876, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFF74674A, 0xFF000000, 
        0xFF211D15, 0xFFBFAC7C, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3B081, 0xFF28241A, 0xFF000000, 0xFF6D6248, 0xFFC5B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 
        0xFFC8B689, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE96, 
        0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C199, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39B, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD6C6A1, 
        0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 
        0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDD0AE, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDED1AF, 0xFFDED1AF, 0xFFDED1B0, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B1, 0xFFE0D2B2, 0xFFE0D2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFE0D2B1, 0xFFE0D2B1, 
        0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B0, 0xFFDFD1B1, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 
        0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCDAC, 0xFFDCCDAA, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 
        0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 
        0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCAB98D, 0xFFC9B88C, 0xFFCAB78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFAB9C75, 0xFF15130E, 0xFF030302, 0xFF756A4F, 0xFF7C7053, 0xFF12100C, 0xFF000000, 0xFF030202, 0xFF231F17, 
        0xFF8F815F, 0xFFC3AF81, 0xFFC2AF7F, 0xFF403A2A, 0xFF000000, 0xFF4D4532, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFA08E64, 0xFF000000, 0xFF6F6245, 0xFFB8A572, 0xFFBBA674, 
        0xFFBBA674, 0xFFAD9A6B, 0xFF756847, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0D08, 0xFF574C32, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB39D67, 0xFFB39C66, 
        0xFFB39C66, 0xFFB29B64, 0xFFB29B64, 0xFFB29A64, 0xFFB19A63, 0xFFB19962, 0xFFB09962, 0xFFB09960, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9258, 
        0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFF1E190E, 0xFF050402, 0xFF887341, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF987F45, 0xFF000000, 
        0xFF201B0E, 0xFF937B41, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8443,
  0xFF9E8343, 0xFF9F8443, 0xFF9F8445, 0xFF9F8545, 0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF3F351C, 0xFF000000, 0xFF5F502B, 0xFFA3894A, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA38A4D, 0xFF9F874C, 0xFF3A311C, 0xFF000000, 0xFF6C5C34, 
        0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD945B, 0xFFAD955C, 0xFFAE965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 
        0xFFB09860, 0xFFB09961, 0xFFAF9761, 0xFF958253, 0xFF252014, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF2C2719, 0xFF9F8C5C, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 
        0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFF060504, 0xFF000000, 0xFF736648, 0xFFBDA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBBA778, 0xFF1B1811, 
        0xFF000000, 0xFF796D4E, 0xFFC1AD7D, 0xFFC1AE7D, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFBAA87A, 0xFF655B43, 0xFF020201, 0xFF000000, 0xFF060504, 0xFFB6A57A, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 
        0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 
        0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD2C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD9C9A5, 0xFFD8CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 
        0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED1AF, 0xFFDED0AF, 
        0xFFDED1AF, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B1, 0xFFDFD1B1, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD2B0, 0xFFDFD2B1, 0xFFDFD1B1, 0xFFDFD2B1, 
        0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDED1B0, 0xFFDFD1AF, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAC, 
        0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCAB98E, 
        0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B588, 0xFFC7B588, 0xFFC4B285, 0xFF5A513D, 0xFF000000, 0xFF0D0B08, 0xFFB2A178, 0xFFC5B284, 0xFFC0AD80, 0xFF524A36, 0xFF080705, 0xFF000000, 
        0xFF000000, 0xFF48412F, 0xFF8E7F5D, 0xFF000000, 0xFF090805, 0xFFA08F67, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA877, 0xFF2B261B, 0xFF4C432F, 0xFFBCA875, 0xFFBCA674, 0xFFBBA674, 
        0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFB39F6D, 0xFF433B28, 0xFF050503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF18150E, 0xFF8E7C52, 0xFFB19B66, 0xFFB49D67, 0xFFB49C67, 0xFFB39C66, 
        0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAB9358, 0xFFAB9258, 
        0xFFAB9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA98F54, 0xFFA88F54, 0xFFA88F53, 0xFF887342, 0xFF0D0B06, 0xFF030301, 0xFF594C2B, 0xFF907A45, 0xFF9F874C, 0xFFA38A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF5E4F2A, 0xFF000000, 
        0xFF3F351C, 0xFFA18748, 0xFFA18747, 0xFFA08747, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9E8444, 0xFF9E8443,
  0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFF66562D, 0xFF030201, 0xFF251F11, 0xFFA3894A, 0xFFA38A4C, 0xFFA48A4C, 0xFF927B43, 0xFF746237, 0xFF4E4125, 0xFF1C180D, 0xFF000000, 0xFF000000, 0xFF2D2616, 
        0xFFA78E51, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFA99157, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 
        0xFFB09860, 0xFF958152, 0xFF52472D, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF282317, 0xFF786945, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 
        0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A470, 0xFFBAA470, 0xFFBAA471, 0xFFBAA572, 0xFF62573C, 0xFF000000, 0xFF000000, 0xFF14120C, 0xFFB09E6F, 0xFFBCA876, 0xFFBDA877, 0xFFBEA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFFBEA979, 0xFF76694C, 
        0xFF000000, 0xFF0C0B08, 0xFFB7A577, 0xFFC1AD7E, 0xFFBDAB7C, 0xFF7E7152, 0xFF211E15, 0xFF000000, 0xFF000000, 0xFF100E0A, 0xFF000000, 0xFF423B2C, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 
        0xFFC7B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBC91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD95, 
        0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0C096, 0xFFD0C097, 0xFFD0C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 
        0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD8C8A3, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACCA9, 0xFFDACCA9, 
        0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDD0AE, 0xFFDECFAE, 0xFFDECFAE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 
        0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDFD1AF, 0xFFDED1B0, 0xFFDED1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 0xFFDFD1B0, 
        0xFFDFD1B0, 0xFFDED1B0, 0xFFDED1B0, 0xFFDFD0B0, 0xFFDFD1B0, 0xFFDED1AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDCCEAC, 0xFFDCCEAC, 
        0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 
        0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 
        0xFFD1C199, 0xFFD1C099, 0xFFD0C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFD0BE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88E, 
        0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B58A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFA69670, 0xFF0C0B08, 0xFF000000, 0xFF000000, 0xFF0F0D0A, 0xFF6F6349, 0xFFB2A177, 0xFFC4B082, 0xFF928461, 0xFF3A3426, 
        0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF47402E, 0xFFBDAA7B, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFAA976B, 0xFF443D2B, 0xFFB8A473, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 
        0xFFBBA573, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFF8A7A53, 0xFF342E1F, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF403825, 0xFF8E7C51, 0xFFB39D66, 0xFFB39C66, 
        0xFFB29C65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9358, 0xFFAB9358, 0xFFAB9257, 
        0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA78E53, 0xFF5F512E, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF201B0F, 0xFF4E4125, 0xFF756336, 0xFF957E45, 0xFFA3894C, 0xFFA3894B, 0xFF251F11, 0xFF030201, 
        0xFF67562E, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343,
  0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFF937A42, 0xFF080603, 0xFF0D0B06, 0xFF87713D, 0xFF6B5A31, 0xFF342C18, 0xFF18140B, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF0E0C07, 0xFF010100, 0xFF0F0D07, 
        0xFF947D48, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAD945A, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 
        0xFF554A2F, 0xFF14110B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0C07, 0xFF716340, 0xFFA99461, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFAE9A6A, 0xFF403927, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4E4530, 0xFFBCA776, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAA7A, 0xFFB09E70, 
        0xFF231F16, 0xFF000000, 0xFF534A35, 0xFF9E8D66, 0xFF332E21, 0xFF020201, 0xFF000000, 0xFF0F0E0A, 0xFF6E6248, 0xFF948562, 0xFF17150F, 0xFF000000, 0xFF817556, 0xFFC5B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 
        0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 
        0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C099, 0xFFD1C099, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 
        0xFFD5C69F, 0xFFD5C6A0, 0xFFD5C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 
        0xFFDACCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCEAD, 0xFFDDCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDECFAD, 
        0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 
        0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAC, 0xFFDDCFAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCDAB, 
        0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A5, 0xFFD8C8A4, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 
        0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF96, 0xFFCFBF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B488, 0xFFC7B487, 0xFF353024, 0xFF000000, 0xFF5B523D, 0xFF484130, 0xFF000000, 0xFF000000, 0xFF201D15, 0xFF776A4F, 0xFFC3B081, 0xFFBCAA7D, 
        0xFF8B7D5B, 0xFF252118, 0xFF000000, 0xFF050403, 0xFF9B8B64, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7C, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFB9A574, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A36F, 0xFFB8A26F, 0xFFB29D6A, 0xFF81724D, 0xFF1B1810, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0906, 0xFF453C27, 0xFFA9945F, 
        0xFFB29B65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 
        0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA1894F, 0xFF362E1A, 0xFF000000, 0xFF716036, 0xFF463B21, 0xFF090804, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF1C170D, 0xFF372F19, 0xFF5C4D2A, 0xFF0A0904, 0xFF080603, 
        0xFF947B41, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9E8444, 0xFF9E8342,
  0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF282112, 0xFF000000, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF332B18, 0xFF736236, 0xFFA68C4F, 0xFF3B321C, 0xFF000000, 
        0xFF685932, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFA28B52, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFF857448, 0xFF110F09, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF4C422B, 0xFFAD9862, 0xFFB39C65, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16C, 
        0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A370, 0xFF716444, 0xFF050503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF99885F, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 
        0xFF726649, 0xFF010100, 0xFF010100, 0xFF030201, 0xFF000000, 0xFF010100, 0xFF403A2A, 0xFFB2A075, 0xFFC3AF80, 0xFFB4A176, 0xFF2A261C, 0xFF000000, 0xFF201D15, 0xFFB4A278, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 
        0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 
        0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD9C9A5, 0xFFD9CAA5, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFDACBA7, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 
        0xFFDDCFAD, 0xFFDDCFAE, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 0xFFDED0AF, 0xFFDED0AF, 0xFFDED0AE, 
        0xFFDED0AE, 0xFFDDD0AE, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDED0AE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDBCDAB, 
        0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 
        0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C39C, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 
        0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B488, 0xFFC7B487, 0xFF766C50, 0xFF000000, 0xFF1D1A13, 0xFFB2A177, 0xFFC4B183, 0xFF928361, 0xFF16140E, 0xFF000000, 0xFF000000, 0xFF2C271D, 0xFFA6956D, 
        0xFFB8A679, 0xFF312C20, 0xFF000000, 0xFF463F2D, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA979, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA673, 0xFFBBA673, 
        0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFF62563A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 
        0xFF6C5E3D, 0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 
        0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF947E48, 0xFF070603, 0xFF201B0F, 0xFFA68D50, 0xFFA68C50, 0xFF9F874B, 0xFF736136, 0xFF2E2715, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF282212, 
        0xFFA18848, 0xFFA18747, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343,
  0xFF9E8342, 0xFF9E8342, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF6A582F, 0xFF000000, 0xFF030301, 0xFF19150B, 0xFF332A17, 0xFF66562F, 0xFF9A8248, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF847040, 0xFF000000, 
        0xFF3D341E, 0xFFA38B50, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFF8C7847, 0xFF0F0D07, 0xFF9C8650, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFF8C784A, 0xFF3B331F, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040402, 0xFF2E2819, 0xFF8A784D, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 
        0xFFB7A16D, 0xFFB59F6C, 0xFF8A7952, 0xFF2C261A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2A251A, 0xFFBBA775, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAB7A, 
        0xFFBFAB7A, 0xFF201C14, 0xFF000000, 0xFF000000, 0xFF28241A, 0xFF837655, 0xFFC1AE7E, 0xFFB5A276, 0xFF766A4D, 0xFF0E0D09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF655B43, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 
        0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 
        0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 
        0xFFD5C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD7C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA7, 
        0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 
        0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDDCFAE, 0xFFDECFAE, 0xFFDECFAE, 0xFFDDD0AE, 0xFFDDCFAE, 0xFFDECFAE, 0xFFDECFAE, 0xFFDECFAE, 0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAE, 
        0xFFDDCFAE, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDDCFAD, 0xFFDDCEAD, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 
        0xFFDBCCAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 
        0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C098, 0xFFD1C098, 
        0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 
        0xFFC9B88C, 0xFFC9B78B, 0xFFC8B68B, 0xFFC8B68A, 0xFFC8B689, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFAE9E76, 0xFF090806, 0xFF000000, 0xFF000000, 0xFF3D3729, 0xFF998A67, 0xFFC4B183, 0xFFC3B081, 0xFF5E553F, 0xFF15130E, 0xFF000000, 0xFF000000, 
        0xFF342F22, 0xFF000000, 0xFF090806, 0xFFB8A577, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBEAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 
        0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB6A16C, 0xFFA28F5F, 0xFF3C3523, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF2B2518, 0xFF85744A, 0xFFAD9660, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9257, 
        0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA78F53, 0xFF6D5C35, 0xFF000000, 0xFF655630, 0xFFA68D50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFF9B8248, 0xFF64542E, 0xFF302816, 0xFF070603, 0xFF000000, 0xFF6A5930, 
        0xFFA18748, 0xFFA18647, 0xFFA18646, 0xFFA08546, 0xFF9F8545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342,
  0xFF9E8341, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18646, 0xFFA18748, 0xFF9F8446, 0xFF000000, 0xFF0F0D07, 0xFF86713D, 0xFFA3894B, 0xFFA4894C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF14110A, 
        0xFF0E0C06, 0xFF98814A, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFF38301D, 0xFF362E1C, 0xFFA89056, 0xFFAC9359, 0xFFAC945A, 0xFF867447, 0xFF413822, 0xFF0C0B06, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF241F14, 0xFF796943, 0xFFAE9860, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 
        0xFF958358, 0xFF3D3624, 0xFF050503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF352F21, 0xFF1B1810, 0xFF000000, 0xFF7B6E4D, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 
        0xFFBFAB7A, 0xFF9B8B64, 0xFF000000, 0xFF000000, 0xFF978762, 0xFFC1AD7D, 0xFF857856, 0xFF2B261C, 0xFF000000, 0xFF000000, 0xFF2E291E, 0xFF796D50, 0xFF030202, 0xFF070605, 0xFFA3936D, 0xFFC4B284, 0xFFC5B285, 0xFFC5B385, 0xFFC6B385, 0xFFC6B486, 
        0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B58A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBB8F, 0xFFCDBB91, 0xFFCCBB91, 0xFFCDBC91, 0xFFCDBC92, 
        0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49D, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 
        0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDDCEAD, 0xFFDDCFAC, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAC, 0xFFDDCFAD, 0xFFDDCFAD, 0xFFDDCFAC, 
        0xFFDDCEAD, 0xFFDDCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDA9, 0xFFDBCCA9, 0xFFDBCCA9, 
        0xFFDACCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 0xFFD9CBA7, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9C9A6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A2, 0xFFD7C7A2, 0xFFD6C6A2, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0BF98, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B58A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC3B084, 0xFF484130, 0xFF000000, 0xFF1D1A13, 0xFF100F0B, 0xFF000000, 0xFF090806, 0xFF494231, 0xFFA7966F, 0xFFC3B081, 0xFFA7966E, 0xFF4F4734, 0xFF030302, 
        0xFF000000, 0xFF000000, 0xFF796D4E, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 
        0xFFBAA472, 0xFFB9A471, 0xFFB9A370, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB69F69, 0xFF88774F, 0xFF362F1F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF030301, 0xFF3B3320, 0xFF907E4F, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFA58E56, 0xFF96814E, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9157, 
        0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF221D11, 0xFF050402, 0xFF917B45, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4C, 0xFFA48A4C, 0xFFA3894B, 0xFF977F45, 0xFF16120A, 0xFF010100, 0xFF9E8446, 
        0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342,
  0xFF9D8242, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18748, 0xFFA18748, 0xFF3B311A, 0xFF000000, 0xFF7D6939, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58C4F, 0xFFA68C4F, 0xFF5A4C2B, 
        0xFF000000, 0xFF736237, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFF8E7949, 0xFF0A0905, 0xFF0F0D08, 0xFF362F1C, 0xFF1E190F, 0xFF050402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF665838, 0xFFAC955E, 0xFFB19961, 0xFFB19A62, 0xFFB19A62, 0xFFB29B63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D67, 0xFFB49E67, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFF544A31, 
        0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF6B5F42, 0xFFB19D6D, 0xFFB6A270, 0xFFB5A070, 0xFF5F553B, 0xFF201C14, 0xFFB29E6F, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 
        0xFFBFAA7A, 0xFFBFAB7B, 0xFF564D37, 0xFF000000, 0xFF262219, 0xFF3D3728, 0xFF010100, 0xFF000000, 0xFF050403, 0xFF73674B, 0xFFBCA97B, 0xFFC3AF81, 0xFF534B37, 0xFF000000, 0xFF1E1B14, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B285, 0xFFC6B386, 
        0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 
        0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C099, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 
        0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACAA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 
        0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDDCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 
        0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACBA8, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 
        0xFFD5C6A0, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B488, 0xFFC6B487, 0xFF8E8161, 0xFF000000, 0xFF010101, 0xFFB09F77, 0xFFB1A077, 0xFF3B3527, 0xFF000000, 0xFF000000, 0xFF090806, 0xFF5E543E, 0xFFC3AF80, 0xFFC2AE7F, 0xFF393325, 
        0xFF000000, 0xFF2E291D, 0xFFB5A275, 0xFFC0AD7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFAF9A65, 0xFF7D6E48, 0xFF0A0906, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF4F442B, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFF665835, 0xFF201B10, 0xFFAB9358, 0xFFAB9258, 0xFFAA9157, 0xFFAA9156, 
        0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F52, 0xFF927C47, 0xFF000000, 0xFF332B18, 0xFF9F864C, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF7D6939, 0xFF000000, 0xFF3B321A, 0xFFA18748, 
        0xFFA18748, 0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342,
  0xFF9D8241, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF7A6636, 0xFF000000, 0xFF3F351D, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA68C4F, 0xFF907A45, 
        0xFF000000, 0xFF2B2414, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFA88F55, 0xFF4B4026, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080704, 
        0xFF3B3320, 0xFFA48E59, 0xFFAF985F, 0xFFB09861, 0xFFB09961, 0xFFB19961, 0xFFB19A62, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFAE9965, 0xFF7D6E49, 0xFF110F0A, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0C08, 0xFF4E452F, 0xFFB39F6D, 0xFFBAA471, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFB5A170, 0xFF2D281C, 0xFF736647, 0xFFBCA876, 0xFFBDA876, 0xFFBEA977, 0xFFBEA978, 0xFFBEAA78, 
        0xFFBFAA7A, 0xFFBFAB7A, 0xFFA7966B, 0xFF15130D, 0xFF000000, 0xFF000000, 0xFF0C0B08, 0xFF4F4733, 0xFFBDAB7C, 0xFFC2AE7F, 0xFFA7966E, 0xFF4B4331, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF59513C, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 
        0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCDBB91, 0xFFCDBB91, 
        0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD4C39D, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59E, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD8C9A5, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFDACBA7, 0xFFD9CBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 
        0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCDAB, 0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAC, 0xFFDCCEAC, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCEAB, 
        0xFFDCCDAB, 0xFFDCCEAB, 0xFFDCCEAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAB, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCDA9, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACBA8, 0xFFDACBA8, 
        0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8CAA6, 0xFFD9C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 
        0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B68B, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFBAA87E, 0xFF15130E, 0xFF000000, 0xFF7C6F53, 0xFFC5B285, 0xFFC4B283, 0xFFC4B183, 0xFF8F8160, 0xFF1E1B14, 0xFF000000, 0xFF000000, 0xFF27231A, 0xFF6E6248, 0xFF020201, 
        0xFF060503, 0xFF837655, 0xFFC1AC7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEA979, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D66, 0xFF4B422B, 0xFF090805, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0D0B07, 0xFF786840, 0xFFA58E59, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAC955B, 0xFF947F4D, 0xFF19150D, 0xFF7E6C41, 0xFFAB9358, 0xFFAB9258, 0xFFAA9157, 0xFFAA9156, 
        0xFFA99156, 0xFFA99054, 0xFFA99054, 0xFFA88F53, 0xFFA78E52, 0xFF473C23, 0xFF000000, 0xFF5F512E, 0xFFA68D4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF3F351C, 0xFF000000, 0xFF7B6636, 0xFFA18748, 
        0xFFA18748, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8343, 0xFF9E8342, 0xFF9D8241,
  0xFF9D8241, 0xFF9D8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFF957C42, 0xFF151209, 0xFF030201, 0xFFA08749, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58C4D, 0xFFA58C4F, 0xFF9E854B, 
        0xFF302817, 0xFF000000, 0xFF957E48, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFAA9155, 0xFFAA9156, 0xFF95804C, 0xFF0E0C07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF352E1C, 0xFF806E44, 
        0xFFAE965E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09861, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49E68, 0xFF81714A, 0xFF332D1E, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF463E2A, 0xFF938258, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFF8C7C57, 0xFF0C0B07, 0xFFAD9A6C, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 
        0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 0xFF655A41, 0xFF000000, 0xFF060503, 0xFF7B6E4F, 0xFFC1AD7E, 0xFFAD9C71, 0xFF59503A, 0xFF110F0B, 0xFF000000, 0xFF000000, 0xFF342E22, 0xFF010101, 0xFF070605, 0xFF8F8160, 0xFFC5B284, 0xFFC5B284, 0xFFC5B285, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 
        0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD3C29B, 0xFFD3C29C, 
        0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 
        0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8CAA5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACAA7, 0xFFD9CBA7, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCDA9, 
        0xFFDBCCA9, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDCCDAA, 0xFFDCCDAA, 0xFFDBCDAA, 0xFFDCCDAA, 0xFFDBCDAA, 
        0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAB, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDACCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 
        0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBB92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98D, 0xFFCAB88D, 0xFFCAB78D, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC8B68A, 0xFFC8B58A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF3C3628, 0xFF000000, 0xFF413B2C, 0xFFC2AF83, 0xFFC5B284, 0xFFC5B183, 0xFFC4B183, 0xFFC4B082, 0xFFB3A276, 0xFF60563F, 0xFF090806, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF3B3426, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFB9A471, 
        0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFF927F52, 0xFF433A26, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2E2818, 0xFF6C5E3A, 0xFFA08A55, 0xFFAD955B, 0xFF7E6C42, 0xFF221D12, 0xFF342D1B, 0xFFA89057, 0xFFAB9258, 0xFFAA9257, 0xFFAA9256, 0xFFAA9056, 
        0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA1894F, 0xFF0E0C07, 0xFF0C0A06, 0xFF8F7945, 0xFFA68D4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA1874A, 0xFF020201, 0xFF151209, 0xFF957C42, 0xFFA18747, 
        0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241,
  0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFF9F8547, 0xFF42371E, 0xFF000000, 0xFF68582F, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 
        0xFF5F502D, 0xFF000000, 0xFF463C22, 0xFFA78E51, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9257, 0xFF5F5130, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0906, 0xFF76653E, 0xFFA69058, 0xFFAE965D, 
        0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09960, 0xFFB09961, 0xFFB09961, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFA28D5C, 0xFF362F1F, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF211D13, 0xFF918057, 0xFFB59F6C, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA571, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFF393323, 0xFF352F21, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBCA879, 0xFF1E1A13, 0xFF000000, 0xFF463E2D, 0xFF635940, 0xFF12100B, 0xFF000000, 0xFF000000, 0xFF16130E, 0xFF8B7E5C, 0xFFC2AE80, 0xFF564D39, 0xFF000000, 0xFF27231A, 0xFFB9A67B, 0xFFC5B284, 0xFFC5B284, 
        0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB91, 
        0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 
        0xFFD3C39B, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C8A3, 0xFFD7C8A3, 
        0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CBA6, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA9, 
        0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCDA9, 0xFFDBCCAA, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCDAA, 0xFFDBCCAA, 0xFFDBCDAA, 0xFFDBCCAA, 
        0xFFDBCCA9, 0xFFDBCDA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCAA, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 
        0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78A, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFF685E46, 0xFF000000, 0xFF16140F, 0xFFA69670, 0xFFC5B284, 0xFFC5B184, 0xFFC4B183, 0xFFC4B082, 0xFFC4B081, 0xFFC3B081, 0xFFC1AD7E, 0xFFA8986F, 0xFF312C20, 0xFF000000, 0xFF010100, 
        0xFFB19E72, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 
        0xFFB9A470, 0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFAD9761, 0xFF907D50, 
        0xFF252014, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF110F09, 0xFF14110B, 0xFF080704, 0xFF090804, 0xFF827044, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 
        0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF6C5B35, 0xFF020201, 0xFF2E2716, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF68562F, 0xFF000000, 0xFF42371E, 0xFF9F8547, 0xFFA18747, 
        0xFFA08647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8343, 0xFF9E8343, 0xFF9E8241, 0xFF9D8241,
  0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF6D5B30, 0xFF030301, 0xFF1E190D, 0xFFA3894A, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 
        0xFF8D7744, 0xFF0E0C06, 0xFF0C0A06, 0xFFA38A4F, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFF1A160D, 0xFF000000, 0xFF000000, 0xFF15120B, 0xFF998451, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 
        0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFAB9661, 0xFF6A5C3C, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF0B0A06, 0xFF6B5E3F, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA673, 0xFFBBA674, 0xFF7F714E, 0xFF000000, 0xFF877855, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 
        0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFF9B8B63, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0F0D09, 0xFF6A5F45, 0xFFC2AF7F, 0xFFC2AF80, 0xFFC3AF81, 0xFFC3B081, 0xFF262219, 0xFF000000, 0xFF574F3A, 0xFFC5B184, 0xFFC5B284, 
        0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB98D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 
        0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 
        0xFFD2C29B, 0xFFD3C39B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C49D, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9CAA5, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 
        0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 
        0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFDACAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD8C9A6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A1, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C59F, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39B, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 
        0xFFCEBE94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 
        0xFFC8B689, 0xFFC7B589, 0xFFC7B588, 0xFFC7B487, 0xFF9D8E6A, 0xFF100E0B, 0xFF000000, 0xFF524B37, 0xFFC5B284, 0xFFC5B284, 0xFFC4B183, 0xFFC4B082, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFB4A176, 0xFF0A0906, 0xFF000000, 0xFF796D4F, 
        0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 
        0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A16E, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A63, 
        0xFFB19A63, 0xFF645737, 0xFF0C0A06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3C331F, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 
        0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA68D52, 0xFF39311C, 0xFF000000, 0xFF776539, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF1D180D, 0xFF030301, 0xFF6D5B30, 0xFFA18748, 0xFFA18647, 
        0xFFA18646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241,
  0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF957D42, 0xFF131008, 0xFF030301, 0xFF86713D, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 
        0xFFA68C4F, 0xFF302917, 0xFF010100, 0xFF695933, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9256, 0xFF867245, 0xFF000000, 0xFF000000, 0xFF867446, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 
        0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFAF9761, 0xFF766742, 0xFF221E13, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A07, 0xFF4E452E, 
        0xFFA49060, 0xFFB6A06C, 0xFFB6A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFF80714F, 0xFF000000, 0xFF342E20, 0xFFB5A271, 0xFFBDA877, 0xFFBDA977, 
        0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFF5E543C, 0xFF000000, 0xFF000000, 0xFF423B2B, 0xFFA9976E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF80, 0xFFC3AF81, 0xFFA7976E, 0xFF12100C, 0xFF000000, 0xFF796D51, 0xFFC5B284, 
        0xFFC5B284, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA8F, 
        0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 
        0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD7C7A2, 0xFFD7C7A2, 
        0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CBA7, 0xFFD9CBA7, 
        0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACCA8, 0xFFDACCA8, 0xFFDACBA8, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA8, 0xFFDBCCA9, 0xFFDACCA9, 0xFFDACCA9, 0xFFDACCA8, 
        0xFFDACCA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD8CAA5, 0xFFD8C9A5, 
        0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 
        0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD2C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 
        0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFBFAD82, 0xFF302B20, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF574E3A, 0xFFB5A378, 0xFFC4B183, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFF342F22, 0xFF000000, 0xFF3B3426, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFC0AC7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA672, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 
        0xFFB8A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 
        0xFFB19A62, 0xFFB09961, 0xFF9E8A57, 0xFF4A4029, 0xFF0B0A06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF090804, 0xFF9C8651, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 
        0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF907A46, 0xFF100D08, 0xFF120F08, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF86703C, 0xFF030301, 0xFF131008, 0xFF957D42, 0xFFA18748, 0xFFA18647, 
        0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240,
  0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF3E341C, 0xFF000000, 0xFF4C4022, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 
        0xFFA68C4F, 0xFF7E6B3D, 0xFF000000, 0xFF372E1A, 0xFFA38B50, 0xFFA78F52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFFA78F55, 0xFF413821, 0xFF000000, 0xFFA99057, 0xFFAC945A, 0xFFAC955B, 0xFFAC955B, 0xFFAD955C, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFF8A784C, 0xFF2B2518, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF403925, 0xFF978457, 0xFFB59F69, 
        0xFFB69F6B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFF352F20, 0xFF000000, 0xFF000000, 0xFF837552, 0xFFBCA876, 0xFFBDA877, 
        0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA7A, 0xFFBFAB7A, 0xFFB3A072, 0xFF2A261B, 0xFF000000, 0xFF3C3627, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF81, 0xFFC3AF81, 0xFF766A4F, 0xFF040403, 0xFF0A0907, 0xFF948563, 
        0xFFC5B284, 0xFFC5B284, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78C, 0xFFC9B88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C099, 0xFFD2C199, 
        0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C39D, 0xFFD3C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 
        0xFFD6C6A2, 0xFFD6C7A2, 0xFFD7C7A3, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD8C9A5, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA8, 0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA7, 
        0xFFDACBA7, 0xFFDACBA8, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CBA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C8A5, 0xFFD8C9A4, 
        0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 
        0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 
        0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCAB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFC9B88C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 
        0xFFC7B588, 0xFFC7B488, 0xFFC6B487, 0xFF484231, 0xFF000000, 0xFF322E22, 0xFF73684D, 0xFF000000, 0xFF000000, 0xFF211D16, 0xFF988A65, 0xFFC3B082, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFF665C43, 0xFF000000, 0xFF100E0A, 0xFF9C8C65, 0xFFC0AC7D, 
        0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 
        0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 
        0xFFB19A62, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFF927E4F, 0xFF38311E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF6B5C37, 0xFFAB9359, 0xFFAA9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99055, 
        0xFFA99054, 0xFFA88F53, 0xFFA78E52, 0xFF685833, 0xFF000000, 0xFF635430, 0xFFA68D50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF4B3F22, 0xFF000000, 0xFF3E341C, 0xFFA28748, 0xFFA18747, 0xFFA08647, 
        0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9D8342, 0xFF9D8241, 0xFF9D8140,
  0xFF9C8140, 0xFF9D8240, 0xFF9D8341, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF836E3B, 0xFF000000, 0xFF221D0F, 0xFF967E44, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 
        0xFFA58B4F, 0xFFA68C4F, 0xFF18140B, 0xFF0B0905, 0xFF8C7743, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFF887445, 0xFF040402, 0xFF8A7647, 0xFFAC935A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFA58F5A, 0xFF453C26, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF100E09, 0xFF84734B, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 
        0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFB29E6D, 0xFF4C442F, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF13110C, 0xFFBCA876, 0xFFBCA876, 
        0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFF897B58, 0xFF090806, 0xFF030201, 0xFF766A4C, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFFC2AE80, 0xFFC2AE80, 0xFFC3AF80, 0xFFC1AE7F, 0xFF242118, 0xFF000000, 0xFF252219, 
        0xFFB2A177, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B486, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC8B588, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCBB88E, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD95, 0xFFCEBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C198, 
        0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A1, 
        0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD8CAA5, 0xFFD9CAA5, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFDACBA7, 0xFFD9CBA7, 0xFFD9CAA7, 0xFFD9CBA7, 0xFFD9CAA7, 
        0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA5, 0xFFD9CAA6, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A4, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD2C39B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD1C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBC93, 
        0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 
        0xFFC7B588, 0xFFC7B487, 0xFF6D634A, 0xFF000000, 0xFF110F0B, 0xFFA1916D, 0xFFC5B284, 0xFF9D8E69, 0xFF17150F, 0xFF000000, 0xFF060504, 0xFF756A4D, 0xFFC0AC7E, 0xFFC2AF80, 0xFF9C8C67, 0xFF12100B, 0xFF000000, 0xFF5F553E, 0xFFC0AD7D, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA672, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 
        0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19962, 
        0xFFB09962, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975E, 0xFFAE975E, 0xFF70613C, 0xFF020101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF272114, 0xFFA89157, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9256, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 
        0xFFA88F54, 0xFFA88F53, 0xFFA78F52, 0xFF1E1A0F, 0xFF070603, 0xFF9A834A, 0xFFA68C50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFF967E45, 0xFF231D0F, 0xFF000000, 0xFF846E3B, 0xFFA18747, 0xFFA18647, 0xFFA08646, 
        0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8240, 0xFF9C8240,
  0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA28748, 0xFF1B170C, 0xFF010100, 0xFF7C6839, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 
        0xFFA58C4E, 0xFFA68C4F, 0xFF6B5B33, 0xFF000000, 0xFF5E502D, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFF433923, 0xFF2B2516, 0xFFAC9359, 0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 
        0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFA18B57, 0xFF6D5E3B, 0xFF12100A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF14110B, 0xFF5A4E33, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 
        0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16B, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB39F6C, 0xFF867651, 0xFF242016, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF594F38, 0xFFBDA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFF504834, 0xFF000000, 0xFF181610, 0xFFA7956C, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFA2926B, 0xFF3A3426, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF4B4432, 0xFFC4B183, 0xFFC5B284, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 
        0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF98, 0xFFD0C098, 0xFFD1C098, 
        0xFFD1C099, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD9CAA5, 0xFFD9C9A5, 0xFFD8CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA7, 0xFFD9CAA6, 0xFFD9CAA6, 
        0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9CAA6, 0xFFD9C9A6, 0xFFD9CAA6, 0xFFD8CAA5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C49F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C49D, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBD93, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98D, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 
        0xFFC7B488, 0xFF948665, 0xFF090806, 0xFF020201, 0xFF756A4F, 0xFFC5B284, 0xFFC5B284, 0xFFC4B183, 0xFFB2A177, 0xFF3F392A, 0xFF000000, 0xFF000000, 0xFF494230, 0xFF9F9069, 0xFF3C3527, 0xFF000000, 0xFF2C281D, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 0xFFBCA875, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 
        0xFFB8A36F, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 
        0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFF786840, 0xFF080704, 0xFF000000, 0xFF040402, 0xFF7D6B41, 0xFFAC9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA89054, 
        0xFFA88F53, 0xFFA88F53, 0xFF836F40, 0xFF000000, 0xFF433920, 0xFFA38A4E, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF7B6738, 0xFF010100, 0xFF1C180C, 0xFFA28748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 
        0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140,
  0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF6F5D32, 0xFF000000, 0xFF473C20, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4D, 
        0xFFA58B4E, 0xFFA58C4F, 0xFF9C834A, 0xFF100E08, 0xFF0E0C07, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFA28B53, 0xFF080604, 0xFF6F5F39, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 
        0xFFAD955C, 0xFFAE965C, 0xFFAE965D, 0xFF72623D, 0xFF252014, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF53482E, 0xFF9A8757, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 
        0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26F, 0xFF948359, 0xFF383122, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050503, 0xFF9B8B60, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 0xFFBCA879, 0xFF29251A, 0xFF000000, 0xFF3C3627, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7E, 0xFF776B4E, 0xFF18150F, 0xFF000000, 0xFF090806, 0xFF6D6248, 0xFF1F1C14, 
        0xFF000000, 0xFF5D533E, 0xFFC5B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA91, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 
        0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A1, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A2, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C8A4, 
        0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD9C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 
        0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 
        0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A1, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 
        0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 
        0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 
        0xFFB5A37A, 0xFF1C1913, 0xFF000000, 0xFF5C533E, 0xFFC5B284, 0xFFC5B284, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC0AD7F, 0xFF7B6F51, 0xFF0E0D09, 0xFF000000, 0xFF12100B, 0xFF000000, 0xFF100E0A, 0xFFAE9C70, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFBFAC7B, 
        0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA674, 0xFFBBA774, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26F, 
        0xFFB8A26E, 0xFFB8A16D, 0xFFB7A16D, 0xFFB7A06C, 0xFFB6A06C, 0xFFB59F6B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB09A62, 0xFFB09961, 
        0xFFB09961, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD955D, 0xFFAD955C, 0xFF252013, 0xFF000000, 0xFF342D1B, 0xFFA89057, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 0xFFA89054, 
        0xFFA88F53, 0xFFA88E52, 0xFF241F12, 0xFF030301, 0xFF776539, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF463B20, 0xFF000000, 0xFF705E32, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08646, 
        0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140,
  0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF9B8144, 0xFF100D07, 0xFF030201, 0xFF9F8548, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 
        0xFFA58B4E, 0xFFA58B4F, 0xFFA38A4E, 0xFF504426, 0xFF000000, 0xFF6C5C34, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAB9258, 0xFF76643C, 0xFF13100A, 0xFF9A8450, 0xFFAC945A, 0xFFAC945A, 
        0xFFAD955C, 0xFF95814F, 0xFF2A2416, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2B2517, 0xFF9C8757, 0xFFB09962, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 
        0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16D, 0xFFB49E6B, 0xFF4C432D, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3B3525, 
        0xFFBBA775, 0xFFBDA877, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFAB996E, 0xFF090805, 0xFF000000, 0xFF685D43, 0xFFC1AD7D, 0xFF574E38, 0xFF040402, 0xFF000000, 0xFF231F17, 0xFFA6956D, 0xFFC3AF81, 0xFF8D7F5E, 
        0xFF090906, 0xFF020201, 0xFF74684D, 0xFFC5B284, 0xFFC5B284, 0xFFC6B285, 0xFFC5B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC7B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 
        0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A3, 
        0xFFD7C8A4, 0xFFD8C8A4, 0xFFD7C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A5, 0xFFD8C9A4, 0xFFD8C9A4, 
        0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD2C29A, 0xFFD2C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 
        0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 
        0xFF27241A, 0xFF000000, 0xFF3F392A, 0xFFC5B285, 0xFFC5B284, 0xFFC4B184, 0xFFC4B183, 0xFFC4B182, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF81, 0xFF9C8D67, 0xFF18150F, 0xFF000000, 0xFF000000, 0xFF877957, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBEAB7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA472, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB09A62, 0xFFB19962, 0xFFB09961, 
        0xFFB09960, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD945C, 0xFF2C2617, 0xFF020201, 0xFF8C7849, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 
        0xFFA88F53, 0xFF847040, 0xFF010100, 0xFF201B0F, 0xFFA0874D, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF9F8548, 0xFF020201, 0xFF110E07, 0xFF9B8144, 0xFFA18748, 0xFFA08647, 0xFFA08646, 0xFFA08546, 
        0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9D8242, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F,
  0xFF9C803F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18747, 0xFF9F8547, 0xFF4C4022, 0xFF000000, 0xFF5D4E2A, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48B4D, 
        0xFFA48B4D, 0xFFA58C4E, 0xFFA58C4F, 0xFF806C3D, 0xFF090804, 0xFF14110A, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFF2A2415, 0xFF16130B, 0xFF695A37, 0xFF76653E, 
        0xFF38311D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF17140C, 0xFF6D5E3C, 0xFFB19962, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 
        0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFAC9766, 0xFF786A47, 0xFF0F0D09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF100E09, 0xFF3D3625, 0xFF887853, 0xFF98875E, 0xFF514832, 0xFF0C0B07, 
        0xFF8A7B56, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF796C4E, 0xFF020201, 0xFF000000, 0xFF2F2A1E, 0xFF000000, 0xFF080705, 0xFF4B4331, 0xFFB8A579, 0xFFC3AF80, 0xFFC3AF80, 0xFFC3B081, 
        0xFF665B43, 0xFF000000, 0xFF0D0B08, 0xFF948563, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 
        0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCEBC92, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF96, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C099, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 
        0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD8C9A4, 0xFFD8C8A4, 0xFFD8C8A4, 0xFFD8C9A4, 0xFFD7C8A4, 0xFFD7C9A4, 
        0xFFD8C8A4, 0xFFD7C8A4, 0xFFD8C8A4, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD8C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A2, 0xFFD6C7A1, 0xFFD6C6A1, 
        0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C19A, 
        0xFFD2C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 
        0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC3B185, 0xFF403A2B, 
        0xFF000000, 0xFF262219, 0xFFB6A47B, 0xFFC5B284, 0xFFC5B283, 0xFFC4B183, 0xFFC4B183, 0xFFC4B081, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFAD9B71, 0xFF191710, 0xFF000000, 0xFF4B4331, 0xFFBEAA7B, 0xFFC0AD7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBBA776, 0xFF90815B, 0xFF877855, 0xFF9A8960, 0xFFA18F64, 0xFFA69467, 0xFFAB996B, 0xFFB19D6E, 0xFFB7A270, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A370, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B65, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19961, 0xFFB09961, 
        0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFA68F57, 0xFF16130B, 0xFF483E25, 0xFFAB945A, 0xFFAB9358, 0xFFAB9258, 0xFFAA9258, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 
        0xFFA88F53, 0xFF3C331D, 0xFF000000, 0xFF594C2B, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF5D4D2A, 0xFF000000, 0xFF4D4022, 0xFF9F8547, 0xFFA18747, 0xFFA18646, 0xFFA08646, 0xFFA08545, 
        0xFFA08444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9C813F, 0xFF9C813F,
  0xFF9C803F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF7B6737, 0xFF080603, 0xFF0F0C06, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 
        0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF251F11, 0xFF000000, 0xFF6F5E36, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFF816E42, 0xFF060503, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0C07, 0xFF5D5133, 0xFFA28C58, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB49D66, 0xFFB49E67, 
        0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFF7C6D49, 0xFF2F291B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF504731, 0xFF98865C, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA674, 0xFF65593E, 
        0xFF2A251A, 0xFFB8A372, 0xFFBDA876, 0xFFBDA877, 0xFFBEA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 0xFFBCA879, 0xFF443D2B, 0xFF000000, 0xFF000000, 0xFF242017, 0xFF867857, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF81, 
        0xFFC3B081, 0xFF5B523D, 0xFF000000, 0xFF1A1711, 0xFFAA9971, 0xFFC4B284, 0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC9B68A, 0xFFC8B68B, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 
        0xFFCAB88C, 0xFFCAB88D, 0xFFCBB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 
        0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 
        0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A1, 0xFFD6C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 
        0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C8A4, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 0xFFD7C8A3, 
        0xFFD7C7A3, 0xFFD7C8A3, 0xFFD7C8A2, 0xFFD7C8A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A3, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C5A0, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C49E, 0xFFD4C49F, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C19A, 0xFFD2C19A, 
        0xFFD1C099, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB90, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC5B386, 0xFF5B523E, 0xFF000000, 
        0xFF100F0B, 0xFFA0916C, 0xFFC5B284, 0xFFC5B183, 0xFFC4B183, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFBDA97C, 0xFF3C3527, 0xFF000000, 0xFF201D15, 0xFFB4A174, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAB7A, 
        0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFB6A373, 0xFF302B1E, 0xFF000000, 0xFF000000, 0xFF080705, 0xFF17140E, 0xFF242016, 0xFF332D1F, 0xFF413928, 0xFF4E4530, 0xFF5E5339, 0xFF6F6243, 0xFF80714D, 0xFF907F57, 0xFFA18F61, 0xFFB29C6A, 0xFFB8A26D, 
        0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB59E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFAF9860, 
        0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFF73633C, 0xFF1A160D, 0xFFA58E56, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 
        0xFF8E7845, 0xFF120F08, 0xFF000000, 0xFF483D22, 0xFF8B7642, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894A, 0xFF0E0C06, 0xFF080603, 0xFF7B6737, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08546, 0xFFA08545, 
        0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813E,
  0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8343, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFF9E8446, 0xFF241E10, 0xFF000000, 0xFF695930, 0xFFA3894B, 0xFFA4894B, 0xFFA48A4C, 
        0xFFA48B4D, 0xFFA48B4E, 0xFF806C3C, 0xFF2B2414, 0xFF040302, 0xFF000000, 0xFF2B2515, 0xFFA58C51, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFF3A321E, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF443B25, 0xFF9F8955, 0xFFAF975F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A64, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB39D67, 
        0xFFB49E68, 0xFFB59E69, 0xFFA3905F, 0xFF342E1E, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF312C1E, 0xFF9D8A5F, 0xFFB6A26E, 0xFFB9A471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFAE9A6C, 
        0xFF675C40, 0xFFB6A271, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA979, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 0xFFB9A677, 0xFF15130D, 0xFF000000, 0xFF363023, 0xFFBEAA7B, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC1AE7F, 0xFFC2AF80, 0xFFC2AF80, 
        0xFFC3AF81, 0xFFBFAC7E, 0xFF4F4734, 0xFF000000, 0xFF16140E, 0xFFB6A67B, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 
        0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 
        0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C19A, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 
        0xFFD3C39D, 0xFFD4C39D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 
        0xFFD6C7A2, 0xFFD6C6A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD7C7A3, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD7C7A2, 
        0xFFD6C7A2, 0xFFD7C7A2, 0xFFD7C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD4C59F, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C199, 0xFFD2C199, 0xFFD1C199, 
        0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 
        0xFFCBBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFF756A4F, 0xFF000000, 0xFF000000, 
        0xFF9E8F6A, 0xFFC5B284, 0xFFC5B283, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AE80, 0xFF625840, 0xFF000000, 0xFF030201, 0xFFAB996E, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFC0AB7B, 0xFFBFAA7A, 0xFFBEAA7A, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA977, 0xFF8B7B57, 0xFF0A0906, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF070604, 0xFF0A0806, 0xFF0D0C08, 0xFF100E09, 0xFF18150E, 
        0xFF2B261A, 0xFF453D29, 0xFF5E5237, 0xFF796A46, 0xFF907F54, 0xFFAB9563, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09861, 0xFFAF9860, 
        0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965C, 0xFFAD955C, 0xFFA48D57, 0xFF14110A, 0xFF6D5E39, 0xFFAC9459, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA68E51, 
        0xFF60512F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF090804, 0xFF2F2816, 0xFF7F6B3C, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF68572F, 0xFF000000, 0xFF241E10, 0xFF9E8446, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 
        0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E,
  0xFF9B803E, 0xFF9C803F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF60512B, 0xFF000000, 0xFF282112, 0xFFA3894B, 0xFFA38A4B, 0xFF9A8247, 
        0xFF786537, 0xFF221D10, 0xFF000000, 0xFF000000, 0xFF060503, 0xFF070603, 0xFF0A0805, 0xFF806D3F, 0xFFA78E52, 0xFFA88E53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9258, 0xFF907C4A, 0xFF070603, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF19160D, 0xFF887548, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 
        0xFFAB9563, 0xFF615538, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF16130D, 0xFF796B48, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7B, 0xFFAA986D, 0xFF080705, 0xFF000000, 0xFF645A41, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 
        0xFFC3AF80, 0xFFC3B081, 0xFFB6A478, 0xFF312D21, 0xFF000000, 0xFF252219, 0xFFB7A67B, 0xFFC5B285, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B68B, 
        0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE94, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD2C199, 0xFFD1C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C39D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 0xFFD6C7A2, 
        0xFFD6C7A1, 0xFFD6C7A2, 0xFFD6C7A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C59E, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 
        0xFFD1C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCBBA90, 
        0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B488, 0xFFC6B487, 0xFF8A7D5E, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF58503B, 0xFFC2AF82, 0xFFC4B183, 0xFFC4B183, 0xFFC4B182, 0xFFC4B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFF887A59, 0xFF000000, 0xFF000000, 0xFF897B59, 0xFFC1AD7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA877, 0xFF5D533A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF15120C, 0xFF2E281A, 0xFF483F29, 0xFF605336, 0xFF7A6B45, 0xFF917E51, 0xFFA08B5A, 0xFFA38D5B, 0xFFA6905C, 0xFFA9935D, 0xFFAB945E, 0xFFAD965E, 0xFFAF9860, 
        0xFFAF985F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFA48D57, 0xFF272114, 0xFF241F13, 0xFFA18954, 0xFFAB9359, 0xFFAB9359, 0xFFAA9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA98F54, 0xFFA88F53, 0xFFA1884F, 
        0xFF1A160D, 0xFF050402, 0xFF705F36, 0xFF211C10, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF272112, 0xFF816C3B, 0xFF9B8347, 0xFFA2884A, 0xFF282112, 0xFF000000, 0xFF61512B, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 
        0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C803F, 0xFF9B803E,
  0xFF9B803E, 0xFF9B803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFFA08544, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF9F8446, 0xFF0C0A05, 0xFF0A0804, 0xFF6C5A31, 0xFF5C4D2A, 0xFF221D10, 
        0xFF000000, 0xFF000000, 0xFF0B0905, 0xFF3A311B, 0xFF776539, 0xFF716036, 0xFF000000, 0xFF493E23, 0xFFA58C51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9358, 0xFF55492C, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF413822, 0xFFA08955, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09960, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFAF9864, 0xFF706240, 
        0xFF1F1B11, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF14120C, 0xFF594E34, 0xFFA99564, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A36F, 0xFFB9A370, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBBA572, 0xFFBBA673, 
        0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBDA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF837654, 0xFF060503, 0xFF000000, 0xFF776B4D, 0xFFC1AD7D, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFFC2AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFAC9B73, 0xFF242118, 0xFF000000, 0xFF3B3527, 0xFFBCA97E, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 
        0xFFC9B68B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD3C29B, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C5A0, 
        0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C7A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 
        0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A1, 0xFFD6C6A0, 0xFFD6C6A0, 0xFFD5C6A0, 0xFFD5C69F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59E, 0xFFD5C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 
        0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 
        0xFFCBB98F, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B587, 0xFFC7B487, 0xFF85795B, 0xFF000000, 0xFF040403, 0xFF423C2C, 0xFF060604, 
        0xFF000000, 0xFF494231, 0xFFBAA87C, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFF978763, 0xFF080705, 0xFF000000, 0xFF5C523B, 0xFFC0AC7C, 0xFFC1AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFF433B29, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A06, 0xFF1D1910, 0xFF2D2719, 0xFF3E3622, 0xFF4E432A, 0xFF5E5133, 
        0xFF6B5C3A, 0xFF776740, 0xFF7E6D43, 0xFF7C6B42, 0xFF5B4E30, 0xFF15120B, 0xFF000000, 0xFF79683F, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF705F37, 
        0xFF000000, 0xFF524527, 0xFFA68D50, 0xFFA68C4F, 0xFF716035, 0xFF382F1A, 0xFF0A0804, 0xFF000000, 0xFF000000, 0xFF251F11, 0xFF483C20, 0xFF0A0804, 0xFF0C0A05, 0xFF9E8447, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08645, 0xFF9F8545, 0xFF9F8444, 
        0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E,
  0xFF9B7F3D, 0xFF9B803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA28748, 0xFF574927, 0xFF000000, 0xFF0A0904, 0xFF000000, 0xFF000000, 
        0xFF0A0905, 0xFF524526, 0xFF8C7641, 0xFFA1874C, 0xFFA58C4F, 0xFFA48A4E, 0xFF1F1B0F, 0xFF000000, 0xFF9A834B, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAB9258, 0xFFA89056, 0xFF1B170E, 
        0xFF000000, 0xFF231E12, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09960, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFF84744B, 0xFF241F14, 0xFF030302, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4A412B, 0xFF9D8A5C, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFBAA470, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 
        0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFF5C523B, 0xFF000000, 0xFF0C0A07, 0xFF8C7E5B, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC2AE7F, 
        0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF80, 0xFFC3B081, 0xFFB1A075, 0xFF242017, 0xFF000000, 0xFF383326, 0xFFC5B184, 0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBD93, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 
        0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C6A0, 
        0xFFD5C6A0, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C69F, 0xFFD5C5A0, 0xFFD5C5A0, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C49F, 0xFFD4C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD3C39D, 
        0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C39C, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF98, 0xFFD0BF97, 
        0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBA91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF918463, 0xFF0D0B08, 0xFF000000, 0xFF645A43, 0xFFC5B285, 0xFF8F8160, 
        0xFF040403, 0xFF000000, 0xFF322D21, 0xFFBEAB7E, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFAE9C72, 0xFF201D15, 0xFF000000, 0xFF322D21, 0xFFBDA97A, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFB29E6E, 0xFF2C271B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF050402, 0xFF080704, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF332C1A, 0xFFAC945A, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF100D08, 
        0xFF0C0A06, 0xFF887341, 0xFFA68D50, 0xFFA68C4F, 0xFFA58B4E, 0xFF9F874A, 0xFF887340, 0xFF4B3F22, 0xFF050402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF574827, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8444, 0xFF9F8444, 
        0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E,
  0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8341, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8445, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF9E8446, 0xFF040302, 0xFF000000, 0xFF100D07, 0xFF564928, 
        0xFF9B8347, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4F, 0xFFA58C4F, 0xFF6C5C34, 0xFF000000, 0xFF483D22, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFF7C6A3F, 
        0xFF000000, 0xFF4F4429, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFB09860, 0xFFB09960, 0xFFB09961, 0xFFB19962, 0xFFB09962, 0xFFA5905C, 0xFF453C26, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1D1A11, 0xFF928156, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA472, 0xFFBAA572, 
        0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFC0AB7B, 0xFF332E21, 0xFF000000, 0xFF181610, 0xFFAA986E, 0xFFC1AD7E, 0xFFC1AD7E, 
        0xFFC2AE7F, 0xFFC2AE80, 0xFFC2AF80, 0xFFC3AF81, 0xFFAE9D73, 0xFF17140F, 0xFF000000, 0xFF000000, 0xFF353023, 0xFFC4B183, 0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 
        0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 
        0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD5C59F, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C69F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 
        0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C59F, 0xFFD4C59F, 0xFFD5C59E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 
        0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFA2936E, 0xFF040403, 0xFF000000, 0xFF59503C, 0xFFC5B285, 0xFFC5B284, 0xFFC4B183, 
        0xFFA2936C, 0xFF100E0A, 0xFF000000, 0xFF1D1A13, 0xFFB19F75, 0xFFC3AF80, 0xFFBFAC7E, 0xFF363023, 0xFF000000, 0xFF15130E, 0xFFBEAA7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 
        0xFFBEA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFF98875D, 0xFF110F0A, 0xFF000000, 0xFF050403, 0xFF231F15, 0xFF17140E, 0xFF070604, 0xFF040302, 0xFF030302, 0xFF020201, 0xFF010100, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF9E8852, 0xFFAC9459, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFAA9155, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F52, 0xFF645531, 0xFF000000, 
        0xFF372F1B, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFF9D8448, 0xFF514425, 0xFF000000, 0xFF050402, 0xFF9E8446, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08645, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D,
  0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA18646, 0xFFA18747, 0xFFA18748, 0xFF4E4123, 0xFF000000, 0xFF5D4E2A, 0xFFA3894B, 
        0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF977F47, 0xFF1D180E, 0xFF000000, 0xFF978049, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFA48D54, 
        0xFF2E2718, 0xFF3A311E, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFA28D59, 0xFF665938, 0xFF0C0A06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF1C1910, 0xFF675A3B, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A370, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 
        0xFFBBA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBCA979, 0xFF2C271C, 0xFF000000, 0xFF2B261B, 0xFFB3A074, 0xFFC1AD7E, 
        0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF7F, 0xFF928360, 0xFF100E0A, 0xFF000000, 0xFF1E1B14, 0xFF13110C, 0xFF000000, 0xFF433D2D, 0xFFBCAA7E, 0xFFC5B285, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 
        0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 
        0xFFCEBC93, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29C, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 
        0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C59F, 0xFFD4C59E, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59E, 0xFFD5C59F, 0xFFD4C59F, 0xFFD4C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD5C59F, 0xFFD4C59F, 
        0xFFD5C59F, 0xFFD5C49F, 0xFFD4C49E, 0xFFD4C49E, 0xFFD5C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD3C39D, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BE96, 0xFFCFBE96, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBE94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB98D, 
        0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF948664, 0xFF040403, 0xFF000000, 0xFF58503B, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC4B183, 
        0xFFC4B182, 0xFF9C8C68, 0xFF201C15, 0xFF000000, 0xFF1F1C14, 0xFF958762, 0xFF49412F, 0xFF000000, 0xFF15120D, 0xFFAB996E, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 
        0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 0xFF706344, 0xFF000000, 0xFF000000, 0xFF4F452F, 0xFFB9A36F, 0xFFB8A36F, 0xFFA99565, 0xFF938158, 0xFF7F704B, 0xFF695C3E, 0xFF554B32, 0xFF413926, 
        0xFF342D1E, 0xFF292418, 0xFF1F1C12, 0xFF15120C, 0xFF0C0A06, 0xFF020101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5F5131, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA1894F, 0xFF1A160D, 0xFF030201, 
        0xFF7E6B3D, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF5D4E2A, 0xFF000000, 0xFF4F4324, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 
        0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D,
  0xFF9A7F3C, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8341, 0xFF9E8342, 0xFF9E8443, 0xFF9E8443, 0xFF9F8445, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF866F3B, 0xFF0C0A05, 0xFF080603, 0xFF9F8548, 
        0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF554829, 0xFF000000, 0xFF3C331D, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 
        0xFF7F6D42, 0xFF080704, 0xFF9D8752, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFF6F5F3C, 0xFF1F1B11, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF080704, 0xFF605437, 0xFF9F8B5A, 0xFFB49E67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A36E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFBAA471, 0xFFB9A572, 
        0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFAA986D, 0xFF231F16, 0xFF000000, 0xFF2F2A1E, 0xFFB8A577, 
        0xFFC1AD7E, 0xFFC1AE7E, 0xFF887A59, 0xFF0F0E0A, 0xFF000000, 0xFF242018, 0xFFA6966E, 0xFFA0906B, 0xFF13120D, 0xFF000000, 0xFF3E3829, 0xFFC4B184, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B588, 
        0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 
        0xFFD1C099, 0xFFD1C199, 0xFFD2C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 
        0xFFD4C39D, 0xFFD3C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49E, 0xFFD4C49D, 
        0xFFD4C49E, 0xFFD4C49D, 0xFFD4C49E, 0xFFD4C49D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 
        0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB78C, 
        0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF8A7E5E, 0xFF0E0D09, 0xFF000000, 0xFF58503B, 0xFFC1AE82, 0xFFC5B284, 0xFFC5B183, 0xFFC4B183, 0xFFC4B182, 
        0xFFC3B082, 0xFFC3B081, 0xFFAA9970, 0xFF262219, 0xFF000000, 0xFF0F0D09, 0xFF000000, 0xFF0B0A07, 0xFF8F805C, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA977, 0xFFBDA877, 
        0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBAA673, 0xFFBAA572, 0xFFBAA572, 0xFF544B33, 0xFF000000, 0xFF000000, 0xFF675A3D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB59F6A, 0xFFAB9663, 0xFFA38F5E, 0xFF988558, 0xFF8F7D51, 0xFF85744C, 0xFF7A6B45, 0xFF67593A, 0xFF51472E, 0xFF3E3622, 0xFF292317, 0xFF14120B, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF211D11, 0xFFA18B54, 0xFFAC9459, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF6B5B34, 0xFF000000, 0xFF2E2716, 
        0xFFA68D50, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4B, 0xFF9F8548, 0xFF070603, 0xFF0C0A05, 0xFF85703B, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9E8443, 0xFF9E8443, 
        0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B7F3E, 0xFF9B7F3D,
  0xFF9B7F3C, 0xFF9B7F3E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFF382F19, 0xFF000000, 0xFF534525, 
        0xFFA3894A, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFF9F874C, 0xFF090804, 0xFF0E0C06, 0xFF887342, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 
        0xFFAB9359, 0xFF342D1B, 0xFF2E2818, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFF947F50, 0xFF231E13, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF332C1D, 
        0xFFA08B5A, 0xFFB29B65, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 
        0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA674, 0xFFBCA674, 0xFFBCA774, 0xFFBCA776, 0xFFBDA876, 0xFFBDA876, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF998962, 0xFF0E0C09, 0xFF000000, 0xFF423B2B, 
        0xFFC1AD7D, 0xFF897B59, 0xFF030201, 0xFF000000, 0xFF29251B, 0xFFB9A77A, 0xFFC3B081, 0xFFC3B081, 0xFFAC9B71, 0xFF17140F, 0xFF000000, 0xFF28241B, 0xFFC0AD80, 0xFFC5B285, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 
        0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98D, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 
        0xFFCDBB91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 
        0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C39D, 0xFFD4C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD4C39D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C39D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C39D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C49D, 0xFFD4C39D, 
        0xFFD3C39D, 0xFFD4C49D, 0xFFD3C39C, 0xFFD3C39D, 0xFFD4C39C, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD3C29C, 0xFFD2C29B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF98, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 
        0xFFC9B78C, 0xFFC9B78B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFF8F8261, 0xFF030202, 0xFF000000, 0xFF564E3A, 0xFFC5B285, 0xFFC5B284, 0xFFC5B183, 0xFFC4B183, 0xFFC4B182, 0xFFC4B082, 
        0xFFC3B081, 0xFFC3AF81, 0xFFC2AF80, 0xFFB5A477, 0xFF262219, 0xFF000000, 0xFF000000, 0xFF796C4F, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 
        0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA573, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A370, 0xFF322C1E, 0xFF000000, 0xFF000000, 0xFF897952, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06A, 
        0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB39D66, 0xFFB39C66, 0xFFB29B64, 0xFFB09963, 0xFFB09963, 0xFFAF9961, 0xFFAE9761, 0xFFAD9660, 0xFFA28C59, 0xFF89764A, 0xFF6D5F3C, 0xFF4E432A, 0xFF241F13, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF6C5D38, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFF9F874E, 0xFF2B2515, 0xFF000000, 0xFF907A45, 
        0xFFA68D50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4B, 0xFFA3894B, 0xFF524525, 0xFF000000, 0xFF382F19, 0xFFA08647, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3E, 0xFF9B7F3C,
  0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8445, 0xFFA08545, 0xFFA08545, 0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFF766335, 0xFF040302, 0xFF110E08, 
        0xFF987F45, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF5B4D2B, 0xFF000000, 0xFF4B4024, 0xFFA58C51, 0xFFA88F52, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 
        0xFFAB9258, 0xFF9F8953, 0xFF0D0B06, 0xFF76663E, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAE965C, 0xFF988351, 0xFF55492E, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF1F1B11, 0xFF7A6A44, 0xFFB29B64, 
        0xFFB29B65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA470, 
        0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF897A58, 0xFF070604, 0xFF000000, 
        0xFF3B3426, 0xFF000000, 0xFF000000, 0xFF443D2C, 0xFFBFAB7D, 0xFFC2AE80, 0xFFC2AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFA0906B, 0xFF1D1B14, 0xFF000000, 0xFF2E291E, 0xFFB09F76, 0xFFC5B285, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 
        0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCCBA91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29C, 0xFFD2C29B, 
        0xFFD3C29C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39D, 0xFFD3C39C, 
        0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C39C, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C19B, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 
        0xFFD1C19A, 0xFFD2C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCDBC93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78C, 
        0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFF7E7356, 0xFF000000, 0xFF030302, 0xFF5E553F, 0xFFC5B285, 0xFFC5B284, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC3B082, 0xFFC3B082, 
        0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFF827555, 0xFF000000, 0xFF000000, 0xFF655A41, 0xFFC1AD7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA7A, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA876, 0xFFBDA876, 
        0xFFBDA876, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFA59164, 0xFF17140E, 0xFF000000, 0xFF0D0C08, 0xFFA08D5F, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975E, 0xFFA8925B, 0xFF5C5031, 
        0xFF080704, 0xFF000000, 0xFF000000, 0xFF262114, 0xFFA79057, 0xFFAC9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F52, 0xFF7B683C, 0xFF000000, 0xFF3E351E, 0xFFA68D50, 
        0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFF987F45, 0xFF110E07, 0xFF040302, 0xFF766334, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C,
  0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8445, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF262011, 0xFF000000, 
        0xFF5E4E2A, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA48A4E, 0xFF121009, 0xFF070603, 0xFF947D48, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 
        0xFFAA9258, 0xFFAB9258, 0xFF695A36, 0xFF0D0B06, 0xFF685936, 0xFF907C4C, 0xFF806E44, 0xFF4B4128, 0xFF15120B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF16130C, 0xFF685A3A, 0xFFA8925E, 0xFFB19A63, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A370, 0xFFB9A470, 
        0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF857755, 0xFF060604, 
        0xFF000000, 0xFF000000, 0xFF5D543C, 0xFFBDA97B, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFA6966F, 0xFF28241B, 0xFF000000, 0xFF27231A, 0xFFA6966F, 0xFFC5B284, 0xFFC5B285, 0xFFC6B385, 0xFFC6B385, 0xFFC6B486, 
        0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC8B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA90, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFD0BF96, 0xFFD0BF96, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD2C199, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 
        0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD3C39B, 0xFFD3C39B, 0xFFD2C29B, 0xFFD3C29C, 0xFFD3C29C, 0xFFD3C29B, 0xFFD3C39B, 0xFFD2C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29B, 0xFFD3C29B, 
        0xFFD3C29B, 0xFFD3C39B, 0xFFD3C39B, 0xFFD3C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD1C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C199, 
        0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBE94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 
        0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBB990, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC6B487, 0xFF665C45, 0xFF000000, 0xFF000000, 0xFF2B271D, 0xFFBEAC7F, 0xFFC4B184, 0xFFC4B183, 0xFFC4B183, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 
        0xFFC2AF80, 0xFFC2AF80, 0xFF786B4E, 0xFF010100, 0xFF000000, 0xFF635941, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFF82724E, 0xFF020101, 0xFF000000, 0xFF322C1D, 0xFFB09B68, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 
        0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 
        0xFF625434, 0xFF000000, 0xFF000000, 0xFF857245, 0xFFAC945A, 0xFFAB9359, 0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E53, 0xFF16130B, 0xFF050402, 0xFF8A7542, 0xFFA68C50, 
        0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF5E4F2A, 0xFF000000, 0xFF262011, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 
        0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3E, 0xFF9B7F3C, 0xFF9A7E3C,
  0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFFA08646, 0xFFA18646, 0xFFA08647, 0xFFA18748, 0xFF846E3A, 0xFF000000, 
        0xFF231D0F, 0xFF988045, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF705E36, 0xFF000000, 0xFF433920, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 
        0xFFAA9257, 0xFFAB9258, 0xFFA18A53, 0xFF282214, 0xFF020101, 0xFF090804, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF564A2F, 0xFFA5905B, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 
        0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 
        0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA979, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF796C4E, 
        0xFF030302, 0xFF000000, 0xFF524935, 0xFFC1AD7E, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AF80, 0xFFC3AF80, 0xFFC3B081, 0xFFB6A479, 0xFF363124, 0xFF000000, 0xFF0E0D09, 0xFF958664, 0xFFC5B284, 0xFFC6B285, 0xFFC6B385, 0xFFC6B386, 
        0xFFC6B486, 0xFFC6B387, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 
        0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 
        0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD2C199, 0xFFD1C19A, 0xFFD2C19A, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 0xFFD2C29B, 
        0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29B, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C19A, 0xFFD2C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 
        0xFFD0C098, 0xFFD1BF98, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78A, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFF4F4836, 0xFF000000, 0xFF000000, 0xFF030202, 0xFF000000, 0xFF5D543E, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 
        0xFFC3AF80, 0xFF817454, 0xFF090805, 0xFF000000, 0xFF504834, 0xFFBEAB7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA875, 0xFFBCA775, 
        0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFF5F5438, 0xFF000000, 0xFF000000, 0xFF584D34, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F69, 0xFFB59F69, 
        0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD955D, 
        0xFF7C6A42, 0xFF000000, 0xFF463C24, 0xFFAC945A, 0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFF60512F, 0xFF000000, 0xFF3E351E, 0xFFA48B4F, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA3894B, 0xFF988046, 0xFF231D0F, 0xFF000000, 0xFF846E3B, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9E8444, 0xFF9E8342, 0xFF9E8342, 
        0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B,
  0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFFA28748, 0xFF312916, 
        0xFF000000, 0xFF736134, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58C4E, 0xFFA58C4F, 0xFF9A8249, 0xFF241E11, 0xFF000000, 0xFF8F7945, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 
        0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFF72623B, 0xFF040402, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040402, 0xFF262115, 0xFF907C4E, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB69F6A, 0xFFB69F6B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 
        0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBCA674, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 
        0xFF655B41, 0xFF030302, 0xFF000000, 0xFF695E44, 0xFFBEAA7C, 0xFFC1AE7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AE80, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFBAA77A, 0xFF3B3627, 0xFF020201, 0xFF060504, 0xFF847758, 0xFFC4B183, 0xFFC5B285, 0xFFC6B385, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD94, 0xFFCFBD94, 0xFFCEBE94, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCFBE96, 0xFFCFBE96, 0xFFCFBF96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0BF98, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 
        0xFFD1C199, 0xFFD1C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C29A, 0xFFD2C19A, 0xFFD2C29A, 
        0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0C097, 0xFFD1BF98, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFCFBF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 
        0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 
        0xFFC8B689, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFBBAA80, 0xFF373225, 0xFF000000, 0xFF0B0A07, 0xFF918362, 0xFF8C7F5E, 0xFF030302, 0xFF000000, 0xFF6A5F46, 0xFFC4B183, 0xFFC3B082, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 
        0xFF91825F, 0xFF060503, 0xFF000000, 0xFF413A2A, 0xFFC1AD7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA774, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFF373121, 0xFF000000, 0xFF000000, 0xFF7F6F49, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 
        0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE955D, 0xFFAC945B, 
        0xFF5C4F30, 0xFF060503, 0xFFA38D55, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9256, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFF9D854D, 0xFF0D0B06, 0xFF0A0805, 0xFF826E3E, 0xFFA68D4F, 0xFFA58C4F, 
        0xFFA58B4F, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF736135, 0xFF000000, 0xFF322A16, 0xFFA28748, 0xFFA18748, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 
        0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B,
  0xFF997E3B, 0xFF9A7E3B, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF826D3A, 
        0xFF000000, 0xFF151209, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF665731, 0xFF010100, 0xFF282213, 0xFFA78E51, 0xFFA78E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 
        0xFFAA9156, 0xFFAA9157, 0xFFAB9258, 0xFFA99157, 0xFF2C2617, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF211C11, 0xFF6F5F3B, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09861, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 
        0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16B, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 
        0xFFB9A36F, 0xFFB9A470, 0xFFBAA470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA573, 0xFFB5A16F, 0xFF9D8B60, 0xFF837451, 0xFF8B7B56, 0xFFBCA775, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 
        0xFFBFAB7B, 0xFF6D6146, 0xFF000000, 0xFF000000, 0xFF645A41, 0xFFC1AD7D, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC2AF7F, 0xFFC2AF7F, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFC0AD7F, 0xFF1B1812, 0xFF000000, 0xFF030202, 0xFF665C44, 0xFFC5B284, 0xFFC5B285, 
        0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98D, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC91, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD95, 
        0xFFCFBE94, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BE96, 0xFFCFBF96, 0xFFCFBF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C099, 
        0xFFD1C099, 0xFFD1C198, 0xFFD1C199, 0xFFD1C199, 0xFFD2C199, 0xFFD1C199, 0xFFD2C199, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C19A, 0xFFD1C19A, 0xFFD1C199, 0xFFD1C199, 0xFFD2C19A, 0xFFD2C199, 0xFFD1C19A, 0xFFD1C19A, 0xFFD2C19A, 0xFFD1C199, 0xFFD1C199, 
        0xFFD1C199, 0xFFD2C199, 0xFFD1C099, 0xFFD1C199, 0xFFD1C199, 0xFFD1C199, 0xFFD1C099, 0xFFD1C199, 0xFFD1C099, 0xFFD1C099, 0xFFD1C198, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 
        0xFFD0BF97, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC91, 0xFFCDBB92, 0xFFCCBB91, 
        0xFFCCBB90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 
        0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFA3946F, 0xFF29251B, 0xFF000000, 0xFF1B1912, 0xFF968865, 0xFFC5B284, 0xFFC5B283, 0xFF73674C, 0xFF030202, 0xFF000000, 0xFF7A6D51, 0xFFC3B082, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AF80, 0xFF827555, 
        0xFF060503, 0xFF000000, 0xFF504734, 0xFFC1AD7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 
        0xFFBBA674, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFAB9765, 0xFF231F14, 0xFF000000, 0xFF050403, 0xFF8E7D52, 0xFFB59F69, 0xFFB49E68, 
        0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAA925A, 
        0xFF18150C, 0xFF615332, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFF534628, 0xFF000000, 0xFF38301B, 0xFFA68D50, 0xFFA58C4F, 0xFFA68C4F, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF151209, 0xFF000000, 0xFF836E3B, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 
        0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B,
  0xFF997D3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08647, 0xFFA18747, 0xFF9D8346, 
        0xFF372E18, 0xFF000000, 0xFF5D4E2A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68D50, 0xFF1B170D, 0xFF030301, 0xFF6F5F36, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA98F54, 0xFFA99055, 0xFFA99055, 
        0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFF907B4B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4A4027, 0xFFA18B55, 0xFFAE965D, 0xFFAE965E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 
        0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29C65, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26D, 0xFFB8A26E, 
        0xFFB8A36F, 0xFFB9A370, 0xFFB7A16F, 0xFF8D7C55, 0xFF60543A, 0xFF363021, 0xFF1B1810, 0xFF110F0A, 0xFF070604, 0xFF4F4631, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAB79, 
        0xFFBFAB7A, 0xFFBFAB7B, 0xFF76694C, 0xFF000000, 0xFF000000, 0xFF504834, 0xFFC1AD7E, 0xFFC2AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF80, 0xFFC3AF80, 0xFF71664B, 0xFF060604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF383326, 0xFFBAA87C, 
        0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B689, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 
        0xFFCAB98D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCFBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C098, 0xFFD1C098, 
        0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 0xFFD1C099, 0xFFD1C099, 0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD1C198, 0xFFD1C098, 0xFFD1C098, 
        0xFFD1C098, 0xFFD1C098, 0xFFD1C099, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD1C098, 0xFFD0BF97, 0xFFD0BF98, 0xFFD0BF98, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBE96, 
        0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCDBD93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 
        0xFFCCBA90, 0xFFCBBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 
        0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFF897C5D, 0xFF100E0B, 0xFF000000, 0xFF2B271D, 0xFFB09F76, 0xFFC5B284, 0xFFC4B184, 0xFFC4B183, 0xFFC4B183, 0xFF5F553F, 0xFF000000, 0xFF0B0A07, 0xFF8D7E5C, 0xFFC2AF80, 0xFFC3AF80, 0xFF786B4E, 0xFF090806, 
        0xFF000000, 0xFF504734, 0xFFBBA879, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 
        0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06B, 0xFF8D7C53, 0xFF0A0906, 0xFF000000, 0xFF231F14, 0xFFA38F5E, 0xFFB49D68, 
        0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFA68F57, 
        0xFF483E26, 0xFF9D8652, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF947E48, 0xFF141109, 0xFF000000, 0xFF121009, 0xFF6B5B33, 0xFFA58C4F, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894C, 0xFFA3894B, 0xFF5C4D2A, 0xFF000000, 0xFF372E18, 0xFF9D8346, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8240, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B,
  0xFF997D3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8141, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8445, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 
        0xFF736033, 0xFF070603, 0xFF0A0804, 0xFF9C8347, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48A4C, 0xFF998148, 0xFF453A20, 0xFF010100, 0xFF000000, 0xFF2A2414, 0xFF9D864C, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 
        0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9358, 0xFF4D4228, 0xFF000000, 0xFF000000, 0xFF473D25, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB09962, 
        0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06B, 0xFFB49E6A, 0xFFB19C69, 0xFFB19B69, 0xFFA48F61, 0xFF7C6D4A, 
        0xFF4D452F, 0xFF19170F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF211D14, 0xFFB8A372, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFC0AB7B, 0xFF685D43, 0xFF040402, 0xFF000000, 0xFF574E38, 0xFFBBA87A, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF8E7F5D, 0xFF090806, 0xFF000000, 0xFF413A2B, 0xFF877959, 0xFF0D0C09, 0xFF000000, 0xFF221F17, 
        0xFFA99971, 0xFFC5B284, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88C, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBD93, 
        0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBD94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 
        0xFFD0C097, 0xFFD0C097, 0xFFD0BF98, 0xFFD0C097, 0xFFD0C097, 0xFFD0C098, 0xFFD0C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 
        0xFFD1C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0C098, 0xFFD0BF97, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BE96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB88D, 0xFFCAB98D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 
        0xFFC7B488, 0xFFC6B386, 0xFF645B44, 0xFF000000, 0xFF000000, 0xFF453E2E, 0xFFC3B082, 0xFFC5B284, 0xFFC5B184, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC3B082, 0xFF4A4331, 0xFF000000, 0xFF090806, 0xFF9D8E67, 0xFF837656, 0xFF010100, 0xFF000000, 
        0xFF413A2A, 0xFFC1AD7D, 0xFFC0AD7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 
        0xFFBBA673, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFF64583B, 0xFF000000, 0xFF000000, 0xFF4A412B, 0xFFB19B65, 
        0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955B, 0xFFAD955B, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFF55482A, 0xFF000000, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF262012, 0xFF8A7441, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF9B8347, 0xFF0A0804, 0xFF070603, 0xFF746233, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 
        0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997D3A,
  0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 
        0xFFA18748, 0xFF292212, 0xFF000000, 0xFF544626, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFF977F47, 0xFF63532E, 0xFF110E08, 0xFF000000, 0xFF000000, 0xFF16120A, 0xFF000000, 0xFF716037, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA98F54, 0xFFA99054, 
        0xFFA99055, 0xFFAA9156, 0xFFAA9256, 0xFFAA9257, 0xFFAB9358, 0xFFA48D55, 0xFF14110A, 0xFF000000, 0xFFA18B54, 0xFFAC945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 
        0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB29B67, 0xFF9F8C5C, 0xFF8B7A51, 0xFF786A46, 0xFF5B5035, 0xFF362F20, 0xFF13110B, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1E1B12, 0xFFB19C6D, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF6C6146, 0xFF060604, 0xFF000000, 0xFF524935, 0xFFB8A578, 0xFFC1AD7E, 0xFFC2AE7E, 0xFF9B8B65, 0xFF100F0A, 0xFF000000, 0xFF3A3426, 0xFFBFAD7E, 0xFFC3B081, 0xFFA2916B, 0xFF2B271D, 0xFF000000, 
        0xFF0D0B08, 0xFF827557, 0xFFC4B183, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 
        0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCEBE95, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF96, 0xFFCFBE96, 0xFFCFBE96, 
        0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C098, 0xFFD0BF97, 0xFFD0C097, 0xFFD0BF97, 0xFFD0C097, 0xFFD0C097, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0C097, 
        0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF97, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBF96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCFBE95, 
        0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA8F, 
        0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC9B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B488, 0xFFC6B488, 
        0xFFAE9E76, 0xFF453E2E, 0xFF000000, 0xFF060604, 0xFF645A43, 0xFFC5B285, 0xFFC5B284, 0xFFC5B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC3B081, 0xFF413A2A, 0xFF000000, 0xFF0A0906, 0xFF010100, 0xFF000000, 0xFF504834, 
        0xFFC1AD7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 
        0xFFBBA573, 0xFFBAA472, 0xFFBAA471, 0xFFB9A471, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 0xFF473E29, 0xFF000000, 0xFF000000, 0xFF695C3C, 
        0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 0xFFAF985F, 0xFFAE975F, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F52, 0xFF937E48, 0xFF000000, 0xFF221D10, 0xFF806D3E, 0xFF38301B, 0xFF0B0905, 0xFF000000, 0xFF000000, 
        0xFF443920, 0xFF88723F, 0xFFA48A4C, 0xFFA3894B, 0xFF534626, 0xFF000000, 0xFF292212, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA08646, 0xFFA08545, 0xFFA08544, 0xFF9F8445, 0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9D8341, 0xFF9D8241, 0xFF9D8240, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A,
  0xFF997D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 
        0xFFA18747, 0xFF87703C, 0xFF000000, 0xFF18140B, 0xFF947C44, 0xFFA3894B, 0xFF6C5B31, 0xFF1F1A0E, 0xFF000000, 0xFF000000, 0xFF19150B, 0xFF6C5B33, 0xFF877240, 0xFF0C0A06, 0xFF100D07, 0xFFA58C50, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 
        0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFF6A5B37, 0xFF000000, 0xFFA18B54, 0xFFAC945A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09861, 
        0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFF8D7C50, 0xFF695C3C, 0xFF453C27, 0xFF292418, 0xFF1A170F, 0xFF0A0906, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF2A2518, 0xFF524830, 
        0xFF746645, 0xFF0C0A07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF17140E, 0xFF9B895F, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA78, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB79, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF867755, 0xFF0A0906, 0xFF000000, 0xFF342E21, 0xFFB4A276, 0xFFAA986F, 0xFF17150F, 0xFF000000, 0xFF363123, 0xFFB5A477, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFB6A479, 0xFF544C38, 
        0xFF000000, 0xFF020201, 0xFF4A4332, 0xFFBBA97D, 0xFFC5B285, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD95, 0xFFCEBE94, 0xFFCFBE94, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFD0BF96, 0xFFCFBF96, 0xFFCFBF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BF96, 0xFFD0BE96, 0xFFD0BF96, 0xFFD0BF96, 0xFFCFBE96, 
        0xFFCFBE96, 0xFFD0BE96, 0xFFD0BE96, 0xFFCFBF96, 0xFFCFBF96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCFBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 
        0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFF877A5B, 
        0xFF1B1812, 0xFF000000, 0xFF1D1A13, 0xFF938563, 0xFFC5B284, 0xFFC5B284, 0xFFC5B183, 0xFFC4B183, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC3AF80, 0xFFAA9870, 0xFF191710, 0xFF000000, 0xFF000000, 0xFF635941, 0xFFBFAB7C, 
        0xFFC1AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA875, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 
        0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFAD9864, 0xFF322B1C, 0xFF000000, 0xFF030302, 
        0xFF7C6C46, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 
        0xFFAC9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF252012, 0xFF000000, 0xFF3B321C, 0xFFA68C50, 0xFFA68C4F, 0xFF806C3D, 0xFF2F2816, 0xFF000000, 
        0xFF000000, 0xFF100D07, 0xFF4A3E22, 0xFF87713E, 0xFF18140B, 0xFF000000, 0xFF87713C, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 
        0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A,
  0xFF997C39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08546, 0xFFA08646, 0xFFA08647, 
        0xFFA18748, 0xFFA18748, 0xFF40361D, 0xFF000000, 0xFF4C4123, 0xFF262011, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF483D22, 0xFF9D844A, 0xFFA58C4F, 0xFF957D46, 0xFF201B0F, 0xFF000000, 0xFF483D23, 0xFFA78E51, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFA18A53, 0xFF1C180F, 0xFF675836, 0xFFAC945A, 0xFFAD945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965C, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 
        0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFA7915C, 0xFF837249, 0xFF53482F, 0xFF211D13, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A07, 0xFF342E1E, 0xFF64573A, 0xFF988558, 0xFFB29C68, 0xFFB69F6B, 0xFFB59F6B, 
        0xFF423A27, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070704, 0xFF83734F, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 
        0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF8C7D59, 0xFF090806, 0xFF000000, 0xFF242017, 0xFF18150F, 0xFF000000, 0xFF252218, 0xFFAE9C72, 0xFFC2AF7F, 0xFFC2AF80, 0xFFC3AF80, 0xFFC3B081, 0xFFC3B081, 0xFFC3B082, 
        0xFF776A4F, 0xFF000000, 0xFF000000, 0xFF1B1912, 0xFFA99871, 0xFFC5B285, 0xFFC6B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 
        0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 
        0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE95, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 0xFFCFBE96, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE96, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD94, 0xFFCFBD95, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 
        0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 
        0xFFCBB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC3B084, 0xFF5E5540, 0xFF030302, 
        0xFF000000, 0xFF000000, 0xFF443E2E, 0xFFC5B284, 0xFFC5B284, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF81, 0xFFC2AF80, 0xFFBFAB7D, 0xFF49412F, 0xFF000000, 0xFF000000, 0xFF655A42, 0xFFC1AD7D, 0xFFC0AC7D, 
        0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFF968356, 0xFF14110B, 0xFF000000, 
        0xFF16130C, 0xFF998557, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE975D, 0xFFAE965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC935A, 
        0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF695933, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF141109, 0xFF746237, 0xFFA58C4E, 0xFFA48B4D, 0xFF736136, 
        0xFF100D07, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF000000, 0xFF41361D, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 
        0xFF9C813F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39,
  0xFF987C39, 0xFF997D39, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 
        0xFFA18647, 0xFFA18748, 0xFF947C43, 0xFF070603, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF302816, 0xFF887240, 0xFFA48A4D, 0xFF947D46, 0xFF544728, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF887342, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 
        0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFF72623B, 0xFF050402, 0xFF887648, 0xFFAC955A, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAC955D, 0xFFA18B57, 0xFF938050, 0xFF857349, 
        0xFF665838, 0xFF3E3622, 0xFF1A160E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0C08, 0xFF1C1910, 0xFF2C2619, 0xFF4D432C, 0xFF766743, 0xFF9C885A, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFF64593B, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF665A3D, 0xFFB9A370, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA573, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 
        0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFC0AB7B, 0xFF94845F, 0xFF18150F, 0xFF000000, 0xFF000000, 0xFF0B0A07, 0xFFA8976E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AF7F, 0xFFC2AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFC3B081, 
        0xFFC4B082, 0xFFA2916B, 0xFF262219, 0xFF000000, 0xFF000000, 0xFF6F644A, 0xFFBBA97D, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC6B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 
        0xFFC9B68A, 0xFFC8B68B, 0xFFC9B68B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCBBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 
        0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCFBD94, 
        0xFFCEBD94, 0xFFCEBE94, 0xFFCEBD94, 0xFFCEBD95, 0xFFCFBD95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCFBE95, 0xFFCEBE95, 
        0xFFCFBE95, 0xFFCFBE95, 0xFFCFBD95, 0xFFCFBD95, 0xFFCFBD95, 0xFFCEBD94, 0xFFCFBE94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBD93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC93, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFA4946F, 0xFF353024, 0xFF000000, 0xFF0A0906, 
        0xFF4B4433, 0xFF191711, 0xFF000000, 0xFF70654B, 0xFFC4B184, 0xFFC4B183, 0xFFC4B182, 0xFFC4B082, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFAE9C72, 0xFF363023, 0xFF000000, 0xFF0B0A07, 0xFF796C4F, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA571, 
        0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFF726341, 0xFF020101, 
        0xFF000000, 0xFF38311F, 0xFFAC9660, 0xFFB19B63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9459, 
        0xFFAB9359, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFF9A834B, 0xFF1C170D, 0xFF010100, 0xFF493E23, 0xFF1A160C, 0xFF000000, 0xFF000000, 0xFF332B18, 0xFF826D3D, 0xFFA48A4C, 
        0xFF9E8549, 0xFF483C21, 0xFF0E0B06, 0xFF000000, 0xFF060503, 0xFF957C42, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFF9F8544, 0xFF9F8444, 0xFF9F8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 
        0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997C39,
  0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 
        0xFFA08646, 0xFFA18647, 0xFFA08647, 0xFF504324, 0xFF000000, 0xFF030301, 0xFF746235, 0xFFA3894B, 0xFFA48A4C, 0xFF5B4C2A, 0xFF18140B, 0xFF000000, 0xFF000000, 0xFF352D19, 0xFF4E4225, 0xFF000000, 0xFF2E2716, 0xFFA1884F, 0xFFA78E52, 0xFFA88F53, 
        0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9258, 0xFFAB9258, 0xFF302A19, 0xFF060503, 0xFF4A3F26, 0xFF71623B, 0xFF7F6D43, 0xFF7A6940, 0xFF6A5B38, 0xFF50452B, 0xFF37301E, 0xFF251F13, 0xFF0F0D08, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF1D1910, 0xFF3B3321, 0xFF5D5134, 0xFF796944, 0xFF8D7A50, 0xFFA38E5C, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F6A, 0xFFB6A06A, 0xFF746644, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF61553A, 0xFFB8A26F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBDA877, 
        0xFFBDA877, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFA49269, 0xFF2D291D, 0xFF000000, 0xFF0C0A07, 0xFF7B6E4F, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AF80, 0xFFC3AF81, 
        0xFFC3AF81, 0xFFC3B081, 0xFFB6A479, 0xFF605640, 0xFF040403, 0xFF000000, 0xFF322D21, 0xFF9B8C68, 0xFFC5B284, 0xFFC5B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 
        0xFFC8B689, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88E, 0xFFCAB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCCBA8F, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBD93, 
        0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD95, 0xFFCEBD94, 
        0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBD94, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB91, 
        0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B88C, 
        0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC2B084, 0xFF655B44, 0xFF0E0D09, 0xFF000000, 0xFF27231A, 0xFF918361, 
        0xFFC5B284, 0xFF7C6F53, 0xFF030302, 0xFF030202, 0xFF8D7F5D, 0xFFC4B082, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC2AF80, 0xFFC2AF80, 0xFF978763, 0xFF201D15, 0xFF000000, 0xFF15120D, 0xFF8F805C, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 
        0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBBA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 
        0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFF5B5033, 
        0xFF000000, 0xFF000000, 0xFF51472D, 0xFFB19A63, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 
        0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFF5A4C2C, 0xFF000000, 0xFF2E2716, 0xFFA68D50, 0xFF957D46, 0xFF4E4225, 0xFF040302, 0xFF000000, 0xFF090804, 0xFF41371E, 
        0xFF8D7741, 0xFFA3894B, 0xFF282212, 0xFF000000, 0xFF514424, 0xFFA08647, 0xFFA18748, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 
        0xFF9C803E, 0xFF9B803E, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39,
  0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 
        0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF8C753E, 0xFF141109, 0xFF010100, 0xFF7A6737, 0xFF7D6939, 0xFF16120A, 0xFF010100, 0xFF000000, 0xFF0E0B06, 0xFF756237, 0xFFA38A4D, 0xFFA68C4F, 0xFF1A160C, 0xFF000000, 0xFF705F37, 0xFFA78E52, 0xFFA88F52, 
        0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99056, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFF9E8851, 0xFF020101, 0xFF000000, 0xFF040302, 0xFF050402, 0xFF040402, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221D12, 
        0xFF55492E, 0xFF817046, 0xFFA08B58, 0xFFAA935E, 0xFFAC965F, 0xFFB09962, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFF86764E, 0xFF020101, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF4A422C, 0xFFB39E6B, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 
        0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFB5A174, 0xFF363023, 0xFF000000, 0xFF030201, 0xFF62583F, 0xFFC1AD7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AF80, 
        0xFFC3AF80, 0xFFC3B081, 0xFFC3B082, 0xFFAA9971, 0xFF070605, 0xFF000000, 0xFF000000, 0xFF060504, 0xFF5B523D, 0xFFC5B285, 0xFFC5B285, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 
        0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 
        0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBB91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 
        0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD94, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCEBD93, 0xFFCEBD93, 0xFFCEBD93, 
        0xFFCEBD93, 0xFFCEBD93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCEBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 
        0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFFA79872, 0xFF211E16, 0xFF000000, 0xFF000000, 0xFF4F4835, 0xFFBBA97E, 0xFFC5B284, 
        0xFFC5B284, 0xFFC5B183, 0xFF413B2B, 0xFF000000, 0xFF262219, 0xFFB1A075, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC2AF80, 0xFF887A59, 0xFF080705, 0xFF000000, 0xFF15130E, 0xFFAB996F, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 
        0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB09A64, 
        0xFF3E3622, 0xFF000000, 0xFF000000, 0xFF6E603D, 0xFFB19A62, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9358, 
        0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88E53, 0xFF9A834B, 0xFF010100, 0xFF000000, 0xFF040302, 0xFF524527, 0xFFA58C4E, 0xFFA48A4D, 0xFF907944, 0xFF2D2615, 0xFF000000, 0xFF000000, 
        0xFF0C0A05, 0xFF3C321B, 0xFF010100, 0xFF141109, 0xFF8C763E, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFF9F8545, 0xFF9F8545, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9D8341, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 
        0xFF9C803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF987C39, 0xFF987C38,
  0xFF987B38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 
        0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF524525, 0xFF000000, 0xFF080603, 0xFF020201, 0xFF000000, 0xFF0C0A05, 0xFF493D22, 0xFFA48A4C, 0xFFA58B4E, 0xFF877340, 0xFF302816, 0xFF000000, 0xFF000000, 0xFF16130B, 0xFF9F874E, 0xFFA78E52, 
        0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAB9257, 0xFFAB9358, 0xFF5D5030, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0905, 0xFF1F1B10, 0xFF52472C, 0xFF897749, 0xFFAE975E, 0xFFAF975F, 
        0xFFAF985F, 0xFFB09860, 0xFFB09861, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFF978357, 0xFF100E09, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF292418, 0xFFAD9866, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 
        0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEA979, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AC7C, 0xFF4E4632, 0xFF020201, 0xFF000000, 0xFF443D2C, 0xFFB4A276, 0xFFC1AE7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AF7F, 
        0xFFC2AF80, 0xFFC3AF81, 0xFFBDAB7D, 0xFF363124, 0xFF000000, 0xFF1A1711, 0xFF3B3527, 0xFF080705, 0xFF000000, 0xFF262219, 0xFF9C8D69, 0xFFC1AF82, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 
        0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B78A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA91, 0xFFCCBB91, 0xFFCCBA91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBB92, 
        0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBC92, 0xFFCDBC93, 0xFFCEBC93, 0xFFCEBC93, 0xFFCDBC92, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCDBC93, 0xFFCEBC93, 
        0xFFCEBC93, 0xFFCDBC93, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBA91, 0xFFCCBA90, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B68B, 0xFFC9B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B488, 0xFFB8A77E, 0xFF645B43, 0xFF000000, 0xFF000000, 0xFF080705, 0xFF8C7F5E, 0xFFC5B284, 0xFFC5B284, 0xFFC5B183, 
        0xFFC4B183, 0xFFC4B183, 0xFFBCA97C, 0xFF191610, 0xFF000000, 0xFF574E3A, 0xFFC0AC7E, 0xFFC2AF80, 0xFFBDA97C, 0xFF625840, 0xFF000000, 0xFF000000, 0xFF322D21, 0xFFBEAA7B, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7A, 
        0xFFBFAB7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA571, 0xFFB9A470, 0xFFB9A370, 
        0xFFB9A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 
        0xFFA08B5A, 0xFF1D1910, 0xFF000000, 0xFF090704, 0xFF8E7B4E, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE955C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 0xFFAB9258, 
        0xFFAB9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9155, 0xFFA99055, 0xFFA98F54, 0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF2E2716, 0xFF000000, 0xFF110E08, 0xFF020201, 0xFF000000, 0xFF1D190E, 0xFF7B683A, 0xFF9F864A, 0xFFA48A4D, 0xFF6E5D33, 0xFF151109, 
        0xFF010100, 0xFF000000, 0xFF000000, 0xFF524525, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8343, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 
        0xFF9B803D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C38, 0xFF987C38,
  0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7F3B, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 
        0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFF141109, 0xFF000000, 0xFF0A0904, 0xFF3F351D, 0xFF84703D, 0xFFA48A4C, 0xFF887340, 0xFF493E22, 0xFF080703, 0xFF000000, 0xFF000000, 0xFF231E11, 0xFF000000, 0xFF463B22, 0xFFA78E52, 
        0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFF9C8550, 0xFF1C180F, 0xFF000000, 0xFF000000, 0xFF221D12, 0xFF837145, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 
        0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFA89461, 0xFF262216, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF1D1911, 0xFFA28E5F, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAC7B, 0xFF766A4C, 0xFF0D0C08, 0xFF000000, 0xFF231F17, 0xFF93845F, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFFC2AE7F, 0xFFC2AF7F, 0xFF6E6248, 0xFF000000, 0xFF000000, 0xFF8F815F, 0xFFC4B082, 0xFF887A5A, 0xFF2C281D, 0xFF000000, 0xFF030202, 0xFF514936, 0xFFA6966F, 0xFFC5B284, 0xFFC6B286, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC7B487, 0xFFC7B487, 
        0xFFC7B488, 0xFFC7B587, 0xFFC7B588, 0xFFC8B588, 0xFFC8B689, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68B, 0xFFC8B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCBB98E, 0xFFCBB88E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA91, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 
        0xFFCDBB91, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCDBB91, 0xFFCDBC91, 0xFFCDBC92, 0xFFCDBB92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC91, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 0xFFCDBC92, 
        0xFFCDBC92, 0xFFCDBB92, 0xFFCDBB92, 0xFFCDBB91, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB92, 0xFFCDBB92, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBA90, 0xFFCCBA91, 0xFFCCBA91, 0xFFCCBB90, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCBBA8F, 0xFFCCBA8F, 
        0xFFCCB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCBB98D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68B, 
        0xFFC8B68A, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC8B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFF7C7054, 0xFF262219, 0xFF000000, 0xFF050403, 0xFF000000, 0xFF060604, 0xFFA1916C, 0xFFC5B183, 0xFFC5B183, 0xFFC4B183, 
        0xFFC4B082, 0xFFC4B182, 0xFFC3B082, 0xFF9D8E68, 0xFF090806, 0xFF000000, 0xFF786B4E, 0xFFAE9C72, 0xFF3C3527, 0xFF000000, 0xFF000000, 0xFF5C523B, 0xFFBDA97A, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBDA876, 0xFFBCA875, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 
        0xFFB19A63, 0xFF827148, 0xFF040402, 0xFF000000, 0xFF252114, 0xFFA58F5A, 0xFFB0975F, 0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 
        0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF655631, 0xFF000000, 0xFF2B2515, 0xFF967F48, 0xFF61522F, 0xFF1A160C, 0xFF000000, 0xFF000000, 0xFF362E19, 0xFF85703D, 0xFFA38A4C, 0xFF9B8247, 
        0xFF382F19, 0xFF000000, 0xFF151209, 0xFFA08647, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803D, 
        0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF977B38,
  0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8242, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8445, 
        0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF816C39, 0xFF000000, 0xFF110E08, 0xFF9B8246, 0xFFA3894B, 0xFF564928, 0xFF100D07, 0xFF000000, 0xFF000000, 0xFF262012, 0xFF84703F, 0xFF937C46, 0xFF1D190E, 0xFF000000, 0xFF77653A, 
        0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFAA9155, 0xFFAA9157, 0xFFAA9257, 0xFFAA9258, 0xFF645633, 0xFF020201, 0xFF050402, 0xFF6F5F3A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 
        0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB19A61, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFFB29B65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFF2B2518, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF0C0A07, 0xFF9F8B5D, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB9A36F, 0xFFB8A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFF9E8E65, 0xFF15130E, 0xFF000000, 0xFF090805, 0xFF6D6247, 0xFFC1AD7E, 0xFFC2AE7E, 
        0xFFC2AE7F, 0xFFA08F69, 0xFF040402, 0xFF000000, 0xFF706449, 0xFFC3B080, 0xFFC3B081, 0xFFC3B082, 0xFFB6A479, 0xFF6D6248, 0xFF010101, 0xFF000000, 0xFF100E0A, 0xFF605740, 0xFFC5B284, 0xFFC6B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 
        0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 
        0xFFCCBA90, 0xFFCCBA91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCDBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 
        0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 
        0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC6B588, 0xFFC7B487, 0xFFC6B487, 0xFF9F8F6C, 0xFF2C281D, 0xFF040403, 0xFF000000, 0xFF322E22, 0xFF9F8F6B, 0xFF3D3728, 0xFF000000, 0xFF1E1B14, 0xFFC4B183, 0xFFC4B183, 0xFFC4B182, 
        0xFFC3B082, 0xFFC3B082, 0xFFC3AF81, 0xFFC3AF81, 0xFF6F6449, 0xFF000000, 0xFF080705, 0xFF17150F, 0xFF000000, 0xFF030201, 0xFF897B59, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA472, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B63, 
        0xFFB19A63, 0xFFB19A63, 0xFF685B39, 0xFF000000, 0xFF000000, 0xFF3F3723, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9257, 
        0xFFAA9157, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF917B47, 0xFF15120A, 0xFF000000, 0xFF857140, 0xFFA68C50, 0xFFA58C4F, 0xFF967F46, 0xFF564828, 0xFF000000, 0xFF000000, 0xFF0C0A05, 0xFF44391F, 0xFF977F44, 
        0xFF1A160B, 0xFF000000, 0xFF826C3A, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803D, 
        0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997C3A, 0xFF987C39, 0xFF987C38, 0xFF987B37,
  0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF9A7D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 
        0xFF9F8544, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18748, 0xFFA18748, 0xFF3F351C, 0xFF000000, 0xFF3C331B, 0xFF1A160C, 0xFF000000, 0xFF000000, 0xFF0C0A06, 0xFF5F512C, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF6D5C34, 0xFF020201, 0xFF1B170D, 
        0xFF9E864C, 0xFFA78E53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFF1C180E, 0xFF090804, 0xFF847045, 0xFFAC945B, 0xFFAC955B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFF3E3623, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080704, 
        0xFF86764E, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFC0AB7B, 0xFFBEAA7A, 0xFF383224, 0xFF000000, 0xFF000000, 0xFF3D3627, 0xFFB7A477, 
        0xFFC0AD7D, 0xFF1C1912, 0xFF000000, 0xFF3C3627, 0xFFC2AF80, 0xFFC3AF80, 0xFFC3B081, 0xFFC3B081, 0xFFC3B082, 0xFFC3B082, 0xFFAF9E74, 0xFF0E0D09, 0xFF000000, 0xFF000000, 0xFF13110C, 0xFF8E805F, 0xFFC1AE82, 0xFFC6B285, 0xFFC6B386, 0xFFC6B386, 
        0xFFC6B486, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB78C, 
        0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCBB88E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCCBA8F, 0xFFCBBA90, 0xFFCBBA90, 0xFFCCBA8F, 
        0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBB91, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCCBA90, 0xFFCCBB90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 
        0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC7B488, 0xFFC5B386, 0xFFB9A87E, 0xFF534B38, 0xFF000000, 0xFF000000, 0xFF070705, 0xFF000000, 0xFF47402F, 0xFFC3B082, 0xFF9C8D69, 0xFF0A0907, 0xFF000000, 0xFF6C6148, 0xFFC3B082, 0xFFC4B082, 
        0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC2AF80, 0xFFAF9E73, 0xFF252118, 0xFF000000, 0xFF000000, 0xFF201D15, 0xFFAB996E, 0xFFC0AD7D, 0xFFC0AD7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAC7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBEA979, 
        0xFFBEA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19961, 0xFFB09961, 0xFF443B25, 0xFF000000, 0xFF000000, 0xFF5E5133, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAB935A, 0xFF9B8652, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 
        0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA68C51, 0xFF493E24, 0xFF000000, 0xFF4C4025, 0xFFA68D50, 0xFFA68C4F, 0xFFA58B4F, 0xFFA58C4E, 0xFFA48B4D, 0xFF907943, 0xFF2B2414, 0xFF010100, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF40351C, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9C8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803D, 0xFF9B7F3D, 
        0xFF9B7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF987D39, 0xFF987C39, 0xFF987B38, 0xFF977B37,
  0xFF977B37, 0xFF977B38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 
        0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF89723C, 0xFF0E0C06, 0xFF000000, 0xFF000000, 0xFF0F0D07, 0xFF453A20, 0xFF937C44, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF372F1A, 0xFF000000, 
        0xFF554829, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9258, 0xFF867345, 0xFF020101, 0xFF6D5D38, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09861, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB19A64, 0xFF5C5034, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF675A3B, 
        0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA571, 0xFFBAA573, 0xFFBBA673, 0xFFBBA673, 
        0xFFBBA675, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA877, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AB7B, 0xFF675C42, 0xFF0A0906, 0xFF000000, 0xFF252118, 
        0xFF3E3728, 0xFF000000, 0xFF1E1B13, 0xFFA9986F, 0xFFC2AF7F, 0xFFC2AF80, 0xFFC2AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFC3B082, 0xFF928360, 0xFF000000, 0xFF060504, 0xFF1F1C15, 0xFF000000, 0xFF000000, 0xFF373225, 0xFF8B7D5D, 0xFFC1AE82, 0xFFC5B385, 
        0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC8B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 
        0xFFC9B88C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBBA8F, 
        0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 0xFFCCBA90, 
        0xFFCCBA90, 0xFFCCBA8F, 0xFFCCBA8F, 0xFFCBBA90, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCCBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88E, 0xFFCAB98D, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B588, 
        0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFAC9C75, 0xFF685E46, 0xFF0B0A07, 0xFF000000, 0xFF000000, 0xFF4F4835, 0xFF998A67, 0xFF0D0C09, 0xFF000000, 0xFF857858, 0xFFC4B183, 0xFF4F4835, 0xFF000000, 0xFF13110C, 0xFFAC9B71, 0xFFC3B081, 
        0xFFC3AF81, 0xFFC2AF80, 0xFFC2AF80, 0xFF9C8D67, 0xFF3B3526, 0xFF000000, 0xFF000000, 0xFF4B4331, 0xFFB4A174, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBEA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 
        0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFA7915B, 0xFF262115, 0xFF000000, 0xFF000000, 0xFF6C5E3A, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFF584C2E, 0xFF100E08, 0xFFA38D54, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 
        0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF7F6C3E, 0xFF000000, 0xFF1D190E, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFF6F5E33, 0xFF151209, 0xFF000000, 
        0xFF0D0B06, 0xFF89723C, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 
        0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37,
  0xFF967A36, 0xFF977B37, 0xFF977B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8240, 0xFF9D8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 
        0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF4E4122, 0xFF000000, 0xFF100D07, 0xFF826D3C, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFF9E854C, 0xFF120F08, 
        0xFF010100, 0xFF8C7744, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFF54482B, 0xFF73633C, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 
        0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF985F, 0xFFAF975F, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFB19A63, 0xFFB19A64, 0xFF7A6A45, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5D5135, 0xFFB49E68, 
        0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 
        0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFB9A573, 0xFFAD9A6C, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFC0AB7B, 0xFF9B8A63, 0xFF262218, 0xFF000000, 
        0xFF000000, 0xFF030201, 0xFF827555, 0xFFC1AE7E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AF80, 0xFFBAA77B, 0xFF242118, 0xFF000000, 0xFF3B3526, 0xFFB19F75, 0xFF665C43, 0xFF000000, 0xFF000000, 0xFF060604, 0xFF302B20, 0xFF8A7C5C, 
        0xFFC5B285, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 
        0xFFC9B68B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCBB88D, 0xFFCAB98D, 0xFFCAB88E, 0xFFCAB98E, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBB98F, 0xFFCBBA8F, 0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98F, 0xFFCBB98F, 
        0xFFCBB98F, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB98E, 0xFFCAB88E, 0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB78C, 
        0xFFCAB88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B488, 
        0xFFC7B487, 0xFFC7B487, 0xFFB8A67C, 0xFF58503B, 0xFF17150F, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF000000, 0xFF7A6E51, 0xFFC5B184, 0xFF635942, 0xFF000000, 0xFF100F0B, 0xFFBCA97C, 0xFFAD9B73, 0xFF0D0B08, 0xFF000000, 0xFF5B523C, 0xFFC0AD7E, 
        0xFFC2AF80, 0xFFC2AF7F, 0xFF665C43, 0xFF12100B, 0xFF000000, 0xFF100E0A, 0xFF877957, 0xFFBEAA7B, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 
        0xFFBDA977, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA371, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 
        0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 
        0xFFB09962, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFF8E7B4D, 0xFF0A0905, 0xFF000000, 0xFF060503, 0xFF5D5031, 0xFFA9925A, 0xFF97824F, 0xFF3F3621, 0xFF000000, 0xFF655734, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 
        0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA38A50, 0xFF0F0C07, 0xFF040302, 0xFF816E3E, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA3894B, 0xFFA1874A, 0xFF1F1A0E, 0xFF000000, 
        0xFF4E4223, 0xFFA18748, 0xFFA18748, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9A7F3C, 
        0xFF9A7F3C, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36,
  0xFF977A36, 0xFF977B36, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 
        0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF9F8547, 0xFF110E08, 0xFF010100, 0xFF63532C, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF79663A, 
        0xFF000000, 0xFF16130B, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB935A, 0xFFAC945A, 0xFFAC955B, 0xFFAD955B, 0xFFAD955C, 
        0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFF907D50, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF443B27, 0xFFB49D67, 0xFFB49E67, 
        0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6B, 0xFFB6A06B, 0xFFB6A16B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 
        0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA775, 0xFF766949, 0xFF050503, 0xFF7C6E4D, 0xFFBAA675, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFBBA778, 0xFF4D4532, 
        0xFF010100, 0xFF000000, 0xFF1A1711, 0xFF9B8B65, 0xFFC1AC7D, 0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF71664A, 0xFF020201, 0xFF060504, 0xFF8E805E, 0xFFC4B082, 0xFF231F17, 0xFF000000, 0xFF1D1B14, 0xFF080705, 0xFF000000, 0xFF000000, 
        0xFF262219, 0xFF9C8D69, 0xFFC5B285, 0xFFC6B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC6B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC8B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 
        0xFFC8B68A, 0xFFC9B68A, 0xFFC9B78A, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98D, 
        0xFFCAB98E, 0xFFCBB98D, 0xFFCBB88E, 0xFFCAB98E, 0xFFCAB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 
        0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCBB98E, 0xFFCAB88E, 0xFFCAB88E, 0xFFCAB98D, 0xFFCBB98D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B88C, 0xFFC9B88C, 0xFFC9B78C, 0xFFC9B78C, 
        0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC7B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC6B488, 0xFFC7B487, 
        0xFFBFAE82, 0xFF645A43, 0xFF080705, 0xFF000000, 0xFF000000, 0xFF2D291E, 0xFFA99972, 0xFF6A6047, 0xFF000000, 0xFF0E0D09, 0xFFC2AF81, 0xFFAC9B73, 0xFF1B1812, 0xFF000000, 0xFF524A37, 0xFFC3B081, 0xFF6B6046, 0xFF000000, 0xFF090806, 0xFFA8976E, 
        0xFFB4A176, 0xFF342F22, 0xFF000000, 0xFF000000, 0xFF2C281D, 0xFFAE9C70, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 
        0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBBA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB09A62, 0xFFB09961, 
        0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFF6B5D3A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1F1B10, 0xFFAC9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 
        0xFFA99055, 0xFFA89054, 0xFFA89053, 0xFFA88F53, 0xFFA88E52, 0xFF332B19, 0xFF000000, 0xFF483D22, 0xFFA68D50, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF62522D, 0xFF010100, 0xFF110E08, 
        0xFFA18648, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 
        0xFF9A7E3C, 0xFF997D3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987B37, 0xFF977B36, 0xFF977A36,
  0xFF967A36, 0xFF977A36, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9D8140, 0xFF9C8240, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8343, 
        0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF7B6837, 0xFF000000, 0xFF16120A, 0xFF937B43, 0xFFA3894B, 0xFFA4894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA2894D, 
        0xFF3F351E, 0xFF000000, 0xFF483C22, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC945B, 0xFFAD955B, 0xFFAD955B, 
        0xFFAD955D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFB09960, 0xFFB09961, 0xFFB09961, 0xFF978353, 0xFF0B0906, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2F291A, 0xFFAB9561, 0xFFB39D67, 0xFFB49D67, 
        0xFFB49E68, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 
        0xFFBBA572, 0xFFBBA673, 0xFFBBA673, 0xFFBCA674, 0xFFBBA774, 0xFF7C6E4D, 0xFF0A0906, 0xFF342E20, 0xFF92815B, 0xFFBAA575, 0xFFBEA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AC7B, 
        0xFF796D4E, 0xFF1D1A12, 0xFF000000, 0xFF000000, 0xFF60563E, 0xFFAE9C71, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFB2A075, 0xFF1F1C14, 0xFF000000, 0xFF433D2C, 0xFFC3AF81, 0xFF75694D, 0xFF000000, 0xFF0D0C09, 0xFFA1906B, 0xFFB3A177, 0xFF0F0D0A, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF353023, 0xFF897C5C, 0xFFB4A379, 0xFFC5B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B488, 0xFFC7B588, 0xFFC8B589, 0xFFC7B589, 0xFFC8B589, 
        0xFFC8B58A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88D, 
        0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB98E, 0xFFCAB88D, 0xFFCAB88E, 0xFFCBB88D, 0xFFCAB98D, 0xFFCAB98E, 0xFFCBB88E, 0xFFCAB98E, 0xFFCAB88E, 0xFFCAB88E, 0xFFCAB98E, 0xFFCAB88D, 0xFFCBB98D, 0xFFCAB88D, 
        0xFFCAB88E, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB78C, 0xFFC9B88C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68B, 0xFFC8B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B487, 0xFFC7B487, 0xFFC4B285, 0xFFA49470, 0xFF635943, 
        0xFF0A0906, 0xFF000000, 0xFF080705, 0xFF302B20, 0xFF877A5B, 0xFFC5B284, 0xFFC5B284, 0xFFB6A47A, 0xFF1A1711, 0xFF000000, 0xFF504835, 0xFFC4B082, 0xFF695F46, 0xFF000000, 0xFF110F0B, 0xFF9F8F69, 0xFFC3AF81, 0xFF262319, 0xFF000000, 0xFF312C20, 
        0xFF0A0906, 0xFF000000, 0xFF100E0A, 0xFF5F553E, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA876, 
        0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19962, 0xFFB09962, 0xFFB09961, 
        0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFF3D3420, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8C7848, 0xFFAB9359, 0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 
        0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF6C5C35, 0xFF010100, 0xFF18150C, 0xFF9A834A, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA4894C, 0xFFA3894B, 0xFF937B42, 0xFF151209, 0xFF000000, 0xFF7C6838, 
        0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 
        0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977A36, 0xFF977A36,
  0xFF967A35, 0xFF977A35, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 
        0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF4B3F21, 0xFF000000, 0xFF3D331B, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4F, 
        0xFF967F48, 0xFF0E0C07, 0xFF030301, 0xFF746339, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFA99156, 0xFFAA9157, 0xFFAA9258, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 
        0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFA08B58, 0xFF221E13, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF15120C, 0xFF9B8858, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 
        0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A16E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFF817350, 0xFF020201, 0xFF060504, 0xFF423B29, 0xFFA18F64, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 0xFFBFAB7B, 
        0xFFBFAB7B, 0xFFAA996D, 0xFF554C36, 0xFF000000, 0xFF000000, 0xFF201D15, 0xFF796C4F, 0xFFC1AE7E, 0xFF6C6146, 0xFF000000, 0xFF0C0B08, 0xFFB4A276, 0xFFB09F74, 0xFF1E1B14, 0xFF000000, 0xFF4E4734, 0xFFC3B081, 0xFF72674C, 0xFF000000, 0xFF0D0B08, 
        0xFF605640, 0xFF1E1B14, 0xFF000000, 0xFF000000, 0xFF28241A, 0xFF5F5640, 0xFFAB9A73, 0xFFC6B385, 0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC6B387, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 
        0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B689, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 
        0xFFC9B88C, 0xFFC9B78C, 0xFFCAB88C, 0xFFCAB78C, 0xFFCAB78C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88D, 0xFFCAB88C, 0xFFC9B88C, 0xFFCAB88D, 0xFFCAB88D, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 
        0xFFC9B88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFCAB88C, 0xFFC9B88C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC8B68B, 0xFFC9B68A, 0xFFC9B68A, 
        0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 0xFFC6B486, 0xFF86795A, 0xFF413A2C, 0xFF100E0B, 0xFF000000, 
        0xFF000000, 0xFF090806, 0xFF7C7053, 0xFFC1AE81, 0xFFC5B184, 0xFFC5B184, 0xFFC4B183, 0xFFC4B183, 0xFF6B6147, 0xFF010101, 0xFF080705, 0xFF998A65, 0xFFC3B081, 0xFF211E16, 0xFF000000, 0xFF4C4432, 0xFFC2AE7F, 0xFF6E6248, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF3B3426, 0xFF9C8C65, 0xFFC0AC7D, 0xFFC0AD7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA776, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19962, 0xFFB19962, 0xFFB09961, 0xFFB09860, 
        0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFF9E8854, 0xFF0C0B06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF483E25, 0xFFAA9258, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 
        0xFFA88F54, 0xFFA88F53, 0xFFA78F53, 0xFF97814A, 0xFF16130B, 0xFF000000, 0xFF84703F, 0xFFA68D50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894A, 0xFF3C331B, 0xFF000000, 0xFF4B3F22, 0xFFA28748, 
        0xFFA18748, 0xFFA18647, 0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8343, 0xFF9E8342, 0xFF9D8341, 0xFF9D8241, 0xFF9C8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35,
  0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8342, 
        0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF917940, 0xFF1B160C, 0xFF000000, 0xFF705E33, 0xFFA3894A, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 
        0xFFA68C4F, 0xFF7E6B3C, 0xFF000000, 0xFF1E190E, 0xFF99824B, 0xFFA88E52, 0xFFA78F52, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9157, 0xFFAA9157, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9459, 0xFFAC945A, 0xFFAC945A, 
        0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFAF9860, 0xFFAF9860, 0xFF362F1D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF9E8958, 0xFFB29B64, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 
        0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A471, 
        0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFF1F1C13, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF594F37, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBEAB7A, 
        0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFF94845F, 0xFF110F0B, 0xFF000000, 0xFF000000, 0xFF312C1F, 0xFF090805, 0xFF000000, 0xFF6E6348, 0xFFC2AE7F, 0xFF685E44, 0xFF000000, 0xFF070605, 0xFFBAA77A, 0xFFB1A075, 0xFF0E0D09, 0xFF000000, 0xFF564D39, 
        0xFFC0AE7F, 0xFFBCAA7D, 0xFF827657, 0xFF1A1711, 0xFF000000, 0xFF000000, 0xFF060504, 0xFF3A3527, 0xFF9C8D69, 0xFFC5B385, 0xFFC6B385, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 
        0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B58A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B68A, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78B, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFCAB78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 0xFFC9B78C, 
        0xFFC9B78C, 0xFFC9B78C, 0xFFCAB78C, 0xFFC9B78B, 0xFFC9B78C, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78A, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B68A, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 
        0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC2B083, 0xFF70654C, 0xFF1A1711, 0xFF040403, 0xFF000000, 0xFF010101, 0xFF544C38, 
        0xFF27231A, 0xFF000000, 0xFF766B4F, 0xFFC4B184, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC4B082, 0xFFBAA87C, 0xFF1C1912, 0xFF000000, 0xFF3A3426, 0xFFBEAA7C, 0xFF9F8F68, 0xFF000000, 0xFF030302, 0xFF393325, 0xFF020201, 0xFF000000, 0xFF010100, 
        0xFF7A6D4F, 0xFFBFAC7C, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA877, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 
        0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 
        0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE955D, 0xFFAB935B, 0xFF52462B, 0xFF000000, 0xFF000000, 0xFF120F09, 0xFF8D7949, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 
        0xFFA88F54, 0xFFA88F53, 0xFFA78E52, 0xFF3A321C, 0xFF000000, 0xFF61522F, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF705E33, 0xFF000000, 0xFF1B170C, 0xFF917940, 0xFFA18748, 
        0xFFA18747, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8443, 0xFF9E8443, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF9A7E3A, 0xFF997C39, 0xFF987D39, 0xFF987C39, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF967A35, 0xFF967935,
  0xFF967934, 0xFF967935, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 
        0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF66552D, 0xFF030201, 0xFF0C0A05, 0xFF967E44, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58C4F, 0xFFA68D4F, 0xFF4E4225, 0xFF000000, 0xFF4A3E24, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 
        0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF985F, 0xFF493F27, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040402, 0xFF86754B, 0xFFB29A63, 0xFFB29B64, 0xFFB29B65, 0xFFB39B65, 0xFFB39C66, 
        0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F69, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 
        0xFFBAA471, 0xFFB9A471, 0xFFBAA571, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFF272318, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF18150F, 0xFF877955, 0xFFB5A272, 0xFFBEA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAA79, 
        0xFFBEAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFC0AC7B, 0xFFC0AC7C, 0xFF534A35, 0xFF0B0A07, 0xFF000000, 0xFF000000, 0xFF17150F, 0xFFA2926A, 0xFFB2A075, 0xFF100F0A, 0xFF000000, 0xFF776B4E, 0xFFC2AF80, 0xFF544C37, 0xFF000000, 0xFF13110C, 0xFFA4946C, 
        0xFFC3B082, 0xFFC3B082, 0xFFC4B082, 0xFFC4B183, 0xFF867959, 0xFF29251B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF262219, 0xFF7D7154, 0xFFAD9C74, 0xFFBFAD80, 0xFFC5B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC7B387, 0xFFC6B487, 0xFFC7B487, 
        0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC9B68A, 0xFFC8B68A, 0xFFC9B68B, 0xFFC9B68A, 
        0xFFC9B68B, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B78B, 
        0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B78B, 0xFFC9B78B, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B68B, 0xFFC9B68A, 0xFFC8B68B, 0xFFC8B68A, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B689, 0xFFC8B589, 
        0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFB7A67C, 0xFF9C8D69, 0xFF534B38, 0xFF030202, 0xFF000000, 0xFF030202, 0xFF171510, 0xFF544C39, 0xFFB09F76, 0xFFC5B284, 
        0xFF908260, 0xFF000000, 0xFF1D1A13, 0xFFC0AD80, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC3B082, 0xFFC3B081, 0xFF827656, 0xFF000000, 0xFF060504, 0xFF8E805D, 0xFFB8A579, 0xFF342F22, 0xFF000000, 0xFF000000, 0xFF060503, 0xFF3B3426, 0xFFB19E72, 
        0xFFC1AD7D, 0xFFC1AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 
        0xFFBBA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB69F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C65, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF985F, 
        0xFFAF985F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFF7A6940, 0xFF030201, 0xFF000000, 0xFF4C4227, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 
        0xFFA88F53, 0xFFA78F52, 0xFF685933, 0xFF000000, 0xFF2E2716, 0xFFA1894D, 0xFFA68C50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF967E44, 0xFF0C0A05, 0xFF030201, 0xFF66562E, 0xFFA18748, 0xFFA18748, 
        0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8341, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 
        0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977A37, 0xFF977A36, 0xFF967A35, 0xFF967935,
  0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA28748, 0xFF322916, 0xFF000000, 0xFF40351D, 0xFFA1874A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA58C4F, 0xFFA0874D, 0xFF2B2515, 0xFF000000, 0xFF665732, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9157, 0xFFAB9358, 0xFFAB9359, 0xFFAB935A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFF594D30, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF6A5B3A, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29C64, 0xFFB39C65, 
        0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB9A36F, 0xFFB9A36F, 
        0xFFB9A470, 0xFFBAA470, 0xFFBAA471, 0xFFBAA472, 0xFFBAA572, 0xFFBAA573, 0xFFA18E63, 0xFF0E0D09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF342E20, 0xFF8A7B57, 0xFFBDA977, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AC7B, 0xFF968661, 0xFF413A2A, 0xFF000000, 0xFF000000, 0xFF252118, 0xFF3D3627, 0xFF000000, 0xFF3B3526, 0xFFC1AE7E, 0xFF9F8F68, 0xFF100F0A, 0xFF000000, 0xFF635941, 0xFFC3AF80, 
        0xFFC3B080, 0xFFC3B082, 0xFFC3B081, 0xFFC4B082, 0xFFC4B082, 0xFF7D7153, 0xFF000000, 0xFF12100C, 0xFF2A261C, 0xFF000000, 0xFF000000, 0xFF100E0A, 0xFF423C2C, 0xFF73684E, 0xFFA69670, 0xFFC6B386, 0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B387, 
        0xFFC6B387, 0xFFC6B487, 0xFFC6B487, 0xFFC6B487, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B68A, 0xFFC8B589, 0xFFC8B689, 0xFFC8B689, 
        0xFFC8B58A, 0xFFC8B689, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68B, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B78A, 0xFFC9B68B, 0xFFC9B78A, 0xFFC8B68B, 0xFFC8B68B, 0xFFC8B68A, 
        0xFFC8B68B, 0xFFC8B68A, 0xFFC9B68A, 0xFFC8B68B, 0xFFC9B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B58A, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B589, 0xFFC7B588, 
        0xFFC7B489, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFBFAD81, 0xFF8D8060, 0xFF59503C, 0xFF29251C, 0xFF000000, 0xFF000000, 0xFF090806, 0xFF433C2D, 0xFF7D7153, 0xFFB5A47A, 0xFFC5B284, 0xFFC5B284, 0xFFC4B183, 
        0xFFC0AE80, 0xFF2A261C, 0xFF000000, 0xFF887A5B, 0xFFC3B082, 0xFFC3B082, 0xFFC3B082, 0xFFC3AF81, 0xFFC3AF81, 0xFFC2AF80, 0xFF3E3829, 0xFF000000, 0xFF252118, 0xFF322D21, 0xFF000000, 0xFF000000, 0xFF2E291D, 0xFF837655, 0xFFC0AD7D, 0xFFC1AD7D, 
        0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBEAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA876, 0xFFBDA876, 0xFFBCA776, 0xFFBCA776, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 
        0xFFBBA673, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 
        0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D68, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFF827044, 0xFF080704, 0xFF110E09, 0xFFA48D55, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 
        0xFFA88F53, 0xFF816E3F, 0xFF050402, 0xFF060503, 0xFF776539, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA18749, 0xFF3F351D, 0xFF000000, 0xFF322A16, 0xFFA18748, 0xFFA18748, 0xFFA18647, 
        0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9A7F3D, 0xFF9B7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 
        0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B38, 0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967935, 0xFF967934,
  0xFF957834, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 
        0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF9A8145, 0xFF080603, 0xFF000000, 0xFF796737, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 
        0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF60512E, 0xFF010100, 0xFF080704, 0xFF836F3F, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFAA9155, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFF71613C, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4C422A, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A26F, 
        0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA472, 0xFF5D5239, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1E1B13, 0xFF5B5138, 0xFF423B29, 0xFF0A0906, 0xFF3D3726, 0xFFB4A171, 0xFFBEA977, 0xFFBEA978, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAC7B, 0xFFB9A677, 0xFF92825E, 0xFF1E1A13, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF6E6348, 0xFFC1AD7E, 0xFF423C2B, 0xFF000000, 0xFF1A1711, 0xFFC2AF7F, 0xFFC2AF80, 
        0xFFC3AF80, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFC0AD7F, 0xFF211E16, 0xFF000000, 0xFF73684C, 0xFFBCAA7D, 0xFF968864, 0xFF47402F, 0xFF010101, 0xFF000000, 0xFF030202, 0xFF0F0D0A, 0xFF2B271C, 0xFF6F644B, 0xFFB7A47B, 0xFFC5B285, 0xFFC6B386, 
        0xFFC6B385, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC7B589, 0xFFC8B589, 
        0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC8B689, 0xFFC8B58A, 0xFFC8B68A, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B58A, 0xFFC8B58A, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B689, 0xFFC8B68A, 0xFFC8B689, 
        0xFFC8B589, 0xFFC8B689, 0xFFC8B689, 0xFFC8B589, 0xFFC8B689, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC7B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 
        0xFFC7B487, 0xFFC6B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B486, 0xFF968865, 0xFF4B4432, 0xFF181610, 0xFF080705, 0xFF000000, 0xFF000000, 0xFF1E1B14, 0xFF73684E, 0xFFAD9D74, 0xFFBEAC7F, 0xFFC4B184, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 
        0xFFC3AF82, 0xFF776B4F, 0xFF000000, 0xFF201C15, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF7F, 0xFF8C7E5C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF090806, 0xFF796D4E, 0xFFB5A275, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 
        0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A370, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F69, 
        0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAF975E, 
        0xFFAE975E, 0xFFAE965E, 0xFFAD965D, 0xFFAE965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFF78673F, 0xFF000000, 0xFF7C6A40, 0xFFAB9358, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 
        0xFF99824B, 0xFF241E11, 0xFF000000, 0xFF000000, 0xFF18150B, 0xFF826E3E, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF7A6637, 0xFF000000, 0xFF080704, 0xFF9B8145, 0xFFA18748, 0xFFA18647, 0xFFA08647, 
        0xFFA08646, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 
        0xFF997D39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934,
  0xFF957833, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 
        0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18646, 0xFFA18648, 0xFFA18748, 0xFF776435, 0xFF000000, 0xFF0F0C06, 0xFF9E8547, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 
        0xFFA58B4D, 0xFFA0884B, 0xFF544727, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF221D10, 0xFF9C854C, 0xFFA78F52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9256, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 
        0xFFAB945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAD955C, 0xFF8D7A4B, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF352E1D, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A16E, 0xFFB7A26E, 0xFFB8A26E, 
        0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFA49164, 0xFF18160F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF373122, 0xFFBBA774, 0xFFBCA775, 0xFFBCA776, 0xFFAD9A6C, 0xFF383223, 0xFF0A0906, 0xFF716547, 0xFFB8A473, 
        0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AC7B, 0xFFC0AC7B, 0xFF62583F, 0xFF0A0906, 0xFF000000, 0xFF000000, 0xFF231F17, 0xFF000000, 0xFF000000, 0xFF968762, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC3AF81, 0xFF8D7E5D, 0xFF000000, 0xFF12100C, 0xFFB9A77B, 0xFFC4B082, 0xFFC4B082, 0xFFC4B183, 0xFFBEAC7F, 0xFF756A4E, 0xFF262219, 0xFF0A0907, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF252219, 0xFF70654B, 
        0xFFAC9B73, 0xFFBBA97E, 0xFFC2AE83, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B588, 
        0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B589, 0xFFC8B589, 0xFFC7B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 0xFFC8B589, 
        0xFFC8B589, 0xFFC7B589, 0xFFC7B589, 0xFFC7B589, 0xFFC8B588, 0xFFC7B589, 0xFFC8B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B488, 0xFFC7B487, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC4B285, 
        0xFFBFAD81, 0xFFB7A67C, 0xFF948664, 0xFF4E4635, 0xFF0C0B08, 0xFF000000, 0xFF000000, 0xFF060504, 0xFF110F0B, 0xFF030302, 0xFF030302, 0xFFAD9C73, 0xFFC5B284, 0xFFC4B284, 0xFFC5B184, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC4B082, 
        0xFFC3B082, 0xFFA99870, 0xFF1B1812, 0xFF000000, 0xFF8A7C5B, 0xFFC3AF80, 0xFFC2AF80, 0xFFBEAC7D, 0xFFA7966D, 0xFF403A2A, 0xFF000000, 0xFF000000, 0xFF050403, 0xFF463F2D, 0xFFB8A577, 0xFFC1AD7C, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAC7B, 
        0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA573, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFB9A471, 0xFFB9A471, 0xFFB9A370, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB6A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB5A06A, 0xFFB59F69, 0xFFB59E69, 
        0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9760, 0xFFAF975F, 0xFFAE975E, 
        0xFFAE965D, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945A, 0xFFAB9359, 0xFF5A4D2F, 0xFF312A19, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA78D51, 
        0xFF4F4326, 0xFF000000, 0xFF312A17, 0xFF1B170D, 0xFF000000, 0xFF000000, 0xFF554828, 0xFFA1874B, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF9E8547, 0xFF0E0C06, 0xFF000000, 0xFF796535, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 
        0xFFA08646, 0xFFA08544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 
        0xFF997C39, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957833,
  0xFF957833, 0xFF957833, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 
        0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFF9F8547, 0xFF42371E, 0xFF000000, 0xFF332B17, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 
        0xFF836F3D, 0xFF2C2514, 0xFF000000, 0xFF010100, 0xFF43381F, 0xFF3B321C, 0xFF000000, 0xFF4A3F24, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFF816E42, 0xFFA28C53, 
        0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFF897648, 0xFF0D0B07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2D2718, 0xFFAA945C, 0xFFAF9860, 0xFFB09860, 0xFFB09960, 0xFFB09962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29A64, 
        0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E68, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A471, 0xFF574D35, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF242016, 0xFFB8A472, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFF857653, 0xFF16130E, 0xFF252017, 
        0xFF7F7150, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFAD9B6F, 0xFF584E38, 0xFF14120D, 0xFF000000, 0xFF000000, 0xFF12100C, 0xFF837655, 0xFFB9A77A, 0xFFC2AE7F, 
        0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AE80, 0xFFC2AF7F, 0xFF242018, 0xFF000000, 0xFF60563F, 0xFFC1AE7F, 0xFFC3B081, 0xFFC3B082, 0xFFC3B082, 0xFFC4B182, 0xFFC4B083, 0xFFC4B182, 0xFFA5956E, 0xFF6E6349, 0xFF433C2D, 0xFF0A0907, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF211E16, 0xFF4E4634, 0xFF766A4F, 0xFF938663, 0xFFB1A077, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B488, 
        0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC8B589, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 
        0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B588, 0xFFC7B488, 0xFFC7B488, 0xFFC7B588, 0xFFC7B488, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFBEAC81, 0xFFA2926D, 0xFF847859, 0xFF635943, 
        0xFF393326, 0xFF0B0A07, 0xFF000000, 0xFF000000, 0xFF090806, 0xFF2D291E, 0xFF554D39, 0xFF8A7C5C, 0xFFBAA87C, 0xFF2D291E, 0xFF000000, 0xFF655A43, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B182, 0xFFC4B182, 0xFFC4B182, 0xFFC3B082, 0xFFC3B081, 
        0xFFC3B081, 0xFFC3AF81, 0xFF4C4432, 0xFF000000, 0xFF322D21, 0xFFBBA97B, 0xFF928460, 0xFF4F4633, 0xFF050403, 0xFF000000, 0xFF090805, 0xFF47402E, 0xFF9B8B64, 0xFFC1AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFC0AB7B, 0xFFBFAB7B, 
        0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 
        0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 
        0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 
        0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFF937E4C, 0xFF9A844F, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF6D5C35, 
        0xFF000000, 0xFF201B0F, 0xFFA28A4E, 0xFF9A8249, 0xFF3C331C, 0xFF000000, 0xFF000000, 0xFF2E2715, 0xFF88723F, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894A, 0xFF332B17, 0xFF000000, 0xFF43381E, 0xFFA08547, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08646, 
        0xFF9F8545, 0xFF9F8445, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF997E3B, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 
        0xFF987C39, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833,
  0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 
        0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF927A41, 0xFF141109, 0xFF000000, 0xFF5B4C29, 0xFFA3894B, 0xFFA3894B, 0xFF62522D, 
        0xFF0E0C06, 0xFF000000, 0xFF070503, 0xFF685831, 0xFFA1894D, 0xFF9C844A, 0xFF231E11, 0xFF000000, 0xFF6A5A33, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA99055, 0xFFA99055, 0xFFA99056, 0xFFAA9156, 0xFFAA9157, 0xFF221D11, 0xFF413721, 
        0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFF7F6D42, 0xFF120F09, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF19150D, 0xFF988452, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB19961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFF9B885D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080704, 0xFF918058, 0xFFBBA573, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFF9A8960, 0xFF070604, 
        0xFF050403, 0xFF2E291D, 0xFF97875F, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFC0AC7C, 0xFFA8976C, 0xFF61573F, 0xFF040402, 0xFF000000, 0xFF060503, 0xFF262219, 0xFF76694D, 
        0xFFC1AE7E, 0xFFC2AE7E, 0xFFC2AE7F, 0xFF8A7C5A, 0xFF000000, 0xFF0F0E0A, 0xFF9B8C66, 0xFFC3AF80, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFC3B081, 0xFFC3B082, 0xFFC4B082, 0xFFC4B082, 0xFFC4B082, 0xFFC3B082, 0xFF110F0B, 0xFF000000, 0xFF373124, 
        0xFF27231A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0A07, 0xFF1B1812, 0xFF2C281E, 0xFF514936, 0xFF7E7155, 0xFFA89971, 0xFFC5B385, 0xFFC5B286, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC6B486, 
        0xFFC6B487, 0xFFC7B486, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 
        0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC7B487, 0xFFC6B487, 0xFFC6B487, 0xFFC6B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFFBBA97F, 0xFF958664, 0xFF685E46, 0xFF3D3729, 0xFF232017, 0xFF12100C, 0xFF040403, 0xFF000000, 
        0xFF000000, 0xFF0B0A07, 0xFF443E2E, 0xFF7F7355, 0xFFA5956E, 0xFFB7A67B, 0xFFC5B284, 0xFFC5B284, 0xFFC4B184, 0xFF635A42, 0xFF000000, 0xFF342F22, 0xFFC0AD80, 0xFFC4B082, 0xFFC4B082, 0xFFC3B082, 0xFFC3B081, 0xFFC3AF81, 0xFFC3B081, 0xFFC3AF81, 
        0xFFC3AF80, 0xFFC2AF80, 0xFF9D8E67, 0xFF020201, 0xFF060604, 0xFF252118, 0xFF0C0A07, 0xFF000000, 0xFF000000, 0xFF4D4532, 0xFFA08F67, 0xFFBCAA7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBEAB7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA774, 0xFFBBA674, 0xFFBBA573, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA571, 
        0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E68, 0xFFB49E68, 
        0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 
        0xFFAD965C, 0xFFAD955C, 0xFFAD945B, 0xFFAD945B, 0xFFAC945B, 0xFFAC9459, 0xFFAB9359, 0xFFAB9359, 0xFFAA9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF826F40, 0xFF060503, 
        0xFF0B0905, 0xFF826F3F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA0884B, 0xFF695831, 0xFF010100, 0xFF000000, 0xFF100E07, 0xFF61522D, 0xFFA3894B, 0xFF5C4C29, 0xFF000000, 0xFF141109, 0xFF927A41, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08546, 0xFFA08545, 
        0xFF9F8545, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF997E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 
        0xFF987C38, 0xFF987B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957833, 0xFF957833,
  0xFF957832, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967935, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997D3A, 0xFF9A7E3A, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 
        0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8445, 0xFFA08545, 0xFFA18646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF736034, 0xFF000000, 0xFF110E07, 0xFF836E3B, 0xFF39301A, 0xFF000000, 
        0xFF000000, 0xFF1A160C, 0xFF927B44, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF846F3F, 0xFF0D0B06, 0xFF000000, 0xFF887442, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFF837043, 0xFF000000, 
        0xFF362F1C, 0xFF7C6A3F, 0xFF504429, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060503, 0xFF8C794B, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 
        0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB5A06A, 0xFFB69F6B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 
        0xFFB7A26D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A36F, 0xFF221E14, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF473F2B, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFB7A372, 0xFF463E2C, 
        0xFF000000, 0xFF000000, 0xFF010100, 0xFF554C36, 0xFFB7A474, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AC7C, 0xFFB4A174, 0xFF4F4733, 0xFF050403, 0xFF000000, 0xFF000000, 
        0xFF12100B, 0xFF75694C, 0xFFC1AE7E, 0xFF3C3627, 0xFF000000, 0xFF3B3526, 0xFFC1AE7E, 0xFFC2AE80, 0xFFC2AF80, 0xFFC3AF80, 0xFFC3AF80, 0xFFC3B081, 0xFFC3AF81, 0xFFC3B081, 0xFFC3B081, 0xFFC3B082, 0xFF9A8A66, 0xFF030202, 0xFF100E0A, 0xFF9C8C68, 
        0xFFC4B183, 0xFFBAA77C, 0xFF847657, 0xFF433D2D, 0xFF0F0D0A, 0xFF020201, 0xFF010101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF26221A, 0xFF554C39, 0xFF7D7154, 0xFFA5956F, 0xFFBDAB7F, 0xFFC2B083, 0xFFC3B084, 0xFFC4B184, 0xFFC4B184, 
        0xFFC5B285, 0xFFC6B386, 0xFFC6B386, 0xFFC6B487, 0xFFC6B486, 0xFFC6B386, 0xFFC6B386, 0xFFC6B486, 0xFFC6B487, 0xFFC6B486, 0xFFC6B487, 0xFFC6B487, 0xFFC6B386, 0xFFC6B487, 0xFFC6B386, 0xFFC6B487, 0xFFC6B487, 0xFFC6B486, 0xFFC6B387, 0xFFC6B387, 
        0xFFC6B386, 0xFFC5B286, 0xFFC5B385, 0xFFC4B184, 0xFFC3B084, 0xFFC2B083, 0xFFC1AE82, 0xFFB4A37A, 0xFF928463, 0xFF6A6047, 0xFF3E382A, 0xFF14120E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF010101, 0xFF000000, 0xFF413B2C, 
        0xFFA2926C, 0xFFC5B284, 0xFFC5B284, 0xFFC5B284, 0xFFC4B184, 0xFFC4B184, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFAB9A72, 0xFF000000, 0xFF16140F, 0xFFA5946D, 0xFFC3B082, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC3AF80, 
        0xFFC1AE7F, 0xFFBFAB7D, 0xFF8D7E5C, 0xFF080705, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF342F22, 0xFFA5946B, 0xFFC0AD7D, 0xFFC1AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA79, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 
        0xFFB9A470, 0xFFB9A471, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 
        0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB19A64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB19962, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965C, 
        0xFFAD965C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF99824B, 0xFF1B170D, 0xFF010100, 
        0xFF5D4F2D, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFF8D7742, 0xFF1E190E, 0xFF000000, 0xFF000000, 0xFF292213, 0xFF100D07, 0xFF000000, 0xFF746234, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 
        0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 
        0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957832,
  0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C813F, 
        0xFF9C813F, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF4A3E21, 0xFF000000, 0xFF040302, 0xFF000000, 0xFF050402, 
        0xFF463B20, 0xFFA0864B, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF60512E, 0xFF000000, 0xFF18150C, 0xFF97804A, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFF3C341F, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF7A6941, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB09962, 
        0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB49D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 
        0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26D, 0xFF726444, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0A07, 0xFF9C8A5F, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA774, 0xFFB8A372, 0xFF4B432F, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF13110C, 0xFF786B4C, 0xFFB39F71, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAC7B, 0xFFC0AC7B, 0xFFAA986D, 0xFF554C37, 0xFF1B1911, 
        0xFF000000, 0xFF000000, 0xFF0D0C08, 0xFF070604, 0xFF010100, 0xFF897C59, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3B081, 0xFFC3B081, 0xFF5A513B, 0xFF000000, 0xFF27231A, 0xFFBFAB7E, 
        0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFA99871, 0xFF7C7053, 0xFF534C37, 0xFF322D21, 0xFF0A0907, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF100F0B, 0xFF2B271D, 0xFF443D2D, 0xFF574F3A, 
        0xFF6D6249, 0xFF7B6F52, 0xFF877A5B, 0xFF908261, 0xFF978866, 0xFF9C8D6A, 0xFFA0916C, 0xFFA5956F, 0xFFA79771, 0xFFA79771, 0xFFA69670, 0xFFA69670, 0xFFA89872, 0xFFA69670, 0xFFA5956F, 0xFFA2926D, 0xFF9E8F6B, 0xFF988A67, 0xFF928463, 0xFF8D7F5F, 
        0xFF847759, 0xFF75694F, 0xFF625942, 0xFF4D4634, 0xFF393326, 0xFF1D1A13, 0xFF060504, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF1B1912, 0xFF2C281E, 0xFF423C2C, 0xFF685E45, 0xFF988965, 0xFF5F553F, 0xFF000000, 0xFF514936, 
        0xFFC5B284, 0xFFC4B184, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B182, 0xFFC4B082, 0xFFC3B082, 0xFFC4B082, 0xFF252118, 0xFF000000, 0xFF817455, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF80, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFA4936B, 
        0xFF73674B, 0xFF221F16, 0xFF000000, 0xFF000000, 0xFF12110C, 0xFF443D2C, 0xFF988963, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBEA979, 0xFFBDA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBCA876, 0xFFBDA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 
        0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB49E69, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 
        0xFFB39D66, 0xFFB39C66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A62, 0xFFB09962, 0xFFB09962, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 
        0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA68D51, 0xFF3F361F, 0xFF000000, 0xFF3F351E, 
        0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4D, 0xFFA58B4D, 0xFFA48A4C, 0xFF9B8448, 0xFF3F351D, 0xFF070503, 0xFF000000, 0xFF000000, 0xFF4B3F22, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 
        0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987C38, 
        0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957834, 0xFF957832, 0xFF957732,
  0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 
        0xFF9C813F, 0xFF9D813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF9E8446, 0xFF2E2614, 0xFF000000, 0xFF060502, 0xFF7B6738, 
        0xFFA1874A, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF4C4125, 0xFF000000, 0xFF362E1A, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFF8B7646, 
        0xFF0E0C07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF695B38, 0xFFAD955B, 0xFFAD955B, 0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFAF9961, 0xFFB09962, 
        0xFFB09A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06C, 
        0xFFB7A16C, 0xFFB7A16C, 0xFFA79364, 0xFF221E14, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5D5238, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBBA572, 0xFFBBA673, 0xFFBBA673, 0xFFAE9A6C, 0xFF16130D, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF231F16, 0xFF807351, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFAA986D, 
        0xFF796D4E, 0xFF2C271C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF322D21, 0xFF71654A, 0xFFB8A578, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE80, 0xFFC2AF80, 0xFFC3AF80, 0xFFB8A679, 0xFF2D291E, 0xFF000000, 0xFF5B523C, 0xFFC3B081, 
        0xFFC3B081, 0xFFC3B082, 0xFFC3B082, 0xFFC3B082, 0xFFC4B082, 0xFFC4B182, 0xFFC4B182, 0xFFC4B183, 0xFFAF9E75, 0xFF1F1C15, 0xFF000000, 0xFF70654B, 0xFF817455, 0xFF635A42, 0xFF473F2F, 0xFF2C271D, 0xFF14120D, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030202, 0xFF090806, 0xFF0D0B08, 0xFF14120D, 0xFF17140F, 0xFF17140F, 0xFF17140F, 0xFF17140F, 0xFF181610, 0xFF16140F, 0xFF15130E, 0xFF100F0B, 0xFF0B0A07, 0xFF090806, 0xFF030202, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF15130E, 0xFF574E3A, 0xFF70654B, 0xFF887B5B, 0xFF9A8B67, 0xFFA99971, 0xFFBCA97E, 0xFFC5B183, 0xFFC5B183, 0xFFC4B183, 0xFFA6956E, 0xFF000000, 0xFF1A1711, 
        0xFFC4B183, 0xFFC4B183, 0xFFC4B082, 0xFFC4B082, 0xFFC4B082, 0xFFC3B082, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFF766A4E, 0xFF000000, 0xFF463F2E, 0xFFC0AD7E, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFF827455, 0xFF3F3929, 0xFF15130D, 
        0xFF000000, 0xFF000000, 0xFF1B1811, 0xFF6B6045, 0xFFA19068, 0xFFC0AD7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBDA978, 
        0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA876, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA673, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 
        0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39C66, 
        0xFFB39C66, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 
        0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F53, 0xFFA78E52, 0xFFA78E52, 0xFF55482A, 0xFF000000, 0xFF302817, 0xFFA28A4E, 
        0xFFA68C50, 0xFFA68C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF262011, 0xFF000000, 0xFF2E2614, 0xFF9D8446, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8443, 0xFF9E8343, 0xFF9E8242, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987B37, 
        0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF947832, 0xFF947732,
  0xFF947731, 0xFF947731, 0xFF947833, 0xFF957833, 0xFF957933, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977B36, 0xFF977B37, 0xFF987B37, 0xFF987C39, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF9A7D3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 
        0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF846F3B, 0xFF100D07, 0xFF000000, 0xFF6C5A31, 
        0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58B4E, 0xFF302917, 0xFF000000, 0xFF544728, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 
        0xFF483D24, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4A3F26, 0xFFAC945B, 0xFFAD945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09861, 
        0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB59E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6B, 0xFFB6A06B, 
        0xFFB6A06C, 0xFFB6A16C, 0xFF6C5F3F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF16130D, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFF6D6043, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1B1811, 0xFF5B5139, 0xFF453D2B, 0xFF060504, 0xFF302B1E, 0xFFAC9A6D, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AB7B, 
        0xFFC0AC7B, 0xFFBCA879, 0xFF988862, 0xFF312C20, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF070604, 0xFF463F2D, 0xFFA19069, 0xFFC1AE7E, 0xFFC1AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF9D8E67, 0xFF0F0E0A, 0xFF000000, 0xFFA2926A, 0xFFC3AF80, 
        0xFFC3AF81, 0xFFC3AF81, 0xFFC3B081, 0xFFC3B082, 0xFFC3B081, 0xFFC3B082, 0xFFC4B082, 0xFFC4B082, 0xFFA0906A, 0xFF0A0907, 0xFF000000, 0xFFBDAA7D, 0xFFC4B183, 0xFFC2AF81, 0xFFC1AE81, 0xFFC0AD80, 0xFFBFAD7F, 0xFFBAA77C, 0xFFAB9A72, 0xFF978965, 
        0xFF807355, 0xFF1A1711, 0xFF000000, 0xFF302B20, 0xFF393426, 0xFF28241A, 0xFF1E1B14, 0xFF1A1711, 0xFF13110C, 0xFF050403, 0xFF000000, 0xFF030202, 0xFF0E0D09, 0xFF030202, 0xFF000000, 0xFF100E0A, 0xFF252219, 0xFF000000, 0xFF000000, 0xFF3C3628, 
        0xFF5C533E, 0xFF74694E, 0xFF8A7C5C, 0xFFA3936D, 0xFFB5A479, 0xFF73674D, 0xFF000000, 0xFF28241A, 0xFFC4B284, 0xFFC4B083, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFB7A57A, 0xFF0A0907, 0xFF000000, 
        0xFFB9A67A, 0xFFC4B082, 0xFFC3B082, 0xFFC4B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFAF9D73, 0xFF000000, 0xFF040403, 0xFFB8A679, 0xFFB2A075, 0xFF5C533C, 0xFF0F0D09, 0xFF020201, 0xFF000000, 0xFF000000, 
        0xFF1F1C14, 0xFF857756, 0xFFBBA879, 0xFFC0AB7C, 0xFFC0AD7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 
        0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 
        0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C66, 
        0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAD955B, 
        0xFFAC945B, 0xFFAC935A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA78F53, 0xFF6F5E36, 0xFF000000, 0xFF16130B, 0xFF907A45, 0xFFA68C50, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894C, 0xFFA3894B, 0xFF6C5B31, 0xFF000000, 0xFF110E07, 0xFF866F3B, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9E8343, 0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987B37, 0xFF977B37, 
        0xFF977B37, 0xFF967A36, 0xFF967935, 0xFF967935, 0xFF957834, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731,
  0xFF947731, 0xFF947731, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8241, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF5F502A, 0xFF010100, 0xFF0F0C06, 
        0xFF8B753F, 0xFFA3894B, 0xFFA4894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF957D47, 0xFF19150C, 0xFF000000, 0xFF6C5C34, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99055, 0xFFA99155, 
        0xFF99824D, 0xFF0E0C07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF282315, 0xFFAB9258, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09960, 
        0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFB19A62, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB29C65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 
        0xFFB6A06B, 0xFFA99563, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8A7952, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFAF9B6B, 0xFF020201, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF473F2C, 0xFFBCA775, 0xFFBCA876, 0xFFBCA876, 0xFFB29E6F, 0xFF5B5139, 0xFFAE9B6D, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 
        0xFFBFAB7B, 0xFFC0AC7B, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFA7956B, 0xFF524935, 0xFF1C1912, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF242017, 0xFF6D6247, 0xFFA19169, 0xFFB4A377, 0xFFC2AE7F, 0xFF776B4E, 0xFF000000, 0xFF1B1811, 0xFFC2AF80, 0xFFC3AF80, 
        0xFFC3AF80, 0xFFC3AF80, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFF867959, 0xFF000000, 0xFF1E1B14, 0xFFC4B082, 0xFFC4B082, 0xFFC4B182, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 
        0xFFC4B183, 0xFF191610, 0xFF000000, 0xFFA6956E, 0xFFC4B183, 0xFFC5B183, 0xFFC4B184, 0xFFC5B183, 0xFFC5B284, 0xFF514836, 0xFF000000, 0xFF2C281E, 0xFFC5B184, 0xFF29251B, 0xFF000000, 0xFF695F46, 0xFFC5B184, 0xFF040403, 0xFF000000, 0xFF958663, 
        0xFFC5B184, 0xFFC4B184, 0xFFC5B184, 0xFFC4B183, 0xFFC5B183, 0xFF7E7254, 0xFF030302, 0xFF181610, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B183, 0xFFC4B182, 0xFFC4B182, 0xFFC4B082, 0xFFC4B182, 0xFFC4B182, 0xFFBCA97D, 0xFF2D291E, 0xFF000000, 
        0xFF867959, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF80, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFB8A679, 0xFF232017, 0xFF000000, 0xFF232017, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF17150F, 0xFF413A2A, 0xFF958661, 
        0xFFC1AD7D, 0xFFC1AD7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFA69468, 0xFF1C1911, 
        0xFF685C41, 0xFFB5A271, 0xFFBCA876, 0xFFBCA875, 0xFFBCA775, 0xFFBBA774, 0xFFBBA774, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB39D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 
        0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA89053, 0xFFA88F53, 0xFFA88F53, 0xFF867241, 0xFF060503, 0xFF070603, 0xFF726137, 0xFFA68D50, 0xFFA58C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF8B753F, 0xFF0F0C06, 0xFF010100, 0xFF5F502A, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987B38, 0xFF987B37, 0xFF977B37, 
        0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957732, 0xFF947731, 0xFF937731,
  0xFF937631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B36, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 
        0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8341, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFF41371D, 0xFF000000, 
        0xFF2E2615, 0xFFA08648, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF7E6B3D, 0xFF050402, 0xFF050402, 0xFF7A683B, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 
        0xFFA99155, 0xFF665733, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF9A844F, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 
        0xFFB09860, 0xFFB09960, 0xFFB09962, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 
        0xFFB69F6A, 0xFF3E3724, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3D3524, 0xFFB49E6B, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFF3C3524, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF252117, 0xFFAD9A6B, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA776, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAB7A, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AC7C, 0xFFB19F72, 0xFF847655, 0xFF504834, 0xFF16140E, 0xFF000000, 0xFF000000, 0xFF060604, 0xFF2E2A1E, 0xFF574E39, 0xFF322D21, 0xFF000000, 0xFF796D4F, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFFC2AE80, 0xFFC2AE7F, 0xFFC2AF7F, 0xFFC2AF80, 0xFFC2AF80, 0xFFC3AF81, 0xFFC3AF80, 0xFFC3AF80, 0xFF5F553F, 0xFF000000, 0xFF514835, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B082, 0xFFC3B082, 0xFFC3B082, 0xFFC3B083, 0xFFC4B083, 
        0xFFC4B082, 0xFF030202, 0xFF000000, 0xFFAC9B72, 0xFFC4B182, 0xFFC4B182, 0xFFC4B183, 0xFFC4B182, 0xFFC4B183, 0xFF4E4634, 0xFF000000, 0xFF2C281D, 0xFFC4B183, 0xFF28241B, 0xFF000000, 0xFF635A42, 0xFFC4B183, 0xFF050403, 0xFF000000, 0xFF8F8160, 
        0xFFC4B182, 0xFFC4B182, 0xFFC4B182, 0xFFC4B183, 0xFFC4B182, 0xFF958562, 0xFF0C0B08, 0xFF0E0D09, 0xFFBEAB7E, 0xFFC4B082, 0xFFC3B082, 0xFFC3B082, 0xFFC3B082, 0xFFC3B082, 0xFFC3B081, 0xFFC3B082, 0xFFC3B081, 0xFFC0AC7F, 0xFF564D39, 0xFF000000, 
        0xFF4B4331, 0xFFC3AF80, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AE80, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF958561, 0xFF635941, 0xFF383224, 0xFF0A0906, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF443D2C, 0xFF796D4E, 0xFFA8976D, 0xFFC0AD7D, 0xFFC0AD7D, 
        0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBDA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFA08E63, 0xFF0D0B08, 
        0xFF000000, 0xFF363021, 0xFFA29065, 0xFFBBA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB69F6B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F68, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965D, 0xFFAD965B, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC9459, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFA99156, 0xFFAA9156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFF97814A, 0xFF1C180D, 0xFF000000, 0xFF62542F, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF9F8648, 0xFF2D2614, 0xFF000000, 0xFF43381E, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 
        0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8140, 0xFF9D813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9B7F3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 
        0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF937631,
  0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987B38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3C, 
        0xFF9B7F3E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFF9E8446, 0xFF272111, 
        0xFF000000, 0xFF4A3E21, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF756238, 0xFF000000, 0xFF121009, 0xFF957F49, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 
        0xFFA99055, 0xFFA99156, 0xFF272113, 0xFF000000, 0xFF312A19, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAD955B, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 
        0xFFAF9860, 0xFFB09860, 0xFFB09960, 0xFFB09962, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 
        0xFF83734C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF8B7A52, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A470, 0xFFB9A470, 0xFF867651, 0xFF070604, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF010100, 0xFF867652, 0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AC7B, 0xFFBCA97A, 0xFFB3A174, 0xFF8D7E5B, 0xFF403929, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF000000, 0xFF342F22, 0xFF7F7253, 0xFFB9A77A, 
        0xFFC2AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AF80, 0xFF312C20, 0xFF000000, 0xFF877958, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 
        0xFFB7A579, 0xFF000000, 0xFF100E0A, 0xFFB09F74, 0xFFC4B081, 0xFFC3B082, 0xFFC4B082, 0xFFC4B082, 0xFFC4B082, 0xFF4F4734, 0xFF000000, 0xFF2C281D, 0xFFC4B082, 0xFF28241B, 0xFF000000, 0xFF635942, 0xFFC3B082, 0xFF050403, 0xFF000000, 0xFF8F815F, 
        0xFFC3B082, 0xFFC4B082, 0xFFC4B082, 0xFFC3B082, 0xFFC3B082, 0xFFA3936D, 0xFF110F0B, 0xFF090806, 0xFFB1A075, 0xFFC3AF81, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3AF80, 0xFFC3AF80, 0xFF75694C, 0xFF000000, 
        0xFF0F0D0A, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AE7F, 0xFF8F805D, 0xFF494230, 0xFF15130D, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2B271C, 0xFF7E7151, 0xFFB19F73, 0xFFBBA879, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 
        0xFFC0AB7B, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBEA977, 0xFFBEA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFB4A070, 0xFF13110C, 
        0xFF000000, 0xFF000000, 0xFF0B0A07, 0xFF847552, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA573, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A16D, 
        0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9459, 
        0xFFAC9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF251F12, 0xFF000000, 0xFF574A2A, 0xFFA68C50, 0xFFA68D50, 0xFFA58C4E, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894A, 0xFF4A3E21, 0xFF000000, 0xFF282112, 0xFF9F8446, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08546, 0xFFA08546, 0xFF9F8544, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 
        0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957834, 0xFF957832, 0xFF947832, 0xFF947731, 0xFF937631, 0xFF937630,
  0xFF937530, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 
        0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9B803E, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF8C753E, 
        0xFF110E07, 0xFF000000, 0xFF6B5A30, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFFA68D50, 0xFF5E502D, 0xFF000000, 0xFF1D180E, 0xFFA1894F, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA99055, 0xFFA99055, 0xFF887444, 0xFF000000, 0xFF463C24, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 
        0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB09965, 
        0xFF262116, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3E3724, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB19C6A, 0xFF342E20, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF3B3424, 0xFFBAA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBBA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 
        0xFFBEAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBAA778, 0xFF796D4E, 0xFF302B1F, 0xFF0D0C08, 0xFF060604, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF2A251B, 0xFF665B42, 0xFF9C8D66, 0xFFB29F73, 0xFFB9A679, 0xFFC0AC7E, 0xFFC2AE7F, 0xFFC0AC7E, 0xFF090805, 0xFF000000, 0xFFAB9A70, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC3AF80, 0xFFC3AF80, 0xFFC3AF80, 0xFFC3AF80, 0xFFC3AF80, 0xFFC3AF80, 
        0xFFA5946D, 0xFF000000, 0xFF201D15, 0xFFB4A277, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFF4E4734, 0xFF000000, 0xFF2C281D, 0xFFC3B081, 0xFF28241B, 0xFF000000, 0xFF635941, 0xFFC3B082, 0xFF050403, 0xFF000000, 0xFF8F815E, 
        0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3B081, 0xFFC3AF81, 0xFFB1A075, 0xFF16140F, 0xFF060504, 0xFF9C8D67, 0xFFC3AF81, 0xFFC3AF80, 0xFFC3AF80, 0xFFC2AF80, 0xFFC3AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFF8D7F5D, 0xFF080705, 
        0xFF000000, 0xFF928360, 0xFF766A4D, 0xFF373124, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF040402, 0xFF0C0B08, 0xFF252118, 0xFF695E44, 0xFFB19E72, 0xFFC1AD7D, 0xFFC0AC7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AB7B, 0xFFC0AB7B, 
        0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBCA876, 0xFFBCA876, 0xFFBCA875, 0xFFBCA775, 0xFF1E1A12, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF584E36, 0xFFB49F6E, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A26D, 
        0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59E69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 
        0xFFB29B63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 
        0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88E52, 0xFF352D1A, 0xFF000000, 0xFF39301B, 0xFFA2884E, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 
        0xFFA48B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF6A5930, 0xFF000000, 0xFF110E07, 0xFF8D763E, 0xFFA28748, 0xFFA18747, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 
        0xFF967A35, 0xFF957934, 0xFF957934, 0xFF957833, 0xFF957732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630,
  0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF957732, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 
        0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 
        0xFF6C5A30, 0xFF010100, 0xFF070603, 0xFF7D6A39, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4E, 0xFF453A21, 0xFF000000, 0xFF2F2816, 0xFF9F874E, 0xFFA78E52, 0xFFA78F53, 0xFFA88F54, 
        0xFFA89054, 0xFFA99055, 0xFFA58D53, 0xFF3D341E, 0xFF201B10, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 
        0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB29A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D66, 0xFFB49D67, 0xFFB49E68, 0xFF726442, 
        0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080704, 0xFFA99463, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFF81714D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF0A0906, 0xFFAC9769, 0xFFBAA572, 0xFFBBA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA774, 0xFFBCA775, 0xFFBCA876, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA876, 0xFFBDA977, 0xFFBDA977, 0xFFBDA978, 
        0xFFBEA978, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFAE9C70, 0xFF807353, 0xFF554D37, 0xFF322D20, 0xFF0F0D09, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF110F0B, 0xFF353023, 0xFF574F39, 0xFF786C4E, 0xFF807454, 0xFF000000, 0xFF1F1C14, 0xFFC1AD7E, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC3AF80, 0xFFC2AF80, 0xFFC3AF80, 
        0xFF897B5A, 0xFF000000, 0xFF302B1F, 0xFFB8A579, 0xFFC2AF81, 0xFFC3AF80, 0xFFC3AF81, 0xFFC3B081, 0xFFC3AF81, 0xFF4F4734, 0xFF000000, 0xFF2C281D, 0xFFC3B081, 0xFF28241A, 0xFF000000, 0xFF635941, 0xFFC3B080, 0xFF050403, 0xFF000000, 0xFF8F815F, 
        0xFFC3AF81, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3AF81, 0xFFC3AF81, 0xFFBAA77A, 0xFF1B1812, 0xFF030302, 0xFF837656, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AF80, 0xFFB09F73, 0xFF988963, 0xFF7D7051, 0xFF514934, 0xFF070604, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070604, 0xFF2A251B, 0xFF4D4532, 0xFF776B4E, 0xFFA5946B, 0xFFC0AD7D, 0xFFC1AD7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFF373122, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF352F20, 0xFF99885D, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 
        0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB29C66, 0xFFB29C65, 0xFFB29B65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 
        0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965C, 0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 
        0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA68E51, 0xFF4F4327, 0xFF000000, 0xFF211C10, 0xFF988149, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 
        0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFF7E6A39, 0xFF070603, 0xFF010100, 0xFF6C5B30, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8341, 
        0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967935, 
        0xFF967935, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF93752F,
  0xFF92752E, 0xFF937630, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987C37, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997D3A, 0xFF9A7E3A, 0xFF9A7E3B, 
        0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8445, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 
        0xFFA28748, 0xFF534525, 0xFF000000, 0xFF1B160C, 0xFF967E44, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA1884D, 0xFF2A2314, 0xFF000000, 0xFF3E351E, 0xFFA48B50, 0xFFA88E52, 0xFFA88E53, 
        0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFF887544, 0xFF1B170E, 0xFFA58E54, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC9459, 0xFFAC945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D66, 0xFFAE9863, 0xFF1A170F, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF766845, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 0xFF14110C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF706344, 0xFFB9A471, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 
        0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEA979, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFB5A275, 0xFFA7956B, 
        0xFF8D7E5B, 0xFF5A503A, 0xFF242017, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF090806, 0xFF000000, 0xFF0A0906, 0xFF3B3527, 0xFF60563F, 0xFF857857, 0xFFA8966E, 0xFFC1AE7E, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFFC2AE7F, 
        0xFF6F6449, 0xFF000000, 0xFF3F3929, 0xFFBBA77A, 0xFFC2AE7F, 0xFFC2AF80, 0xFFC2AF80, 0xFFC2AE80, 0xFFC2AF7F, 0xFF4F4734, 0xFF000000, 0xFF2C271D, 0xFFC2AF80, 0xFF28241A, 0xFF000000, 0xFF625941, 0xFFC2AF80, 0xFF050403, 0xFF000000, 0xFF8F815E, 
        0xFFC2AF7F, 0xFFC2AE7F, 0xFFC2AF7F, 0xFFC2AF7F, 0xFFC2AE7F, 0xFFC2AE7F, 0xFF242017, 0xFF020201, 0xFF72664A, 0xFFC2AE7F, 0xFFAF9D73, 0xFF8E7F5D, 0xFF695F45, 0xFF453E2C, 0xFF262219, 0xFF191610, 0xFF0E0C09, 0xFF020201, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF16140E, 0xFF4D4532, 0xFF847655, 0xFFA3936A, 0xFFB2A073, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFC0AC7B, 0xFFBFAC7B, 0xFFBFAC7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 
        0xFFBEAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA674, 0xFF554C34, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0F0E09, 0xFF6F6343, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 
        0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 
        0xFFB19962, 0xFFB09962, 0xFFB09960, 0xFFAF9860, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAC955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78F52, 0xFF685933, 0xFF000000, 0xFF0F0D07, 0xFF978048, 0xFFA68D50, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 
        0xFFA48A4D, 0xFFA4894B, 0xFFA3894B, 0xFF967E44, 0xFF1B160C, 0xFF000000, 0xFF544626, 0xFFA18748, 0xFFA18747, 0xFFA18646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8241, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997C3A, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967934, 
        0xFF967934, 0xFF957833, 0xFF957832, 0xFF957832, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937530, 0xFF92752F,
  0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08546, 0xFFA18646, 0xFFA18647, 
        0xFFA18748, 0xFFA18748, 0xFF372E19, 0xFF000000, 0xFF302816, 0xFFA3894A, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA48B4F, 0xFF14110A, 0xFF000000, 0xFF574A2A, 0xFFA68D51, 0xFFA88E52, 
        0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B65, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFF5F5336, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF2A2518, 0xFFB19B66, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A26D, 0xFF584E34, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF262217, 
        0xFFAB9667, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA776, 0xFFBDA876, 0xFFBCA876, 
        0xFFBDA877, 0xFFBDA877, 0xFFBAA775, 0xFFB7A373, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAC7B, 0xFFC0AC7C, 0xFFC0AC7B, 
        0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFB9A678, 0xFF8C7D5A, 0xFF554C37, 0xFF242017, 0xFF070604, 0xFF040402, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF17150F, 0xFF383224, 0xFF544C37, 0xFF73684B, 0xFF938560, 
        0xFF49422F, 0xFF000000, 0xFF4D4532, 0xFFB9A679, 0xFFBCA97B, 0xFFBDA97C, 0xFFBEAA7C, 0xFFBEAA7C, 0xFFC2AE7F, 0xFF4E4633, 0xFF000000, 0xFF2C271C, 0xFFC2AE7F, 0xFF272319, 0xFF000000, 0xFF61573F, 0xFFC2AE7F, 0xFF030302, 0xFF000000, 0xFF8B7C5B, 
        0xFFBCA97B, 0xFFBBA87B, 0xFFB5A377, 0xFFA9986F, 0xFF92835F, 0xFF7C6F51, 0xFF18150F, 0xFF000000, 0xFF0B0A07, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF040402, 0xFF060503, 0xFF1A1711, 0xFF4A4230, 0xFF7E7151, 
        0xFFB4A174, 0xFFC1AD7D, 0xFFC0AD7D, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFF756848, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF524831, 0xFFB29D6B, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A26D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06A, 0xFFB5A06A, 0xFFB59F69, 0xFFB59F6A, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39D65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 
        0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955D, 0xFFAD955B, 0xFFAD945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9258, 
        0xFFAA9257, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA89054, 0xFFA88F53, 0xFFA88E53, 0xFF79673B, 0xFF000000, 0xFF000000, 0xFF8E7944, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4C, 
        0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFF2F2815, 0xFF000000, 0xFF382F19, 0xFFA18749, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 
        0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 
        0xFF957934, 0xFF957833, 0xFF957732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752F,
  0xFF92742E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 
        0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 
        0xFFA18647, 0xFFA18748, 0xFF9B8145, 0xFF241E10, 0xFF000000, 0xFF463A1F, 0xFFA3894A, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFF877341, 0xFF000000, 0xFF000000, 0xFF60522F, 0xFFA78E52, 
        0xFFA78F52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965C, 
        0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFF9C8859, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF040402, 0xFF81724B, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFF9B885B, 0xFF020101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF746646, 
        0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBBA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA875, 0xFFBDA776, 
        0xFFBDA876, 0xFFB7A473, 0xFF594F38, 0xFF282419, 0xFFBDA977, 0xFFBDA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 
        0xFFC0AB7B, 0xFFC0AB7B, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AD7C, 0xFFBBA779, 0xFF978862, 0xFF766A4C, 0xFF584F39, 0xFF3E3728, 0xFF2D281D, 0xFF1F1C14, 0xFF100E0A, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF020201, 0xFF110F0B, 0xFF1A1711, 0xFF28241A, 0xFF2E2A1E, 0xFF393325, 0xFF443D2C, 0xFF1C1912, 0xFF000000, 0xFF0F0D09, 0xFF4D4532, 0xFF0E0C09, 0xFF000000, 0xFF211E15, 0xFF3F3829, 0xFF000000, 0xFF000000, 0xFF14120D, 
        0xFF13110C, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0D0C08, 0xFF1C1912, 0xFF2B261C, 0xFF393325, 0xFF514934, 0xFF706549, 0xFF92835F, 0xFFB4A275, 0xFFC1AD7D, 0xFFC1AD7D, 0xFFC0AC7D, 
        0xFFC0AC7C, 0xFFC0AC7D, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 
        0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA978, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFF918159, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF302A1C, 0xFF968459, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 
        0xFFB09861, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAC9459, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 
        0xFFAA9156, 0xFFAA9156, 0xFFAA9155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFF7B683C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3B321C, 0xFF967E47, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 
        0xFFA4894B, 0xFFA3894B, 0xFF453A1F, 0xFF000000, 0xFF241E10, 0xFF9C8246, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934, 
        0xFF957833, 0xFF957833, 0xFF957832, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF937530, 0xFF92752E, 0xFF92752E,
  0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997D3A, 
        0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 
        0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF88723C, 0xFF0E0C06, 0xFF000000, 0xFF564827, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFF85713F, 0xFF1C180D, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF5B4D2D, 
        0xFFA78E52, 0xFFA78F52, 0xFFA78F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9256, 0xFFAB9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9459, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFF30291B, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF342D1D, 0xFFB29B66, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB39E69, 0xFF3C3524, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF292418, 0xFFB8A26E, 
        0xFFB8A26F, 0xFFB8A26F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFB9A471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBCA774, 0xFFBCA775, 
        0xFFB5A170, 0xFF383223, 0xFF000000, 0xFF2F2A1D, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AC7B, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFB6A375, 0xFFAA986D, 0xFF9E8D66, 0xFF93845F, 0xFF847755, 0xFF73664A, 0xFF5C533C, 0xFF4A4330, 
        0xFF332E21, 0xFF252118, 0xFF15120D, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF030302, 0xFF13110C, 0xFF211D15, 0xFF2F2A1E, 0xFF473F2E, 0xFF584F39, 0xFF6E6347, 0xFF807353, 0xFF91825E, 0xFF9B8A64, 0xFFA8966C, 0xFFB3A174, 0xFFBFAB7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 
        0xFFC0AC7B, 0xFFC0AC7B, 0xFFC0AB7B, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 
        0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA774, 0xFFBBA774, 0xFFBBA673, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFAF9A6A, 
        0xFF000000, 0xFF000000, 0xFF2F291C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0F0D09, 0xFF6B5E40, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB6A06A, 0xFFB59F69, 
        0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D67, 0xFFB49D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09960, 
        0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 
        0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F52, 0xFF806D3F, 0xFF0D0B06, 0xFF000000, 0xFF574A2A, 0xFF141109, 0xFF000000, 0xFF211C10, 0xFF897340, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA38A4B, 
        0xFFA3894B, 0xFF554726, 0xFF000000, 0xFF0E0C06, 0xFF89723D, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 
        0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF967A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957833, 
        0xFF957833, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937530, 0xFF92752F, 0xFF92752E, 0xFF92742D,
  0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93752F, 0xFF937731, 0xFF947731, 0xFF947731, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C39, 0xFF997C39, 0xFF997D39, 
        0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3D, 0xFF9B7F3E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 
        0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF7D6938, 0xFF000000, 0xFF050402, 0xFF766335, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFF7F6B3B, 0xFF0E0C07, 0xFF000000, 0xFF15120A, 0xFF6A5A33, 0xFF010100, 0xFF040302, 
        0xFF705F37, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 
        0xFFAD955C, 0xFFAE965C, 0xFFAD965D, 0xFFAE975E, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFF7A6A44, 0xFF060603, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF948254, 0xFFB49D67, 0xFFB49D68, 0xFFB49E67, 0xFFB59E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFF897850, 0xFF050503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF99875B, 0xFFB7A26D, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFAA976A, 
        0xFF201C14, 0xFF000000, 0xFF000000, 0xFF544B34, 0xFFBCA776, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBEA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA979, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 
        0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFC0AC7B, 0xFFC0AB7C, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFBFAB7B, 0xFFBEAA7B, 
        0xFFBEAA7C, 0xFFBDA97A, 0xFFBDA97A, 0xFFBDA97B, 0xFFBCA97A, 0xFFB3A175, 0xFFAD9C70, 0xFFA8966D, 0xFFA09068, 0xFF978862, 0xFF8F805D, 0xFF8C7E5B, 0xFF8F805D, 0xFF8E7F5C, 0xFF958661, 0xFF9F8E67, 0xFFA7956C, 0xFFAC996F, 0xFFB2A074, 0xFFBAA879, 
        0xFFBDAA7B, 0xFFBDAA7B, 0xFFBDAA7B, 0xFFBEAB7C, 0xFFBEAA7C, 0xFFBFAB7B, 0xFFBFAC7B, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 
        0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 
        0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA776, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 
        0xFF040302, 0xFF000000, 0xFF766847, 0xFF877751, 0xFF040302, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF473E29, 0xFFB6A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 
        0xFFB59E69, 0xFFB59E68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFAF9860, 
        0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 
        0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E53, 0xFF97804A, 0xFF0C0A06, 0xFF000000, 0xFF6F5E35, 0xFFA68D50, 0xFF867140, 0xFF0A0804, 0xFF000000, 0xFF120F08, 0xFF8B7641, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 
        0xFF766335, 0xFF040302, 0xFF000000, 0xFF7D6838, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8341, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 
        0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF957834, 0xFF957833, 
        0xFF957832, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92742E, 0xFF92742D,
  0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987C39, 
        0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 
        0xFFA08546, 0xFFA18646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF66552E, 0xFF000000, 0xFF070603, 0xFF87723E, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFF786538, 0xFF0C0A06, 0xFF000000, 0xFF1A160C, 0xFF877341, 0xFFA68C50, 0xFF7C693B, 0xFF030301, 
        0xFF030201, 0xFF7D6A3D, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC955B, 
        0xFFAD955B, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFA8925E, 0xFF2D2719, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF4E442C, 0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB29D68, 0xFF302B1C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF514730, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBBA572, 0xFFBBA573, 0xFFBBA673, 0xFF97865C, 0xFF1D1A12, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF746748, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEAA78, 0xFFBEAA78, 0xFFBEAA78, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AC7B, 0xFFC0AC7B, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 
        0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7C, 0xFFC0AC7B, 0xFFC0AC7B, 0xFFC0AC7B, 0xFFC0AC7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBEAA7A, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 
        0xFFBCA876, 0xFFBCA776, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 
        0xFF201C13, 0xFF000000, 0xFF554C33, 0xFFB8A36F, 0xFF9E8B5F, 0xFF292418, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1E1A12, 0xFF958357, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E68, 
        0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF985F, 
        0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAC955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 
        0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF937D48, 0xFF100D08, 0xFF000000, 0xFF5D4F2D, 0xFFA68D50, 0xFFA58B4F, 0xFFA58C4F, 0xFF877241, 0xFF17130B, 0xFF000000, 0xFF090804, 0xFF7E6A3A, 0xFFA3894B, 0xFFA3894B, 0xFF88723E, 
        0xFF070503, 0xFF000000, 0xFF67562E, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08445, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 
        0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A35, 0xFF967935, 0xFF967935, 0xFF957934, 0xFF957833, 0xFF957833, 
        0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D,
  0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 
        0xFF997C3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 
        0xFFA08545, 0xFFA08546, 0xFFA18646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF554726, 0xFF000000, 0xFF131008, 0xFF8A743E, 0xFFA3894B, 0xFF5F502B, 0xFF070603, 0xFF000000, 0xFF302816, 0xFF907A44, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF726137, 
        0xFF050402, 0xFF070603, 0xFF716037, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 
        0xFFAD945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09960, 0xFFB09961, 0xFFB09962, 0xFF73643F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF16130C, 0xFFAD9661, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E68, 0xFF746543, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF18150E, 0xFFA79262, 0xFFB7A06B, 0xFFB7A16C, 
        0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFF7A6C4B, 0xFF110F0A, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF8E7E58, 0xFFBBA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA876, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA876, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBEA978, 
        0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 
        0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFC0AC7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAC7C, 0xFFBFAC7B, 
        0xFFBFAB7B, 0xFFBFAB7B, 0xFFC0AB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB79, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAA79, 
        0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA776, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA672, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 
        0xFF3F3826, 0xFF000000, 0xFF3A3322, 0xFFB8A26E, 0xFFB8A26E, 0xFFAB9766, 0xFF594E35, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A07, 0xFF665A3C, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49D68, 
        0xFFB49D67, 0xFFB49D67, 0xFFB49C67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19A64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 
        0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAC935A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99054, 
        0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFF8C7745, 0xFF1A160C, 0xFF000000, 0xFF514527, 0xFFA48B4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFF8F7943, 0xFF272112, 0xFF000000, 0xFF0B0905, 0xFF68572F, 0xFF87713D, 0xFF131008, 
        0xFF000000, 0xFF554726, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9B813F, 0xFF9C803E, 
        0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957832, 0xFF947732, 
        0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92742E, 0xFF92742E, 0xFF92742D, 0xFF91732C,
  0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 
        0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 
        0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18646, 0xFFA18647, 0xFFA18748, 0xFFA08647, 0xFF39301A, 0xFF000000, 0xFF1E190D, 0xFF473C20, 0xFF050402, 0xFF000000, 0xFF362E19, 0xFF998148, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 
        0xFF6D5C34, 0xFF000000, 0xFF0A0805, 0xFF756439, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F54, 0xFFA98F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 
        0xFFAC945A, 0xFFAD945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFAD975F, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF796944, 0xFFB29B64, 0xFFB29B65, 0xFFB29B65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFAD9864, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF685B3D, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06C, 
        0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFF665A3E, 0xFF060504, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF0E0C09, 0xFF9C8B60, 0xFFBBA674, 0xFFBBA674, 0xFFBCA774, 0xFFBBA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 0xFFBDA776, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 
        0xFFBDA977, 0xFFBDA878, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA979, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBFAA79, 0xFFBEAA7A, 0xFFBEAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7B, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 
        0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA979, 
        0xFFBEA978, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBDA875, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA472, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A26F, 
        0xFF5E5339, 0xFF000000, 0xFF1F1B12, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB59F6B, 0xFF897851, 0xFF0D0B08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF332D1E, 0xFFB19C66, 0xFFB49D68, 0xFFB49D67, 
        0xFFB39D67, 0xFFB39D67, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB19B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 
        0xFFAE975E, 0xFFAE965D, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 
        0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFF99824B, 0xFF19150C, 0xFF000000, 0xFF4D4125, 0xFFA68D50, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFF998147, 0xFF262112, 0xFF000000, 0xFF080603, 0xFF0A0904, 0xFF000000, 
        0xFF3A311A, 0xFFA08647, 0xFFA18748, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 
        0xFF9B803D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF997E3A, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF977A35, 0xFF967934, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957832, 0xFF947732, 
        0xFF947731, 0xFF947630, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742C, 0xFF91732C,
  0xFF90732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92742E, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A35, 0xFF967A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 
        0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 
        0xFF9F8445, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA18646, 0xFFA18647, 0xFFA18747, 0xFFA28748, 0xFF221D0F, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF362D19, 0xFF9F8749, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 
        0xFFA68D50, 0xFF675731, 0xFF000000, 0xFF070603, 0xFF826F40, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975D, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFF453C26, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2D2719, 
        0xFFA7925E, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFF463D28, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1F1C12, 0xFFA99563, 0xFFB6A06A, 0xFFB69F6B, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB7A06B, 0xFFB6A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB39F6C, 0xFF5F5439, 0xFF000000, 0xFF020201, 0xFF020101, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF1F1B13, 0xFFA79466, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBCA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBDA776, 0xFFBCA876, 0xFFBDA876, 0xFFBDA876, 
        0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBEA977, 0xFFBDA977, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBFAA7A, 0xFFBEAA7A, 0xFFBFAA79, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 
        0xFFBFAA7A, 0xFFBFAB7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA7A, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 
        0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA674, 
        0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA472, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A471, 0xFFB9A370, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 
        0xFF7F704C, 0xFF000000, 0xFF030302, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06C, 0xFF9F8B5D, 0xFF252015, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF16130D, 0xFF907E52, 0xFFB39D67, 
        0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 
        0xFFAE965D, 0xFFAE965C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 
        0xFFA88F53, 0xFFA88F53, 0xFF99824B, 0xFF16130B, 0xFF000000, 0xFF4B4024, 0xFFA68D50, 0xFFA58C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF302816, 0xFF000000, 0xFF000000, 0xFF221C0F, 
        0xFFA28749, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 
        0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 
        0xFF947731, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C,
  0xFF90732B, 0xFF91732C, 0xFF91742C, 0xFF92742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF947631, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987C38, 
        0xFF987B38, 0xFF997C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 
        0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF9B8145, 0xFF262011, 0xFF000000, 0xFF120F08, 0xFFA3894A, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 
        0xFFA48B4E, 0xFFA68C4F, 0xFF6C5B34, 0xFF040302, 0xFF070603, 0xFF756439, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 
        0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 0xFFAD945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFF88764A, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF7C6C45, 
        0xFFB19A62, 0xFFB19A63, 0xFFB29A64, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFF8E7C51, 0xFF0B0A06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF7B6B47, 0xFFB59E69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB69F6A, 
        0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16E, 0xFFB7A26E, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFAB9867, 0xFF443C29, 0xFF000000, 0xFF000000, 0xFF63573C, 0xFF060503, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF302B1D, 0xFFB09C6C, 0xFFBBA572, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBCA674, 0xFFBBA774, 0xFFBCA674, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA875, 0xFFBCA876, 0xFFBCA776, 
        0xFFBDA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA78, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA7A, 0xFFBFAA79, 0xFFBFAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 
        0xFFBEAA79, 0xFFBFAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA978, 0xFFBEAA78, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA979, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEAA79, 0xFFBEA979, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA977, 0xFFBEA977, 0xFFBDA978, 0xFFBDA977, 
        0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA775, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA675, 0xFFBBA774, 0xFFBCA774, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 
        0xFFBBA673, 0xFFBBA673, 0xFFBBA572, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA472, 0xFFB9A471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A26E, 
        0xFF9B885C, 0xFF000000, 0xFF000000, 0xFFAA9564, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB29B67, 0xFF574C32, 0xFF050403, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0A0906, 0xFF625638, 
        0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F54, 
        0xFFA88F52, 0xFF8C7745, 0xFF19150C, 0xFF000000, 0xFF4D4125, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF3E341C, 0xFF000000, 0xFF262011, 0xFF9B8246, 
        0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8343, 0xFF9E8343, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 
        0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947832, 0xFF947731, 0xFF947731, 
        0xFF937630, 0xFF93762F, 0xFF93762F, 0xFF92752E, 0xFF92752E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732C,
  0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF937732, 0xFF947732, 0xFF947833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 
        0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3A, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 
        0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFFA18748, 0xFF8E773F, 0xFF1B170C, 0xFF000000, 0xFF372E19, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4D, 
        0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF6C5C34, 0xFF000000, 0xFF0A0805, 0xFF6F5F36, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA88F54, 0xFFA98F54, 0xFFA99054, 0xFFA99055, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 
        0xFFAB9359, 0xFFAC9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFFAD945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975E, 0xFFA8925B, 0xFF362E1D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF342D1C, 0xFFB09961, 
        0xFFB19962, 0xFFB09A62, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFAE9863, 0xFF413825, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF37301F, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F6A, 
        0xFFB69F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26E, 0xFFA28E61, 0xFF262217, 0xFF000000, 0xFF050403, 0xFF776A48, 0xFFAB9768, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF453D2A, 0xFFBAA471, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA572, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBCA674, 0xFFBBA774, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA876, 0xFFBCA876, 0xFFBCA776, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBDA876, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA978, 0xFFBDA978, 0xFFBEA978, 
        0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEAA78, 0xFFBEA978, 0xFFBEA978, 
        0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 0xFFBDA978, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 
        0xFFBDA876, 0xFFBCA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA875, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA675, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBBA573, 0xFFBAA572, 
        0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16D, 
        0xFFA99563, 0xFF000000, 0xFF000000, 0xFF8B7A51, 0xFFB6A06B, 0xFFB6A06A, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB49E68, 0xFF85754D, 0xFF0E0D08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 
        0xFF2F281A, 0xFFA48E5C, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE955D, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 
        0xFF937D48, 0xFF1A160C, 0xFF000000, 0xFF4C4024, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF362D18, 0xFF000000, 0xFF1C180C, 0xFF8E773F, 0xFFA18748, 
        0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 
        0xFF9A7E3C, 0xFF997E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF967A36, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF937631, 0xFF937630, 
        0xFF937630, 0xFF92752F, 0xFF92752F, 0xFF92752E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF91732C, 0xFF90722A,
  0xFF90722A, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92742E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977B36, 
        0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF88713C, 0xFF0D0B06, 0xFF000000, 0xFF4A3D21, 0xFFA1874A, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA58B4D, 
        0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF695932, 0xFF000000, 0xFF050402, 0xFF79673B, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA89055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9256, 0xFFAA9257, 0xFFAB9257, 
        0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC935A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFF7B6B42, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFFA6905A, 0xFFB09961, 
        0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFF8F7C51, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFFA48F5E, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 
        0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFA08D5F, 0xFF19160E, 0xFF000000, 0xFF090805, 0xFF867650, 0xFFB8A36F, 0xFF83744F, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF010100, 0xFF5C5238, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBCA674, 0xFFBCA675, 
        0xFFBBA775, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBDA876, 0xFFBDA876, 0xFFB9A574, 0xFFB4A070, 0xFFB3A070, 0xFFB4A071, 0xFFB4A070, 0xFFB4A071, 0xFFB4A071, 0xFFB4A071, 0xFFB4A171, 0xFFB4A071, 
        0xFFB4A171, 0xFFB4A171, 0xFFB4A171, 0xFFB4A072, 0xFFB4A171, 0xFFB4A172, 0xFFB4A172, 0xFFBEA977, 0xFFBDA977, 0xFFBEA978, 0xFFBDA977, 0xFFBDA978, 0xFFBDA978, 0xFFBDA977, 0xFFBEA978, 0xFFBDA977, 0xFFBDA978, 0xFFBEA978, 0xFFBDA978, 0xFFBEA978, 
        0xFFBEA977, 0xFFBDA977, 0xFFBDA977, 0xFFBDA977, 0xFFAD9B6D, 0xFF1B1811, 0xFF8F7F5A, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA876, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 
        0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA674, 0xFFBBA675, 0xFFBCA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBBA572, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 
        0xFFAC9866, 0xFF16140D, 0xFF000000, 0xFF695C3E, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E69, 0xFFB49E68, 0xFFA99460, 0xFF252015, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF14120B, 0xFF917E51, 0xFFB09962, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09861, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F52, 0xFF97804A, 
        0xFF100D08, 0xFF000000, 0xFF4E4225, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA1874A, 0xFF493E21, 0xFF000000, 0xFF0D0B06, 0xFF89723D, 0xFFA18748, 0xFFA18647, 
        0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8341, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C803F, 0xFF9C803E, 0xFF9B7F3E, 0xFF9B803D, 0xFF9A7F3C, 0xFF9A7E3C, 
        0xFF9A7E3C, 0xFF9A7D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947630, 0xFF937630, 
        0xFF937630, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722A,
  0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947732, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977A36, 
        0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9E8241, 0xFF9D8342, 
        0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF806C3A, 0xFF0D0B06, 0xFF000000, 0xFF574927, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 
        0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA48B4E, 0xFFA68D4F, 0xFF6F5E35, 0xFF070603, 0xFF000000, 0xFF695933, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 
        0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFF9E8854, 0xFF14110A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF635636, 0xFFAF9860, 0xFFB09860, 
        0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFF1D1910, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5B5034, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 
        0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A06C, 0xFF81714C, 0xFF0B0A06, 0xFF000000, 0xFF1E1B12, 0xFF968458, 0xFFB8A26E, 0xFFB8A26E, 0xFF594F35, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF040302, 0xFF766847, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBAA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 
        0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBCA774, 0xFFBBA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFF897A55, 0xFF231F16, 0xFF252117, 0xFF12100B, 0xFF0E0C08, 0xFF13110C, 0xFF13110C, 0xFF13110C, 0xFF13110C, 0xFF13110C, 
        0xFF13110C, 0xFF13110C, 0xFF110F0B, 0xFF0B0A07, 0xFF1C1912, 0xFF262218, 0xFF2D281C, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA977, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA977, 0xFFBDA977, 
        0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFFBDA877, 0xFF7E704F, 0xFF000000, 0xFF2F2A1D, 0xFFBDA877, 0xFFBDA876, 0xFFBDA877, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBBA573, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA571, 
        0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 
        0xFFAE9966, 0xFF2B2619, 0xFF000000, 0xFF49402A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49E67, 0xFFB39D67, 0xFFB39D67, 0xFF584D32, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF635637, 0xFFAA935E, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 
        0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88E52, 0xFF806D3F, 0xFF0C0A06, 
        0xFF000000, 0xFF514527, 0xFFA68D50, 0xFFA58C4F, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58C4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFF574927, 0xFF000000, 0xFF0E0C06, 0xFF816C3A, 0xFFA18748, 0xFFA18747, 0xFFA08647, 
        0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 
        0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987D39, 0xFF987C38, 0xFF987C38, 0xFF987C37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 
        0xFF93752E, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF90732C, 0xFF90722A, 0xFF90722A,
  0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732D, 0xFF91742D, 0xFF91742D, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 
        0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 
        0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF7E6A38, 0xFF0D0B06, 0xFF000000, 0xFF4C3F22, 0xFFA3884B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFF776539, 0xFF080704, 0xFF020201, 0xFF564829, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9157, 
        0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFF9E8852, 0xFF342D1B, 0xFF73633C, 0xFFAC945B, 0xFFAD955B, 0xFF968150, 0xFF201C11, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF211D12, 0xFFA28C58, 0xFFAF985F, 0xFFAF9860, 
        0xFFAF9860, 0xFFB09860, 0xFFB09861, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19A63, 0xFF5A4E32, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF19160E, 0xFF9F8A59, 0xFFB39C65, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D68, 
        0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB6A06A, 0xFFB5A06A, 0xFF685C3D, 0xFF070604, 0xFF000000, 0xFF322C1D, 0xFFA28F60, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A26D, 0xFF342E1F, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF070604, 0xFF918157, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA472, 0xFFBAA572, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 
        0xFFBBA573, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBCA774, 0xFFB19E6E, 0xFF9D8C61, 0xFF9D8B61, 0xFF8F7F59, 0xFF473F2C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF0C0B07, 0xFF706446, 0xFF97865E, 0xFF9D8C63, 0xFF9F8D63, 0xFFBCA876, 0xFFBCA876, 0xFFBDA776, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBCA876, 0xFFBDA876, 0xFFBCA876, 0xFFBCA876, 
        0xFFBCA876, 0xFFBCA876, 0xFFBCA875, 0xFFBDA876, 0xFF1C1912, 0xFF000000, 0xFF000000, 0xFF99885F, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBBA774, 0xFFBCA774, 0xFFBBA674, 
        0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA573, 0xFFBBA673, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA571, 0xFFBAA471, 0xFFB9A471, 0xFFBAA471, 0xFFB9A470, 
        0xFFB9A470, 0xFFB9A470, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A16B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB19B67, 0xFF403825, 0xFF000000, 0xFF282317, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB49D67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFF88764C, 0xFF13110A, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF312B1B, 0xFF9E8957, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA78F52, 0xFF7B683C, 0xFF0D0B06, 0xFF000000, 
        0xFF5D4F2D, 0xFFA48B4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF4C3F22, 0xFF000000, 0xFF0E0C06, 0xFF7F6A39, 0xFFA18748, 0xFFA18747, 0xFFA18646, 0xFFA18646, 
        0xFFA08646, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF93762F, 0xFF92752F, 
        0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F7129,
  0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF93762F, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 
        0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF9A7E3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF776435, 0xFF090804, 0xFF010100, 0xFF524525, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 
        0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF867240, 0xFF030301, 0xFF000000, 0xFF554829, 0xFFA58C51, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 
        0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFA89157, 0xFF685936, 0xFF0A0805, 0xFF0B0906, 0xFF15120B, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF645736, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 
        0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFF988454, 0xFF0D0C07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF615436, 0xFFB29C65, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB49D67, 
        0xFFB49D67, 0xFFB49E67, 0xFFB49D68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFF5C5136, 0xFF000000, 0xFF000000, 0xFF342E1F, 0xFFB59F6A, 0xFFB6A06C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A16D, 0xFF13110B, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF0B0A06, 0xFFAF9A68, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA572, 0xFFBAA572, 0xFFBBA573, 0xFFBAA573, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA774, 0xFFBAA473, 0xFF655B3F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF090805, 0xFF867753, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA875, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA776, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFF908059, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF352F21, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA774, 0xFFBCA774, 0xFFBCA674, 0xFFBCA774, 0xFFBCA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 
        0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBAA673, 0xFFBBA673, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 
        0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB39D69, 0xFF564C32, 0xFF000000, 0xFF0C0B07, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB39B65, 0xFFB29B64, 0xFFAD9661, 0xFF362F1E, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0906, 0xFF8A784C, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC935A, 0xFFAB9459, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA78F52, 0xFF79673B, 0xFF000000, 0xFF000000, 0xFF6F5F35, 
        0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFF514425, 0xFF010100, 0xFF090804, 0xFF786435, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 
        0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3A, 
        0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987B37, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947731, 0xFF947731, 0xFF947630, 0xFF937630, 0xFF93752F, 0xFF92752F, 
        0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF90732C, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129,
  0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957933, 0xFF967934, 0xFF967934, 
        0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 
        0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF6F5D32, 0xFF080704, 0xFF000000, 0xFF5F502B, 0xFFA3894A, 0xFFA3894B, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA68C4E, 0xFFA68D50, 0xFF8D7744, 0xFF16120A, 0xFF000000, 0xFF4F4326, 0xFFA0884E, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99155, 
        0xFFA99156, 0xFFAA9256, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9259, 0xFF9C8651, 0xFF413721, 0xFF0A0905, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF13100A, 0xFF9C8753, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 
        0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFAE9760, 0xFF4B4129, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1B180F, 0xFFB29B63, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB29C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 
        0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49D68, 0xFFB59E68, 0xFFB59E69, 0xFFA99462, 0xFF403825, 0xFF000000, 0xFF040302, 0xFF50462E, 0xFFB5A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFA79263, 0xFF080705, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF16130D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA571, 
        0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBBA573, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFF9A895F, 0xFF13100B, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF1B1811, 0xFFBBA674, 0xFFBCA775, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 0xFFBCA775, 
        0xFFBCA775, 0xFFBCA775, 0xFFBCA774, 0xFF332D20, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030302, 0xFF9E8C62, 0xFFBBA774, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 
        0xFFBBA673, 0xFFBBA573, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A470, 0xFFB8A36F, 0xFFB8A36F, 
        0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB5A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB59F69, 0xFF695C3D, 0xFF000000, 0xFF010100, 0xFFAC9763, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29A64, 0xFFB29A64, 0xFFB19A63, 0xFF5A4E31, 0xFF0A0905, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5B4F31, 0xFFA7905A, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9256, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA68E51, 0xFF685933, 0xFF000000, 0xFF000000, 0xFF463B21, 0xFFA68D50, 
        0xFFA68C50, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFF5E4F2B, 0xFF000000, 0xFF090804, 0xFF705E32, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08545, 
        0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 
        0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752F, 
        0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129,
  0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90732B, 0xFF90732C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF947833, 0xFF957833, 0xFF957933, 0xFF967934, 
        0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803E, 0xFF9C803F, 0xFF9D8140, 
        0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF776435, 0xFF0A0904, 0xFF000000, 0xFF514525, 0xFFA3894B, 
        0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA48B4E, 0xFFA68C4F, 0xFF4E4225, 0xFF000000, 0xFF000000, 0xFF332B18, 0xFF9B834C, 0xFFA78F52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 
        0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFF867346, 0xFF3B331F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF292316, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 
        0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFF927E51, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF8C794D, 0xFFB19A63, 0xFFB19A63, 0xFFB19B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB29B65, 0xFFB39C65, 
        0xFFB39C66, 0xFFB39D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFA18C5C, 0xFF2D281A, 0xFF000000, 0xFF020201, 0xFF6E6140, 0xFFB59F69, 0xFFB59F69, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFF8B7A51, 0xFF050503, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF383121, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB9A470, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 
        0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA472, 0xFFBAA472, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBBA572, 0xFFBAA573, 0xFFBAA572, 0xFFA79466, 0xFF1B1811, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF2E291C, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA673, 0xFFBBA674, 0xFFBBA673, 0xFFBBA673, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA674, 0xFFBBA673, 0xFFBBA674, 
        0xFFBBA674, 0xFFBBA674, 0xFF9D8B61, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF524832, 0xFFBBA673, 0xFFBBA573, 0xFFBBA573, 0xFFBBA573, 0xFFBBA673, 0xFFBBA572, 0xFFBBA573, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA571, 0xFFBAA572, 0xFFBAA572, 0xFFBAA571, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A370, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB5A06A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 
        0xFFB49E68, 0xFF796A46, 0xFF020201, 0xFF020101, 0xFF938054, 0xFFB49D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB29C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB19A62, 0xFF847349, 
        0xFF211D12, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2F2819, 0xFF95804F, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC955A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 
        0xFFAB9359, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF4F4327, 0xFF000000, 0xFF030301, 0xFF050402, 0xFF040302, 0xFF63542F, 
        0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFF514525, 0xFF000000, 0xFF0A0904, 0xFF786435, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 
        0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D39, 
        0xFF997C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 
        0xFF92742D, 0xFF91742C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8E7028,
  0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7229, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957833, 
        0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 
        0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18748, 0xFFA28748, 0xFF786435, 0xFF080704, 0xFF010100, 0xFF4B3F22, 
        0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4E, 0xFF675731, 0xFF000000, 0xFF000000, 0xFF110E08, 0xFF000000, 0xFF1F1A0F, 0xFF9B844C, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 
        0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFA99158, 0xFF837144, 0xFF18140C, 0xFF000000, 0xFF000000, 0xFF1B170E, 0xFFAD955C, 0xFFAE955C, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE975E, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFF332C1B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4A4029, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 
        0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFF9B8859, 0xFF100E09, 0xFF000000, 0xFF000000, 0xFF87764E, 0xFFB49E68, 0xFFB49E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFF716342, 0xFF030302, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF615539, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB8A26D, 0xFFB8A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 
        0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA572, 0xFFBAA471, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFAC9969, 0xFF201C13, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF3E3726, 0xFFBBA573, 0xFFBBA573, 0xFFBAA673, 0xFFBBA573, 0xFFBBA673, 0xFFBBA573, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 0xFFBBA673, 
        0xFFBBA673, 0xFFBBA673, 0xFF5A5037, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1F1B13, 0xFFA69265, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA472, 0xFFBAA472, 0xFFBAA571, 
        0xFFB9A471, 0xFFBAA471, 0xFFB9A471, 0xFFBAA471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 
        0xFFB49E68, 0xFF87764E, 0xFF0B0906, 0xFF010100, 0xFF796A45, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 
        0xFFA48E59, 0xFF3F3622, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060503, 0xFF685A37, 0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945B, 0xFFA68F57, 0xFF98834F, 0xFFAB9459, 0xFFAB9359, 0xFFAB9358, 
        0xFFAB9258, 0xFFAA9258, 0xFFAA9157, 0xFFAA9157, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA78E53, 0xFFA78E52, 0xFF352D1A, 0xFF000000, 0xFF0F0D07, 0xFF907A45, 0xFF5D4F2D, 0xFF000000, 0xFF020201, 
        0xFF64552F, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFF4C3F22, 0xFF010100, 0xFF090804, 0xFF786435, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 
        0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987D39, 
        0xFF987C39, 0xFF987B38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967935, 0xFF957933, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 
        0xFF91742D, 0xFF91732C, 0xFF90732C, 0xFF90722B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028,
  0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 
        0xFF957934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997C3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 
        0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8341, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA28748, 0xFF6F5D31, 0xFF090804, 0xFF000000, 
        0xFF574927, 0xFFA1874A, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFF746237, 0xFF000000, 0xFF000000, 0xFF453A20, 0xFFA68D50, 0xFF362E1A, 0xFF000000, 0xFF0F0D07, 0xFF8A7644, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFA99157, 0xFF54492C, 0xFF100D08, 0xFF030201, 0xFF665835, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAF975E, 0xFF796841, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF100E09, 0xFF988454, 0xFFB09962, 0xFFB09962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB19B64, 0xFFB29B64, 
        0xFFB29C65, 0xFFB39B65, 0xFFB29C65, 0xFF86744C, 0xFF020201, 0xFF000000, 0xFF17140D, 0xFF9B8758, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFF534830, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF887750, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB8A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 
        0xFFB8A370, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA571, 0xFFAE9969, 0xFF211D14, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF433C29, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA572, 0xFFBAA573, 0xFFBBA572, 0xFFBBA572, 0xFFBAA572, 0xFFBBA572, 0xFFBAA573, 0xFFBAA572, 0xFFBAA572, 
        0xFFBAA572, 0xFFAC9869, 0xFF272218, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF7E6F4D, 0xFFBAA572, 0xFFBAA472, 0xFFBAA571, 0xFFBAA571, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 
        0xFFB9A471, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A26D, 0xFFB8A16E, 0xFFB7A16D, 
        0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49D68, 
        0xFFB49D67, 0xFF958356, 0xFF13110B, 0xFF000000, 0xFF605437, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 
        0xFFB09860, 0xFFAF985F, 0xFF574B2F, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1D190F, 0xFF53482C, 0xFF5C4F30, 0xFF3C341F, 0xFF060503, 0xFF39311E, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 
        0xFFAB9257, 0xFFAA9157, 0xFFAA9157, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF98814A, 0xFF251F12, 0xFF000000, 0xFF211C10, 0xFF978048, 0xFFA68D50, 0xFFA3894E, 0xFF3A311C, 0xFF000000, 
        0xFF070603, 0xFF756336, 0xFFA48A4D, 0xFFA48A4D, 0xFFA3894C, 0xFFA3894B, 0xFFA1874A, 0xFF574927, 0xFF000000, 0xFF090804, 0xFF705D32, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 
        0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF987D39, 0xFF997C39, 
        0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A37, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947730, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92742E, 0xFF92742E, 0xFF91742D, 
        0xFF91732D, 0xFF91732B, 0xFF90732B, 0xFF90722B, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027,
  0xFF8E6F27, 0xFF8E7027, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 
        0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 
        0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF776435, 0xFF0E0C06, 
        0xFF000000, 0xFF493D21, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFF7B6739, 0xFF0C0A05, 0xFF000000, 0xFF352C19, 0xFF9D854A, 0xFFA58D4F, 0xFFA58B4F, 0xFF534728, 0xFF000000, 0xFF090704, 0xFF6C5B34, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFF907C4B, 0xFF483E26, 0xFF120F09, 0xFF52472B, 0xFF9E8853, 0xFFAD955C, 
        0xFFAD965D, 0xFFAE965C, 0xFFAE965D, 0xFF94804F, 0xFF0D0B07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF54492E, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09962, 0xFFB09961, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29C64, 0xFF685A3A, 0xFF080704, 0xFF000000, 0xFF2A2418, 0xFF9B8758, 0xFFB39C66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59F69, 0xFF3C3523, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFFA89463, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16B, 0xFFB6A06C, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26D, 0xFFB7A26E, 0xFFB7A26E, 0xFFB7A26E, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26F, 
        0xFFB8A26E, 0xFFB9A26F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A370, 0xFFB8A36F, 0xFFB9A36F, 0xFFB8A46F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A471, 0xFFB9A470, 0xFFB9A470, 0xFFAF9A69, 0xFF211D14, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF443C29, 0xFFBAA571, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFB9A472, 0xFFBAA472, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 0xFFBAA571, 0xFFBAA471, 0xFFBAA471, 0xFFBAA471, 
        0xFFBAA471, 0xFF8C7B55, 0xFF000000, 0xFF000000, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2B261A, 0xFFB9A471, 0xFFB9A471, 0xFFBAA470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A471, 0xFFB9A471, 0xFFB9A370, 0xFFB9A470, 0xFFB9A36F, 
        0xFFB9A36F, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A26F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A26F, 0xFFB8A26E, 0xFFB7A26E, 0xFFB7A26D, 0xFFB8A16D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 
        0xFFB6A06C, 0xFFB6A06C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB59E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49D68, 0xFFB49D67, 0xFFB39D66, 
        0xFFB39C67, 0xFFA38E5D, 0xFF1B180F, 0xFF000000, 0xFF473E28, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 
        0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFF796841, 0xFF0F0D08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1B170E, 0xFF6B5C37, 0xFFA88F56, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 
        0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F53, 0xFFA78E52, 0xFFA88F53, 0xFF867241, 0xFF1C180D, 0xFF000000, 0xFF39301B, 0xFF988149, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4F, 0xFF9C834A, 0xFF312916, 
        0xFF000000, 0xFF120F08, 0xFF836E3D, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFF4A3D21, 0xFF000000, 0xFF0E0C06, 0xFF786436, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 
        0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 
        0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 
        0xFF91732C, 0xFF90732B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7027, 0xFF8E7027,
  0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732B, 0xFF91732C, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957832, 
        0xFF957833, 0xFF957933, 0xFF957934, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 
        0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF7F6A38, 
        0xFF0D0B06, 0xFF000000, 0xFF362D18, 0xFFA28849, 0xFFA3894B, 0xFF8F7842, 0xFF0F0C07, 0xFF000000, 0xFF221C10, 0xFF9F864A, 0xFFA58B4E, 0xFFA58B4F, 0xFFA58C4F, 0xFFA68C50, 0xFF716036, 0xFF000000, 0xFF000000, 0xFF544728, 0xFFA78E52, 0xFFA78E52, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAB9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFA89158, 0xFF8C7849, 0xFF2A2416, 0xFF0E0C07, 0xFF6A5B38, 
        0xFFAD955C, 0xFFAD955C, 0xFF9B8652, 0xFF241F13, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0C07, 0xFFA38D58, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 
        0xFFB29A63, 0xFF4A4129, 0xFF010100, 0xFF000000, 0xFF403824, 0xFFAB9561, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFA99461, 0xFF2B2619, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF0C0A07, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26D, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFAE9969, 0xFF211D14, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF443C29, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFBAA471, 0xFFBAA471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 0xFFB9A471, 
        0xFFB9A471, 0xFF423A28, 0xFF000000, 0xFF18150E, 0xFF675B3F, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF96845A, 0xFFB9A370, 0xFFB9A470, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A36F, 0xFFB8A36F, 
        0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB8A16E, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D66, 0xFFB39D67, 0xFFB39C66, 
        0xFFB39C65, 0xFFB19A65, 0xFF221E13, 0xFF000000, 0xFF332C1D, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9760, 0xFFAF975F, 
        0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965E, 0xFF7A6941, 0xFF0A0805, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020101, 0xFF625433, 0xFFA18A54, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9156, 
        0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89055, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF6F5E36, 0xFF060503, 0xFF000000, 0xFF574A2A, 0xFFA2894E, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA48B4D, 0xFF9A8348, 
        0xFF282212, 0xFF000000, 0xFF0E0C06, 0xFF8E7741, 0xFFA3894A, 0xFF362D18, 0xFF000000, 0xFF0E0C06, 0xFF806A39, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8343, 0xFF9E8343, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987B38, 
        0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967A36, 0xFF967934, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92752D, 0xFF91742D, 0xFF91742C, 0xFF91732C, 
        0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26,
  0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90732B, 0xFF90732B, 0xFF91732C, 0xFF91742C, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 
        0xFF947732, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 
        0xFF816C3A, 0xFF0D0B06, 0xFF000000, 0xFF3D331C, 0xFF917942, 0xFF110F08, 0xFF000000, 0xFF1B170C, 0xFF9D8449, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA68C50, 0xFF887340, 0xFF0D0B06, 0xFF000000, 0xFF352D19, 0xFFA38A50, 
        0xFFA78F52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC9359, 0xFFAC945A, 0xFF71623B, 0xFF0E0C07, 
        0xFF0B0906, 0xFF17140C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF605434, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFAA935E, 
        0xFF3A3220, 0xFF000000, 0xFF000000, 0xFF53482E, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39D66, 0xFFB39D66, 0xFFB39D67, 0xFFB39D67, 0xFFB39D67, 0xFF9E895A, 0xFF1B180F, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF302A1C, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB7A06B, 0xFFB6A06B, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26D, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A36E, 0xFFB8A36E, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB9A36F, 0xFFAE9968, 0xFF211D14, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF443C29, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A370, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 0xFFB9A470, 
        0xFFAE9A69, 0xFF000000, 0xFF000000, 0xFF6F6243, 0xFFAA9667, 0xFF070704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF322C1E, 0xFFB9A370, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A36F, 0xFFB8A26F, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB8A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 
        0xFFB39C65, 0xFFB39C65, 0xFF322C1C, 0xFF000000, 0xFF272215, 0xFFAA945E, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 
        0xFFAF975E, 0xFFAE975D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFF342D1C, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF352D1B, 0xFF9E8852, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 
        0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA99054, 0xFFA88F53, 0xFFA88F53, 0xFFA68C51, 0xFF55482A, 0xFF000000, 0xFF070603, 0xFF62542F, 0xFFA68D50, 0xFFA68D50, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4D, 0xFFA48A4D, 
        0xFF937B44, 0xFF1C170C, 0xFF000000, 0xFF131008, 0xFF352C18, 0xFF000000, 0xFF0D0B06, 0xFF816C3A, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7D3B, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 
        0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF90732B, 
        0xFF90722B, 0xFF8F722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26,
  0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7028, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947732, 
        0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9B803E, 0xFF9C813E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 
        0xFFA18748, 0xFF88713C, 0xFF1C180C, 0xFF000000, 0xFF0D0B06, 0xFF000000, 0xFF1A160C, 0xFF8B7540, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA68C4F, 0xFF8C7743, 0xFF292214, 0xFF000000, 0xFF221D10, 
        0xFF887443, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFF9F8953, 
        0xFF50452A, 0xFF100E08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0A06, 0xFFAE965E, 0xFFAE975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFF9B8756, 0xFF2F291A, 
        0xFF000000, 0xFF040402, 0xFF615436, 0xFFB19B63, 0xFFB29A64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB49D66, 0xFF927F53, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF51472E, 0xFFB59E68, 0xFFB59E69, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 
        0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFAD9968, 0xFF211D14, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF433C28, 0xFFB8A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A36F, 0xFFB9A370, 0xFFB9A36F, 
        0xFF534932, 0xFF000000, 0xFF0C0A07, 0xFFAD9868, 0xFFB49F6C, 0xFF453E2A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF9A875D, 0xFFB8A26F, 0xFFB8A26F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 
        0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6B, 0xFFB6A06A, 0xFFB5A06A, 
        0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59E68, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E67, 0xFFB49D68, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 
        0xFFB29B64, 0xFFB29B64, 0xFF4B412A, 0xFF000000, 0xFF1C180F, 0xFF9E8958, 0xFFB19A63, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975F, 0xFFAE975E, 0xFFAE975E, 
        0xFFAE965E, 0xFFAE965D, 0xFFAD965C, 0xFFAD965C, 0xFFAD955C, 0xFF403721, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2D2617, 0xFF78673E, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 
        0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF99834B, 0xFF3F361F, 0xFF000000, 0xFF16130B, 0xFF726137, 0xFFA68D50, 0xFFA68D4F, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 
        0xFFA4894C, 0xFF846F3D, 0xFF120F08, 0xFF000000, 0xFF000000, 0xFF1C180C, 0xFF89723D, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 
        0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3C, 0xFF9A7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 
        0xFF977A36, 0xFF977A35, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90732B, 
        0xFF90722A, 0xFF90722A, 0xFF8F7229, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26,
  0xFF8C6E25, 0xFF8D6E26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947630, 
        0xFF947731, 0xFF957732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF977A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 
        0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8445, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 
        0xFFA18747, 0xFFA18748, 0xFF8E773F, 0xFF262011, 0xFF000000, 0xFF040302, 0xFF6B5A30, 0xFFA3894B, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFF9C834A, 0xFF4C4125, 0xFF000000, 
        0xFF0D0B06, 0xFF6B5A34, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA89054, 0xFFA99155, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 
        0xFFAC945A, 0xFF927D4C, 0xFF483E26, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF37301D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAE975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFF907C4E, 0xFF18150D, 0xFF000000, 
        0xFF070604, 0xFF827148, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB29B63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFF84734B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF766743, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB8A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFAD9867, 0xFF211D13, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF433B28, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A36E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26F, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB29D6A, 
        0xFF090805, 0xFF000000, 0xFF4D432E, 0xFFB59F6C, 0xFFB8A26E, 0xFF80714C, 0xFF070604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433B28, 0xFFB8A26E, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 
        0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 
        0xFFB59F69, 0xFFB59F69, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB19B64, 0xFFB29B63, 0xFF645738, 0xFF000000, 0xFF120F09, 0xFF917E50, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFF95814E, 0xFF14110B, 0xFF000000, 0xFF121009, 0xFF73623B, 0xFFA28B54, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFAA9155, 0xFFA99055, 0xFFA99054, 
        0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA78F53, 0xFFA88F53, 0xFF826F40, 0xFF1B170D, 0xFF000000, 0xFF302817, 0xFF907A45, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 
        0xFFA3894B, 0xFF8A743E, 0xFF0F0C06, 0xFF000000, 0xFF262011, 0xFF8E773F, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 
        0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977B36, 0xFF977B36, 
        0xFF967A36, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF90722B, 0xFF90722A, 
        0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8C6E25,
  0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF937630, 
        0xFF947631, 0xFF947732, 0xFF947832, 0xFF957832, 0xFF957933, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 
        0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFF9B8144, 0xFF211C0F, 0xFF000000, 0xFF131008, 0xFF88723E, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFFA68C50, 0xFF675731, 
        0xFF050402, 0xFF000000, 0xFF473C22, 0xFFA68D51, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 
        0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFF877446, 0xFF1A170E, 0xFF000000, 0xFF000000, 0xFF19150D, 0xFFAD965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE975D, 0xFFAE975E, 0xFFAE975F, 0xFFAF975F, 0xFFAF975F, 0xFF7B6B43, 0xFF080704, 0xFF000000, 0xFF12100A, 
        0xFF937F51, 0xFFB09961, 0xFFB09962, 0xFFB09962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFF695C3B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF948255, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06A, 0xFFB6A06B, 
        0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFAC9766, 0xFF211D13, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF433B28, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26D, 0xFFB7A26E, 0xFFB7A26E, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB7A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB8A26E, 0xFF6C5F40, 
        0xFF010100, 0xFF070604, 0xFF83734E, 0xFFB8A26E, 0xFFB8A26E, 0xFFB6A06C, 0xFF1C1911, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF17140E, 0xFF9E8B5E, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16D, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 
        0xFFB7A16C, 0xFFB6A06C, 0xFFB7A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06A, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 
        0xFFB59E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB39B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19B63, 
        0xFFB19A63, 0xFFB19A63, 0xFF817047, 0xFF000000, 0xFF070604, 0xFF857349, 0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE955C, 0xFFAD965C, 
        0xFFAD955C, 0xFFAD955C, 0xFFAC955B, 0xFF9E8853, 0xFF1D190F, 0xFF000000, 0xFF4E4329, 0xFFAA9158, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9256, 0xFFA99156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 
        0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78D51, 0xFF6D5C35, 0xFF060503, 0xFF010100, 0xFF3F351E, 0xFFA28A4E, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 
        0xFF88723E, 0xFF131008, 0xFF000000, 0xFF221C0F, 0xFF9B8146, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 
        0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF977B38, 0xFF977B37, 0xFF977A36, 0xFF967A36, 
        0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957834, 0xFF957832, 0xFF957732, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 
        0xFF90722A, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25,
  0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F712A, 0xFF8F722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 
        0xFF937631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957834, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08544, 0xFFA08545, 0xFFA08546, 
        0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA28749, 0xFF39301A, 0xFF000000, 0xFF070603, 0xFF766335, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 
        0xFF776539, 0xFF1A160C, 0xFF000000, 0xFF312917, 0xFF8E7845, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 
        0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFFAC945A, 0xFF615333, 0xFF18150D, 0xFF000000, 0xFF5E5132, 0xFFAD955C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFA18B56, 0xFF615434, 0xFF030201, 0xFF000000, 0xFF1C190F, 0xFF907D4F, 
        0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFF473E28, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0B0A06, 
        0xFFA08C5B, 0xFFB39D66, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB6A16B, 0xFFB6A06C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFAC9765, 0xFF211D13, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF433B28, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A16D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A26D, 0xFFB7A16D, 0xFFB39D6A, 0xFF2D271A, 
        0xFF000000, 0xFF211D13, 0xFFAE9967, 0xFFB7A26D, 0xFFB7A16D, 0xFFB7A16D, 0xFF685C3E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF6D6040, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 
        0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 
        0xFFB49E68, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB19B64, 0xFFB29B63, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19A62, 0xFF998454, 0xFF000000, 0xFF000000, 0xFF786842, 0xFFB09861, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975E, 0xFFAE975D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAC955B, 0xFFAA9259, 0xFF16130B, 0xFF2F2919, 0xFF8E7A49, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99155, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 
        0xFFA88F53, 0xFFA88F53, 0xFF99824B, 0xFF4F4326, 0xFF000000, 0xFF0B0905, 0xFF5D4F2D, 0xFFA68D50, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF766336, 
        0xFF060503, 0xFF000000, 0xFF3A311A, 0xFFA28748, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 
        0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987B38, 0xFF987C38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 
        0xFF967935, 0xFF957934, 0xFF957933, 0xFF957833, 0xFF957732, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722A, 0xFF8F722A, 
        0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6D24,
  0xFF8C6D23, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF90722B, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93752F, 
        0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF957732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF977B38, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7D3B, 
        0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8341, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 
        0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18747, 0xFFA18747, 0xFFA08647, 0xFF554726, 0xFF000000, 0xFF050402, 0xFF554827, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 
        0xFFA58C4F, 0xFF927B45, 0xFF3D331D, 0xFF000000, 0xFF141109, 0xFF685832, 0xFFA78E52, 0xFFA78F52, 0xFFA78F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9157, 0xFFAA9157, 0xFFAA9258, 
        0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC945A, 0xFF98834F, 0xFF594C2F, 0xFF0A0805, 0xFF413822, 0xFF877447, 0xFFA18B55, 0xFF988451, 0xFF645635, 0xFF252014, 0xFF000000, 0xFF000000, 0xFF19160E, 0xFF998452, 0xFFAF975F, 
        0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFF272215, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF201C12, 
        0xFFA4905D, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 
        0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06B, 0xFFB69F6A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFAB9664, 0xFF201C13, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF433A27, 0xFFB6A16C, 0xFFB7A06C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB7A16C, 0xFFB7A06C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB6A16C, 0xFF907F55, 0xFF0A0906, 
        0xFF000000, 0xFF5B5036, 0xFFB7A16C, 0xFFB6A16C, 0xFFB7A16C, 0xFFB7A16C, 0xFFB59F6B, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF282317, 0xFFB19C68, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6A, 
        0xFFB6A06A, 0xFFB6A06A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 
        0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB29B65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 
        0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFF000000, 0xFF000000, 0xFF655837, 0xFFAE975F, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAC955B, 
        0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFF847245, 0xFFA78F56, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88E52, 0xFF816E3F, 0xFF241E11, 0xFF000000, 0xFF201B0F, 0xFF826F3F, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF554726, 0xFF040302, 
        0xFF000000, 0xFF554626, 0xFFA08647, 0xFFA18748, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 
        0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF967A36, 0xFF967A35, 0xFF967935, 
        0xFF957934, 0xFF957934, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF90732B, 0xFF90732B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 
        0xFF8F7129, 0xFF8F7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24,
  0xFF8C6D23, 0xFF8C6D24, 0xFF8D6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91742C, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 
        0xFF937630, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957933, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 
        0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 
        0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF66562E, 0xFF000000, 0xFF000000, 0xFF463B1F, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4D, 0xFFA58B4E, 
        0xFFA58C4F, 0xFFA68C4F, 0xFFA3894D, 0xFF5B4D2C, 0xFF000000, 0xFF030201, 0xFF433921, 0xFFA38B50, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 
        0xFFAB9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAB9459, 0xFFAC945A, 0xFFAB9359, 0xFF998450, 0xFF312A1A, 0xFF000000, 0xFF050402, 0xFF050402, 0xFF020101, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF947F4F, 0xFFAE975E, 0xFFAF975E, 
        0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09861, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB09962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFF090705, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF393120, 
        0xFFAB9561, 0xFFB29C65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB49D66, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 
        0xFFB59E69, 0xFFB59E69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB6A06A, 0xFFB6A06B, 0xFFAB9664, 0xFF201C13, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF433A27, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A16C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB7A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06C, 0xFFB49F6A, 0xFF5A4F35, 0xFF000000, 
        0xFF000000, 0xFFAD9865, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06C, 0xFFB6A06B, 0xFFB6A06B, 0xFF615539, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF918054, 0xFFB69F6B, 0xFFB5A06A, 0xFFB69F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 
        0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E69, 0xFFB59E69, 0xFFB59E69, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 
        0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29C64, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09961, 
        0xFFB09961, 0xFFB09861, 0xFFB09860, 0xFF110F09, 0xFF000000, 0xFF4C4229, 0xFFAC955D, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 
        0xFFAC945A, 0xFFAB935A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 
        0xFF685933, 0xFF050402, 0xFF000000, 0xFF211C10, 0xFFA48B4F, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894A, 0xFF453A1F, 0xFF000000, 0xFF000000, 
        0xFF67562E, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 
        0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967935, 0xFF967934, 
        0xFF957834, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947731, 0xFF947630, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90722B, 0xFF90722A, 0xFF90712A, 0xFF8F7129, 0xFF8F7129, 
        0xFF8F7128, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8D6E25, 0xFF8C6D24, 0xFF8C6D23,
  0xFF8C6D23, 0xFF8C6D23, 0xFF8C6E24, 0xFF8D6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8E7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 
        0xFF92752F, 0xFF937630, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947732, 0xFF957732, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967A36, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF977B38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 
        0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08647, 0xFFA18647, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF7D6838, 0xFF0E0C06, 0xFF000000, 0xFF302816, 0xFF967E44, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFF574A2A, 0xFF000000, 0xFF000000, 0xFF231E11, 0xFF8C7744, 0xFFA78E52, 0xFFA78F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 
        0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFF74633D, 0xFF1D190F, 0xFF020101, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF312A1A, 0xFFA79059, 0xFFAE965D, 0xFFAE965E, 
        0xFFAF975E, 0xFFAE975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFA08B58, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF4F452C, 
        0xFFB19A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 
        0xFFB49E68, 0xFFB59E68, 0xFFB49E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFAB9563, 0xFF201C13, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF433A27, 0xFFB6A06B, 0xFFB6A06A, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFAF9A67, 0xFF13110B, 0xFF000000, 
        0xFF433B27, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB6A06B, 0xFFB69F6B, 0xFFB6A06B, 0xFFAD9865, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2F291B, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F69, 
        0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59F69, 0xFFB59E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39D66, 
        0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19B64, 0xFFB19A63, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09962, 0xFFB09961, 0xFFB09961, 
        0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFF30291A, 0xFF000000, 0xFF322B1B, 0xFFAB945D, 0xFFAE975E, 0xFFAE965E, 0xFFAE965E, 0xFFAE965D, 0xFFAD965C, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFF97814A, 0xFF3A321C, 
        0xFF000000, 0xFF0B0905, 0xFF010100, 0xFF0A0805, 0xFF84703E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFF967E44, 0xFF2F2815, 0xFF000000, 0xFF0E0C06, 0xFF7D6938, 
        0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 
        0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF977A35, 0xFF967935, 0xFF967934, 0xFF957934, 
        0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7128, 
        0xFF8E7128, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23,
  0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 
        0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 
        0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8341, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF89723C, 0xFF241E10, 0xFF000000, 0xFF1B160C, 0xFF7E6939, 0xFFA3894A, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFF907A45, 0xFF16130A, 0xFF000000, 0xFF17130B, 0xFF000000, 0xFF060503, 0xFF574A2A, 0xFFA38B50, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99155, 
        0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9358, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC935A, 0xFFA38C56, 0xFF625434, 0xFF16130B, 0xFF000000, 0xFF000000, 0xFF1F1A10, 0xFFA68F58, 0xFFAD965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFF7A6A43, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF635637, 
        0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29B64, 0xFFB29C64, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C65, 0xFFB39C67, 0xFFB39D66, 0xFFB39D66, 0xFFB49D66, 0xFFB49D67, 0xFFB49D67, 
        0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49F69, 0xFFB59E69, 0xFFB59E68, 0xFFB59E68, 0xFFB59E69, 0xFFB59E69, 0xFFB59E69, 0xFFB49E69, 0xFFAA9563, 0xFF201C12, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF423A27, 0xFFB59F6A, 0xFFB59F69, 0xFFB59F69, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB5A06A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6B, 0xFFB59F6A, 0xFF7A6B48, 0xFF000000, 0xFF000000, 
        0xFF9C895B, 0xFFB59F6A, 0xFFB69F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB59F6A, 0xFFB29D67, 0xFF4E452E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF958356, 0xFFB59F68, 0xFFB59E68, 0xFFB49E68, 0xFFB59E68, 0xFFB49F68, 
        0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49E68, 0xFFB49E67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB39D66, 0xFFB39C66, 0xFFB49C67, 0xFFB39C67, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 
        0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 
        0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFF4E442A, 0xFF000000, 0xFF100E08, 0xFFA9925A, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 
        0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFF6C5C35, 0xFF16130B, 0xFF000000, 
        0xFF2E2716, 0xFF836F3F, 0xFF352D19, 0xFF000000, 0xFF221D10, 0xFF988147, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF7E6A39, 0xFF1B160C, 0xFF000000, 0xFF241E10, 0xFF89723E, 0xFFA18748, 
        0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9C8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 
        0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A37, 0xFF977A36, 0xFF967935, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 
        0xFF957833, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7027, 
        0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6D23,
  0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 0xFF90722B, 0xFF90732B, 0xFF90732C, 0xFF91732D, 0xFF91742D, 0xFF92742D, 
        0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937530, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 
        0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFF9C8245, 0xFF382F19, 0xFF000000, 0xFF070603, 0xFF6A5930, 0xFFA3894A, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48B4D, 0xFFA58B4D, 0xFF9F874B, 0xFF38301A, 0xFF000000, 0xFF100E08, 0xFF927C46, 0xFF79663A, 0xFF030301, 0xFF000000, 0xFF201B0F, 0xFF957E49, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA98F54, 0xFFA99054, 0xFFA99055, 
        0xFFA99056, 0xFFA99156, 0xFFA99156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAC9359, 0xFFAC945A, 0xFF9E8852, 0xFF50452A, 0xFF000000, 0xFF000000, 0xFF655736, 0xFFAD955C, 0xFFAD965C, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09960, 0xFFB09861, 0xFF574C30, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060603, 0xFF796943, 
        0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 
        0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFA99462, 0xFF201C12, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF423A26, 0xFFB59F69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFF18150E, 0xFF000000, 0xFF322C1D, 
        0xFFB39C68, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59F69, 0xFFB59E69, 0xFFB59E68, 0xFF87764E, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF373020, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 
        0xFFB49D67, 0xFFB49E67, 0xFFB49D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C65, 0xFFB29C65, 0xFFB29B65, 0xFFB29B65, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB09A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFAF9860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 
        0xFFAF975F, 0xFFAE975F, 0xFFAE975E, 0xFF6A5B39, 0xFF000000, 0xFF000000, 0xFF947F4F, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 
        0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA38A50, 0xFF332B19, 0xFF010100, 0xFF000000, 0xFF61522F, 
        0xFFA1894D, 0xFFA68C50, 0xFF9D844A, 0xFF0C0A06, 0xFF000000, 0xFF41371E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFF6A5930, 0xFF070603, 0xFF000000, 0xFF382F19, 0xFF9C8246, 0xFFA18748, 0xFFA18747, 
        0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957832, 
        0xFF957732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF92742D, 0xFF91732D, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 
        0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22,
  0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 
        0xFF92742E, 0xFF92742E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 
        0xFF997C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA28748, 0xFF534625, 0xFF010100, 0xFF000000, 0xFF4A3E21, 0xFFA08648, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48B4D, 0xFF695931, 0xFF000000, 0xFF000000, 0xFF776539, 0xFFA58C4F, 0xFFA68C4F, 0xFF9D854B, 0xFF2B2515, 0xFF000000, 0xFF000000, 0xFF665631, 0xFFA38B50, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 
        0xFFA99055, 0xFFA99155, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFF917C4B, 0xFF292315, 0xFF000000, 0xFF6F603A, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFF30291A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0C07, 0xFF8F7C4F, 
        0xFFB19962, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 0xFFB19B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C64, 0xFFB29C65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 
        0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49E67, 0xFFB49D67, 0xFFB49E68, 0xFFA99461, 0xFF201C12, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF423A26, 0xFFB49E68, 0xFFB49E68, 0xFFB59E69, 0xFFB59E68, 0xFFB49E69, 0xFFB59E69, 0xFFB49E69, 0xFFB59E69, 0xFFB59E69, 0xFFB59E69, 0xFFB59E68, 0xFFB59E69, 0xFFB59E69, 0xFFB49E69, 0xFF88774F, 0xFF000000, 0xFF000000, 0xFF786946, 
        0xFFB59E68, 0xFFB59E69, 0xFFB59E68, 0xFFB49E69, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFAF9965, 0xFF292418, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0E0D08, 0xFF988457, 0xFFB49D67, 0xFFB49D68, 0xFFB49D67, 0xFFB49D67, 
        0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B63, 0xFFB19B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 
        0xFFAF975E, 0xFFAE975E, 0xFFAE965E, 0xFF816F46, 0xFF000000, 0xFF000000, 0xFF433A24, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFA89158, 0xFFA58E57, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAB9459, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 
        0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA58D52, 0xFF7F6C3E, 0xFF0F0C07, 0xFF000000, 0xFF18150C, 0xFF84703F, 0xFFA68D50, 
        0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFF7B683A, 0xFF000000, 0xFF000000, 0xFF6C5C33, 0xFFA48B4D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF9F8649, 0xFF4A3D21, 0xFF000000, 0xFF010100, 0xFF544626, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 
        0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 
        0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977B36, 0xFF977A36, 0xFF967A36, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957832, 
        0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 
        0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D23, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22,
  0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F7229, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742C, 
        0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B38, 
        0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8443, 0xFF9E8443, 0xFF9F8444, 0xFF9F8445, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF6C5B30, 0xFF110E07, 0xFF000000, 0xFF2D2614, 0xFF8B753F, 0xFFA3894B, 0xFFA3894C, 
        0xFFA3894C, 0xFF87713F, 0xFF070503, 0xFF000000, 0xFF554727, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68D50, 0xFF5E502D, 0xFF110E08, 0xFF000000, 0xFF322A18, 0xFF826E3F, 0xFFA88E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9256, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 0xFF685937, 0xFF6E5F3A, 0xFFAD945B, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965C, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFF0C0A06, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF14110A, 0xFFA28D59, 
        0xFFB09961, 0xFFB09962, 0xFFB09962, 0xFFB19962, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFFB29C65, 0xFFB29C64, 
        0xFFB39C66, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D66, 0xFFB49D67, 0xFFB49D67, 0xFFA99360, 0xFF201C12, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF423A26, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFF373020, 0xFF000000, 0xFF1A160F, 0xFF9E8B5A, 
        0xFFB49E68, 0xFFB49E68, 0xFFB49E68, 0xFFB49E67, 0xFFB49E68, 0xFFB49E68, 0xFFB49D68, 0xFFB49E68, 0xFFB49E67, 0xFF6B5E3D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5F5336, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39D66, 
        0xFFB39D67, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39B65, 0xFFB29B65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19B64, 0xFFB19A63, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB19962, 0xFFB19961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 
        0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFF897648, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF433923, 0xFF6A5C38, 0xFF645634, 0xFF3D3420, 0xFF413822, 0xFFA48D56, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 
        0xFFAA9256, 0xFFAA9157, 0xFFAA9156, 0xFFAA9155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA89053, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFF907B47, 0xFF493E23, 0xFF000000, 0xFF040302, 0xFF483D23, 0xFF9A834A, 0xFFA68D50, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFF4D4124, 0xFF000000, 0xFF070503, 0xFF87713E, 0xFFA38A4C, 0xFFA3894B, 0xFF8B7540, 0xFF2D2514, 0xFF000000, 0xFF110E07, 0xFF6C5A30, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA08647, 0xFFA08647, 
        0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9C8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3D, 
        0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 0xFF977A35, 0xFF967935, 0xFF967935, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF957832, 0xFF947732, 
        0xFF947731, 0xFF937731, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F27, 
        0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E24, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6B21,
  0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6D24, 0xFF8C6D24, 0xFF8D6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF91732C, 0xFF91732C, 
        0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92752F, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 
        0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 
        0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA18646, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF8C753E, 0xFF272111, 0xFF000000, 0xFF0F0C06, 0xFF6C5A31, 0xFFA3894A, 
        0xFF9C8348, 0xFF17140A, 0xFF000000, 0xFF322A17, 0xFF9E854A, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA68C4F, 0xFFA68C50, 0xFF907945, 0xFF3A311C, 0xFF000000, 0xFF0B0905, 0xFF483D22, 0xFFA48B50, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE965E, 0xFFAE975E, 0xFF9E8955, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1E1A10, 0xFFB09860, 
        0xFFB09860, 0xFFB09860, 0xFFB09960, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29C65, 0xFFB29C65, 0xFFB29C65, 0xFFB39B65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFA89260, 0xFF201C12, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF413925, 0xFFB49D67, 0xFFB39D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFF978456, 0xFF110F0A, 0xFF000000, 0xFF453C27, 0xFFB49D67, 
        0xFFB49D67, 0xFFB39D67, 0xFFB49D67, 0xFFB49D67, 0xFFB49D67, 0xFFB39D67, 0xFFB39D66, 0xFFB39D67, 0xFFB39D66, 0xFFB39D66, 0xFF090805, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF241F14, 0xFFA7925F, 0xFFB39C65, 0xFFB39C66, 0xFFB39C65, 
        0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB29C64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB29B64, 0xFFB19A63, 0xFFB29A63, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 
        0xFFB19962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE965C, 0xFFAD955C, 0xFF7D6C42, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2B2516, 0xFF8A7647, 0xFFA89157, 0xFFAB9358, 0xFFAB9358, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 
        0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88E53, 0xFFA88F52, 0xFF655631, 0xFF15120A, 0xFF000000, 0xFF1D190E, 0xFF816E3E, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFF9A8247, 0xFF201B0F, 0xFF000000, 0xFF262011, 0xFF9F8549, 0xFF6C5B31, 0xFF0F0C06, 0xFF000000, 0xFF282112, 0xFF8C763F, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA08546, 0xFFA08546, 
        0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 
        0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 
        0xFF947630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF90732C, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 
        0xFF8D6E25, 0xFF8D6E25, 0xFF8C6D24, 0xFF8C6D23, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B20,
  0xFF8A6B20, 0xFF8A6B20, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722B, 0xFF90722B, 0xFF91732B, 
        0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977B36, 
        0xFF977B37, 0xFF987B38, 0xFF987B38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 
        0xFF9D8242, 0xFF9D8342, 0xFF9E8342, 0xFF9E8342, 0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8445, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFF9E8446, 0xFF43381D, 0xFF010100, 0xFF000000, 0xFF4D4123, 
        0xFF3C331B, 0xFF000000, 0xFF100E07, 0xFF86713E, 0xFFA38A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C50, 0xFF6A5A33, 0xFF090704, 0xFF000000, 0xFF18140B, 0xFF887342, 0xFFA68D51, 0xFFA78E52, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9157, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD945B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFF7A6A42, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3C3420, 0xFFAF985F, 
        0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09861, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19A62, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29B65, 0xFFB29B65, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB39C65, 0xFFB39C65, 0xFFB39C65, 0xFFA89260, 0xFF201C12, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF413925, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFF65593A, 0xFF000000, 0xFF030302, 0xFF88774D, 0xFFB39D66, 
        0xFFB39D66, 0xFFB39D66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39D66, 0xFFB39C66, 0xFFB39C66, 0xFF605437, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF87764C, 0xFFB29C65, 0xFFB29C65, 0xFFB29B65, 
        0xFFB29B65, 0xFFB29B65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB19A63, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB19962, 0xFFB09961, 
        0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD965C, 
        0xFFAD965C, 0xFFAD955C, 0xFFAD955B, 0xFF5E5131, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF100D08, 0xFF76643D, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 
        0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFF9A834B, 0xFF2E2716, 0xFF000000, 0xFF000000, 0xFF4C4024, 0xFFA68D50, 0xFFA68D50, 0xFFA68D4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFF87723E, 0xFF040302, 0xFF000000, 0xFF1A160B, 0xFF000000, 0xFF010100, 0xFF43381E, 0xFF9E8546, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08545, 0xFFA08545, 
        0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987B38, 0xFF987C38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF937630, 
        0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F25, 
        0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20,
  0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90732B, 
        0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752F, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957832, 0xFF957834, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A36, 
        0xFF977B36, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9B803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 
        0xFF9D8240, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF5E4F2A, 0xFF100D07, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF66552F, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFF978048, 0xFF3B321C, 0xFF030201, 0xFF000000, 0xFF463C22, 0xFF8F7946, 
        0xFFA78F52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 
        0xFFAC9459, 0xFFAC935A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945A, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965D, 0xFFAD965C, 0xFFAE965D, 0xFF4A4027, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5E5133, 0xFFAF975F, 
        0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 
        0xFFB29A63, 0xFFB19B63, 0xFFB19A63, 0xFFB29B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29B65, 0xFFB29C64, 0xFFB29C65, 0xFFA7915F, 0xFF201B12, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF413925, 0xFFB39C65, 0xFFB39C66, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFAB9561, 0xFF2A2518, 0xFF000000, 0xFF1C1910, 0xFFB39C66, 0xFFB39C66, 
        0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB39C66, 0xFFB29C66, 0xFFB39C66, 0xFFB39C65, 0xFFB39C65, 0xFFB29C65, 0xFFB39C65, 0xFFAD9862, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF2B2618, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB19B64, 0xFFB19B63, 0xFFB19B63, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 
        0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 0xFF1F1B10, 0xFF000000, 0xFF000000, 0xFF120F09, 0xFF4C4127, 0xFFA08A53, 0xFFAB9358, 0xFFAB9359, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFA99156, 0xFFA99156, 0xFFA99055, 
        0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFF9A844C, 0xFF5A4C2C, 0xFF010100, 0xFF000000, 0xFF2B2515, 0xFF857140, 0xFFA68D50, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4F, 0xFFA58B4E, 0xFFA58B4D, 
        0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF4C4123, 0xFF000000, 0xFF000000, 0xFF100D07, 0xFF5F502A, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 
        0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8443, 0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957834, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 
        0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91742D, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8F7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 
        0xFF8C6E24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6B22, 0xFF8B6B21, 0xFF8A6B20, 0xFF8A6B20,
  0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 
        0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957933, 0xFF967934, 0xFF967A35, 0xFF967935, 
        0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987D39, 0xFF987D3A, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 
        0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8341, 0xFF9D8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8445, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA18646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF866F3B, 0xFF2D2614, 
        0xFF000000, 0xFF000000, 0xFF5A4C29, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFF7B693B, 0xFF1F1A0F, 0xFF000000, 0xFF110E08, 
        0xFF554829, 0xFFA78E52, 0xFFA88E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 0xFFAB9258, 0xFFAB9358, 
        0xFFAB9358, 0xFFAB9358, 0xFFAC9359, 0xFFAC9459, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFA08A55, 0xFF1E1A10, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF7E6D43, 0xFFAE965E, 
        0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975E, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFB09860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB19962, 0xFFB19A62, 
        0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29A63, 0xFFB19A63, 0xFFB19B63, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFA7915E, 0xFF201B12, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF413924, 0xFFB29B64, 0xFFB29B64, 0xFFB29B65, 0xFFB29B64, 0xFFB29B65, 0xFFB29C64, 0xFFB29B64, 0xFFB29C65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B65, 0xFFB29C65, 0xFF907D51, 0xFF000000, 0xFF000000, 0xFF796A44, 0xFFB29B65, 0xFFB29B65, 
        0xFFB29B64, 0xFFB29B65, 0xFFB29B65, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFF554A30, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF917D50, 0xFFB19B63, 0xFFB19A63, 
        0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB19A62, 0xFFB09962, 0xFFB09962, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 
        0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAE975E, 0xFFAE965E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC955B, 
        0xFFAC945B, 0xFFAC945A, 0xFF605232, 0xFF000000, 0xFF000000, 0xFF473D24, 0xFF8D7949, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 
        0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F52, 0xFF695933, 0xFF1C170D, 0xFF000000, 0xFF000000, 0xFF0E0C06, 0xFF8F7945, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894A, 0xFF5B4C29, 0xFF120F08, 0xFF000000, 0xFF2E2614, 0xFF856F3B, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 
        0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7D3B, 0xFF997D3A, 
        0xFF997D39, 0xFF997C39, 0xFF987C38, 0xFF977C38, 0xFF987B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF967933, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF937630, 0xFF937630, 
        0xFF93752F, 0xFF92752F, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7128, 0xFF8F7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6D24, 
        0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8A6C22, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F,
  0xFF896A1E, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 
        0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752F, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 
        0xFF967A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 
        0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA18748, 0xFF9D8446, 
        0xFF4A3E21, 0xFF000000, 0xFF000000, 0xFF332B17, 0xFF9E8547, 0xFFA3894B, 0xFFA4894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58C4E, 0xFFA58C4E, 0xFFA68C4F, 0xFFA68C4F, 0xFF231E11, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF100D07, 0xFF7C693C, 0xFFA78E52, 0xFFA88F53, 0xFFA78F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 
        0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFF6D5E39, 0xFF917C4C, 0xFFAC945B, 0xFFAD955B, 0xFF574B2E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFFA18B56, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF9860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09960, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 
        0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB19962, 0xFFB09962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFA6905D, 0xFF1F1B11, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF413924, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFF3F3723, 0xFF000000, 0xFF0F0D08, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 
        0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B64, 0xFFB29B63, 0xFFB29B63, 0xFF8F7D50, 0xFF090705, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF302A1B, 0xFFB19A63, 0xFFB19A62, 
        0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB09962, 0xFFB19A62, 0xFFB09962, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 
        0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC955B, 0xFFAC945B, 0xFFAC945A, 
        0xFFAC945A, 0xFF73633C, 0xFF040302, 0xFF1A160D, 0xFF897647, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFF937D48, 0xFF252012, 0xFF010100, 0xFF010100, 0xFF2E2716, 0xFF030301, 0xFF000000, 0xFF574A2A, 0xFFA58C4F, 0xFFA58B4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4E, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF9E8548, 0xFF332B17, 0xFF000000, 0xFF000000, 0xFF4B3F22, 0xFF9D8446, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9E8443, 
        0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8341, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7D3B, 0xFF997D3A, 0xFF997D3A, 
        0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF93752F, 
        0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 
        0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F,
  0xFF89691E, 0xFF89691F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F712A, 
        0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742C, 0xFF92742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967934, 
        0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D3A, 0xFF997D39, 0xFF997E3B, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 
        0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18747, 
        0xFFA28748, 0xFF736034, 0xFF141109, 0xFF000000, 0xFF0F0C06, 0xFF796737, 0xFFA18749, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF6B5B33, 0xFF040302, 0xFF030301, 0xFF574A2A, 
        0xFF342C19, 0xFF000000, 0xFF000000, 0xFF3B321D, 0xFF8A7644, 0xFFA68D51, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA99155, 0xFFA99055, 0xFFA99056, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 
        0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9459, 0xFF302919, 0xFF000000, 0xFF121009, 0xFF13100A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060503, 0xFFAD965C, 0xFFAE965C, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 
        0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB09961, 0xFFB19962, 0xFFB19962, 0xFFB09A62, 0xFFB09A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFA6905C, 0xFF1F1B11, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF413824, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB29A63, 0xFFB29A63, 0xFFB19A63, 0xFFB29A63, 0xFFB29B64, 0xFFB29B63, 0xFFB29B63, 0xFFB29A63, 0xFFA7925D, 0xFF000000, 0xFF000000, 0xFF615336, 0xFFB29B63, 0xFFB19B64, 0xFFB19A63, 
        0xFFB29B63, 0xFFB29B63, 0xFFB19A63, 0xFFB19A63, 0xFFB19B63, 0xFFB19A63, 0xFFB29A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFB19A63, 0xFFAB955F, 0xFF342D1D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF050403, 0xFF948152, 0xFFB19962, 
        0xFFB19A62, 0xFFB19962, 0xFFB09961, 0xFFB19961, 0xFFB19961, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09861, 0xFFB09861, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 
        0xFFAF975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945A, 0xFFAC9459, 
        0xFFAC945A, 0xFF79683F, 0xFF615332, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F52, 0xFF947E48, 0xFF55482A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF463B21, 0xFFA68D50, 0xFF483D22, 0xFF000000, 0xFF141109, 0xFF927C45, 0xFFA58B4E, 0xFFA48B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4B, 
        0xFFA3894B, 0xFFA1874A, 0xFF7A6637, 0xFF0E0C06, 0xFF000000, 0xFF141109, 0xFF746033, 0xFFA28748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFFA08544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 
        0xFF9E8343, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 
        0xFF987C39, 0xFF987B38, 0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 
        0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 
        0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6A1F, 0xFF896A1F, 0xFF89691E,
  0xFF88691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 
        0xFF8F7229, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92742E, 0xFF92752F, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 
        0xFF967934, 0xFF967935, 0xFF977A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 
        0xFF9C803E, 0xFF9C813E, 0xFF9C813F, 0xFF9D813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18647, 
        0xFFA18747, 0xFFA18748, 0xFF927A41, 0xFF43381D, 0xFF000000, 0xFF000000, 0xFF40351D, 0xFF967E44, 0xFFA3894A, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFF9C834A, 0xFF231D10, 0xFF000000, 0xFF2F2816, 0xFFA68C4F, 
        0xFF716036, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF090704, 0xFF433920, 0xFF8C7744, 0xFFA78E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFAA9156, 0xFFAA9156, 
        0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9359, 0xFF7A683F, 0xFF2B2516, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1D190F, 0xFFAD955B, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE965E, 0xFFAF975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF9860, 
        0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09861, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB09961, 0xFFB19961, 0xFFB09961, 0xFFA6905C, 0xFF1F1B11, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF413824, 0xFFB19962, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A63, 0xFFB19A62, 0xFF4E432B, 0xFF000000, 0xFF0B0906, 0xFF978353, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 
        0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19A62, 0xFFB19963, 0xFFB19A62, 0xFFB19A62, 0xFFB19962, 0xFFB19A62, 0xFFB19A61, 0xFFB09962, 0xFFB09962, 0xFF6E603D, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF50452C, 0xFFB09961, 
        0xFFB09961, 0xFFB09960, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFB09860, 0xFFB09861, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 
        0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB9359, 0xFFAB935A, 0xFFAB9359, 0xFFAB9359, 
        0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9258, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA98F54, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E52, 
        0xFF9D854D, 0xFF534628, 0xFF141109, 0xFF000000, 0xFF221D10, 0xFF362E1A, 0xFF000000, 0xFF16120A, 0xFF917A45, 0xFF9C844A, 0xFF141109, 0xFF000000, 0xFF463B21, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 
        0xFF967E44, 0xFF3F351D, 0xFF000000, 0xFF000000, 0xFF43381E, 0xFF937A41, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 
        0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 
        0xFF987C38, 0xFF977B38, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92742F, 0xFF92742E, 
        0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF907129, 0xFF8F7129, 0xFF8F7128, 0xFF8F7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D23, 0xFF8C6D23, 
        0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691D,
  0xFF88681D, 0xFF88691D, 0xFF89691F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7128, 
        0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752F, 0xFF93752F, 0xFF937530, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF957832, 0xFF957833, 0xFF957833, 
        0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 
        0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFF9F8547, 0xFF786536, 0xFF080603, 0xFF000000, 0xFF0C0A05, 0xFF6F5E33, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF64552F, 0xFF000000, 0xFF000000, 0xFF967F47, 0xFF9D854B, 
        0xFF211C10, 0xFF000000, 0xFF342C19, 0xFF776539, 0xFF141109, 0xFF000000, 0xFF070603, 0xFF483D23, 0xFFA58C51, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 
        0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAB9257, 0xFFAA9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFA58E56, 0xFF74643C, 0xFF0E0C07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF231E12, 0xFFAC945B, 0xFFAD955B, 
        0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 
        0xFFAF985F, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09961, 0xFFB09860, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFA5905B, 0xFF1F1B11, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF403823, 0xFFB09962, 0xFFB09961, 0xFFB09962, 0xFFB09962, 0xFFB19962, 0xFFB19962, 0xFFB19962, 0xFFB19962, 0xFFB09962, 0xFFB19962, 0xFFA8915D, 0xFF110F09, 0xFF000000, 0xFF38311F, 0xFFAC945F, 0xFFB09962, 0xFFB09962, 0xFFB19962, 
        0xFFB19961, 0xFFB09962, 0xFFB09961, 0xFFB19962, 0xFFB09961, 0xFFB09961, 0xFFB09962, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFF0E0C07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1E1A10, 0xFF9E8856, 
        0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE975E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAD965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 
        0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF60512F, 
        0xFF0D0B06, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF806C3D, 0xFFA48A4F, 0xFF0C0A05, 0xFF000000, 0xFF4E4125, 0xFFA48A4D, 0xFF776438, 0xFF000000, 0xFF000000, 0xFF85703D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF705E33, 
        0xFF0C0A05, 0xFF000000, 0xFF080704, 0xFF796535, 0xFFA08547, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 
        0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 
        0xFF987B37, 0xFF977B36, 0xFF977A36, 0xFF967A36, 0xFF967A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937631, 0xFF937530, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 
        0xFF92742D, 0xFF91742C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF8F722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C23, 
        0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 0xFF89691F, 0xFF89691D, 0xFF88691D,
  0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF896B20, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E24, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 
        0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF8F722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732D, 0xFF92742D, 0xFF91742D, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947732, 0xFF957732, 0xFF957833, 
        0xFF957833, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08546, 
        0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF9B8145, 0xFF322A16, 0xFF030201, 0xFF000000, 0xFF3D331B, 0xFF937B43, 0xFFA3894B, 0xFFA3894B, 0xFFA3894C, 0xFF9B8248, 0xFF040302, 0xFF000000, 0xFF564928, 0xFFA58B4E, 0xFF63532F, 
        0xFF000000, 0xFF050402, 0xFF8E7844, 0xFFA48A4E, 0xFF141109, 0xFF000000, 0xFF060503, 0xFF000000, 0xFF030201, 0xFF635430, 0xFF9B834C, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 
        0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFA28B53, 0xFF433922, 0xFF0A0805, 0xFF000000, 0xFF000000, 0xFF020201, 0xFFAB9359, 0xFFAC945B, 
        0xFFAC945B, 0xFFAC955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD955C, 0xFFAE965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 
        0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF9860, 0xFFAF985F, 0xFFAF9860, 0xFFAF985F, 0xFFAF9860, 0xFFAF9860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFA58F5A, 0xFF1F1B11, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF403823, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFF6E603C, 0xFF040302, 0xFF040302, 0xFF6E603C, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 
        0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09861, 0xFFB09861, 0xFFB09961, 0xFFB09961, 0xFFB09961, 0xFFB09960, 0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFF605334, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF796942, 
        0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965C, 0xFFAD965C, 
        0xFFAD955C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAA9258, 0xFFAA9257, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA0884E, 0xFF7B683C, 0xFF16130B, 0xFF000000, 
        0xFF0A0805, 0xFF38301B, 0xFF120F08, 0xFF000000, 0xFF3F351E, 0xFFA68C4F, 0xFF736137, 0xFF000000, 0xFF040302, 0xFF907944, 0xFF9C8549, 0xFF2D2615, 0xFF000000, 0xFF1D180D, 0xFFA48A4C, 0xFFA3894B, 0xFFA3894B, 0xFF937B43, 0xFF3C331B, 0xFF000000, 
        0xFF030201, 0xFF322A16, 0xFF9B8146, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8241, 0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF977B37, 
        0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947832, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 
        0xFF91742C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF90712A, 0xFF8F7129, 0xFF8F7028, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E26, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 
        0xFF8A6C22, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691D, 0xFF88681D,
  0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C22, 0xFF8B6C22, 0xFF8B6D22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 
        0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91732D, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752F, 0xFF92752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 
        0xFF957833, 0xFF957933, 0xFF957934, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 
        0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 
        0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA28748, 0xFF66552E, 0xFF1B160C, 0xFF000000, 0xFF16120A, 0xFF62522C, 0xFF9F8649, 0xFFA3894B, 0xFF372F19, 0xFF000000, 0xFF1B160C, 0xFF988047, 0xFF998248, 0xFF16120A, 
        0xFF000000, 0xFF544627, 0xFFA58C4E, 0xFF554828, 0xFF000000, 0xFF0B0905, 0xFF6E5E35, 0xFF4E4225, 0xFF120F08, 0xFF000000, 0xFF1B170D, 0xFF5D4F2D, 0xFF957E49, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA99054, 0xFFA99054, 
        0xFFA99054, 0xFFA99055, 0xFFA99155, 0xFFA99056, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFF857245, 0xFF3A321E, 0xFF020201, 0xFF000000, 0xFF55492C, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAD955B, 0xFFAC955B, 0xFFAD955B, 0xFFAD945C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965D, 0xFFAD955D, 0xFFAE965C, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE965E, 0xFFAE975E, 
        0xFFAE975D, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAE975F, 0xFFAF975F, 0xFFAE975E, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF9860, 0xFFAF9860, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 0xFFA48F5A, 0xFF1F1B11, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF403823, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09960, 0xFFB09960, 0xFFB09861, 0xFFAB945D, 0xFF39311F, 0xFF000000, 0xFF0F0D08, 0xFFA7905C, 0xFFB09861, 0xFFB09961, 0xFFB09860, 0xFFAF9860, 
        0xFFB09961, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFB09860, 0xFFAF9860, 0xFFAF9860, 0xFFB0985F, 0xFFAF9860, 0xFFAF985F, 0xFFAC955E, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF282215, 
        0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975D, 0xFFAD965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD965D, 0xFFAD955C, 0xFFAD965C, 0xFFAD955B, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFFAB945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9257, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 
        0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA98F54, 0xFFA99053, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA28A4F, 0xFF6B5B34, 0xFF2B2515, 0xFF000000, 0xFF050402, 0xFF3E341E, 
        0xFF826E3F, 0xFFA68D50, 0xFF635430, 0xFF000000, 0xFF0A0804, 0xFF7F6C3D, 0xFFA58C4E, 0xFF332B18, 0xFF000000, 0xFF2E2716, 0xFFA48A4D, 0xFF766336, 0xFF060502, 0xFF010100, 0xFF63532D, 0xFFA1874A, 0xFF62522C, 0xFF16120A, 0xFF000000, 0xFF1B170C, 
        0xFF66562E, 0xFFA28748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 
        0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 
        0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF967A34, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91732C, 
        0xFF91732C, 0xFF90732C, 0xFF90722B, 0xFF90722A, 0xFF90712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8A6C21, 
        0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88681D, 0xFF88681D,
  0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6D23, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E6F27, 
        0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF90712A, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF90732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 
        0xFF947832, 0xFF957733, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 
        0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFF917940, 0xFF4B3F21, 0xFF000000, 0xFF010100, 0xFF272111, 0xFF5C4D2A, 0xFF050402, 0xFF030301, 0xFF63542E, 0xFFA48A4C, 0xFF493E22, 0xFF000000, 
        0xFF1C170D, 0xFFA0874B, 0xFF8E7843, 0xFF15110A, 0xFF000000, 0xFF443A20, 0xFFA58C4F, 0xFFA68C4F, 0xFF917A46, 0xFF564929, 0xFF010100, 0xFF000000, 0xFF141109, 0xFF4F4326, 0xFFA48B50, 0xFFA78E52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 
        0xFFA88F54, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 0xFFA68E55, 0xFF806D41, 0xFF1E1A0F, 0xFF000000, 0xFF655735, 
        0xFFA99158, 0xFFAB9359, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAD945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAE965C, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE975E, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975F, 0xFFA48D59, 0xFF1F1B11, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF403723, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF9760, 0xFFAF975F, 0xFFAF985F, 0xFF968251, 0xFF080704, 0xFF000000, 0xFF443B25, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF9860, 
        0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF985F, 0xFFAF975F, 0xFFAF985F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFF50452B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF8B784B, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAC945B, 
        0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC9359, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9258, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9157, 0xFFA99156, 
        0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA89054, 0xFFA88F54, 0xFFA99054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF645531, 0xFF1A160D, 0xFF000000, 0xFF000000, 0xFF3E351E, 0xFF8A7542, 0xFFA48A4F, 
        0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFF211C0F, 0xFF000000, 0xFF332B18, 0xFFA48B4D, 0xFF826E3D, 0xFF0A0804, 0xFF000000, 0xFF6A5931, 0xFFA48A4C, 0xFF332B17, 0xFF000000, 0xFF15120A, 0xFF201B0E, 0xFF010100, 0xFF000000, 0xFF4B4022, 0xFF927941, 
        0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9C8140, 0xFF9C8140, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7D3A, 0xFF997D3A, 0xFF997D39, 0xFF987D39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF987B37, 0xFF977B37, 0xFF977A36, 
        0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947731, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 0xFF91732C, 
        0xFF90732C, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8B6D24, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B21, 
        0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88681D, 0xFF88691D, 0xFF88681C, 0xFF87681C,
  0xFF87671B, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691D, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 
        0xFF8E6F27, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752F, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF947631, 0xFF947731, 
        0xFF947732, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977A37, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B803D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 
        0xFF9F8445, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF7C6738, 0xFF110E08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF19150B, 0xFFA2884A, 0xFF89733F, 0xFF000000, 0xFF000000, 
        0xFF756236, 0xFFA3894C, 0xFF4E4224, 0xFF000000, 0xFF080703, 0xFFA1894C, 0xFFA58B4E, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C50, 0xFF9D854B, 0xFF433820, 0xFF030301, 0xFF000000, 0xFF010100, 0xFF584B2B, 0xFF9D854D, 0xFFA58D51, 0xFFA88F52, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFF5F5131, 0xFF2E2717, 
        0xFF9F8952, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAC955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 
        0xFFAD965C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFFAE965E, 0xFFAE965E, 0xFFAE975E, 0xFFAE965E, 0xFFAE975E, 0xFFA18B56, 0xFF1E1A10, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF3D3421, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFF574B2F, 0xFF000000, 0xFF000000, 0xFF8B784B, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 
        0xFFAF975F, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975F, 0xFFAF975F, 0xFFAF975E, 0xFFAF975E, 0xFFAF975E, 0xFFAE975F, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFF907D4E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF2D2718, 0xFFAE965D, 0xFFAD965D, 0xFFAE965D, 0xFFAD965D, 0xFFAE965C, 0xFFAE965C, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD945B, 0xFFAD955B, 0xFFAD945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB935A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 
        0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA98F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA78F53, 0xFFA78D51, 0xFFA1884F, 0xFF716037, 0xFF100D07, 0xFF000000, 0xFF030201, 0xFF2E2716, 0xFF907A45, 0xFFA68D50, 0xFFA68C50, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFF8B7542, 0xFF000000, 0xFF000000, 0xFF726035, 0xFFA48A4D, 0xFF40361E, 0xFF000000, 0xFF151109, 0xFF9B8247, 0xFF8F7841, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF110E08, 0xFF7D6937, 0xFFA18748, 0xFFA18748, 
        0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9D8242, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 
        0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF987C39, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 
        0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 
        0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B21, 
        0xFF8A6B1F, 0xFF896A1F, 0xFF896A1F, 0xFF896A1E, 0xFF88691D, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87671B,
  0xFF86671B, 0xFF87671B, 0xFF87681C, 0xFF87681D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8B6D23, 0xFF8C6E24, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 
        0xFF8E6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937630, 
        0xFF947731, 0xFF947732, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 
        0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 
        0xFF9F8444, 0xFF9F8544, 0xFF9F8445, 0xFFA08545, 0xFFA08646, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA18647, 0xFF4F4223, 0xFF0D0B06, 0xFF000000, 0xFF151209, 0xFF715F33, 0xFF251F11, 0xFF000000, 0xFF2E2715, 
        0xFF9E8649, 0xFF88733F, 0xFF000000, 0xFF000000, 0xFF6C5B32, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58D4F, 0xFFA68C50, 0xFF917A45, 0xFF463C22, 0xFF16130B, 0xFF000000, 0xFF0A0805, 0xFF514527, 0xFF857141, 0xFFA58C51, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAB9257, 0xFFAA9258, 0xFFAB9257, 
        0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945A, 0xFFAD945B, 0xFFAC945B, 0xFFAD945B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955B, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD965C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965E, 0xFF9A8452, 0xFF19150D, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF312B1A, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFF9E8955, 0xFF030201, 0xFF000000, 0xFF020201, 0xFFAE975E, 0xFFAE975E, 0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 
        0xFFAF975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE975E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965E, 0xFFAE975E, 0xFFAE965E, 0xFFAE965D, 0xFFAE965D, 0xFF9E8854, 0xFF19150D, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF8D794A, 0xFFAE965C, 0xFFAD955C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC9459, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 
        0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88E53, 0xFFA88F53, 0xFF8E7845, 0xFF5F512E, 0xFF1A160D, 0xFF000000, 0xFF0C0A06, 0xFF382F1B, 0xFF7E6B3D, 0xFFA68D50, 0xFFA68D50, 0xFFA68C50, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48A4C, 0xFF443920, 0xFF000000, 0xFF0F0C07, 0xFF9D8549, 0xFF8D7741, 0xFF0C0A05, 0xFF010100, 0xFF382F19, 0xFF1B170C, 0xFF000000, 0xFF0D0B06, 0xFF4E4223, 0xFFA18647, 0xFFA18748, 0xFFA18747, 0xFFA18747, 
        0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8240, 0xFF9C8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 
        0xFF9B803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A35, 0xFF967A35, 
        0xFF967934, 0xFF967934, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957732, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752F, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 
        0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 
        0xFF896A1F, 0xFF896A1F, 0xFF896A1E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF88681C, 0xFF87671C, 0xFF87671B,
  0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF88681C, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 
        0xFF8D6F26, 0xFF8E6F26, 0xFF8D7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F712A, 0xFF8F722A, 0xFF90722A, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 
        0xFF947630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957834, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 
        0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 
        0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18648, 0xFFA18748, 0xFF88723C, 0xFF3E341B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060502, 0xFF836E3C, 
        0xFFA3894B, 0xFF221D0F, 0xFF000000, 0xFF2E2715, 0xFFA0874A, 0xFFA48A4C, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFF8F7945, 0xFF645530, 0xFF131009, 0xFF000000, 0xFF0B0A05, 0xFF2F2817, 
        0xFF716037, 0xFFA78E52, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89053, 0xFFA98F54, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFAA9155, 0xFFAA9156, 0xFFA99156, 0xFFAA9256, 0xFFAA9257, 
        0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 0xFFAB9258, 0xFFAA9258, 0xFFAB9258, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9459, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 
        0xFFAC945B, 0xFFAC955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD945B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD955C, 0xFFAD965D, 0xFF8C794A, 0xFF0F0D08, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF1E1A10, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFF292316, 0xFF000000, 0xFF000000, 0xFF0F0D08, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 
        0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAE965D, 0xFFAD965D, 0xFFAD965C, 0xFFAD955C, 0xFFAE955C, 0xFFA28B56, 0xFF282215, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF372F1D, 0xFFAD955B, 0xFFAD955B, 0xFFAD945B, 0xFFAD955B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC9459, 0xFFAC935A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 
        0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA89054, 
        0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E52, 0xFF847040, 0xFF3C331D, 0xFF120F08, 0xFF000000, 0xFF090704, 0xFF524527, 0xFF887341, 0xFFA68D50, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4F, 0xFFA58C4E, 0xFFA58B4E, 
        0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFF88733F, 0xFF100E07, 0xFF000000, 0xFF473C20, 0xFFA3894B, 0xFF3C321B, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF40351C, 0xFF89723D, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08646, 
        0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8341, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 
        0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A36, 0xFF967935, 0xFF967934, 
        0xFF957934, 0xFF957933, 0xFF957833, 0xFF957832, 0xFF947832, 0xFF947731, 0xFF947631, 0xFF947630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752F, 0xFF92752D, 0xFF92742D, 0xFF92742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 
        0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7128, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8D6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 
        0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671A,
  0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF89691D, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 
        0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7028, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 
        0xFF937630, 0xFF937631, 0xFF937631, 0xFF947731, 0xFF947832, 0xFF947832, 0xFF957833, 0xFF957933, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 
        0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9C8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF836D3A, 0xFF16120A, 0xFF000000, 0xFF010100, 0xFF3B311A, 
        0xFF564827, 0xFF000000, 0xFF070603, 0xFF786537, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68D50, 0xFF6B5B33, 0xFF080704, 0xFF000000, 
        0xFF000000, 0xFF121009, 0xFF6D5C35, 0xFFA58C51, 0xFFA78E52, 0xFFA78E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89053, 0xFFA89054, 0xFFA89054, 0xFFA89054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFAA9155, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 
        0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC945A, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC955B, 0xFFAC945B, 0xFFAC955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFFAD955C, 0xFFAD955B, 0xFF655735, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF0D0B07, 0xFF8B7749, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD965C, 0xFFAD955D, 0xFFAD965C, 0xFF494027, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF7E6C43, 0xFFAD965C, 0xFFAE965C, 0xFFAD965C, 0xFFAE965D, 0xFFAE965D, 
        0xFFAD965C, 0xFFAD965D, 0xFFAD955C, 0xFFAD965C, 0xFFAD965C, 0xFFAD965C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFF998450, 0xFF0A0905, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF010100, 0xFF675836, 0xFFAC945B, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAB945A, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9258, 0xFFAB9358, 
        0xFFAB9258, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA88F54, 0xFFA89053, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA88E52, 0xFF836F40, 0xFF241F12, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF463C22, 0xFFA68D50, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58B4D, 0xFFA48B4D, 
        0xFFA48A4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFF493D21, 0xFF000000, 0xFF0E0B06, 0xFF282112, 0xFF010100, 0xFF000000, 0xFF151209, 0xFF816C39, 0xFFA28748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA08546, 0xFFA08646, 
        0xFFA08545, 0xFF9F8545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8341, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF957934, 0xFF967834, 
        0xFF957934, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF92742D, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF90722A, 0xFF90722A, 0xFF8F712A, 
        0xFF8F7129, 0xFF8F7128, 0xFF8E7128, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6A20, 0xFF896A20, 0xFF896A1F, 
        0xFF896A1F, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF86671A, 0xFF86661A,
  0xFF866619, 0xFF86661A, 0xFF86671B, 0xFF87671B, 0xFF87671B, 0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 
        0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 
        0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF967A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 
        0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9B803E, 0xFF9B803F, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9E8341, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFF504324, 0xFF141109, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF2D2614, 0xFFA3894B, 0xFFA38A4B, 0xFFA4894C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4E, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFF9F874C, 0xFF060503, 0xFF030201, 
        0xFF1F1A0F, 0xFF0B0905, 0xFF000000, 0xFF0F0C07, 0xFF594C2B, 0xFF8A7543, 0xFFA1884F, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA89053, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 
        0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9256, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 
        0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945B, 0xFFAC945A, 0xFFA69058, 0xFF9C8552, 0xFF998451, 0xFF927E4D, 0xFF635534, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF17130C, 0xFF75653E, 0xFF947F4F, 0xFF9C8652, 0xFF978250, 0xFF847346, 0xFF38311E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF5A4E30, 0xFF8B784A, 0xFF988351, 0xFFAD955C, 0xFFAD955C, 
        0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955C, 0xFFAD955B, 0xFFAD955B, 0xFFAD955B, 0xFF988350, 0xFF8F7B4B, 0xFF78673F, 0xFF1B170E, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF403721, 0xFF867346, 0xFF937F4D, 0xFFA48D56, 0xFFAC945A, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA98F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 
        0xFFA68D52, 0xFF907A46, 0xFF685833, 0xFF1F1A0F, 0xFF000000, 0xFF030301, 0xFF201B0F, 0xFF5B4D2C, 0xFF62532F, 0xFF040302, 0xFF0D0B06, 0xFF957E47, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 
        0xFFA48A4D, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894C, 0xFFA3894B, 0xFF87713E, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF141109, 0xFF524525, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 
        0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8341, 0xFF9D8241, 0xFF9D8241, 0xFF9C8240, 0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9C803D, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF957934, 0xFF957833, 
        0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF937731, 0xFF947630, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752F, 0xFF92742E, 0xFF92742D, 0xFF92742D, 0xFF91742C, 0xFF91732C, 0xFF91732B, 0xFF90732B, 0xFF90722A, 0xFF8F722A, 0xFF8F7229, 
        0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8A6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896B1F, 0xFF896A1F, 0xFF896A1E, 
        0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87671C, 0xFF87671B, 0xFF87671B, 0xFF86661A, 0xFF866619,
  0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86671A, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 
        0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 
        0xFF93752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF987C38, 
        0xFF987C39, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 
        0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18646, 0xFFA18748, 0xFFA18747, 0xFFA18748, 0xFF8C763E, 0xFF514424, 
        0xFF060503, 0xFF000000, 0xFF141109, 0xFF554726, 0xFF9C8247, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFF493E23, 0xFF000000, 0xFF282213, 
        0xFF998149, 0xFF806D3E, 0xFF524527, 0xFF141109, 0xFF000000, 0xFF050402, 0xFF2F2817, 0xFF5E502E, 0xFF968049, 0xFFA78E52, 0xFFA78E52, 0xFFA78F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA89054, 0xFFA99054, 0xFFA99054, 
        0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9257, 0xFFAA9256, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAB9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 
        0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC9359, 0xFFAC9359, 0xFFAC9459, 0xFF7C6A40, 0xFF19150D, 0xFF1C180E, 0xFF0B0906, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF110F09, 0xFF1D190F, 0xFF0D0B07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF1D190F, 0xFFAD955B, 0xFFAC955B, 
        0xFFAC945B, 0xFFAC945B, 0xFFAC955B, 0xFFAC945B, 0xFFAC945A, 0xFFAC945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945B, 0xFFAC945A, 0xFF14110A, 0xFF080604, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A06, 0xFF6C5D38, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 
        0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA98F55, 0xFFA89054, 0xFFA98F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA78E52, 0xFFA1894F, 0xFF6C5B35, 
        0xFF39311B, 0xFF0F0D07, 0xFF000000, 0xFF070603, 0xFF433921, 0xFF776539, 0xFFA0884D, 0xFFA68C4F, 0xFFA2884D, 0xFF15120A, 0xFF010100, 0xFF564928, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA4894B, 
        0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFF9C8347, 0xFF534526, 0xFF18140B, 0xFF000000, 0xFF060503, 0xFF514424, 0xFF8C763E, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 
        0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8341, 0xFF9E8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C8140, 0xFF9C803F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 
        0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF967A36, 0xFF977A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 
        0xFF957732, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7128, 
        0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF89691E, 
        0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87671C, 0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF86661A, 0xFF866619,
  0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF86671A, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88681D, 0xFF88691D, 0xFF89691F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 
        0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF90732C, 0xFF91732C, 0xFF91732D, 0xFF91742D, 0xFF92742E, 
        0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957933, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 
        0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813E, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 
        0xFF9D8241, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA18646, 0xFFA08747, 0xFFA18747, 0xFFA18748, 0xFFA08647, 
        0xFF937B42, 0xFF40351C, 0xFF000000, 0xFF000000, 0xFF0A0804, 0xFF5C4D2A, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA58B4D, 0xFFA58B4D, 0xFF977F47, 0xFF0F0D07, 0xFF020201, 0xFF5C4E2C, 
        0xFFA68C4F, 0xFFA68C4F, 0xFFA48A4E, 0xFF9F874C, 0xFF756438, 0xFF231D10, 0xFF000000, 0xFF000000, 0xFF0A0805, 0xFF332B19, 0xFF826F40, 0xFFA78E52, 0xFFA78E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA98F54, 
        0xFFA89054, 0xFFA99054, 0xFFA89055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99156, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 
        0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFA68F56, 0xFF9E8852, 0xFFA08953, 0xFFA08953, 0xFFA08953, 0xFFA08A53, 0xFFA08A54, 0xFFA08A54, 0xFFA08954, 0xFFA08A54, 
        0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFF9F8953, 0xFF9F8853, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFA08A54, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC935A, 0xFF9F8853, 0xFF9F8954, 0xFF9F8A53, 0xFFA08953, 0xFF9F8953, 0xFFA08953, 0xFFA08953, 0xFF9F8953, 0xFF9F8953, 
        0xFF9F8953, 0xFF9F8953, 0xFF9F8852, 0xFF9F8952, 0xFF9F8952, 0xFF9E8851, 0xFFA58D55, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 
        0xFFA99156, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA98F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E52, 0xFF927C47, 0xFF473C23, 0xFF0E0C07, 0xFF020201, 
        0xFF000000, 0xFF120F08, 0xFF635430, 0xFF9A834A, 0xFFA38A4E, 0xFFA68D50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFF524627, 0xFF000000, 0xFF211B0F, 0xFF977F46, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA38A4B, 
        0xFFA3894B, 0xFFA3894B, 0xFF5C4D2A, 0xFF0A0804, 0xFF000000, 0xFF000000, 0xFF40361D, 0xFF947C42, 0xFFA08647, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8444, 0xFF9E8443, 0xFF9E8342, 0xFF9E8343, 0xFF9E8342, 0xFF9D8341, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 
        0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF997D3A, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF947732, 
        0xFF947732, 0xFF947731, 0xFF937731, 0xFF937631, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF91742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF91732B, 0xFF90722A, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 
        0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8A6C21, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691D, 
        0xFF88691D, 0xFF87681C, 0xFF87681C, 0xFF87671C, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856619, 0xFF856518,
  0xFF856518, 0xFF856518, 0xFF866619, 0xFF866619, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 
        0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 
        0xFF92742D, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947731, 0xFF957732, 0xFF957832, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 
        0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 
        0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9F8443, 0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8445, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18647, 
        0xFFA18748, 0xFFA18748, 0xFF87703C, 0xFF292212, 0xFF070603, 0xFF000000, 0xFF151209, 0xFF736134, 0xFF988045, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFF5D4F2B, 0xFF020201, 0xFF100E07, 0xFF937C45, 
        0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C50, 0xFF8A7542, 0xFF3D331D, 0xFF0F0D07, 0xFF010100, 0xFF000000, 0xFF120F08, 0xFF5C4E2D, 0xFF8F7946, 0xFF9E864D, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA89054, 0xFFA88F54, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9358, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC9359, 0xFFAB9359, 
        0xFFAC9359, 0xFFAB9459, 0xFFAC9359, 0xFFAC9359, 0xFFAB9359, 0xFFAC9459, 0xFFAC935A, 0xFFAC945A, 0xFFAC945A, 0xFFAC9459, 0xFFAC9459, 0xFFAC945A, 0xFFAC9459, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 0xFFAC945A, 
        0xFFAC9359, 0xFFAC935A, 0xFFAC945A, 0xFFAC9359, 0xFFAC9359, 0xFFAC9359, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 
        0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFAA9155, 0xFFA99156, 0xFFA99055, 
        0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA28950, 0xFF947E48, 0xFF6E5D36, 0xFF221D11, 0xFF000000, 0xFF000000, 0xFF0C0A06, 0xFF2E2716, 
        0xFF77653A, 0xFFA68D50, 0xFFA68D50, 0xFFA68D4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58B4E, 0xFF9F864B, 0xFF050402, 0xFF000000, 0xFF756337, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA4894C, 0xFFA3894B, 0xFFA3894B, 0xFF988046, 
        0xFF736134, 0xFF151209, 0xFF000000, 0xFF070603, 0xFF292212, 0xFF87723D, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 
        0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 
        0xFF947732, 0xFF937631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF8F722A, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7028, 0xFF8E7027, 
        0xFF8E7027, 0xFF8D6F27, 0xFF8E6F26, 0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 
        0xFF88681D, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518,
  0xFF856517, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF86671B, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C22, 0xFF8B6C22, 
        0xFF8B6D23, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F27, 0xFF8E6F27, 0xFF8E7028, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742C, 
        0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977A36, 
        0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3B, 0xFF9A7E3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C803F, 
        0xFF9C813F, 0xFF9D8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9E8242, 0xFF9D8342, 0xFF9E8342, 0xFF9E8443, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA08647, 
        0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFF746133, 0xFF372E18, 0xFF000000, 0xFF000000, 0xFF231D0F, 0xFF5D4E2A, 0xFF987F46, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFF9A8147, 0xFF282213, 0xFF000000, 0xFF473C21, 0xFFA48B4D, 
        0xFFA48B4D, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4F, 0xFFA68C4E, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFF9A824A, 0xFF6A5A33, 0xFF3D331D, 0xFF100D07, 0xFF000000, 0xFF000000, 0xFF2B2515, 0xFF55482A, 0xFF7F6C3E, 0xFFA58C51, 0xFFA78F53, 0xFFA88F53, 
        0xFFA88F52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA99054, 0xFFA89054, 0xFFA99055, 0xFFA89055, 0xFFA99055, 0xFFA99054, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 
        0xFFAA9157, 0xFFAA9257, 0xFFAA9256, 0xFFAA9256, 0xFFAA9256, 0xFFAA9157, 0xFFAA9257, 0xFFAB9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9357, 0xFFAA9358, 0xFFAB9358, 0xFFAB9357, 0xFFAB9358, 0xFFAB9358, 0xFFAB9259, 0xFFAB9358, 0xFFAB9358, 
        0xFFAB9359, 0xFFAB9259, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAB9358, 0xFFAB9358, 0xFFAB9358, 0xFFAB9359, 0xFFAC9359, 0xFFAB9359, 0xFFAB9359, 0xFFAC9359, 0xFFAC9358, 0xFFAB9459, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 
        0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9359, 0xFFAB9358, 0xFFAB9359, 0xFFAA9359, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAB9258, 0xFFAA9257, 0xFFAB9258, 0xFFAB9258, 
        0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9256, 0xFFAA9156, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFAA9155, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99156, 0xFFA99054, 0xFFA99054, 0xFFA99054, 
        0xFFA88F55, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA88F53, 0xFFA78E53, 0xFF887442, 0xFF5F512E, 0xFF362E1A, 0xFF070603, 0xFF000000, 0xFF050502, 0xFF332B18, 0xFF5F512E, 0xFF8F7945, 0xFFA68C50, 
        0xFFA68D4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4D, 0xFFA58B4E, 0xFFA48B4D, 0xFF514425, 0xFF000000, 0xFF221D10, 0xFFA48A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF987F45, 0xFF5D4E2A, 0xFF221D0F, 
        0xFF000000, 0xFF000000, 0xFF372E18, 0xFF746133, 0xFFA28748, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8445, 0xFF9F8544, 0xFF9F8443, 0xFF9F8443, 0xFF9E8443, 0xFF9E8443, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 
        0xFF997D39, 0xFF997D3A, 0xFF997D38, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957934, 0xFF957833, 0xFF947832, 0xFF947832, 0xFF947732, 0xFF947731, 
        0xFF947631, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732C, 0xFF90722B, 0xFF90722B, 0xFF90712A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7128, 0xFF8F7028, 0xFF8E7028, 0xFF8E6F27, 
        0xFF8D6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6B21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691D, 0xFF88691D, 0xFF87681C, 
        0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856418,
  0xFF846417, 0xFF856417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF86661A, 0xFF86661A, 0xFF87671A, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6B22, 
        0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90732B, 0xFF90732B, 0xFF91732C, 
        0xFF91742C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957933, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A35, 
        0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 
        0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF9D8346, 0xFF836D3A, 0xFF322A16, 0xFF000000, 0xFF000000, 0xFF110E07, 0xFF524425, 0xFF9F8548, 0xFFA3894A, 0xFFA3894B, 0xFF7C6839, 0xFF000000, 0xFF010100, 0xFF967E45, 0xFFA48A4D, 
        0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA2894D, 0xFF957E47, 0xFF756338, 0xFF302917, 0xFF000000, 0xFF000000, 0xFF090704, 0xFF14110A, 0xFF463B21, 0xFF857141, 
        0xFFA78E52, 0xFFA78E52, 0xFFA78F52, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA98F54, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 
        0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9256, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9258, 
        0xFFAB9257, 0xFFAB9257, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9358, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9358, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 
        0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9258, 0xFFAB9257, 0xFFAB9258, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 
        0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA89054, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA78F52, 0xFFA78E52, 0xFF937D48, 0xFF55482A, 0xFF1E190E, 0xFF0D0B06, 0xFF010100, 0xFF000000, 0xFF201B0F, 0xFF655630, 0xFF917B45, 0xFF9F864C, 0xFFA68C50, 0xFFA68C4F, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFF917A43, 0xFF080703, 0xFF000000, 0xFF816C3B, 0xFFA3894B, 0xFF9F8548, 0xFF524525, 0xFF110E07, 0xFF000000, 0xFF000000, 
        0xFF322A16, 0xFF836D3B, 0xFF9D8346, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8342, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9B803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 
        0xFF997D3A, 0xFF997C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967935, 0xFF957934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 
        0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7028, 0xFF8E6F27, 0xFF8E6F26, 
        0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D23, 0xFF8C6C23, 0xFF8B6C23, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1E, 0xFF89691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87681C, 
        0xFF87671B, 0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856517, 0xFF846417,
  0xFF846416, 0xFF846417, 0xFF856417, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF87681C, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 
        0xFF8B6B21, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E25, 0xFF8C6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF907129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732B, 
        0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF91742D, 0xFF92752E, 0xFF92752F, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957732, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967935, 0xFF967A35, 
        0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7D3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 
        0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9E8241, 0xFF9D8241, 0xFF9D8341, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08545, 
        0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF846E3B, 0xFF262011, 0xFF040302, 0xFF000000, 0xFF070603, 0xFF584A28, 0xFF9B8246, 0xFF362E19, 0xFF000000, 0xFF41371E, 0xFFA3894C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68D50, 0xFFA0884D, 0xFF5E502D, 0xFF0F0D07, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF0D0B06, 0xFF483D23, 0xFF836F40, 0xFF9F864D, 0xFFA38A50, 0xFFA78E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 
        0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9157, 0xFFAA9157, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAB9257, 0xFFAA9257, 0xFFAB9257, 0xFFAA9258, 0xFFAA9257, 0xFFAB9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 
        0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9157, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9257, 0xFFAA9156, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 
        0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA99156, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA48C50, 0xFF9F884E, 0xFF8E7946, 0xFF584B2B, 0xFF18140B, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF070603, 0xFF000000, 0xFF594B2A, 0xFFA68D50, 0xFFA68D50, 0xFFA68C50, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4E, 
        0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA58B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF9F8649, 0xFF41371E, 0xFF000000, 0xFF282212, 0xFF60512B, 0xFF070603, 0xFF000000, 0xFF040302, 0xFF262011, 0xFF846F3B, 
        0xFFA28748, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 
        0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF997E3C, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987D39, 
        0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967935, 0xFF967935, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 
        0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732B, 0xFF90722B, 0xFF90722B, 0xFF8F722A, 0xFF90712A, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 
        0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8A6C22, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691E, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 
        0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416,
  0xFF846316, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF88691D, 0xFF88691D, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 
        0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8B6D23, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 
        0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 
        0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B803D, 0xFF9B803E, 0xFF9C803F, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFF9F8545, 0xFFA08545, 
        0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFF766335, 0xFF382F19, 0xFF0C0A05, 0xFF000000, 0xFF0B0905, 0xFF040302, 0xFF010100, 0xFF8B7540, 0xFFA3894B, 0xFFA38A4B, 
        0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFF9A834A, 0xFF201B0F, 0xFF000000, 0xFF423820, 0xFF39311C, 
        0xFF18150C, 0xFF000000, 0xFF000000, 0xFF0C0A06, 0xFF39311C, 0xFF60522F, 0xFF7D6A3D, 0xFF957F49, 0xFFA88E52, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA89054, 0xFFA98F54, 0xFFA88F54, 
        0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99055, 0xFFA99155, 0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 
        0xFFAA9157, 0xFFAA9256, 0xFFAA9156, 0xFFAA9156, 0xFFAA9257, 0xFFAA9157, 0xFFAA9157, 0xFFAA9157, 0xFFAA9157, 0xFFAA9157, 0xFFAA9257, 0xFFAA9157, 0xFFAA9257, 0xFFAA9256, 0xFFAA9157, 0xFFAA9157, 0xFFAA9157, 0xFFAA9257, 0xFFAA9157, 0xFFAA9157, 
        0xFFAA9257, 0xFFAA9157, 0xFFAA9157, 0xFFAA9156, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9157, 0xFFAA9156, 0xFFAA9156, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 0xFFA99056, 0xFFA99155, 0xFFA99155, 
        0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA98F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFF9C844D, 
        0xFF826F40, 0xFF685933, 0xFF433921, 0xFF16130B, 0xFF000000, 0xFF000000, 0xFF110F08, 0xFF302817, 0xFF534628, 0xFF847040, 0xFF806C3D, 0xFF000000, 0xFF241E11, 0xFFA58B4E, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA58B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFF594B29, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF0C0A05, 0xFF382F19, 0xFF766335, 0xFFA28748, 0xFFA18748, 
        0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08546, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8443, 0xFF9F8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8240, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 
        0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 
        0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 
        0xFF8D6E25, 0xFF8C6E25, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691D, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87671C, 0xFF87671B, 
        0xFF86661A, 0xFF86661A, 0xFF86661A, 0xFF856618, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846316,
  0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856517, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86671A, 0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF89691E, 0xFF896A1F, 0xFF8A6A1F, 0xFF8A6B20, 
        0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 
        0xFF90722B, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947833, 0xFF957833, 0xFF957833, 0xFF957833, 
        0xFF967934, 0xFF967934, 0xFF967935, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B37, 0xFF977B37, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 
        0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9C8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA08647, 0xFFA18748, 0xFFA18747, 0xFFA08647, 0xFF86713B, 0xFF504324, 0xFF040302, 0xFF000000, 0xFF010100, 0xFF272111, 0xFF69582F, 0xFFA3894A, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4E, 0xFF7C693A, 0xFF010100, 0xFF030201, 0xFFA3894D, 0xFFA58B4F, 
        0xFF937C46, 0xFF7E6B3C, 0xFF574A2A, 0xFF221D10, 0xFF000000, 0xFF000000, 0xFF050402, 0xFF19150C, 0xFF2D2615, 0xFF534729, 0xFF806D3F, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA98F54, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99155, 0xFFA99055, 0xFFA99155, 
        0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99155, 0xFFA99055, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFA99155, 0xFFA99156, 0xFFA99156, 0xFFAA9155, 0xFFA99156, 0xFFA99156, 0xFFA99156, 0xFFAA9156, 0xFFA99156, 0xFFAA9156, 0xFFA99156, 0xFFA99156, 
        0xFFA99156, 0xFFA99056, 0xFFAA9155, 0xFFA99155, 0xFFA99155, 0xFFA99155, 0xFFA99155, 0xFFA99055, 0xFFA99155, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 
        0xFFA89054, 0xFFA99054, 0xFFA89054, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFFA88F52, 0xFFA88E52, 0xFFA88E52, 0xFF8A7644, 0xFF5E502E, 0xFF352D1A, 0xFF1D190E, 
        0xFF0A0805, 0xFF000000, 0xFF000000, 0xFF16120A, 0xFF4A3F24, 0xFF776539, 0xFF8E7944, 0xFFA0884D, 0xFFA68C50, 0xFFA68C4F, 0xFF9D854B, 0xFF120F08, 0xFF000000, 0xFF8B7541, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48A4D, 
        0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894A, 0xFF68582F, 0xFF272111, 0xFF0A0904, 0xFF000000, 0xFF050402, 0xFF4F4223, 0xFF86703B, 0xFFA08647, 0xFFA18748, 0xFFA18748, 0xFFA18647, 
        0xFFA08647, 0xFFA08647, 0xFFA08546, 0xFFA08646, 0xFFA08546, 0xFF9F8545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9F8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 
        0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 
        0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF977A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 
        0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7128, 0xFF8F7028, 0xFF8E7028, 0xFF8E7028, 0xFF8D6F27, 0xFF8D6F27, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 
        0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87681B, 0xFF87671A, 0xFF86661A, 
        0xFF86661A, 0xFF856619, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846416, 0xFF836315,
  0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86671A, 0xFF86671B, 0xFF87671B, 0xFF87681C, 0xFF88681C, 0xFF88691D, 0xFF88691E, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 
        0xFF8A6B20, 0xFF8A6B21, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 
        0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 
        0xFF967934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 
        0xFF9B7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFF9F8545, 0xFFA08546, 0xFFA08646, 0xFFA18646, 0xFFA18647, 0xFFA18747, 0xFFA18648, 0xFFA18747, 0xFFA28748, 0xFF9E8446, 0xFF554826, 0xFF0C0A05, 0xFF000000, 0xFF000000, 0xFF0F0C06, 
        0xFF5D4D2A, 0xFF9F8548, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4E, 0xFFA58B4E, 0xFF504325, 0xFF000000, 0xFF39301B, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA68C4F, 0xFFA68C4F, 0xFFA68C50, 0xFFA68D50, 0xFFA0884D, 0xFF685932, 0xFF2C2615, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF272113, 0xFF594C2C, 0xFF8A7644, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E52, 0xFFA88E53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99055, 
        0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 
        0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA89055, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA88F54, 0xFFA89054, 0xFFA89054, 0xFFA99054, 0xFFA88F54, 
        0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFFA88F53, 0xFFA88F52, 0xFFA88F52, 0xFFA68D51, 0xFFA78E52, 0xFF947D48, 0xFF665632, 0xFF332B19, 0xFF070603, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF201B0F, 0xFF594C2B, 0xFF957F48, 0xFFA68D50, 0xFFA68D50, 0xFFA68C50, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA1894D, 0xFF3C331C, 0xFF000000, 0xFF463B21, 0xFFA58B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA4894C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF9F8549, 0xFF5C4D2A, 0xFF0F0C06, 0xFF000000, 0xFF000000, 0xFF0C0A05, 0xFF574927, 0xFF9E8447, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08647, 
        0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 
        0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987B38, 0xFF977C38, 0xFF987B37, 
        0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A35, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 
        0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722A, 0xFF8F712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F25, 0xFF8C6E25, 0xFF8C6E24, 
        0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691E, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF87661A, 0xFF86661A, 
        0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846416, 0xFF836315, 0xFF836315,
  0xFF836214, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846416, 0xFF856417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691D, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 
        0xFF896A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 
        0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91742C, 0xFF91742C, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 
        0xFF957833, 0xFF967934, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7D3B, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9E8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 
        0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08544, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFF9F8446, 0xFF61512B, 0xFF241E10, 0xFF080603, 
        0xFF000000, 0xFF030201, 0xFF473C20, 0xFF7C6838, 0xFF967E44, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA2894C, 0xFF18140B, 0xFF000000, 0xFF776438, 0xFFA58B4E, 0xFFA58C4E, 
        0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C50, 0xFFA68C50, 0xFFA68D50, 0xFFA68D50, 0xFF7C6A3C, 0xFF514527, 0xFF2D2616, 0xFF1A160D, 0xFF090704, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF272113, 0xFF4C4125, 0xFF6E5E36, 0xFF826E3F, 
        0xFF8F7946, 0xFF9B834C, 0xFFA58C51, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA98F54, 0xFFA89054, 0xFFA98F54, 0xFFA88F54, 
        0xFFA99054, 0xFFA89054, 0xFFA89054, 0xFFA89055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA99054, 0xFFA99055, 0xFFA99054, 0xFFA99055, 0xFFA99055, 0xFFA99054, 0xFFA99055, 0xFFA99054, 0xFFA99054, 0xFFA99054, 
        0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA99054, 0xFFA99054, 0xFFA89054, 0xFFA89054, 0xFFA89054, 0xFFA98F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F52, 0xFF9D864D, 0xFF917B47, 0xFF847141, 0xFF746339, 0xFF55482A, 0xFF302917, 0xFF090804, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF16130B, 0xFF272113, 0xFF463C22, 0xFF726137, 0xFFA0884D, 
        0xFFA68D50, 0xFFA68C50, 0xFFA68C50, 0xFFA68C50, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4E, 0xFF695831, 0xFF000000, 0xFF0E0C06, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA3894C, 0xFFA3894B, 0xFFA3894B, 0xFF967E45, 0xFF7B6738, 0xFF463B20, 0xFF020201, 0xFF000000, 0xFF080603, 0xFF241E10, 0xFF61512B, 0xFF9D8446, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 
        0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9E8241, 0xFF9D8240, 0xFF9D8240, 0xFF9D8240, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 
        0xFF9C813F, 0xFF9B803E, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 
        0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947832, 0xFF947731, 0xFF947731, 0xFF947630, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 
        0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 
        0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87671C, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF86661A, 
        0xFF856619, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846416, 0xFF846316, 0xFF836315, 0xFF836214,
  0xFF826213, 0xFF836214, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856418, 0xFF856518, 0xFF856518, 0xFF866519, 0xFF866619, 0xFF86671A, 0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88691D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 
        0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6B21, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7029, 
        0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722B, 0xFF90732B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF947832, 
        0xFF957832, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF987B37, 0xFF987B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987D39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 
        0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3B, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8341, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA08647, 0xFFA18747, 0xFFA18747, 0xFFA18747, 0xFF9E8446, 0xFF7C6737, 
        0xFF4C4022, 0xFF100D07, 0xFF000000, 0xFF010100, 0xFF221D0F, 0xFF4C4022, 0xFF86703C, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFF86713E, 0xFF000000, 0xFF100E07, 0xFF9A8348, 0xFFA48B4D, 0xFFA58B4D, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C50, 0xFF967E48, 0xFF826E3E, 0xFF6D5C34, 0xFF4E4225, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF110E08, 0xFF241F11, 0xFF332B18, 0xFF483D22, 0xFF61522F, 0xFF78663B, 0xFF917B47, 0xFFA58C51, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88E53, 0xFFA78F53, 0xFFA88E52, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F54, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88E53, 0xFFA88E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 
        0xFF968049, 0xFF7F6C3E, 0xFF665732, 0xFF4D4225, 0xFF372E1A, 0xFF272113, 0xFF16120A, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF1C170D, 0xFF040302, 0xFF050402, 0xFF7D6A3C, 0xFF917B46, 0xFFA58C4F, 0xFFA68C50, 0xFFA68C4F, 0xFFA68C4F, 
        0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFF87733F, 0xFF110E08, 0xFF000000, 0xFF7E6A3A, 0xFFA38A4C, 0xFFA38A4C, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 
        0xFFA3894A, 0xFF86703C, 0xFF4C3F22, 0xFF221D0F, 0xFF010100, 0xFF000000, 0xFF110E07, 0xFF4D4022, 0xFF7C6737, 0xFF9E8446, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 
        0xFF9F8544, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803F, 0xFF9B803E, 
        0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9B7F3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 
        0xFF967A36, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 
        0xFF91732D, 0xFF91732C, 0xFF90732C, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF8F7229, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E24, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 
        0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF856519, 0xFF856519, 
        0xFF856518, 0xFF856518, 0xFF856417, 0xFF846417, 0xFF846416, 0xFF846315, 0xFF836315, 0xFF836214, 0xFF836214,
  0xFF826113, 0xFF826214, 0xFF836214, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846417, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF87671A, 0xFF86671B, 0xFF87671C, 0xFF87681C, 0xFF87681C, 0xFF88691D, 0xFF88691E, 0xFF89691E, 
        0xFF896A1F, 0xFF896A1F, 0xFF8A6A1F, 0xFF8A6A20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6B21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6C23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 
        0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 
        0xFF947732, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF957834, 0xFF967934, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D39, 0xFF997D3A, 
        0xFF997D3A, 0xFF9A7E3B, 0xFF997E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9D8140, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8443, 0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 
        0xFFA08547, 0xFF9A8144, 0xFF705D31, 0xFF1B170C, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF1D190D, 0xFF67562F, 0xFFA18749, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFF42381E, 0xFF000000, 0xFF3F351D, 0xFFA0874A, 0xFFA48A4D, 0xFFA48B4D, 
        0xFFA58A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFF917A46, 0xFF000000, 0xFF100D07, 0xFF8D7844, 0xFF705F36, 0xFF473C22, 
        0xFF1E190E, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF050502, 0xFF080704, 0xFF19150C, 0xFF332B19, 0xFF4B4025, 0xFF6A5A34, 0xFF826E3F, 0xFF968049, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA88F52, 0xFFA78F52, 
        0xFFA78F52, 0xFFA88E52, 0xFFA88F52, 0xFFA78F53, 0xFFA88F53, 0xFFA78F53, 0xFFA88E53, 0xFFA88E53, 0xFFA88F53, 0xFFA88F52, 0xFFA88F53, 0xFFA88F53, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA88F53, 0xFFA78F53, 0xFFA88F53, 
        0xFFA88F53, 0xFFA88E53, 0xFFA88F53, 0xFFA88F53, 0xFFA78E53, 0xFFA78F52, 0xFFA78E53, 0xFFA88E52, 0xFFA78F52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFFA78E52, 0xFF9A834B, 0xFF897443, 0xFF6F5E36, 0xFF534628, 0xFF3B321D, 0xFF1D190E, 0xFF0B0905, 
        0xFF060503, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF16120A, 0xFF3D331D, 0xFF665731, 0xFF8B7643, 0xFF9E864C, 0xFF8C7743, 0xFF18140B, 0xFF000000, 0xFF917A45, 0xFFA58C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA58C4E, 0xFFA58B4F, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA3894B, 0xFF292213, 0xFF000000, 0xFF41371E, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA1874A, 0xFF67572F, 
        0xFF1D180D, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF1C180C, 0xFF705D32, 0xFF9A8144, 0xFFA08547, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8343, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C803F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A35, 
        0xFF967A35, 0xFF967934, 0xFF957934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF947631, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742E, 0xFF91742D, 0xFF91732C, 
        0xFF91732C, 0xFF91732B, 0xFF90722B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6D23, 
        0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691E, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 0xFF86671B, 0xFF86671A, 0xFF86661A, 0xFF85661A, 0xFF866619, 0xFF856518, 
        0xFF856518, 0xFF856417, 0xFF846417, 0xFF846416, 0xFF846315, 0xFF836315, 0xFF836214, 0xFF826214, 0xFF826113,
  0xFF826113, 0xFF826213, 0xFF836214, 0xFF836214, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846417, 0xFF856417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 
        0xFF89691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7027, 
        0xFF8F7028, 0xFF8E7129, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937730, 0xFF947631, 
        0xFF947732, 0xFF947732, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF957933, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987B37, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D39, 
        0xFF997D3A, 0xFF997D3A, 0xFF9A7D3B, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 
        0xFF9E8341, 0xFF9E8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9E8343, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 
        0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA28748, 0xFF846E3A, 0xFF3E341C, 0xFF131008, 0xFF030301, 0xFF000000, 0xFF030201, 0xFF3F351D, 0xFF7D6939, 0xFF947D43, 0xFFA1874A, 0xFF0B0905, 0xFF000000, 0xFF6A5931, 0xFFA38A4C, 0xFFA38A4C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFF6C5C34, 0xFF000000, 0xFF2E2716, 0xFFA48A4F, 0xFFA68C50, 0xFFA68D50, 
        0xFFA68C50, 0xFFA68D50, 0xFF917B45, 0xFF6E5D35, 0xFF524527, 0xFF302917, 0xFF1C180D, 0xFF141109, 0xFF0E0C06, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080704, 0xFF1E1A0F, 0xFF2D2616, 0xFF433921, 0xFF4E4226, 
        0xFF625430, 0xFF6C5C35, 0xFF76643A, 0xFF847141, 0xFF8B7644, 0xFF8C7744, 0xFF8F7946, 0xFF917B47, 0xFF927C48, 0xFF927C48, 0xFF927C48, 0xFF927C48, 0xFF937D48, 0xFF927C48, 0xFF927C48, 0xFF937D48, 0xFF937D48, 0xFF927C48, 0xFF927C47, 0xFF917B47, 
        0xFF907A46, 0xFF8D7845, 0xFF8B7644, 0xFF877342, 0xFF7A683C, 0xFF6D5C35, 0xFF665631, 0xFF524628, 0xFF443A21, 0xFF332B19, 0xFF221C10, 0xFF100D08, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF040302, 0xFF0C0A06, 0xFF121009, 
        0xFF19150C, 0xFF2A2314, 0xFF4A3F23, 0xFF665631, 0xFF877341, 0xFFA68D50, 0xFFA68D50, 0xFFA68D50, 0xFFA68C50, 0xFFA68C4F, 0xFFA68C50, 0xFF9E854B, 0xFF262012, 0xFF000000, 0xFF61522E, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFF554827, 0xFF000000, 0xFF1E190D, 0xFF8B7540, 0xFF7D6939, 0xFF3F351D, 0xFF020201, 0xFF000000, 
        0xFF030301, 0xFF131008, 0xFF3E341C, 0xFF846E3A, 0xFFA28748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 
        0xFF967934, 0xFF957934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 
        0xFF91732C, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 
        0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF86661A, 0xFF856519, 0xFF856518, 0xFF856518, 
        0xFF846417, 0xFF846417, 0xFF846416, 0xFF846316, 0xFF836315, 0xFF836315, 0xFF836214, 0xFF826213, 0xFF826113,
  0xFF826112, 0xFF826113, 0xFF826113, 0xFF836213, 0xFF836214, 0xFF836315, 0xFF846315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681D, 
        0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E25, 0xFF8C6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 
        0xFF8E7028, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 
        0xFF937730, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957834, 0xFF957834, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987B38, 0xFF987C39, 
        0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8240, 
        0xFF9D8140, 0xFF9D8240, 0xFF9D8242, 0xFF9D8241, 0xFF9E8341, 0xFF9E8342, 0xFF9E8343, 0xFF9E8342, 0xFF9F8343, 0xFF9F8443, 0xFF9F8444, 0xFF9E8444, 0xFF9F8545, 0xFF9F8444, 0xFF9F8544, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA18646, 
        0xFFA08646, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFF957D43, 0xFF6D5B30, 0xFF42371D, 0xFF151209, 0xFF000000, 0xFF000000, 0xFF19150B, 0xFF332B17, 0xFF000000, 0xFF131008, 0xFF907942, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4B, 
        0xFFA3894B, 0xFFA48A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFF3D331D, 0xFF000000, 0xFF524527, 0xFFA48A4D, 0xFFA58C4E, 0xFFA58C4F, 
        0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C50, 0xFFA68D50, 0xFFA68D50, 0xFF988148, 0xFF8B7543, 0xFF7A673A, 0xFF6C5B34, 0xFF5D4F2D, 0xFF4F4326, 0xFF3F361E, 0xFF000000, 0xFF000000, 0xFF0F0D07, 0xFF090804, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF070603, 0xFF0B0A05, 0xFF0D0B06, 0xFF0B0905, 0xFF0B0A05, 0xFF0D0B06, 0xFF0D0B06, 0xFF0C0A06, 0xFF0A0805, 0xFF0C0A06, 0xFF0B0905, 0xFF050502, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070603, 0xFF120F08, 0xFF221D10, 0xFF211C10, 0xFF010100, 0xFF0B0905, 0xFF554829, 0xFF685933, 0xFF776539, 0xFF867240, 0xFF957F48, 
        0xFFA68C50, 0xFFA68D50, 0xFFA68C50, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58B4E, 0xFFA58B4F, 0xFF382F1A, 0xFF000000, 0xFF39301B, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 
        0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA4894B, 0xFFA38A4B, 0xFFA3894C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFF786537, 0xFF000000, 0xFF050402, 0xFF110E07, 0xFF000000, 0xFF000000, 0xFF151209, 0xFF42381E, 
        0xFF6C5B30, 0xFF957D42, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08647, 0xFFA08647, 0xFFA08546, 0xFFA08646, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9F8443, 
        0xFF9E8343, 0xFF9E8342, 0xFF9D8342, 0xFF9E8342, 0xFF9D8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9C8240, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 
        0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF997C39, 0xFF987C38, 0xFF987B38, 0xFF987C38, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967935, 0xFF967934, 
        0xFF957934, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947631, 0xFF937631, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752F, 0xFF92752D, 0xFF92742E, 0xFF92742D, 0xFF91742C, 0xFF91732C, 0xFF91732C, 0xFF90722B, 
        0xFF90722B, 0xFF90722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8E7027, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D22, 0xFF8B6C22, 0xFF8A6C21, 
        0xFF8A6B21, 0xFF8A6B21, 0xFF8A6A20, 0xFF8A6A1F, 0xFF896A1F, 0xFF896A1E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF88681C, 0xFF87681C, 0xFF87681B, 0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF846417, 
        0xFF846416, 0xFF846416, 0xFF836315, 0xFF836315, 0xFF836315, 0xFF826214, 0xFF826213, 0xFF826113, 0xFF826112,
  0xFF816112, 0xFF826012, 0xFF826113, 0xFF826213, 0xFF826214, 0xFF836214, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856517, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86671A, 0xFF87671B, 0xFF87671C, 0xFF87671C, 0xFF88681C, 
        0xFF88691D, 0xFF88691D, 0xFF89691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F26, 
        0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF8F722A, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF93752F, 
        0xFF937630, 0xFF947631, 0xFF937731, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967935, 0xFF967934, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977A36, 0xFF977A37, 0xFF977B37, 0xFF977B37, 0xFF987B38, 
        0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 
        0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 
        0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFF9F8547, 0xFF957C42, 0xFF7B6637, 0xFF3B311A, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF231D10, 0xFF5F502B, 0xFF987F45, 0xFFA3894A, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFF131009, 0xFF000000, 0xFF6E5D33, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C50, 0xFFA68C4F, 0xFF9B834A, 0xFF000000, 0xFF0D0B06, 0xFF7F6C3D, 0xFF967F48, 0xFF937D47, 0xFF917B45, 
        0xFF897442, 0xFF776539, 0xFF6B5B33, 0xFF645530, 0xFF554829, 0xFF473C22, 0xFF453B21, 0xFF40361F, 0xFF3B321C, 0xFF141109, 0xFF000000, 0xFF0E0C06, 0xFF252012, 0xFF070603, 0xFF000000, 0xFF131009, 0xFF2C2515, 0xFF090804, 0xFF000000, 0xFF2E2716, 
        0xFF453A21, 0xFF463C22, 0xFF514527, 0xFF60522E, 0xFF6A5A33, 0xFF726137, 0xFF857140, 0xFF907A45, 0xFF937C46, 0xFF957F48, 0xFF988149, 0xFF9D854B, 0xFF7F6C3D, 0xFF050402, 0xFF131009, 0xFF998249, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 
        0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFF584A29, 0xFF010100, 0xFF201B0F, 0xFFA1884B, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF987F46, 0xFF5E4F2A, 0xFF251F11, 0xFF0C0A05, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF3B311A, 0xFF7B6737, 0xFF957C42, 0xFF9F8547, 
        0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF997D3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B38, 0xFF987B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967935, 0xFF967935, 0xFF957834, 0xFF957833, 
        0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937631, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF91732C, 0xFF90722B, 0xFF90722B, 
        0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 
        0xFF8A6B20, 0xFF896B20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691E, 0xFF88681D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF87671A, 0xFF86661A, 0xFF866619, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 
        0xFF846316, 0xFF846315, 0xFF836315, 0xFF836315, 0xFF836214, 0xFF826113, 0xFF826213, 0xFF826012, 0xFF816012,
  0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF826214, 0xFF836215, 0xFF836315, 0xFF836316, 0xFF846316, 0xFF846417, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 
        0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 
        0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F7229, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF92752F, 
        0xFF937630, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF967934, 0xFF967934, 0xFF967935, 0xFF967935, 0xFF967A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 
        0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF997D39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C803F, 
        0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFF9F8545, 
        0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA08647, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA28748, 0xFF9F8547, 0xFF6A592F, 0xFF272111, 0xFF080603, 0xFF030201, 0xFF000000, 0xFF000000, 0xFF211B0F, 
        0xFF5D4E2A, 0xFF907941, 0xFF9B8247, 0xFFA08649, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF998047, 0xFF000000, 0xFF0B0905, 0xFF836F3D, 0xFFA58B4D, 0xFFA58B4D, 0xFFA58B4D, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58C4E, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFF8D7843, 0xFF000000, 0xFF16120A, 0xFF8F7944, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 
        0xFFA68C50, 0xFFA68D50, 0xFFA68C50, 0xFFA68D50, 0xFFA68C50, 0xFFA68C50, 0xFFA68D50, 0xFFA68D50, 0xFFA68D50, 0xFF433820, 0xFF000000, 0xFF463C22, 0xFFA68D50, 0xFF241E11, 0xFF000000, 0xFF574A2A, 0xFFA68D50, 0xFF262012, 0xFF000000, 0xFF7B693B, 
        0xFFA68D50, 0xFFA68D50, 0xFFA68D50, 0xFFA68C50, 0xFFA68C50, 0xFFA68D4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C50, 0xFFA68C4F, 0xFFA68C50, 0xFFA68C4F, 0xFF917A45, 0xFF070603, 0xFF0C0A05, 0xFF85713F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA58C4F, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFF786538, 0xFF020201, 0xFF120F08, 0xFF8C7541, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 
        0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA08649, 0xFF9B8247, 0xFF8F7841, 0xFF5D4E2A, 0xFF201B0E, 0xFF000000, 0xFF000000, 0xFF030201, 0xFF080603, 0xFF282212, 0xFF6A5930, 0xFF9F8547, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18747, 
        0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 
        0xFF9D8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997C3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 
        0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF91732B, 0xFF90722A, 0xFF90722A, 
        0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E26, 0xFF8D6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6B21, 0xFF8A6B20, 
        0xFF8A6A20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846416, 
        0xFF846316, 0xFF836315, 0xFF836215, 0xFF836214, 0xFF826213, 0xFF826113, 0xFF826113, 0xFF816012, 0xFF816011,
  0xFF816011, 0xFF816011, 0xFF816112, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836314, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 
        0xFF87671C, 0xFF87681C, 0xFF88691D, 0xFF88691D, 0xFF88691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8D6E25, 0xFF8D6E25, 
        0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8F7028, 0xFF8E7128, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742D, 0xFF92752E, 0xFF92752E, 
        0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF937631, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967A34, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 
        0xFF977B37, 0xFF987C37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 
        0xFF9C803F, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9E8443, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA28748, 0xFF937C41, 0xFF67562E, 0xFF3F351C, 0xFF211B0E, 0xFF020201, 
        0xFF000000, 0xFF000000, 0xFF1B170C, 0xFF44391F, 0xFF66562E, 0xFF816C3B, 0xFF9A8146, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF726035, 0xFF000000, 0xFF1B170C, 0xFF927B43, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 
        0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFF776438, 0xFF000000, 0xFF201B0F, 0xFF967F47, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 
        0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68B4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFF40361E, 0xFF000000, 0xFF453A21, 0xFFA68C4F, 0xFF231D10, 0xFF000000, 0xFF544728, 0xFFA68C4F, 0xFF251F11, 0xFF000000, 0xFF796639, 
        0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA68C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFFA58C4F, 0xFF9A8249, 0xFF0A0804, 0xFF080703, 0xFF776438, 0xFFA58B4E, 0xFFA58C4E, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFF9A8147, 0xFF050402, 0xFF070603, 0xFF766437, 0xFFA38A4C, 0xFFA48A4C, 0xFFA3894B, 0xFFA38A4B, 
        0xFFA3894B, 0xFF9A8146, 0xFF816C3B, 0xFF66562E, 0xFF44391F, 0xFF1B170C, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF211B0E, 0xFF3F351C, 0xFF67562E, 0xFF947C42, 0xFFA28748, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 
        0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9D8342, 0xFF9D8341, 0xFF9D8241, 
        0xFF9D8241, 0xFF9D8240, 0xFF9D8240, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B803D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3A, 0xFF997D3A, 
        0xFF997D39, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF967A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957833, 
        0xFF947732, 0xFF947731, 0xFF947731, 0xFF947630, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752F, 0xFF92752E, 0xFF92742D, 0xFF92742D, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF91732B, 0xFF91732B, 0xFF90722A, 0xFF90722A, 0xFF90712A, 
        0xFF8F7129, 0xFF8F7129, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E26, 0xFF8D6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6B21, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 
        0xFF896A1F, 0xFF896A1F, 0xFF89691F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF856417, 0xFF846417, 0xFF846416, 0xFF846316, 
        0xFF836315, 0xFF836215, 0xFF836214, 0xFF826213, 0xFF826113, 0xFF826113, 0xFF816112, 0xFF816011, 0xFF816011,
  0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836215, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846417, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856519, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF86671A, 
        0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF89691F, 0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6C23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8D6E24, 
        0xFF8D6E25, 0xFF8D6F25, 0xFF8D6F26, 0xFF8D6F27, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7027, 0xFF8F7028, 0xFF8F7129, 0xFF8F7129, 0xFF90712A, 0xFF90722A, 0xFF90722A, 0xFF90732B, 0xFF90732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF92742D, 0xFF92742E, 
        0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957834, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A36, 
        0xFF977B36, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3A, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 
        0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18648, 0xFFA18748, 0xFFA18748, 0xFF947B41, 0xFF836E3A, 
        0xFF61512C, 0xFF2F2815, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF0C0A05, 0xFF1A160C, 0xFF322A16, 0xFF5D4E2A, 0xFF89733E, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFF4B3F22, 0xFF000000, 0xFF2B2414, 0xFFA08749, 0xFFA38A4C, 0xFFA38A4C, 0xFFA38A4C, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA58B4D, 0xFF63532E, 0xFF000000, 0xFF292213, 0xFF9A8349, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 
        0xFFA48B4E, 0xFFA58B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58C4E, 0xFF40361E, 0xFF000000, 0xFF453A20, 0xFFA58C4E, 0xFF221C10, 0xFF000000, 0xFF544627, 0xFFA58B4E, 0xFF251F11, 0xFF000000, 0xFF776438, 
        0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA48B4E, 0xFFA58B4D, 0xFFA58B4D, 0xFF110E08, 0xFF030301, 0xFF6A5931, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 
        0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA38A4B, 0xFFA38A4B, 0xFFA3894B, 0xFF1A160C, 0xFF000000, 0xFF61512C, 0xFFA3894A, 0xFFA3894B, 0xFF89733E, 0xFF5D4E2A, 
        0xFF322A16, 0xFF1A160C, 0xFF0C0A05, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF2F2815, 0xFF61522B, 0xFF846E3A, 0xFF937B41, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA18646, 0xFFA08646, 0xFFA08646, 
        0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8344, 0xFF9E8443, 0xFF9E8443, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8141, 0xFF9D8240, 
        0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 
        0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF947833, 0xFF947732, 0xFF947732, 
        0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722A, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 
        0xFF8F7129, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F25, 0xFF8C6E24, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B21, 0xFF896A20, 0xFF896A1F, 
        0xFF896A1F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF86671A, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF866518, 0xFF856518, 0xFF846518, 0xFF856417, 0xFF846416, 0xFF846416, 0xFF836315, 0xFF836315, 
        0xFF836315, 0xFF836214, 0xFF826213, 0xFF826113, 0xFF826113, 0xFF816112, 0xFF816011, 0xFF816011, 0xFF805F10,
  0xFF805F10, 0xFF805F10, 0xFF806011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836215, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 0xFF86661A, 
        0xFF86671A, 0xFF87671B, 0xFF87681C, 0xFF87681C, 0xFF88681D, 0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6D23, 0xFF8C6D23, 0xFF8C6D24, 
        0xFF8D6E25, 0xFF8D6E25, 0xFF8D6E26, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8F7028, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF90722A, 0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF91732B, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF91742D, 
        0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF93762F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957933, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A35, 
        0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 
        0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9D8140, 0xFF9D8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9E8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 
        0xFF9F8443, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18646, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFFA18748, 
        0xFFA18748, 0xFFA28748, 0xFF9E8447, 0xFF766334, 0xFF3E341C, 0xFF0E0C06, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF080603, 0xFF342B17, 0xFF68562F, 0xFF211C0F, 0xFF000000, 0xFF44391F, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 
        0xFFA3894B, 0xFFA38A4B, 0xFFA38A4B, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFF4E4224, 0xFF000000, 0xFF332B18, 0xFFA1884B, 0xFFA48A4D, 0xFFA48B4D, 0xFFA58B4D, 
        0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFFA58B4E, 0xFF40351E, 0xFF000000, 0xFF453A20, 0xFFA58B4D, 0xFF221C10, 0xFF000000, 0xFF534627, 0xFFA58B4E, 0xFF251F11, 0xFF000000, 0xFF776438, 
        0xFFA58B4E, 0xFFA58B4D, 0xFFA58B4E, 0xFFA48B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA58B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48B4D, 0xFF1D190D, 0xFF000000, 0xFF5B4C2A, 0xFFA48B4D, 0xFFA48B4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA38A4C, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA2884A, 0xFFA3894B, 0xFF42371E, 0xFF000000, 0xFF262011, 0xFF322A17, 0xFF080603, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF010100, 0xFF0E0C06, 0xFF3E341C, 0xFF766335, 0xFF9D8446, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA08647, 0xFFA18647, 0xFFA08647, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 
        0xFFA08545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8443, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 0xFF9D8341, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 
        0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 
        0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977B36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF947832, 0xFF947732, 0xFF947731, 0xFF947731, 
        0xFF937731, 0xFF937630, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92752E, 0xFF92742D, 0xFF91742D, 0xFF91732D, 0xFF91732C, 0xFF91732B, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF90712A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 
        0xFF8F7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6E26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 
        0xFF896A1E, 0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856519, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846316, 0xFF836315, 0xFF836315, 0xFF836215, 
        0xFF836214, 0xFF826214, 0xFF826113, 0xFF826113, 0xFF816012, 0xFF816011, 0xFF816011, 0xFF805F10, 0xFF805F10,
  0xFF805E0F, 0xFF805F10, 0xFF806010, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836214, 0xFF836315, 0xFF846315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF866619, 0xFF86661A, 
        0xFF86671A, 0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF89691E, 0xFF89691F, 0xFF896A1F, 0xFF896B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8C6C22, 0xFF8B6D23, 0xFF8C6D24, 
        0xFF8C6D24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90722B, 0xFF91732C, 0xFF91732C, 0xFF91742C, 
        0xFF91742D, 0xFF92742E, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937631, 0xFF937731, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF967934, 0xFF967934, 0xFF967935, 
        0xFF977A35, 0xFF967A36, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7E3C, 
        0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 
        0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 
        0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA28748, 0xFFA28748, 0xFF89733C, 0xFF5F502A, 0xFF39301A, 0xFF221C0F, 0xFF110E07, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1D180D, 0xFF504324, 0xFF6A5930, 0xFF7D6939, 0xFF8B753F, 
        0xFF977F45, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4C, 0xFFA48A4B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF39301A, 0xFF000000, 0xFF3E341C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4D, 
        0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48B4D, 0xFFA48A4D, 0xFF3F351D, 0xFF000000, 0xFF443A20, 0xFFA48B4D, 0xFF221D10, 0xFF000000, 0xFF534627, 0xFFA48A4D, 0xFF251F11, 0xFF000000, 0xFF776538, 
        0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48B4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4D, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFF312916, 0xFF000000, 0xFF4B3F23, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 
        0xFFA38A4B, 0xFFA3894C, 0xFFA3894B, 0xFFA38A4B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF977F45, 0xFF8B753F, 0xFF7D6939, 0xFF6A5930, 0xFF4F4223, 0xFF2C2514, 0xFF070603, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF110E07, 0xFF221C0F, 0xFF39301A, 
        0xFF5F4F2A, 0xFF89723D, 0xFFA28748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18747, 0xFFA18647, 0xFFA08646, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08546, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 
        0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9E8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 
        0xFF9C813F, 0xFF9C803E, 0xFF9B803E, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF9A7D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF987C39, 0xFF987C39, 0xFF987C38, 
        0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF987B37, 0xFF977B36, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957833, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF947631, 
        0xFF937630, 0xFF937630, 0xFF93762F, 0xFF93752F, 0xFF92752E, 0xFF92752E, 0xFF92752E, 0xFF91742D, 0xFF91742D, 0xFF91742D, 0xFF91732C, 0xFF90732B, 0xFF90732B, 0xFF90722B, 0xFF8F722A, 0xFF8F7229, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 
        0xFF8E7027, 0xFF8E6F27, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF89691F, 0xFF896A1F, 
        0xFF88691E, 0xFF88691D, 0xFF88691D, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF866619, 0xFF86661A, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846517, 0xFF846417, 0xFF846416, 0xFF846316, 0xFF836315, 0xFF836214, 0xFF836214, 
        0xFF826213, 0xFF826113, 0xFF826113, 0xFF816012, 0xFF816011, 0xFF816011, 0xFF816010, 0xFF805F10, 0xFF805F0F,
  0xFF7F5E0E, 0xFF805E0F, 0xFF805F10, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816112, 0xFF816112, 0xFF826113, 0xFF826213, 0xFF826214, 0xFF836214, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846317, 0xFF846417, 0xFF856418, 0xFF856518, 0xFF856518, 0xFF856619, 
        0xFF86661A, 0xFF86661A, 0xFF86661B, 0xFF87671B, 0xFF87671C, 0xFF87681C, 0xFF88681D, 0xFF88691D, 0xFF88691D, 0xFF88691E, 0xFF89691F, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6D23, 
        0xFF8B6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6E26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7027, 0xFF8F7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF8F722A, 0xFF90722A, 0xFF90722B, 0xFF90722B, 0xFF90732B, 0xFF91732C, 
        0xFF91742C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957933, 0xFF967934, 
        0xFF967934, 0xFF967935, 0xFF967A35, 0xFF977A35, 0xFF977A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF987C39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3B, 
        0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9C803E, 0xFF9B803E, 0xFF9C813E, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9C8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08546, 0xFFA08646, 0xFFA08646, 
        0xFFA08646, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18747, 0xFFA18748, 0xFF988044, 0xFF87703C, 0xFF746133, 0xFF5B4C29, 0xFF39301A, 0xFF17130A, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF020201, 0xFF141109, 
        0xFF221C0F, 0xFF312916, 0xFF463B20, 0xFF5F512B, 0xFF786436, 0xFF917941, 0xFFA3894B, 0xFFA3894A, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF262011, 0xFF000000, 0xFF4A3E22, 0xFFA3894B, 0xFFA3894B, 0xFFA38A4B, 0xFFA3894B, 
        0xFFA38A4B, 0xFFA38A4B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA38A4B, 0xFFA38A4C, 0xFFA48A4C, 0xFFA4894C, 0xFFA48A4C, 0xFF40361D, 0xFF000000, 0xFF44391F, 0xFFA48A4C, 0xFF221C0F, 0xFF000000, 0xFF534626, 0xFFA48A4C, 0xFF251F11, 0xFF000000, 0xFF776437, 
        0xFFA38A4C, 0xFFA38A4C, 0xFFA48A4C, 0xFFA3894C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA48A4C, 0xFFA38A4C, 0xFFA3894C, 0xFFA3894B, 0xFFA38A4B, 0xFFA3894C, 0xFFA3894B, 0xFF453A1F, 0xFF000000, 0xFF43381F, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 
        0xFFA3894B, 0xFFA3894A, 0xFF917941, 0xFF786536, 0xFF60502B, 0xFF463B20, 0xFF302916, 0xFF221C0F, 0xFF141109, 0xFF020201, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF18140A, 0xFF39301A, 0xFF5A4B28, 0xFF746133, 0xFF86703C, 0xFF988044, 0xFFA18748, 
        0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8242, 0xFF9E8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803E, 0xFF9C803E, 
        0xFF9B803E, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 
        0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF977A35, 0xFF967935, 0xFF967935, 0xFF967934, 0xFF957834, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 
        0xFF93762F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742D, 0xFF91742D, 0xFF91742C, 0xFF91732C, 0xFF90732B, 0xFF90732B, 0xFF90722B, 0xFF8F722A, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 
        0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691E, 
        0xFF88691D, 0xFF88681D, 0xFF87681C, 0xFF87681B, 0xFF87671B, 0xFF86671B, 0xFF86661A, 0xFF866619, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846416, 0xFF846315, 0xFF836315, 0xFF836215, 0xFF826214, 0xFF826113, 
        0xFF826113, 0xFF826113, 0xFF816112, 0xFF816011, 0xFF816011, 0xFF815F10, 0xFF805F10, 0xFF805F0F, 0xFF7F5E0E,
  0xFF7F5E0E, 0xFF7F5E0E, 0xFF805F0F, 0xFF805F10, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826113, 0xFF836213, 0xFF826214, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 0xFF856418, 0xFF856518, 0xFF856518, 
        0xFF866619, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87681C, 0xFF88681D, 0xFF88681D, 0xFF88691D, 0xFF88691E, 0xFF896A1E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C22, 
        0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6D24, 0xFF8C6E24, 0xFF8D6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E6F27, 0xFF8E7028, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F712A, 0xFF90712A, 0xFF90722B, 0xFF90722B, 0xFF90732B, 
        0xFF91732C, 0xFF91732C, 0xFF91742C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF93752F, 0xFF93752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 0xFF957833, 0xFF957833, 0xFF957833, 
        0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF977A36, 0xFF977B36, 0xFF977A37, 0xFF977B37, 0xFF977B37, 0xFF987B38, 0xFF987C38, 0xFF987C38, 0xFF987C39, 0xFF997D39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997E3B, 
        0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 
        0xFF9D8241, 0xFF9D8241, 0xFF9E8241, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8343, 0xFF9E8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFFA08545, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 
        0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA08647, 0xFF9F8547, 0xFF9E8346, 0xFF967E44, 0xFF796536, 0xFF514424, 0xFF282112, 0xFF070603, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF030201, 0xFF030301, 0xFF070603, 0xFF1D180D, 0xFF352C18, 0xFF514425, 0xFF6E5C32, 0xFF846F3C, 0xFF9F8548, 0xFF1A160C, 0xFF010100, 0xFF5C4D29, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF3F351D, 0xFF000000, 0xFF43381F, 0xFFA3894B, 0xFF211C0F, 0xFF000000, 0xFF534626, 0xFFA3894B, 0xFF251F11, 0xFF000000, 0xFF766336, 
        0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFFA3894B, 0xFF5D4E2A, 0xFF000000, 0xFF352C18, 0xFF7E6A39, 0xFF6E5C32, 0xFF514425, 0xFF352C18, 
        0xFF1D180D, 0xFF070503, 0xFF030301, 0xFF030201, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF070603, 0xFF282112, 0xFF514424, 0xFF796536, 0xFF967E43, 0xFF9E8346, 0xFFA08547, 0xFFA08647, 0xFFA18748, 0xFFA18747, 0xFFA18748, 0xFFA18747, 
        0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 
        0xFF9F8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8342, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9B803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 
        0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF9A7E3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 
        0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 0xFF967934, 0xFF967934, 0xFF967934, 0xFF957933, 0xFF957833, 0xFF957833, 0xFF947732, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937731, 0xFF947631, 0xFF937630, 0xFF93762F, 0xFF93762F, 
        0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF91742C, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7128, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F27, 
        0xFF8D6F26, 0xFF8D6F26, 0xFF8D6E25, 0xFF8D6E25, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6D24, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A1F, 0xFF896A1F, 0xFF896A1F, 0xFF88691E, 0xFF88691D, 0xFF88691D, 
        0xFF88681C, 0xFF87681C, 0xFF87681C, 0xFF87671B, 0xFF87671A, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846416, 0xFF836315, 0xFF836315, 0xFF836314, 0xFF836214, 0xFF826214, 0xFF826113, 
        0xFF826112, 0xFF826012, 0xFF816011, 0xFF816011, 0xFF805F10, 0xFF805F10, 0xFF805F0F, 0xFF7F5E0F, 0xFF7F5E0E,
  0xFF7F5E0D, 0xFF7F5E0E, 0xFF805E0F, 0xFF805E0F, 0xFF805F10, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826113, 0xFF836214, 0xFF836214, 0xFF836315, 0xFF846315, 0xFF846316, 0xFF846416, 0xFF846417, 0xFF856518, 0xFF856518, 
        0xFF856518, 0xFF866519, 0xFF866619, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF88681C, 0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF89691F, 0xFF896A1F, 0xFF8A6A1F, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B21, 0xFF8A6C21, 0xFF8B6C22, 
        0xFF8B6C22, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D23, 0xFF8C6E24, 0xFF8C6E25, 0xFF8C6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F27, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 0xFF90722B, 0xFF90722B, 
        0xFF91722B, 0xFF90732C, 0xFF91732C, 0xFF91732D, 0xFF91742D, 0xFF92742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF93752F, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF947631, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF957832, 0xFF957833, 0xFF957833, 
        0xFF957933, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A36, 0xFF977A36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF977B38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997C39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 
        0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C813F, 0xFF9C803F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8140, 
        0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8242, 0xFF9E8341, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFF9F8545, 
        0xFFA08545, 0xFFA08546, 0xFFA08545, 0xFFA08646, 0xFFA08546, 0xFFA08646, 0xFFA08647, 0xFFA18646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 
        0xFF927B41, 0xFF725F33, 0xFF564826, 0xFF362D18, 0xFF211C0F, 0xFF16130A, 0xFF100D07, 0xFF080704, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF1B170C, 0xFF352D18, 0xFF4A3D21, 0xFF574927, 0xFF64542D, 
        0xFF766335, 0xFF7D6938, 0xFF826D3B, 0xFF88723D, 0xFF8A743E, 0xFF8B7540, 0xFF8E7741, 0xFF907942, 0xFF977F45, 0xFF3A301A, 0xFF000000, 0xFF3D331C, 0xFFA2884A, 0xFF1E190E, 0xFF000000, 0xFF4B3F22, 0xFF9D8448, 0xFF211B0F, 0xFF000000, 0xFF6A5930, 
        0xFF917942, 0xFF8E7741, 0xFF8B753F, 0xFF8A743E, 0xFF88723D, 0xFF826D3B, 0xFF7D6938, 0xFF766335, 0xFF64542D, 0xFF574927, 0xFF4A3E21, 0xFF352C18, 0xFF272111, 0xFF0A0904, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF080704, 0xFF100D07, 0xFF17130A, 0xFF211C0F, 0xFF362D18, 0xFF564826, 0xFF725F33, 0xFF927A42, 0xFFA28748, 0xFFA28748, 0xFFA18748, 0xFFA28748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA08647, 
        0xFFA08646, 0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 0xFF9F8445, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8343, 0xFF9E8343, 0xFF9E8343, 
        0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8242, 0xFF9E8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B7F3E, 0xFF9B7F3D, 0xFF9B7F3D, 
        0xFF9B7F3D, 0xFF9B7F3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF997E3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997C39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF987B37, 0xFF977B37, 0xFF977B37, 0xFF977B36, 
        0xFF977A36, 0xFF977A35, 0xFF967A35, 0xFF967935, 0xFF967934, 0xFF957934, 0xFF957934, 0xFF957934, 0xFF957833, 0xFF957832, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF937530, 0xFF92752F, 0xFF92752F, 
        0xFF92752E, 0xFF92742E, 0xFF92742D, 0xFF92742D, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8D7027, 0xFF8E6F27, 0xFF8D6F26, 
        0xFF8D6F26, 0xFF8C6E25, 0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8B6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6B21, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6A20, 0xFF896A1F, 0xFF896A1E, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 
        0xFF88681C, 0xFF87671B, 0xFF87671B, 0xFF86671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846417, 0xFF846316, 0xFF846316, 0xFF836315, 0xFF836215, 0xFF836214, 0xFF826213, 0xFF826113, 0xFF826113, 
        0xFF816012, 0xFF816012, 0xFF816011, 0xFF806011, 0xFF805F10, 0xFF805F0F, 0xFF7F5E0F, 0xFF7F5E0E, 0xFF7F5E0E,
  0xFF7E5D0D, 0xFF7F5D0D, 0xFF7F5E0E, 0xFF7F5E0F, 0xFF805F0F, 0xFF805F10, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826113, 0xFF826213, 0xFF836214, 0xFF836315, 0xFF836315, 0xFF846316, 0xFF846416, 0xFF846416, 0xFF856517, 
        0xFF856518, 0xFF856518, 0xFF866619, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF88681C, 0xFF88681D, 0xFF88691D, 0xFF89691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF8A6A20, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6C21, 
        0xFF8B6C21, 0xFF8B6C22, 0xFF8B6C23, 0xFF8B6D23, 0xFF8C6D23, 0xFF8C6D24, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8F7128, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF90722A, 
        0xFF90722A, 0xFF90722A, 0xFF91732B, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF91742E, 0xFF92752E, 0xFF92752F, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947731, 0xFF947732, 0xFF947832, 
        0xFF957832, 0xFF957833, 0xFF957833, 0xFF957934, 0xFF957934, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967A35, 0xFF967A36, 0xFF977B36, 0xFF977B36, 0xFF977B37, 0xFF977B37, 0xFF987B37, 0xFF977C38, 0xFF987C38, 0xFF987C39, 0xFF997C39, 0xFF997D3A, 
        0xFF997D3A, 0xFF997D3A, 0xFF997D3B, 0xFF997E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B803D, 0xFF9B803D, 0xFF9C803E, 0xFF9C803E, 0xFF9C803F, 0xFF9C8140, 0xFF9C813F, 
        0xFF9C8140, 0xFF9C8140, 0xFF9D8140, 0xFF9D8140, 0xFF9D8240, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8341, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8343, 0xFF9E8343, 0xFF9E8443, 0xFF9F8443, 0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 
        0xFF9F8444, 0xFF9F8444, 0xFF9F8545, 0xFF9F8545, 0xFF9F8545, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA08646, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18748, 0xFFA18747, 
        0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFFA18748, 0xFF967E43, 0xFF88723C, 0xFF796637, 0xFF6C5A30, 0xFF5E4E2A, 0xFF4E4123, 0xFF40351C, 0xFF302815, 0xFF221D0F, 0xFF110E07, 0xFF060503, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 
        0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF030301, 0xFF060503, 0xFF0D0B06, 0xFF131008, 0xFF18140B, 0xFF090804, 0xFF000000, 0xFF0B0905, 0xFF1F1A0E, 0xFF050402, 0xFF000000, 0xFF0E0C06, 0xFF1D190D, 0xFF050402, 0xFF000000, 0xFF100D07, 
        0xFF131008, 0xFF0D0B06, 0xFF060503, 0xFF030301, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF000000, 0xFF060502, 0xFF110E08, 0xFF221D0F, 0xFF2F2715, 0xFF40351C, 0xFF4E4223, 0xFF5E4E2A, 0xFF6C5A30, 
        0xFF796636, 0xFF88723C, 0xFF967E44, 0xFFA18748, 0xFFA18748, 0xFFA18747, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA08646, 0xFFA08646, 0xFFA08647, 0xFFA08646, 0xFFA08546, 0xFFA08546, 
        0xFFA08546, 0xFFA08545, 0xFFA08546, 0xFFA08545, 0xFF9F8545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9E8443, 0xFF9E8444, 0xFF9E8343, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8241, 
        0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8240, 0xFF9D8140, 0xFF9D8141, 0xFF9C8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9C813F, 0xFF9C803F, 0xFF9B803F, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9A7F3C, 
        0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7E3B, 0xFF997E3B, 0xFF9A7D3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997C39, 0xFF987C39, 0xFF987C38, 0xFF987C38, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977B36, 0xFF977A36, 0xFF967A35, 
        0xFF967A35, 0xFF967935, 0xFF957934, 0xFF967934, 0xFF957934, 0xFF957933, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF947731, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF93752F, 0xFF92752F, 0xFF92752E, 0xFF92742E, 
        0xFF92742D, 0xFF91742D, 0xFF91732C, 0xFF91732C, 0xFF91732C, 0xFF90732B, 0xFF90722B, 0xFF90722A, 0xFF90722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8E7128, 0xFF8F7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E6F26, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E26, 
        0xFF8C6E25, 0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D24, 0xFF8B6D23, 0xFF8B6C23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8A6B21, 0xFF8A6B21, 0xFF8A6B20, 0xFF896A20, 0xFF896A1F, 0xFF896A1F, 0xFF89691E, 0xFF89691E, 0xFF88681D, 0xFF88681D, 0xFF87681C, 0xFF87681C, 
        0xFF87671B, 0xFF87671B, 0xFF86671A, 0xFF86661A, 0xFF866619, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF846417, 0xFF846416, 0xFF846316, 0xFF836315, 0xFF836315, 0xFF836214, 0xFF836214, 0xFF826213, 0xFF826113, 0xFF826112, 0xFF816012, 
        0xFF816011, 0xFF816011, 0xFF805F10, 0xFF805F10, 0xFF805F0F, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF7F5D0D,
  0xFF7E5D0C, 0xFF7E5D0D, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF805F0F, 0xFF805F10, 0xFF805F10, 0xFF816011, 0xFF816011, 0xFF816012, 0xFF826112, 0xFF826113, 0xFF826113, 0xFF836214, 0xFF836215, 0xFF836315, 0xFF836315, 0xFF846416, 0xFF846416, 0xFF846417, 
        0xFF846517, 0xFF856518, 0xFF856518, 0xFF866518, 0xFF866619, 0xFF86661A, 0xFF86661A, 0xFF87671B, 0xFF87671B, 0xFF87671C, 0xFF88681C, 0xFF88681D, 0xFF88681D, 0xFF88691E, 0xFF89691E, 0xFF896A1F, 0xFF896A1F, 0xFF896A20, 0xFF8A6B20, 0xFF8A6B20, 
        0xFF8B6B21, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C23, 0xFF8C6D23, 0xFF8C6D23, 0xFF8C6D23, 0xFF8C6E24, 0xFF8C6E25, 0xFF8D6E25, 0xFF8D6F26, 0xFF8D6F26, 0xFF8E6F26, 0xFF8E7027, 0xFF8E7027, 0xFF8E7028, 0xFF8E7028, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 
        0xFF90722A, 0xFF90722A, 0xFF90722B, 0xFF90732B, 0xFF91732B, 0xFF91732C, 0xFF91732C, 0xFF91742D, 0xFF91742D, 0xFF92742E, 0xFF92752E, 0xFF92752E, 0xFF92752F, 0xFF93762F, 0xFF937630, 0xFF937630, 0xFF947630, 0xFF947731, 0xFF947731, 0xFF947731, 
        0xFF957732, 0xFF957832, 0xFF957833, 0xFF957833, 0xFF957933, 0xFF957933, 0xFF967934, 0xFF967935, 0xFF967A35, 0xFF967935, 0xFF977A36, 0xFF967A36, 0xFF977A36, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF987C38, 0xFF987C38, 0xFF987C38, 0xFF987C38, 
        0xFF987C39, 0xFF997D39, 0xFF997D39, 0xFF997D3A, 0xFF997D3A, 0xFF997D3A, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3B, 0xFF9A7E3C, 0xFF9A7F3C, 0xFF9A7F3C, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9B7F3E, 0xFF9B803E, 0xFF9C803E, 0xFF9C803E, 0xFF9C803F, 
        0xFF9C803F, 0xFF9C813F, 0xFF9C813F, 0xFF9C8140, 0xFF9D8140, 0xFF9D8140, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9D8241, 0xFF9E8242, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9E8343, 0xFF9E8443, 0xFF9E8343, 0xFF9F8443, 
        0xFF9F8443, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8544, 0xFF9F8544, 0xFF9F8545, 0xFF9F8545, 0xFF9F8545, 0xFFA08545, 0xFFA08545, 0xFFA08546, 0xFFA08545, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA18647, 
        0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18747, 0xFFA18747, 0xFFA18748, 0xFFA18747, 0xFFA18748, 0xFFA18748, 0xFFA08647, 0xFF9D8446, 0xFF9B8145, 0xFF987F44, 0xFF957C42, 0xFF937B42, 0xFF927940, 0xFF8B743E, 0xFF796535, 0xFF6C5A30, 
        0xFF61512B, 0xFF4E4123, 0xFF463B1F, 0xFF3E331C, 0xFF312916, 0xFF241E10, 0xFF211C0F, 0xFF1D180D, 0xFF16130A, 0xFF110E07, 0xFF0A0804, 0xFF030201, 0xFF010100, 0xFF000000, 0xFF000000, 0xFF010100, 0xFF050402, 0xFF090804, 0xFF110E07, 0xFF17130A, 
        0xFF1D180D, 0xFF211C0F, 0xFF241E10, 0xFF312916, 0xFF3E331C, 0xFF463B1F, 0xFF4E4223, 0xFF60512B, 0xFF6C5A30, 0xFF796536, 0xFF8B753E, 0xFF927940, 0xFF947B42, 0xFF957D42, 0xFF987F44, 0xFF9A8145, 0xFF9D8446, 0xFFA08647, 0xFFA18748, 0xFFA18748, 
        0xFFA18748, 0xFFA18648, 0xFFA18748, 0xFFA18747, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18647, 0xFFA18646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08646, 0xFFA08546, 0xFFA08545, 0xFFA08545, 0xFFA08545, 0xFF9F8545, 
        0xFF9F8545, 0xFF9F8545, 0xFF9F8544, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8444, 0xFF9F8443, 0xFF9F8443, 0xFF9E8343, 0xFF9E8343, 0xFF9E8343, 0xFF9E8342, 0xFF9E8342, 0xFF9E8342, 0xFF9D8342, 0xFF9E8342, 0xFF9E8242, 0xFF9E8241, 0xFF9D8241, 
        0xFF9D8241, 0xFF9D8241, 0xFF9D8140, 0xFF9D8140, 0xFF9D8140, 0xFF9C813F, 0xFF9C813F, 0xFF9C803F, 0xFF9C803F, 0xFF9C803E, 0xFF9B803E, 0xFF9B803E, 0xFF9B803D, 0xFF9B7F3D, 0xFF9B7F3D, 0xFF9A7F3D, 0xFF9B7F3C, 0xFF9A7F3C, 0xFF9A7E3C, 0xFF9A7E3C, 
        0xFF9A7E3B, 0xFF9A7E3B, 0xFF997E3B, 0xFF997D3A, 0xFF997D3A, 0xFF997D39, 0xFF997D39, 0xFF997C39, 0xFF987C39, 0xFF987C39, 0xFF987C38, 0xFF987B38, 0xFF977B37, 0xFF977B37, 0xFF977B37, 0xFF977A36, 0xFF977A36, 0xFF977A36, 0xFF967A35, 0xFF967A35, 
        0xFF967935, 0xFF967934, 0xFF957934, 0xFF967934, 0xFF957833, 0xFF957833, 0xFF957832, 0xFF947732, 0xFF947732, 0xFF947731, 0xFF947731, 0xFF947730, 0xFF937630, 0xFF937630, 0xFF937630, 0xFF92752F, 0xFF92752E, 0xFF92752E, 0xFF92742E, 0xFF92742D, 
        0xFF92742D, 0xFF91732C, 0xFF91732C, 0xFF90732C, 0xFF90732B, 0xFF90722B, 0xFF90722B, 0xFF8F722A, 0xFF8F7129, 0xFF8F7129, 0xFF8F7129, 0xFF8E7028, 0xFF8E7028, 0xFF8E7027, 0xFF8E7027, 0xFF8E6F27, 0xFF8D6F26, 0xFF8D6F25, 0xFF8D6E25, 0xFF8C6E24, 
        0xFF8C6E24, 0xFF8C6D24, 0xFF8C6D23, 0xFF8C6D23, 0xFF8B6C22, 0xFF8B6C22, 0xFF8B6C21, 0xFF8A6C21, 0xFF8A6B20, 0xFF8A6B20, 0xFF8A6B20, 0xFF896A1F, 0xFF89691F, 0xFF89691E, 0xFF88691E, 0xFF88691D, 0xFF88681D, 0xFF88681C, 0xFF87681C, 0xFF87671B, 
        0xFF87671B, 0xFF86661A, 0xFF86661A, 0xFF866619, 0xFF856518, 0xFF856518, 0xFF856518, 0xFF856517, 0xFF846417, 0xFF846416, 0xFF846416, 0xFF836315, 0xFF836315, 0xFF836215, 0xFF836213, 0xFF826213, 0xFF826113, 0xFF826112, 0xFF816112, 0xFF816011, 
        0xFF816011, 0xFF805F10, 0xFF805F10, 0xFF805F0F, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF7F5E0E, 0xFF7F5D0D, 0xFF7E5D0C
#else
  0x000C5D7E, 0x000C5D7E, 0x000D5E7F, 0x000E5E7F, 0x000E5E7F, 0x000F5E80, 0x00105F80, 0x00105F80, 0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136182, 0x00136282, 0x00146283, 0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 
        0x00176485, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001B6787, 0x001C6888, 0x001C6888, 0x001D6888, 0x001D6988, 0x001E6989, 0x001E6A89, 0x001F6A89, 0x00206A89, 0x00206B89, 0x00206B8A, 
        0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029708F, 0x0029718F, 0x0029718F, 
        0x002A728F, 0x002A7290, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 
        0x00327794, 0x00327894, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00347995, 0x00347996, 0x00357996, 0x00357996, 0x00367A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387B98, 0x00387C98, 0x00387C98, 
        0x00397C98, 0x00397D99, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809B, 0x003E809B, 0x003F819C, 
        0x003F819C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041839D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849F, 
        0x0043849F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x0045859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x004685A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004786A0, 
        0x004786A0, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x004786A0, 0x0046849D, 0x0045819A, 0x00447F98, 0x00427C95, 0x00427B93, 0x00407992, 0x003D738A, 0x00356478, 0x0030596B, 
        0x002A5060, 0x0023414E, 0x001F3A45, 0x001B333D, 0x00162930, 0x00101E24, 0x000E1B21, 0x000C181C, 0x000A1316, 0x00070D10, 0x0004080A, 0x00010203, 0x00000101, 0x00000000, 0x00000000, 0x00000101, 0x00020405, 0x0004080A, 0x00070D10, 0x000A1316, 
        0x000C171C, 0x000E1B21, 0x00101E24, 0x00162830, 0x001B333D, 0x001F3A45, 0x0023414E, 0x002A5060, 0x00305A6B, 0x00356579, 0x003D738B, 0x00417991, 0x00427B93, 0x00427C95, 0x00447F98, 0x0045819A, 0x0046849D, 0x004786A0, 0x004887A1, 0x004887A1, 
        0x004787A1, 0x004886A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004786A1, 0x004686A0, 0x004786A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004685A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0045859F, 
        0x0045859F, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0043849E, 0x0043839E, 0x0042849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0041829D, 0x0041829D, 
        0x0040829D, 0x0040829D, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003F809C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 
        0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357996, 
        0x00357996, 0x00347996, 0x00347895, 0x00337995, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 
        0x002D7491, 0x002C7391, 0x002C7391, 0x002C7390, 0x002B7290, 0x002A7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0029708F, 0x0028708E, 0x0027708E, 0x0027708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00256E8D, 
        0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00226C8A, 0x00216C8A, 0x00206B8A, 0x00206B8A, 0x001F6A8A, 0x001F6A89, 0x001E6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001B6787, 0x001B6787, 
        0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176584, 0x00176484, 0x00166484, 0x00166384, 0x00156383, 0x00156383, 0x00146283, 0x00146282, 0x00136182, 0x00136182, 0x00126182, 0x00126081, 0x00116081, 
        0x00116081, 0x00105F80, 0x00105F80, 0x000F5F80, 0x000F5E7F, 0x000E5E7F, 0x000E5E7F, 0x000D5D7F, 0x000C5C7E,
  0x000D5D7E, 0x000D5D7F, 0x000E5E7F, 0x000E5E7F, 0x000F5E80, 0x000F5F80, 0x00105F80, 0x00116081, 0x00116081, 0x00116081, 0x00126182, 0x00136182, 0x00136182, 0x00146282, 0x00146283, 0x00156283, 0x00156383, 0x00166384, 0x00166484, 0x00176484, 0x00176585, 
        0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6687, 0x001B6787, 0x001B6787, 0x001C6787, 0x001C6888, 0x001C6888, 0x001D6888, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206A8A, 0x00206B8A, 0x00216B8A, 
        0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236C8C, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256E8C, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A718F, 0x0029728F, 
        0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7391, 0x002D7491, 0x002D7492, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00317794, 0x00327794, 
        0x00327895, 0x00337895, 0x00337895, 0x00347895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00387C98, 0x00397C98, 0x00397D99, 
        0x00397D99, 0x003A7D99, 0x003B7D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9A, 0x003D7F9B, 0x003E7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819B, 0x003F819C, 
        0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0040829D, 0x0041819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0043849E, 0x0044849F, 0x0044849F, 
        0x0044849F, 0x0045859F, 0x0044859F, 0x0044859F, 0x0045859F, 0x0046859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004685A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004686A1, 0x004686A0, 0x004786A1, 0x004786A1, 0x004686A1, 0x004786A1, 0x004786A1, 
        0x004787A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x00437E96, 0x003C7287, 0x00366579, 0x00305A6C, 0x002A4E5E, 0x0023424E, 0x001C353F, 0x0015282F, 0x000F1D22, 0x00070E11, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010303, 0x00030607, 0x00060B0E, 0x00091114, 0x000B1418, 0x00040708, 0x00000000, 0x00020506, 0x000E1A1F, 0x00020506, 0x00000000, 0x00060C0E, 0x000D181D, 0x00000000, 0x00000000, 0x00070D10, 
        0x00091114, 0x00060B0D, 0x00030607, 0x00010303, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020405, 0x00070E11, 0x000F1D22, 0x0015272F, 0x001C353F, 0x0023414E, 0x002A4E5E, 0x00305A6B, 
        0x00376679, 0x003C7187, 0x00437E96, 0x004987A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004686A0, 0x004585A0, 
        0x004585A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0045859F, 0x004485A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0044849E, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042829E, 
        0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 
        0x003C7E9A, 0x003B7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A96, 0x00357A96, 
        0x00357996, 0x00357996, 0x00347995, 0x00347996, 0x00347895, 0x00347895, 0x00337895, 0x00337895, 0x00327894, 0x00317794, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x00307693, 0x00307593, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 
        0x002D7492, 0x002D7492, 0x002C7391, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A7190, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 
        0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00236C8B, 0x00226C8B, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001C6887, 
        0x001B6787, 0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00196685, 0x00186585, 0x00186585, 0x00176585, 0x00166484, 0x00166484, 0x00166384, 0x00156383, 0x00156283, 0x00156283, 0x00136282, 0x00136282, 0x00136182, 0x00126182, 0x00126081, 
        0x00116081, 0x00116081, 0x00105F80, 0x000F5F80, 0x000F5F80, 0x000E5E7F, 0x000E5E7F, 0x000E5D7F, 0x000D5D7F,
  0x000E5E7F, 0x000E5E7F, 0x000F5E80, 0x000F5F80, 0x000F5F80, 0x00105F80, 0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136182, 0x00146283, 0x00146283, 0x00156383, 0x00166384, 0x00166384, 0x00176484, 0x00176484, 0x00176585, 0x00186585, 
        0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001B6787, 0x001B6786, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6888, 0x001D6888, 0x001E6988, 0x001E6989, 0x001F6A89, 0x00206A89, 0x00206A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 
        0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7290, 
        0x002B7290, 0x002C7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00317794, 0x00327895, 0x00327895, 0x00327895, 
        0x00337895, 0x00347995, 0x00347995, 0x00347996, 0x00357996, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 
        0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819C, 
        0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043849F, 0x0043849E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045849F, 0x0045859F, 
        0x004585A0, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004786A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A2, 0x004887A1, 
        0x00407992, 0x00335F71, 0x00264855, 0x00182C35, 0x000F1C21, 0x000A1316, 0x00070D10, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E1B20, 0x00182D36, 0x00213E4A, 0x00284958, 0x002E5565, 
        0x00356376, 0x0039697D, 0x003B6E83, 0x003D7287, 0x003E748A, 0x003F758B, 0x0041778D, 0x00427991, 0x00457F97, 0x001A2F38, 0x00000000, 0x000F1C21, 0x004987A1, 0x000E191E, 0x00000000, 0x00223F4B, 0x0046819A, 0x00010303, 0x00000000, 0x0030596A, 
        0x00427991, 0x0041778E, 0x003F758B, 0x003E748A, 0x003D7288, 0x003B6E83, 0x0039697D, 0x00356376, 0x002E5565, 0x00284958, 0x00213E4A, 0x00182C35, 0x00122228, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00040708, 0x00070D10, 0x000A1317, 0x000F1C21, 0x00182C35, 0x00264755, 0x00325F72, 0x00407992, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004786A1, 
        0x004786A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0045859F, 0x0045849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 
        0x0042839E, 0x0042839E, 0x0042839D, 0x0042829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7F9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B98, 0x00377B97, 0x00377B97, 
        0x00367A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00327794, 0x00317794, 0x00317793, 0x00307693, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002F7592, 
        0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002C7391, 0x002B7290, 0x002A7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00276F8E, 0x00266F8E, 0x00266F8D, 
        0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246E8C, 0x00236D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8B, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x00206A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6888, 0x001D6888, 
        0x001C6887, 0x001C6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166384, 0x00156384, 0x00156383, 0x00146283, 0x00146283, 0x00136182, 0x00136182, 0x00126182, 
        0x00126081, 0x00116081, 0x00116081, 0x00106081, 0x00105F80, 0x000F5F80, 0x000E5E80, 0x000E5E7F, 0x000D5E7F,
  0x000E5E7F, 0x000E5E7F, 0x000F5F80, 0x00105F80, 0x00105F80, 0x00106081, 0x00116081, 0x00116081, 0x00126182, 0x00136182, 0x00136182, 0x00146283, 0x00146283, 0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 0x00176585, 0x00186585, 0x00186585, 
        0x00196686, 0x001A6686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001D6988, 0x001E6989, 0x001E6989, 0x001E6A89, 0x001F6A89, 0x00206B89, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 
        0x00236D8B, 0x00236D8C, 0x00236D8C, 0x00236E8C, 0x00256E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x0029718F, 0x002A7190, 0x002A7290, 0x002B7290, 0x002B7290, 
        0x002B7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x002F7593, 0x00307693, 0x00307693, 0x00307693, 0x00317694, 0x00327794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00337895, 
        0x00347995, 0x00347996, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 
        0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 
        0x0041829D, 0x0041829E, 0x0041829D, 0x0042829E, 0x0042829D, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0044849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x004584A0, 0x004585A0, 0x004585A0, 0x004585A0, 
        0x004685A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A1, 0x004686A0, 0x004786A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004787A1, 0x004787A1, 0x004786A0, 0x0046849F, 0x0046839D, 0x00437E96, 0x00366577, 0x00244351, 0x00112027, 0x00030506, 
        0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00010203, 0x00010303, 0x00030607, 0x000D191D, 0x00182D36, 0x00254551, 0x00325C6F, 0x003C6E84, 0x0046829A, 0x000B1418, 0x00020304, 0x00346073, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 
        0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x001D353F, 0x00000000, 0x00111F25, 0x004B89A3, 0x000F1C21, 0x00000000, 0x00264553, 0x004B89A3, 0x00020304, 0x00000000, 0x00366376, 
        0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004A89A3, 0x00213C48, 0x00000000, 0x001C353F, 0x003B6D83, 0x00325C6E, 0x00254552, 0x00182D36, 
        0x000D191D, 0x00030607, 0x00010303, 0x00010203, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00030506, 0x00112027, 0x00244450, 0x00356579, 0x00437E97, 0x0046839D, 0x0046849E, 0x004786A0, 0x004887A1, 0x004787A1, 0x004787A1, 0x004787A1, 
        0x004786A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0045849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 
        0x0043839E, 0x0043839E, 0x0042839E, 0x0042839D, 0x0041839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D809B, 
        0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 
        0x00377B97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357A96, 0x00357996, 0x00347996, 0x00337995, 0x00337895, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x00307693, 0x002F7693, 0x002F7592, 
        0x002F7592, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 
        0x00266F8D, 0x00256F8D, 0x00256E8D, 0x00256E8C, 0x00246D8C, 0x00246D8C, 0x00236D8B, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6989, 0x001D6988, 0x001D6888, 
        0x001C6887, 0x001C6887, 0x001B6887, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166484, 0x00156383, 0x00156383, 0x00156383, 0x00146282, 0x00136282, 0x00136182, 
        0x00126182, 0x00126081, 0x00116081, 0x00116081, 0x00105F80, 0x00105F80, 0x000F5F80, 0x000E5E7F, 0x000E5E7F,
  0x000E5E7F, 0x000F5E80, 0x00105F80, 0x00105F80, 0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136282, 0x00136283, 0x00146283, 0x00156283, 0x00156383, 0x00166384, 0x00166484, 0x00176484, 0x00176585, 0x00186585, 0x00186585, 0x00196586, 
        0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00226D8B, 
        0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00256E8C, 0x00256E8C, 0x00266E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A728F, 0x002B7290, 0x002B7290, 0x002B7390, 0x002C7391, 
        0x002C7491, 0x002D7491, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00317694, 0x00327794, 0x00327894, 0x00327794, 0x00337895, 0x00337995, 0x00337895, 0x00347996, 
        0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A96, 0x00367B97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E99, 0x003B7E9A, 
        0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E7F9B, 0x003E809B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 
        0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x0045859F, 0x004685A0, 0x004585A0, 0x004586A0, 0x004686A0, 
        0x004686A0, 0x004686A1, 0x004786A0, 0x004786A1, 0x004786A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004787A1, 0x00447F98, 0x003B7085, 0x00336174, 0x00284B5A, 0x00192F38, 0x000A1317, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00091114, 
        0x000F1C22, 0x00162931, 0x00203B46, 0x002C5160, 0x00376578, 0x00417990, 0x004A89A2, 0x004A88A3, 0x004A89A3, 0x004B89A3, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x000E191E, 0x00000101, 0x00294B59, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 
        0x004C8AA3, 0x004C89A3, 0x004B8AA3, 0x004C89A3, 0x004C8AA3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C89A4, 0x001D353F, 0x00000000, 0x00111F25, 0x004C8AA4, 0x00101D22, 0x00000000, 0x00274654, 0x004C8AA3, 0x00020304, 0x00000000, 0x00366377, 
        0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004C89A4, 0x004B8AA3, 0x004B8AA3, 0x004B8AA4, 0x004B8AA4, 0x004B89A4, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00162931, 0x00000000, 0x0023414D, 0x004B89A3, 0x004A89A3, 0x004B89A3, 0x004A89A3, 
        0x004A89A3, 0x004A89A3, 0x00417991, 0x00376678, 0x002C5161, 0x00203B46, 0x00162931, 0x000F1C22, 0x00091114, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x000A1418, 0x00193039, 0x00284B5A, 0x00336174, 0x003C7086, 0x00447F98, 0x004787A1, 
        0x004787A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A1, 0x004686A0, 0x004685A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849F, 
        0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041839E, 0x0042829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003F819C, 0x003E809C, 0x003E809B, 
        0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00387C98, 0x00377B98, 
        0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357996, 0x00347996, 0x00347996, 0x00347895, 0x00337995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317793, 0x00307693, 0x00307693, 0x002F7693, 
        0x002F7593, 0x002F7592, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028718E, 0x0028708E, 0x0028708E, 0x00276F8E, 
        0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236C8C, 0x00226D8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001D6988, 
        0x001D6888, 0x001D6887, 0x001C6887, 0x001B6887, 0x001B6787, 0x001A6786, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00186485, 0x00176484, 0x00166484, 0x00166484, 0x00156383, 0x00156383, 0x00146283, 0x00146282, 0x00136282, 
        0x00136182, 0x00126181, 0x00116081, 0x00116081, 0x00116081, 0x00105F80, 0x00105F80, 0x000F5F80, 0x000E5E7F,
  0x000F5E80, 0x000F5F80, 0x00106080, 0x00116081, 0x00116081, 0x00126081, 0x00136182, 0x00136182, 0x00136282, 0x00146283, 0x00146283, 0x00156283, 0x00166384, 0x00166484, 0x00166484, 0x00176485, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 
        0x001A6686, 0x001B6787, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6988, 0x001D6888, 0x001D6989, 0x001E6988, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206A8A, 0x00206B8A, 0x00216B8B, 0x00216C8B, 0x00226C8B, 0x00226C8B, 0x00236D8C, 0x00246D8C, 
        0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x00276F8D, 0x0027708E, 0x0028708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x002A718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7390, 0x002C7391, 0x002D7491, 
        0x002D7491, 0x002D7492, 0x002D7592, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307593, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357996, 
        0x00357A96, 0x00367A97, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7D9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 
        0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 
        0x0042839E, 0x0043839E, 0x0043839E, 0x0043839F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A1, 0x004686A1, 0x004786A1, 0x004786A1, 
        0x004787A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x003C7187, 0x002A4F5E, 0x00193039, 0x000F1C22, 0x00070E11, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00112026, 0x00244350, 0x00305A6A, 0x00396A7E, 0x003F758B, 
        0x00467F98, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004B89A3, 0x004C89A3, 0x004C89A4, 0x004C8AA3, 0x004C8AA3, 0x004C8AA4, 0x0013242B, 0x00000000, 0x00233F4B, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x001E3640, 0x00000000, 0x00112025, 0x004D8BA4, 0x00101C22, 0x00000000, 0x00274654, 0x004D8AA4, 0x00010303, 0x00000000, 0x00386477, 
        0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x000D181D, 0x00000000, 0x002A4C5B, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C89A3, 
        0x004B89A3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00467F98, 0x003F758B, 0x00396A7E, 0x00305A6A, 0x0024424F, 0x0014252D, 0x00030607, 0x00000000, 0x00000000, 0x00000000, 0x00070E11, 0x000F1C22, 0x00193039, 
        0x002A4F5E, 0x003C7187, 0x004887A1, 0x004887A2, 0x004887A1, 0x004887A1, 0x004787A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0045859F, 
        0x0044859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043849E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819C, 0x0040819C, 0x003F819C, 0x003F819C, 
        0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00397C98, 0x00387C98, 
        0x00387C98, 0x00377B98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357996, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 
        0x00307693, 0x002F7693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A718F, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028708F, 0x0028708E, 
        0x0027708E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00256E8C, 0x00246D8C, 0x00236D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00216C8A, 0x00206B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6988, 
        0x001D6988, 0x001D6888, 0x001D6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00196685, 0x00186585, 0x00186585, 0x00176485, 0x00166484, 0x00166484, 0x00166384, 0x00156383, 0x00156283, 0x00146283, 
        0x00136282, 0x00136182, 0x00126182, 0x00126081, 0x00116081, 0x00116081, 0x00116080, 0x00105F80, 0x000F5F80,
  0x000F5F80, 0x00105F80, 0x00116081, 0x00116081, 0x00126181, 0x00126182, 0x00136182, 0x00136282, 0x00146283, 0x00146283, 0x00156283, 0x00156383, 0x00166384, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 
        0x001A6786, 0x001B6787, 0x001B6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206A8A, 0x00216B8A, 0x00216B8A, 0x00226B8A, 0x00226C8B, 0x00226C8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 
        0x00256E8C, 0x00256E8D, 0x00256E8C, 0x00266F8D, 0x00266F8E, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0028708F, 0x0029718F, 0x002A718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002B7390, 0x002C7491, 0x002D7491, 0x002D7491, 
        0x002E7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317693, 0x00317794, 0x00317794, 0x00327894, 0x00327794, 0x00337895, 0x00337895, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00357996, 0x00357996, 
        0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C98, 0x003A7D98, 0x003A7D99, 0x003A7D99, 0x003A7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003C7F9B, 
        0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003E819C, 0x003F809C, 0x0040819C, 0x003F819C, 0x0040819C, 0x0040829C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 
        0x0043849E, 0x0043849F, 0x0044849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x0045849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004586A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004786A0, 0x004786A0, 0x004787A1, 0x004787A1, 0x004787A1, 
        0x004887A1, 0x004887A1, 0x0046849D, 0x00346276, 0x001C333E, 0x00060B0D, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00040708, 0x00182C35, 0x002B5160, 0x00091215, 0x00000101, 0x00325B6C, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 
        0x004B8AA3, 0x004B89A3, 0x004B89A4, 0x004C8AA3, 0x004C8AA3, 0x004C89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 0x001C333D, 0x00000000, 0x001D353F, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 
        0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004D8BA5, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x001E3640, 0x00000000, 0x00112026, 0x004D8BA4, 0x00101C22, 0x00000000, 0x00274653, 0x004E8BA5, 0x00020304, 0x00000000, 0x00386577, 
        0x004E8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8AA4, 0x00070E10, 0x00010203, 0x00305767, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004C8AA3, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004988A2, 0x004A89A3, 0x001E3742, 0x00000000, 0x00111F25, 0x00172B33, 0x00030608, 0x00000000, 0x00000000, 
        0x00000000, 0x00000101, 0x00060C0E, 0x001B333E, 0x00346276, 0x0046849D, 0x004887A1, 0x004887A1, 0x004787A1, 0x004787A1, 0x004786A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 
        0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819D, 0x0040819C, 
        0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809C, 0x003E7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 
        0x00387C98, 0x00387C98, 0x00387C97, 0x00377B98, 0x00377B97, 0x00377A97, 0x00367A97, 0x00367A97, 0x00357A97, 0x00357A96, 0x00357A96, 0x00347995, 0x00347996, 0x00337995, 0x00337895, 0x00327895, 0x00327895, 0x00327794, 0x00317794, 0x00317694, 
        0x00317794, 0x00307693, 0x00307693, 0x00307593, 0x002E7593, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7390, 0x002B7390, 0x002A7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028718F, 
        0x0028708E, 0x0027708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266E8D, 0x00256E8D, 0x00256E8C, 0x00246D8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00206B8A, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 
        0x001E6989, 0x001E6988, 0x001D6888, 0x001D6988, 0x001C6887, 0x001C6887, 0x001B6787, 0x001A6786, 0x001A6786, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166484, 0x00156383, 0x00156383, 0x00146283, 
        0x00146283, 0x00136182, 0x00136182, 0x00136182, 0x00126081, 0x00116081, 0x00116081, 0x00105F81, 0x00105F80,
  0x00105F80, 0x00116080, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136282, 0x00146283, 0x00156283, 0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00166484, 0x00186485, 0x00186585, 0x00186585, 0x00196586, 0x001A6686, 0x001A6686, 0x001A6786, 
        0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00236D8C, 0x00246D8B, 0x00246D8C, 0x00246E8C, 
        0x00256E8D, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002A7290, 0x002B7290, 0x002C7390, 0x002C7391, 0x002C7491, 0x002D7491, 0x002D7491, 0x002D7492, 
        0x002E7592, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00317794, 0x00327894, 0x00337895, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00357A96, 0x00367A97, 
        0x00367A97, 0x00377B97, 0x00377B98, 0x00387C97, 0x00377C98, 0x00387C98, 0x00397C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 
        0x003D809B, 0x003E809C, 0x003E809B, 0x003F809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042829D, 0x0041829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849E, 0x0043849F, 
        0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004686A1, 0x004786A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x00417B93, 0x003A6D83, 
        0x002B5161, 0x0014262E, 0x00000000, 0x00000000, 0x00000000, 0x00050A0C, 0x000C161B, 0x00172A32, 0x002A4E5D, 0x003E748A, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x0015272E, 0x00000000, 0x001F3944, 0x004B8AA3, 0x004B8AA3, 0x004C89A4, 0x004C89A4, 
        0x004C8AA4, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8AA4, 0x004D8BA4, 0x004D8AA4, 0x004D8BA4, 0x00254450, 0x00000000, 0x00182B33, 0x004B88A1, 0x004D8BA5, 0x004D8BA4, 0x004E8BA5, 
        0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x001E3741, 0x00000000, 0x00122026, 0x004E8BA5, 0x00101C22, 0x00000000, 0x00274654, 0x004E8BA5, 0x00010203, 0x00000000, 0x00386578, 
        0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA5, 0x004E8BA5, 0x0049849C, 0x00030708, 0x00030607, 0x00366274, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 
        0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004C8AA3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x000C171C, 0x00000000, 0x002C505F, 0x004A89A3, 0x004A89A3, 0x003E7489, 0x002A4E5D, 
        0x00172A32, 0x000C161B, 0x00050A0C, 0x00000000, 0x00000000, 0x00000101, 0x0014262E, 0x002B5160, 0x003A6D82, 0x00417B93, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004685A0, 
        0x004585A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 
        0x0040819C, 0x0040819C, 0x003F819C, 0x003F809C, 0x003F809C, 0x003E809B, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7D9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 
        0x00397C98, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00357A96, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 
        0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7390, 0x002B7390, 0x002A7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 
        0x0029718F, 0x0027708E, 0x0027708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00246D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 
        0x001F6A89, 0x001E6988, 0x001D6988, 0x001D6888, 0x001D6888, 0x001C6887, 0x001C6787, 0x001B6787, 0x001B6786, 0x001A6786, 0x001A6686, 0x00196686, 0x00196585, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166484, 0x00156383, 0x00156383, 
        0x00156283, 0x00146282, 0x00136282, 0x00136182, 0x00126181, 0x00126081, 0x00116081, 0x00116081, 0x00105F80,
  0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136282, 0x00146283, 0x00146283, 0x00156283, 0x00166384, 0x00166484, 0x00176484, 0x00176484, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 
        0x001C6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00246D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 
        0x00256F8D, 0x00266F8E, 0x00276F8E, 0x0027708E, 0x0027708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x002A718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002C7491, 0x002D7491, 0x002D7492, 0x002E7592, 0x002E7592, 
        0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00307694, 0x00317794, 0x00327794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357996, 0x00357A96, 0x00357A96, 0x00357A97, 0x00377A97, 0x00367B97, 
        0x00377B97, 0x00387B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C99, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809B, 
        0x003E809C, 0x003F819C, 0x003F819C, 0x003F819C, 0x003F819D, 0x0040829D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0042829E, 0x0042839E, 0x0043849E, 0x0043849E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 
        0x0045849F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A1, 0x004786A0, 0x004686A1, 0x004786A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x00417A93, 0x002D5566, 0x001C353F, 0x000E1B20, 0x00000101, 
        0x00000000, 0x00000000, 0x000D181C, 0x001F3A44, 0x002E5666, 0x003A6C81, 0x0047829A, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C89A3, 0x004C8AA3, 0x004C8AA4, 0x0023404C, 0x00000000, 0x0014252C, 0x004A86A0, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 
        0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x002F5564, 0x00000000, 0x0013232A, 0x0049849B, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 
        0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x00203A44, 0x00000000, 0x00122127, 0x004F8CA6, 0x00111E23, 0x00000000, 0x002A4B59, 0x004F8CA5, 0x00010303, 0x00000000, 0x003C6A7D, 
        0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x0042788D, 0x00030607, 0x0005090B, 0x003D6D81, 0x004E8BA5, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 
        0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x0048829B, 0x00020405, 0x00030607, 0x00366376, 0x004C89A4, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 
        0x004B89A3, 0x0047829A, 0x003A6C81, 0x002E5666, 0x001F3944, 0x000D181C, 0x00000000, 0x00000000, 0x00000101, 0x000E1B20, 0x001C353F, 0x002D5566, 0x00417A93, 0x004887A2, 0x004887A1, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 
        0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041839D, 0x0041829D, 0x0041829D, 
        0x0041829D, 0x0040829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 
        0x003A7D99, 0x003A7D99, 0x00397D98, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357A96, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 0x00337895, 0x00337895, 
        0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7391, 0x002B7290, 0x002A7290, 0x002A7290, 0x00297190, 
        0x0029718F, 0x0029718F, 0x0028708E, 0x0028708E, 0x00276F8E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00246D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206B8A, 
        0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x001A6686, 0x00196585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166384, 0x00166384, 
        0x00156383, 0x00146283, 0x00146283, 0x00136282, 0x00136182, 0x00136182, 0x00126081, 0x00116081, 0x00116081,
  0x00116081, 0x00116081, 0x00126182, 0x00136182, 0x00136182, 0x00146282, 0x00146283, 0x00156383, 0x00166384, 0x00166484, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 
        0x001C6887, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 
        0x00266F8D, 0x00276F8E, 0x00276F8E, 0x0027708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002A7290, 0x002B7390, 0x002B7390, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7592, 
        0x00307693, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B97, 
        0x00387C97, 0x00387C98, 0x00397C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 
        0x003F819C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045849F, 0x0044859F, 
        0x004585A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004686A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x0046849E, 0x002F586A, 0x00112026, 0x00030608, 0x00010203, 0x00000000, 0x00000000, 0x000F1B21, 
        0x002A4F5E, 0x00417990, 0x0046829B, 0x004886A0, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004B8AA3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x00366375, 0x00000000, 0x000C171B, 0x00447C92, 0x004D8BA4, 0x004D8BA4, 0x004E8AA5, 
        0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x003B697C, 0x00000000, 0x000F1B20, 0x0049829A, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 
        0x004F8CA5, 0x00477D94, 0x00417488, 0x003E6E81, 0x00376172, 0x00305564, 0x002F5261, 0x002C4F5D, 0x002A4A57, 0x000F1B20, 0x00000000, 0x00060B0D, 0x00203943, 0x00050A0C, 0x00000000, 0x00101C21, 0x00223C48, 0x00000000, 0x00000000, 0x00203943, 
        0x002F5261, 0x002F5362, 0x00345C6E, 0x003C6A7E, 0x00417288, 0x0044798F, 0x004D89A2, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x003D6D80, 0x00020405, 0x00070C0E, 0x0043788D, 0x004F8CA5, 0x004F8CA5, 0x004F8BA5, 0x004E8CA5, 
        0x004F8CA5, 0x004E8BA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x00396679, 0x00010202, 0x00080F12, 0x0041758C, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 
        0x004C89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004986A0, 0x0046829B, 0x00417990, 0x002A4E5D, 0x000E1B20, 0x00000000, 0x00000000, 0x00010203, 0x00030608, 0x00122128, 0x002F586A, 0x0046849F, 0x004887A1, 0x004887A1, 0x004787A1, 0x004787A1, 
        0x004786A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x004585A0, 0x0044859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041839E, 
        0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819C, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 
        0x003A7D9A, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A97, 0x00357996, 0x00347996, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 
        0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7390, 0x002B7290, 0x002A7290, 
        0x002A718F, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00276F8D, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246D8C, 0x00246D8C, 0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00226C8B, 0x00216C8A, 0x00216B8A, 0x00206B8A, 
        0x00206B8A, 0x001F6A8A, 0x001F6A89, 0x001F6989, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166484, 
        0x00166384, 0x00156383, 0x00156283, 0x00146283, 0x00136182, 0x00136182, 0x00126182, 0x00116081, 0x00116081,
  0x00126081, 0x00126182, 0x00136182, 0x00136282, 0x00136282, 0x00146283, 0x00156383, 0x00156383, 0x00166384, 0x00176484, 0x00176485, 0x00176585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6686, 0x001A6786, 0x001C6787, 0x001C6887, 0x001C6887, 
        0x001D6888, 0x001D6988, 0x001D6988, 0x001E6A88, 0x001F6A89, 0x001F6A89, 0x001F6A8A, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00246D8C, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00266E8D, 0x00266F8D, 
        0x0027708E, 0x0027708E, 0x0027708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7290, 0x002C7390, 0x002C7391, 0x002C7391, 0x002D7492, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7692, 
        0x00307693, 0x00317693, 0x00317693, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00337895, 0x00337995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B97, 0x00377C98, 
        0x00387C98, 0x00397C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F809C, 0x003F819C, 
        0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x0045859F, 0x004585A0, 
        0x004685A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x004786A1, 0x004887A1, 0x0046859F, 0x00427C95, 0x00366679, 0x001A313B, 0x00000000, 0x00000000, 0x00000000, 0x00020405, 0x00112026, 0x002B505F, 0x00457F97, 0x004B89A3, 
        0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x00478097, 0x00000000, 0x0004080A, 0x003C6D82, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 
        0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8CA5, 0x004F8BA5, 0x004F8BA5, 0x004F8CA5, 0x004D88A1, 0x004B859D, 0x00498299, 0x00477E96, 0x00457A91, 0x00417287, 0x002B4C5A, 0x00000000, 0x00040709, 0x00122127, 0x000D171B, 0x00050A0C, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00010303, 0x00010203, 0x00000101, 0x00010203, 0x00010303, 0x00010202, 0x00000000, 0x00010303, 0x00010203, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020405, 0x000B1518, 0x00132229, 0x001E3640, 0x001A2E36, 0x00010202, 0x00070D10, 0x00407186, 0x00477E95, 0x00488198, 0x004A849D, 0x004C88A0, 
        0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x00294A58, 0x00000101, 0x000E191E, 0x004B88A1, 0x004D8BA4, 0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x004C8AA4, 0x004B8AA4, 0x004B89A3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00457F98, 0x002B4F5E, 0x00111F25, 0x00060B0D, 0x00000000, 0x00000000, 0x00000000, 0x001A313B, 0x0036667A, 0x00427C95, 0x0047859F, 
        0x004887A1, 0x004787A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0043849E, 0x0042839E, 0x0042839E, 
        0x0042839E, 0x0042839D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E819B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 
        0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387C98, 0x00387B97, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347996, 0x00347996, 0x00337895, 
        0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317693, 0x00307694, 0x00307693, 0x002F7593, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002C7391, 0x002B7290, 0x002A7290, 
        0x002A7290, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0027708E, 0x0027708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216C8A, 0x00216B8A, 
        0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6887, 0x001B6787, 0x001B6787, 0x001B6786, 0x001A6786, 0x001A6686, 0x001A6685, 0x00196585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 
        0x00166384, 0x00156383, 0x00156383, 0x00156283, 0x00146282, 0x00136282, 0x00136182, 0x00126182, 0x00126081,
  0x00126182, 0x00126182, 0x00136282, 0x00146283, 0x00156283, 0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6786, 0x001A6787, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 
        0x001D6988, 0x001E6988, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206B89, 0x00216B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00246D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 
        0x0027708E, 0x0027708E, 0x0029718F, 0x0029718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7390, 0x002C7391, 0x002C7491, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7693, 0x00307693, 
        0x00307694, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00367A97, 0x00377A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 
        0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x003F819C, 0x0040819D, 
        0x0040819C, 0x0041829D, 0x0041829D, 0x0042829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045849F, 0x004585A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004686A0, 
        0x004786A0, 0x004686A0, 0x004787A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x00427C95, 0x00305A6B, 0x001D3742, 0x00091114, 0x00000000, 0x00000000, 0x000C161A, 0x000E1A1F, 0x00000000, 0x0014262D, 0x004B89A3, 0x004A89A3, 0x004B89A3, 0x004B89A3, 
        0x004B89A4, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA4, 0x004E8BA5, 0x004E8BA5, 0x000A1316, 0x00000000, 0x00345C6E, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 
        0x004F8CA5, 0x004F8CA5, 0x004B849C, 0x00417388, 0x00396577, 0x002F5464, 0x00274653, 0x001E353F, 0x0016262E, 0x000C161A, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0005090B, 0x000A1114, 0x00101D22, 0x0014232A, 
        0x001A2D36, 0x001C333B, 0x00203842, 0x0025414C, 0x00274551, 0x00284653, 0x002C4D5B, 0x00305463, 0x00325767, 0x00325868, 0x00335767, 0x00325968, 0x00335A6A, 0x00325868, 0x00335768, 0x00335968, 0x00335968, 0x00325867, 0x00315666, 0x00305464, 
        0x002E505E, 0x00294856, 0x00274551, 0x0026424E, 0x00213B46, 0x001D333C, 0x001B3038, 0x0015262D, 0x00111E23, 0x000B1418, 0x00060B0D, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x000A1216, 0x00132229, 0x001C323B, 
        0x00264350, 0x002E515F, 0x00376173, 0x003F7084, 0x00488097, 0x004F8CA5, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004F8CA5, 0x001B3039, 0x00000000, 0x001A2E37, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 
        0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x003C6F84, 0x00000101, 0x00010203, 0x00060C0E, 0x00000000, 0x00000000, 0x00091114, 0x001E3742, 
        0x00305B6C, 0x00427D95, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004686A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044859F, 0x0044849F, 0x0043849F, 0x0044849E, 0x0043839F, 
        0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819D, 0x003F819D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003F809B, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003C7F9A, 
        0x003C7E9A, 0x003B7E9A, 0x003A7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00367A96, 0x00357996, 0x00357996, 0x00347996, 
        0x00337995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00307694, 0x00307693, 0x002F7693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7491, 0x002C7391, 0x002C7390, 0x002B7290, 
        0x002B7290, 0x002A7290, 0x0029728F, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 
        0x00216B8A, 0x00206B8A, 0x00206A8A, 0x00206A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6888, 0x001D6888, 0x001C6888, 0x001C6787, 0x001B6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00196585, 0x00186585, 0x00186585, 0x00186484, 
        0x00176484, 0x00166384, 0x00156383, 0x00156383, 0x00146283, 0x00146283, 0x00136282, 0x00136182, 0x00126182,
  0x00136182, 0x00136182, 0x00146283, 0x00146283, 0x00156383, 0x00166384, 0x00166484, 0x00166484, 0x00176484, 0x00176585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6888, 0x001D6988, 
        0x001E6988, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0027708E, 
        0x0028708E, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002C7391, 0x002D7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7593, 0x00307693, 0x00307693, 0x00307694, 
        0x00327794, 0x00327794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357996, 0x00367A96, 0x00367A97, 0x00377A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397C98, 
        0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0040829D, 0x0040829D, 
        0x0041829D, 0x0041829E, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004686A1, 0x004786A1, 0x004786A1, 
        0x004786A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x003A6D83, 0x001C333E, 0x00080F13, 0x00010303, 0x00000000, 0x00010203, 0x001D353F, 0x0039697D, 0x00447F97, 0x0039687C, 0x00000000, 0x00080F12, 0x003E7288, 0x004C8AA4, 0x004C8AA3, 0x004C8AA4, 
        0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x001F3842, 0x00000000, 0x00284754, 0x004F8CA6, 0x0042748A, 0x00305464, 
        0x001E353F, 0x00101D23, 0x000A1114, 0x00060B0D, 0x00020405, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x000C1518, 0x00172930, 0x0025404C, 0x002F5462, 0x00386274, 0x00427488, 0x0045798E, 0x00477D93, 0x00498096, 0x004C839B, 0x004C859D, 
        0x004F89A1, 0x004F8BA3, 0x00518CA5, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 
        0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00518DA6, 0x00508BA3, 0x004F8AA2, 0x004D869D, 0x004B839B, 0x00498197, 0x00487D94, 0x00467B90, 0x0043768A, 0x003A6678, 0x00325868, 0x00274450, 0x001A2E36, 0x000F1B20, 0x00020304, 0x00000000, 
        0x00000000, 0x00000000, 0x00010203, 0x0005090B, 0x00091013, 0x000E191E, 0x001A2F37, 0x002B4D5B, 0x003E6D81, 0x004C88A1, 0x00508CA6, 0x004D89A2, 0x00111F25, 0x00000000, 0x002C4E5D, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 
        0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x0030596A, 0x00000000, 0x000A1216, 0x003B6E83, 0x0039697D, 0x001D353F, 0x00010203, 0x00000000, 
        0x00010303, 0x00081013, 0x001C343D, 0x003A6E84, 0x004888A1, 0x004887A1, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0044849F, 
        0x0043849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829C, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 
        0x003C7F9A, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 
        0x00357996, 0x00347995, 0x00347895, 0x00337895, 0x00327895, 0x00327795, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7593, 0x002F7592, 0x002E7492, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 
        0x002B7391, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 
        0x00226C8B, 0x00216B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001D6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001C6787, 0x001B6787, 0x001A6787, 0x001A6686, 0x001A6686, 0x00196585, 0x00186585, 0x00186585, 
        0x00176485, 0x00176484, 0x00166384, 0x00166384, 0x00156383, 0x00146283, 0x00146283, 0x00136182, 0x00136182,
  0x00136182, 0x00136282, 0x00146283, 0x00156383, 0x00156383, 0x00166384, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x00196686, 0x001A6786, 0x001A6786, 0x001B6787, 0x001C6887, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6989, 
        0x001F6A89, 0x001F6A89, 0x001F6A89, 0x00206B89, 0x00216B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00266F8D, 0x00266F8D, 0x00266F8E, 0x00276F8E, 0x0028708E, 0x0028708E, 
        0x0028718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002C7391, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00317793, 0x00317693, 0x00317794, 
        0x00327794, 0x00327795, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 
        0x003A7E99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 
        0x0042839D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004686A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004786A1, 0x004787A1, 
        0x0047859F, 0x0044819A, 0x00315D6F, 0x000C171B, 0x00000000, 0x00000000, 0x00010303, 0x000D191E, 0x002F5768, 0x004987A1, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00060B0D, 0x00000000, 0x00305768, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 
        0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8CA5, 0x004E8CA5, 0x004F8CA5, 0x004D89A3, 0x004C87A0, 0x004B859E, 0x00274552, 0x00000000, 0x00020405, 0x00000000, 0x00000000, 0x00000000, 
        0x00000101, 0x00020405, 0x00030607, 0x000C1519, 0x001C313A, 0x002B4B59, 0x003C697C, 0x00498197, 0x00518EA7, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 
        0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538EA8, 0x00528EA8, 0x00538FA7, 0x00538FA8, 0x00528EA8, 0x00538FA7, 0x00538EA7, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x00538FA8, 0x00538EA8, 0x00538FA8, 0x00528EA8, 0x00538FA7, 0x00538FA7, 
        0x00528FA8, 0x00528FA8, 0x00528FA7, 0x00528FA7, 0x00538FA8, 0x00538FA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x004C859D, 
        0x003F6F83, 0x002F5462, 0x001F3741, 0x000F1B1F, 0x00040709, 0x00020405, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x000A1316, 0x001A2F37, 0x00060B0D, 0x00000000, 0x003D6C80, 0x004E8BA4, 0x004E8BA4, 0x004E8CA5, 0x004F8CA5, 0x004E8BA5, 
        0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x00182C34, 0x00000000, 0x00172B33, 0x004B89A3, 0x004B89A3, 0x004A89A3, 0x004987A1, 0x002F5768, 
        0x000D191E, 0x00010303, 0x00000000, 0x00000000, 0x000C171B, 0x00315D70, 0x0044819B, 0x0047859F, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 
        0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F809C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A96, 0x00357A96, 
        0x00357996, 0x00347996, 0x00347995, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317794, 0x00307793, 0x00307693, 0x002F7693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7391, 0x002C7491, 
        0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0028708E, 0x00276F8E, 0x00266F8D, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00246D8C, 0x00236D8B, 0x00226D8B, 
        0x00226C8B, 0x00216C8A, 0x00216B8A, 0x00216B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6887, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00196585, 0x00186585, 
        0x00186585, 0x00176484, 0x00176484, 0x00166384, 0x00156383, 0x00156383, 0x00146283, 0x00146282, 0x00136282,
  0x00136182, 0x00146283, 0x00146383, 0x00156383, 0x00166384, 0x00166484, 0x00166484, 0x00176585, 0x00186585, 0x00196685, 0x00196585, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001C6887, 0x001C6888, 0x001D6888, 0x001E6988, 0x001E6989, 
        0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8B, 0x00216C8A, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00246D8B, 0x00246D8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708F, 0x0028718F, 
        0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317693, 0x00317794, 0x00317794, 0x00327794, 
        0x00327795, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357A96, 0x00357A96, 0x00357A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 
        0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F819B, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829E, 0x0042839E, 
        0x0042839E, 0x0042839E, 0x0043849E, 0x0043849F, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044859F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004686A1, 0x004786A1, 0x004786A1, 0x004887A1, 0x0046849E, 0x0037677C, 
        0x0022404C, 0x00070D0F, 0x00000000, 0x00000101, 0x00101D23, 0x0022404C, 0x003D7086, 0x004A89A3, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x00213C47, 0x00000000, 0x001C343D, 0x004B88A1, 0x004D8AA4, 0x004D8BA4, 
        0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x00467C92, 0x003B697D, 0x00305564, 0x001F3842, 0x000D181D, 0x00000000, 0x00000000, 0x00000000, 0x00080E11, 0x00111E24, 0x001A2E37, 0x0026424F, 
        0x00345B6C, 0x00427488, 0x004E8AA2, 0x00518EA7, 0x00518EA7, 0x00518EA7, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00528EA8, 0x00538EA8, 0x00538FA8, 0x00538EA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538EA8, 0x00538FA7, 0x00528EA7, 0x00528EA8, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 
        0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00518EA7, 0x00518DA7, 0x0045798F, 0x00376072, 0x00294855, 0x001D323C, 0x00132228, 0x000A1114, 0x00000000, 0x00000000, 0x00000000, 0x000A1114, 0x001B3039, 0x002C4F5D, 0x00396578, 0x0043778D, 0x004E8AA3, 
        0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x00447A91, 0x000B1418, 0x00000000, 0x002F5666, 0x004C8AA4, 0x004B89A4, 0x004B89A3, 0x004B89A3, 0x004B89A3, 
        0x004A89A3, 0x003D7086, 0x0022404C, 0x000F1D22, 0x00000101, 0x00000000, 0x00070D10, 0x0022404C, 0x0037677B, 0x0046849E, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004586A0, 0x004585A0, 0x004585A0, 0x0045859F, 
        0x0045859F, 0x0044859F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003E809B, 
        0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 
        0x00367A96, 0x00357A96, 0x00347995, 0x00347995, 0x00347995, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00317693, 0x00307693, 0x00307693, 0x002F7593, 0x002E7593, 0x002E7592, 0x002E7492, 0x002E7492, 0x002D7491, 
        0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00256F8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00236D8C, 0x00236C8B, 
        0x00236D8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x00206A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 
        0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166384, 0x00156383, 0x00156383, 0x00146283, 0x00146282,
  0x00146283, 0x00156383, 0x00166383, 0x00166384, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001D6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001F6A89, 0x001F6A89, 
        0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00246E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 
        0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002C7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 0x00327895, 
        0x00337895, 0x00347995, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E99, 0x003B7E9A, 
        0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9A, 0x003D809B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0042839E, 
        0x0043849E, 0x0043849F, 0x0044849F, 0x0044859F, 0x0045849F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x0046849D, 0x002B5060, 0x00101E24, 0x00030608, 
        0x00000000, 0x00010203, 0x00203B47, 0x0038677C, 0x00457F97, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x00407388, 0x00000000, 0x00060B0D, 0x0049829B, 0x004E8BA5, 0x004E8BA5, 
        0x004E8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x003D6D81, 0x00274451, 0x0014232A, 0x000B1518, 0x00020304, 0x00000000, 0x00000000, 0x00070D10, 0x001C323B, 0x002F5462, 0x003D6C7F, 0x0044788D, 0x004C839B, 0x00528EA7, 0x00528EA7, 
        0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538EA8, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x00548FA8, 0x005490A8, 0x005490A8, 
        0x005490A8, 0x005490A8, 0x005490A8, 0x005490A8, 0x005490A9, 0x00548FA8, 0x005490A9, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A8, 0x005490A9, 0x005490A9, 
        0x005490A9, 0x005490A9, 0x005490A8, 0x005490A9, 0x005490A8, 0x005490A8, 0x005490A9, 0x00548FA9, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00538EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x004C869E, 0x00477B90, 0x003F6F82, 0x00335A6A, 0x00213B45, 0x000D171B, 0x00000000, 0x00000000, 0x00000000, 0x00091114, 0x00111F25, 
        0x00223C46, 0x00386375, 0x004F8BA5, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x00366275, 0x00020304, 0x00010303, 0x0048839A, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 
        0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x00457E96, 0x0038687C, 0x00203C47, 0x00010203, 0x00000000, 0x00030608, 0x00101E24, 0x002B5161, 0x0046849F, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004585A0, 
        0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 
        0x003F809C, 0x003E809B, 0x003D809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B98, 0x00377B97, 0x00367B97, 
        0x00367A97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00347996, 0x00347895, 0x00337895, 0x00337895, 0x00337895, 0x00327795, 0x00317794, 0x00317794, 0x00317694, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002E7592, 0x002E7492, 
        0x002D7491, 0x002D7391, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x0029728F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00256F8D, 0x00256F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 
        0x00236D8B, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A8A, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001E6988, 0x001D6988, 0x001D6887, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6686, 0x001A6686, 0x001A6686, 
        0x00196586, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166384, 0x00166383, 0x00156383, 0x00146283,
  0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6786, 0x001A6786, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 0x001E6988, 0x001E6988, 0x001F6A89, 0x001F6A89, 0x001F6A89, 
        0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226B8A, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x00276F8D, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7190, 
        0x002A7290, 0x002B7290, 0x002B7390, 0x002B7390, 0x002C7391, 0x002D7491, 0x002D7491, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00327895, 0x00337895, 0x00337895, 
        0x00347995, 0x00347996, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 
        0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849E, 
        0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x0046839D, 0x00264755, 0x0005090B, 0x00000000, 0x00000000, 0x00070D0F, 
        0x002A4E5D, 0x0048859F, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x000D171B, 0x00000000, 0x00396779, 0x004E8CA5, 0x004F8CA6, 
        0x004F8CA6, 0x004D89A2, 0x003A687B, 0x001D333C, 0x00020405, 0x00000000, 0x00000000, 0x00000000, 0x00020405, 0x00172830, 0x00315666, 0x004A8198, 0x00528DA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00528FA8, 
        0x00538EA8, 0x00538FA8, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x005490A8, 0x005490A8, 0x005490A8, 0x005490A9, 0x005490A8, 0x005490A9, 0x005590A9, 0x005490A9, 0x005490A9, 
        0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 
        0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A8, 0x005490A8, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x004D879F, 0x00386273, 0x001E343E, 0x00060B0D, 0x00000000, 
        0x00000000, 0x00000000, 0x00000101, 0x0015262D, 0x00345B6C, 0x004B859E, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004D8AA3, 0x0024404C, 0x00000000, 0x00162830, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004A89A3, 0x0048849F, 0x002A4E5D, 0x00060C0F, 0x00000000, 0x00000000, 0x00050A0C, 0x00264857, 0x0046849E, 0x004887A1, 0x004887A1, 0x004886A1, 0x004786A1, 0x004786A1, 0x004786A1, 
        0x004685A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x0040819C, 0x0040819C, 0x003F819C, 
        0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x003A7D99, 0x00397D98, 0x00397C99, 0x00397C98, 0x00387C98, 0x00387B97, 0x00377B97, 
        0x00377B97, 0x00367A97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7693, 0x002F7693, 0x002E7592, 0x002E7592, 
        0x002E7492, 0x002D7492, 0x002C7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x00256E8C, 0x00246D8C, 
        0x00246E8C, 0x00236D8B, 0x00226D8B, 0x00226C8B, 0x00216B8B, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001C6787, 0x001A6786, 0x001A6786, 0x001A6686, 
        0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166384, 0x00156383, 0x00156383,
  0x00156383, 0x00166384, 0x00166484, 0x00176484, 0x00176585, 0x00186585, 0x00196585, 0x00196685, 0x00196686, 0x001A6686, 0x001A6787, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6A89, 0x001F6A89, 0x00206A89, 0x00206B8A, 
        0x00216B8A, 0x00216C8A, 0x00216B8B, 0x00226C8B, 0x00236D8B, 0x00236D8B, 0x00236D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x00297290, 0x002A7290, 
        0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00317794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 
        0x00347996, 0x00347996, 0x00357A96, 0x00357A97, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 
        0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0044849F, 0x0044849F, 
        0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004686A0, 0x004787A1, 0x004787A1, 0x0047859F, 0x003B6F85, 0x0023424F, 0x00010303, 0x00000000, 0x00030608, 0x00122128, 0x00305869, 0x004A89A3, 
        0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C89A4, 0x004C89A4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA5, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x00274552, 0x00000000, 0x00182A32, 0x0044788F, 0x00335A6B, 
        0x001A2E36, 0x00000101, 0x00000000, 0x00000101, 0x000A1216, 0x0014242A, 0x00274551, 0x003E6D81, 0x00518DA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A8, 0x005490A8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 
        0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005591A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005591A9, 0x005691A9, 0x005591AA, 0x005591AA, 0x005591A9, 0x005590A9, 
        0x005591A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 
        0x00548FA9, 0x005490A8, 0x005490A8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA8, 0x00528FA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00518EA7, 0x00528EA7, 0x0044778C, 
        0x002D4F5D, 0x00182A32, 0x000D161A, 0x00030506, 0x00000000, 0x00000000, 0x00142329, 0x002E505F, 0x003F7084, 0x00488097, 0x004C88A0, 0x000E191E, 0x00000000, 0x00376375, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 
        0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004A89A3, 0x002F5868, 0x00122128, 0x0004090A, 0x00000000, 0x00020405, 0x0023424E, 0x003C6F86, 0x004786A0, 0x004887A1, 0x004787A1, 0x004786A1, 
        0x004686A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819C, 
        0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387C98, 
        0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592, 
        0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00256E8D, 
        0x00246D8C, 0x00236D8C, 0x00236C8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 0x001E6A89, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6888, 0x001C6887, 0x001C6787, 0x001B6786, 0x001A6786, 
        0x001A6686, 0x00196586, 0x00186585, 0x00186585, 0x00176584, 0x00176485, 0x00176484, 0x00166384, 0x00156384,
  0x00166384, 0x00166484, 0x00176484, 0x00176485, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6786, 0x001B6787, 0x001B6787, 0x001C6887, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6988, 0x001F6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 
        0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A7190, 0x002B7290, 0x002B7290, 
        0x002B7390, 0x002C7391, 0x002C7491, 0x002D7491, 0x002E7491, 0x002E7592, 0x002E7592, 0x002F7693, 0x002F7593, 0x00307693, 0x00307693, 0x00317693, 0x00317794, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00337895, 0x00347995, 0x00357996, 
        0x00357996, 0x00367A96, 0x00367A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00397C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 
        0x003D809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043849F, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044859F, 0x0045859F, 
        0x0045859F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004786A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x00356276, 0x00192E37, 0x00050A0C, 0x00000000, 0x00010202, 0x00000000, 0x0015272E, 0x0049869F, 0x004B89A3, 0x004B89A3, 
        0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x002F5362, 0x00000000, 0x00020304, 0x0005080A, 0x00000000, 
        0x00000000, 0x0014232A, 0x00294855, 0x00396477, 0x00477C92, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00538FA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A8, 0x005490A8, 
        0x005490A9, 0x005490A9, 0x004A7F95, 0x002C4B58, 0x002A4754, 0x002B4956, 0x002B4956, 0x002B4956, 0x002B4956, 0x002B4956, 0x002B4A56, 0x002B4956, 0x002C4956, 0x002C4956, 0x002C4A57, 0x002C4A57, 0x002C4A57, 0x002B4956, 0x00294552, 0x00396172, 
        0x00558FA8, 0x005791AA, 0x005691AA, 0x005791AA, 0x005791AA, 0x005791AA, 0x005791AA, 0x00294551, 0x00294652, 0x002B4956, 0x002C4B57, 0x002C4A57, 0x002C4A57, 0x002C4B57, 0x002C4B57, 0x002C4B57, 0x002C4A57, 0x002C4B57, 0x002B4854, 0x00294552, 
        0x00294552, 0x00294552, 0x002A4854, 0x002C4A57, 0x002C4B57, 0x002C4A57, 0x002C4A57, 0x002C4A57, 0x002C4A57, 0x002C4A56, 0x002C4A56, 0x002C4A57, 0x002B4956, 0x00294652, 0x00294551, 0x0028434E, 0x00294551, 0x002A4752, 0x002B4956, 0x002B4956, 
        0x002B4956, 0x002B4956, 0x002B4956, 0x002B4956, 0x002B4956, 0x002B4956, 0x002B4956, 0x002A4955, 0x00294753, 0x00284551, 0x002A4854, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538EA8, 0x00538FA8, 0x00528EA8, 0x00528EA8, 
        0x00528EA7, 0x00528EA7, 0x004A8198, 0x003D6A7D, 0x002E515F, 0x001A2D35, 0x00020405, 0x00000000, 0x00000000, 0x00101C21, 0x001C323B, 0x00000000, 0x00080E11, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 
        0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x002F5868, 0x00040708, 0x00000000, 0x00000000, 0x00050A0C, 0x00192F38, 0x00346376, 0x004887A2, 0x004887A1, 
        0x004887A1, 0x004787A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 
        0x0041829D, 0x0040819C, 0x0040819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9A, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 
        0x00387C98, 0x00387B97, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357996, 0x00347996, 0x00337995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7693, 
        0x002F7592, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7391, 0x002B7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00256F8D, 
        0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8B, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A8A, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6888, 0x001C6787, 0x001B6787, 0x001B6787, 
        0x001A6786, 0x001A6686, 0x00196686, 0x00196585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166384,
  0x00166384, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x00196686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6988, 0x001D6988, 0x001E6988, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 
        0x00216C8B, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00246E8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002B7390, 
        0x002C7391, 0x002D7491, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00347996, 0x00357996, 0x00357A96, 
        0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397C99, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 
        0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004585A0, 
        0x004685A0, 0x004686A0, 0x004686A1, 0x004786A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x003A6E83, 0x00101F26, 0x00020304, 0x00000000, 0x00030608, 0x00284B59, 0x00417990, 0x00000000, 0x00000000, 0x003F748A, 0x004B89A4, 0x004C89A4, 
        0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x00467D94, 0x0024404C, 0x00070D10, 0x00010303, 0x00000000, 0x00000000, 0x00132127, 0x00345A6B, 
        0x004A8198, 0x004E89A1, 0x00508CA5, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 
        0x005590A9, 0x005590A9, 0x00497C91, 0x001F363E, 0x000C1417, 0x00000000, 0x00000000, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000000, 0x00010202, 0x00132026, 0x00325564, 
        0x005590A8, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x001F343D, 0x001A2C33, 0x00070C0E, 0x00000000, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000000, 0x00000000, 0x000C1519, 0x001D3038, 
        0x00213841, 0x001F343D, 0x000D161A, 0x00000000, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000000, 0x00060B0D, 0x001B2E36, 0x00213740, 0x001F353E, 0x00203740, 0x0017272E, 0x00010203, 0x00000000, 
        0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000000, 0x00000000, 0x00132127, 0x001F353E, 0x00223A44, 0x00538FA8, 0x005490A8, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00508AA3, 0x004D869E, 0x003B687A, 0x001B2F37, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x001C313B, 0x00407084, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 
        0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C89A3, 0x004B8AA3, 0x002A4D5C, 0x00000000, 0x0004080A, 0x00294C5A, 0x00030607, 0x00000000, 0x00020304, 0x00112026, 0x003A6E83, 
        0x004887A1, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x004585A0, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 
        0x0041829D, 0x0040829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 
        0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00357996, 0x00347996, 0x00337995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 
        0x00307693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7491, 0x002C7391, 0x002C7390, 0x002B7290, 0x002B7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 
        0x00266F8D, 0x00256E8C, 0x00246E8C, 0x00246E8C, 0x00236D8B, 0x00236C8C, 0x00226C8B, 0x00226C8B, 0x00216B8B, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6989, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6888, 0x001C6787, 0x001B6787, 
        0x001B6787, 0x001A6686, 0x00196686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00166484,
  0x00176484, 0x00176584, 0x00186585, 0x00186585, 0x00196586, 0x00196686, 0x001A6686, 0x001A6787, 0x001B6787, 0x001B6887, 0x001C6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x00206A89, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00216C8A, 
        0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 
        0x002C7491, 0x002D7491, 0x002D7491, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00337995, 0x00347995, 0x00357996, 0x00357A96, 0x00357A96, 
        0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 
        0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043839F, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004585A0, 
        0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x0046839C, 0x003A6D82, 0x00162931, 0x00000000, 0x00000000, 0x00080E11, 0x00264553, 0x0048859E, 0x004B89A3, 0x004B89A3, 0x001A3039, 0x00000000, 0x001E3640, 0x004C8AA4, 0x004C8AA4, 
        0x004D8AA4, 0x004D8BA4, 0x004E8BA4, 0x004D8BA5, 0x004E8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004D89A1, 0x00467D95, 0x00325A6A, 0x00121F25, 0x00000000, 0x00000000, 0x00060B0D, 0x00101C21, 0x002D4E5C, 0x004B859B, 0x00528EA7, 0x00528EA7, 
        0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 
        0x005591A9, 0x005691A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x004C8198, 0x00233C46, 0x00060B0D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001F343C, 0x005590A8, 0x005792AA, 0x005792AB, 
        0x005892AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x005792AA, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x001E323A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010203, 0x001A2B32, 0x004B7C91, 0x005892AB, 0x005892AB, 
        0x005892AA, 0x005892AB, 0x005892AB, 0x00416D80, 0x00090F12, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0026404A, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x0050889F, 0x001A2C34, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00101B1F, 0x004C8097, 0x005590A9, 0x005591A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x005490A9, 0x005490A8, 0x00548FA9, 0x00548FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x00528FA7, 0x00528EA8, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00508CA6, 0x00345B6C, 0x0016262D, 0x00070D0F, 0x00000000, 0x00000000, 0x000A1114, 0x002B4C5A, 0x00457A91, 0x004B859E, 0x004F8CA5, 
        0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x0047829A, 0x00101D23, 0x00000000, 0x00284956, 0x004B89A3, 0x0048869F, 0x00254553, 0x00080E11, 0x00000000, 0x00000000, 
        0x00162931, 0x003A6D82, 0x0046839D, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 
        0x0041829E, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 
        0x00397C99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347996, 0x00337995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 
        0x00307693, 0x002F7593, 0x002F7592, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7390, 0x002B7390, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0028708E, 0x00276F8E, 0x00276F8E, 
        0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00226C8B, 0x00236C8B, 0x00226C8A, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001C6887, 
        0x001B6787, 0x001A6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00176485, 0x00176484,
  0x00176585, 0x00186585, 0x00186585, 0x00196686, 0x00196686, 0x001A6686, 0x001A6787, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6887, 0x001D6988, 0x001E6989, 0x001F6989, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 
        0x00236D8B, 0x00236D8C, 0x00236D8C, 0x00246E8C, 0x00256E8C, 0x00266E8D, 0x00266F8D, 0x00276F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 
        0x002D7491, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 
        0x00367B97, 0x00377B97, 0x00377C98, 0x00387C98, 0x00387C99, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 
        0x003F819C, 0x003F819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x0044859F, 0x004685A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 
        0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x00336072, 0x00182E37, 0x00000000, 0x00000000, 0x00101D23, 0x002A4F5E, 0x00457E98, 0x004B89A3, 0x004B89A3, 0x004C89A3, 0x004B8AA3, 0x003A697D, 0x00000101, 0x00000000, 0x00457C93, 0x004D8AA4, 
        0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8BA5, 0x004F8CA6, 0x00498198, 0x0032596A, 0x001C323B, 0x0005080A, 0x00000000, 0x00010303, 0x00192B33, 0x002E505E, 0x00437489, 0x00518EA7, 0x00518EA7, 0x00528EA7, 0x00538EA8, 0x00538EA7, 
        0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x00548FA8, 0x005590A8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005690A9, 0x005691AA, 0x005591AA, 0x005691AA, 0x005691A9, 
        0x005791AA, 0x005791AA, 0x005792AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x0046758A, 0x0015242A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090F12, 0x004C8095, 0x005893AB, 0x005893AB, 0x005893AB, 
        0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005892AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005893AB, 0x00568EA6, 0x00000000, 0x00000000, 0x00000000, 0x00030607, 0x00385C6B, 0x005993AC, 0x005893AB, 0x005993AB, 0x005993AB, 
        0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x00467588, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00111D22, 0x005893AB, 0x005892AB, 0x005792AB, 0x005892AB, 0x005892AA, 0x005792AB, 0x005892AA, 0x005892AB, 0x005892AA, 
        0x00080E10, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030607, 0x004C7F96, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A8, 0x005490A9, 0x005590A8, 
        0x00548FA9, 0x005490A8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x00528FA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00477C94, 0x00335969, 0x001E343D, 0x00060C0E, 0x00000000, 0x00000000, 0x00172830, 0x002D505F, 
        0x0044778D, 0x004F8CA6, 0x004F8CA6, 0x004E8BA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x00376476, 0x00000000, 0x0004080A, 0x0049859D, 0x004C89A3, 0x004B89A3, 0x004A89A3, 0x00467F98, 0x002A4F5E, 0x00101D23, 
        0x00000000, 0x00000000, 0x00182E37, 0x00346073, 0x004887A1, 0x004887A1, 0x004787A1, 0x004786A0, 0x004786A1, 0x004686A0, 0x004586A0, 0x004685A0, 0x004585A0, 0x004484A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0043839E, 
        0x0042839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 
        0x00397D99, 0x00397D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00327794, 0x00317794, 
        0x00307694, 0x00307693, 0x00307693, 0x002F7592, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7390, 0x002B7390, 0x002B7290, 0x002A7190, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708F, 0x0028708E, 0x00276F8E, 
        0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001D6988, 0x001D6888, 0x001C6888, 
        0x001C6887, 0x001B6787, 0x001A6786, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00176585,
  0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6786, 0x001B6787, 0x001C6887, 0x001C6887, 0x001D6888, 0x001D6888, 0x001E6988, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00226D8C, 
        0x00236D8C, 0x00246D8C, 0x00256E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029708F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 
        0x002E7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327794, 0x00327895, 0x00337895, 0x00347895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 
        0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7E99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x003F819C, 
        0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004685A0, 0x004685A0, 0x004686A0, 0x004686A1, 0x004786A1, 0x004887A1, 
        0x004887A1, 0x004887A1, 0x003B7086, 0x00122228, 0x00030607, 0x00000000, 0x000A1216, 0x00346174, 0x00458098, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x0048839A, 0x0013232A, 0x00000000, 0x001E3741, 0x004E8BA5, 
        0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x0044798F, 0x001F3741, 0x00080F12, 0x00000101, 0x00000000, 0x000C1519, 0x00305464, 0x00487E94, 0x004E88A0, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00548FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005490A8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005691A9, 0x005791AA, 0x005791AA, 0x005792AA, 0x005792AA, 
        0x005792AA, 0x005792AA, 0x005792AA, 0x005892AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x004F849A, 0x00132025, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070C0E, 0x004B7B90, 0x005993AB, 0x005993AB, 0x005993AC, 
        0x005993AB, 0x005993AC, 0x005993AB, 0x005993AC, 0x005993AC, 0x005994AC, 0x005993AC, 0x005A93AC, 0x005994AC, 0x005A94AC, 0x004F849A, 0x00000000, 0x00000000, 0x00000000, 0x00467386, 0x005993AC, 0x005994AB, 0x005A94AC, 0x005A93AC, 0x005A94AC, 
        0x005993AC, 0x005994AC, 0x005993AB, 0x005994AC, 0x0051869C, 0x000A1114, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002E4D59, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005893AB, 
        0x001E313A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00142228, 0x00528AA1, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005692AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005591A9, 0x005591A9, 0x005590A9, 
        0x005591A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A8, 0x005490A8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538EA7, 0x00528EA7, 0x00528EA7, 0x00508BA3, 0x004A8198, 0x00376273, 0x0014242B, 0x00000000, 0x00000000, 
        0x00060C0E, 0x00172930, 0x003D6B7E, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x00111F24, 0x00000000, 0x00274654, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00458098, 
        0x00346073, 0x00091215, 0x00000000, 0x00030607, 0x00122229, 0x003C7087, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043849F, 0x0043849E, 
        0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E99, 
        0x003B7D9A, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367B97, 0x00357A96, 0x00357996, 0x00357996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00327794, 
        0x00327794, 0x00307694, 0x00307693, 0x00307693, 0x002F7592, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002B7290, 0x002A7190, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0028708E, 
        0x0027708E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001E6988, 0x001D6988, 
        0x001C6888, 0x001C6787, 0x001B6787, 0x001B6787, 0x001A6786, 0x00196686, 0x00196686, 0x00186585, 0x00186585,
  0x00186585, 0x00196685, 0x00196686, 0x001A6686, 0x001A6786, 0x001B6787, 0x001B6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206A89, 0x00216B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00236C8B, 0x00236D8C, 
        0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002B7390, 0x002C7391, 0x002D7491, 0x002D7491, 0x002D7492, 
        0x002E7592, 0x002E7592, 0x002F7593, 0x00307593, 0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00327894, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00357996, 0x00357996, 0x00357A96, 0x00367A96, 0x00377A97, 0x00377B97, 0x00377B97, 
        0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 
        0x0041829D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043849F, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x0045859F, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004786A0, 
        0x00427B93, 0x001C3540, 0x00000000, 0x00000000, 0x0004080A, 0x002A4E5D, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x002D515F, 0x00010202, 0x00060B0D, 0x00477E94, 
        0x004F8CA5, 0x004B859D, 0x003C6B7E, 0x0014232A, 0x00000000, 0x00000000, 0x00040708, 0x00192C35, 0x00407085, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 
        0x005490A8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005591A9, 0x005691AA, 0x005691A9, 0x005691AA, 0x005791AA, 0x005692AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AA, 
        0x005892AB, 0x005892AB, 0x005892AA, 0x005892AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x004D8095, 0x00070C0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00345664, 0x005A94AC, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x001E3139, 0x00000000, 0x00000000, 0x00406A7B, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x00548AA0, 0x00111D21, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003D6476, 0x005993AC, 0x005993AC, 0x005993AB, 0x005993AC, 0x005993AB, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 
        0x002A4551, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001C3038, 0x00548CA4, 0x005892AB, 0x005792AA, 0x005792AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005691AA, 
        0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA8, 0x00528FA8, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00487E95, 0x00223B46, 
        0x00060A0C, 0x00000101, 0x00000000, 0x000B1418, 0x00335A6B, 0x004A839C, 0x004E8AA3, 0x004F8CA5, 0x004F8CA5, 0x003B6A7E, 0x00000000, 0x0005090A, 0x0041758A, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 
        0x004B89A3, 0x004B89A3, 0x002A4E5D, 0x0004080A, 0x00000000, 0x00000000, 0x001D3640, 0x00427C95, 0x004786A0, 0x004787A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 
        0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 
        0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367A96, 0x00367A96, 0x00357A96, 0x00357996, 0x00347995, 0x00347995, 0x00337995, 0x00327895, 0x00327794, 
        0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x00307693, 0x002F7592, 0x002F7593, 0x002E7592, 0x002D7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7190, 0x00297290, 0x0029718F, 0x0029718F, 0x0028718E, 
        0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00246E8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001E6A89, 0x001E6988, 0x001D6988, 
        0x001D6988, 0x001C6888, 0x001B6887, 0x001B6787, 0x001A6787, 0x001A6686, 0x00196686, 0x00196586, 0x00186585,
  0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001C6887, 0x001C6887, 0x001D6888, 0x001D6888, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00216B8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 
        0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266E8D, 0x00266F8E, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A7290, 0x002A728F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 
        0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307694, 0x00317794, 0x00317794, 0x00327794, 0x00327795, 0x00337895, 0x00347995, 0x00347995, 0x00357996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00377B98, 
        0x00387C98, 0x00387C98, 0x00397D98, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003D7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 
        0x0041829D, 0x0041829E, 0x0042839D, 0x0042839E, 0x0043839E, 0x0043839F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A1, 0x003E768C, 0x00234350, 
        0x00020506, 0x00000000, 0x000B151A, 0x00264553, 0x0047839C, 0x004A89A3, 0x004B89A3, 0x004B8AA3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x00488198, 0x00080F12, 0x00000101, 0x00233E49, 
        0x002D505F, 0x000F1A1F, 0x00000000, 0x00010202, 0x0015252C, 0x002C4D5B, 0x00498097, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005490A9, 
        0x005590A8, 0x005590A9, 0x005591A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005893AB, 
        0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x00436E80, 0x00010102, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060A0C, 0x0053889F, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005B94AC, 0x005B94AC, 0x003A5F6E, 0x00000000, 0x00000000, 0x002D4956, 0x005A95AC, 0x005B94AC, 0x005B95AC, 0x005B95AC, 0x005B94AC, 0x005B95AC, 0x005B95AC, 
        0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x00548BA1, 0x00142127, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00447082, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005994AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 
        0x002E4D5A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00213740, 0x00558FA6, 0x005893AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005791AA, 0x005791AA, 
        0x005691AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A8, 0x005490A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00528EA7, 0x00528EA7, 0x00528EA7, 
        0x004F8AA3, 0x00335A6A, 0x001A2E36, 0x0005090B, 0x00000000, 0x00070D10, 0x00264450, 0x003D6C80, 0x004F8CA6, 0x0016272E, 0x00000000, 0x001B313A, 0x004C87A1, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C89A4, 
        0x004B89A3, 0x004B89A3, 0x004A89A3, 0x0047839C, 0x00264654, 0x000A1317, 0x00000000, 0x00030607, 0x00244451, 0x003E758C, 0x004887A1, 0x004787A1, 0x004787A1, 0x004686A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 
        0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 
        0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00377A97, 0x00367A97, 0x00367A96, 0x00357996, 0x00347996, 0x00347996, 0x00337995, 0x00337895, 0x00327895, 
        0x00327894, 0x00327794, 0x00317794, 0x00317793, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7390, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A7190, 0x0029718F, 0x0029718F, 
        0x0028708E, 0x0028708E, 0x00276F8E, 0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8D, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 
        0x001D6988, 0x001D6888, 0x001C6887, 0x001C6887, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00196586,
  0x00196686, 0x001A6686, 0x001A6786, 0x001B6787, 0x001B6787, 0x001C6888, 0x001C6888, 0x001D6888, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246E8C, 0x00246E8C, 
        0x00246E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002B7390, 0x002C7491, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 
        0x002F7592, 0x00307693, 0x00307694, 0x00317693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 
        0x00397C98, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829E, 
        0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x0047859F, 0x00244451, 0x00091014, 0x00000000, 
        0x00000000, 0x00000000, 0x00335F71, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x001E353F, 0x00000000, 0x00010202, 
        0x00000000, 0x00000000, 0x0024404B, 0x00407184, 0x004D879F, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005490A9, 0x005590A9, 0x005591A9, 0x005591A9, 
        0x005691AA, 0x005691A9, 0x005691AA, 0x005691A9, 0x005691AA, 0x005791AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x005892AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 
        0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x00355664, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00192A30, 0x005B95AD, 0x005B95AD, 
        0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x004E7F93, 0x000A1012, 0x00000000, 0x00162329, 0x005990A8, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 
        0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x00568CA2, 0x00152328, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00457184, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 
        0x0030505D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00223842, 0x005790A7, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005792AA, 
        0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005692AA, 0x005691AA, 0x005691A9, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x00538FA8, 
        0x00528FA7, 0x00528EA7, 0x00508BA3, 0x0044778C, 0x002D505E, 0x00070C0E, 0x00000000, 0x00040809, 0x00122025, 0x00020304, 0x00030607, 0x00396577, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004D8AA4, 
        0x004C8AA4, 0x004C8AA3, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00457E96, 0x00182D35, 0x00000000, 0x00000000, 0x00081013, 0x00254452, 0x004887A1, 0x004887A1, 0x004787A1, 0x004787A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004585A0, 0x004585A0, 
        0x004585A0, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F809C, 0x003F809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 
        0x00337895, 0x00327894, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002E7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A7190, 0x0029718F, 
        0x0029718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 
        0x001E6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001B6887, 0x001B6787, 0x001B6686, 0x001A6686, 0x00196686,
  0x00196686, 0x001B6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001D6888, 0x001D6888, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x001F6A8A, 0x00206B8A, 0x00216B8A, 0x00216B8B, 0x00226C8B, 0x00236D8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8D, 
        0x00266F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029708F, 0x0029718F, 0x002A718F, 0x002A728F, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7593, 
        0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00347995, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D99, 
        0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E7F9B, 0x003E809C, 0x003E809C, 0x003F809C, 0x0040819C, 0x0040819D, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 
        0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A2, 0x00396C82, 0x00091114, 0x00000000, 0x00000101, 0x00162830, 
        0x00081013, 0x00000000, 0x00162931, 0x004B89A3, 0x004C8AA3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004E8BA4, 0x0043778D, 0x00142329, 0x00000000, 0x00000000, 0x0005080A, 
        0x00294855, 0x00508CA5, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691A9, 0x005691AA, 
        0x005691AA, 0x005791AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x005892AB, 0x005892AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005993AC, 0x005994AC, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AD, 0x005B94AD, 0x005B94AD, 0x005B95AC, 0x005B95AD, 0x005B94AD, 0x00568DA4, 0x00192930, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00395C6B, 0x005C95AD, 
        0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005A94AA, 0x00192A30, 0x00000000, 0x00020405, 0x00558AA0, 0x005C95AD, 0x005C96AD, 0x005D96AD, 0x005C95AD, 0x005C96AE, 0x005C96AD, 0x005C96AD, 0x005C95AD, 
        0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x00568DA2, 0x00152328, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00467184, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 
        0x0031505D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00223842, 0x005790A7, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005A93AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AB, 
        0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x00548FA9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538EA8, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00518EA7, 0x00345B6C, 0x00091114, 0x00000000, 0x00000000, 0x00030607, 0x00386274, 0x004E8AA3, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA5, 
        0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x0048859E, 0x0005090A, 0x00000000, 0x00060B0D, 0x00010202, 0x00000000, 0x00091114, 0x00396C81, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004686A0, 
        0x004585A0, 0x0045859F, 0x0044849F, 0x0044859F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0040829D, 0x0040829D, 0x0040819C, 0x0040819C, 0x003F809C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387C97, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00347995, 
        0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317794, 0x00317693, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A718F, 
        0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x00256E8C, 0x00246E8C, 0x00246E8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00216B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 
        0x001F6989, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001B6887, 0x001B6787, 0x001A6686, 0x001A6686,
  0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6888, 0x001E6988, 0x001E6988, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00256E8D, 0x00256E8D, 
        0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0028708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A7190, 0x002A728F, 0x002A7290, 0x002B7291, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 
        0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00337995, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 
        0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003C7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F809C, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 
        0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x003C7188, 0x001C343F, 0x00000000, 0x00000000, 0x00000000, 0x00122229, 0x004B89A3, 
        0x002E5464, 0x00000000, 0x00030507, 0x00376476, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004B859D, 0x00396679, 0x00182A32, 0x00000000, 0x00000000, 0x00101C21, 0x002C4D5B, 0x004E88A1, 
        0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005792AA, 
        0x005792AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005993AC, 0x005A93AC, 0x005A94AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 
        0x005B94AC, 0x005B94AD, 0x005B95AC, 0x005B95AC, 0x005B94AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x00467184, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1417, 0x0052879C, 
        0x005C96AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x002E4A56, 0x00000000, 0x00000000, 0x00446E80, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 
        0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x00578DA3, 0x00152328, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00467284, 0x005C96AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 
        0x0031505D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00223842, 0x005891A7, 0x005A94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005A94AC, 0x005993AC, 0x005994AC, 0x005993AB, 0x005993AB, 0x005993AC, 0x005993AB, 
        0x005893AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x00548FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA8, 0x00528EA7, 0x00528EA7, 0x00518EA7, 0x00365E6F, 0x0015252B, 0x00040809, 0x00000000, 0x000F1B1F, 0x00345C6C, 0x00477F97, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 
        0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x00213C48, 0x00000000, 0x00070D10, 0x0041778D, 0x00346174, 0x00000000, 0x00000000, 0x00000000, 0x001C343F, 0x003D7289, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 
        0x004686A0, 0x004685A0, 0x0045859F, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 
        0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E99, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397D98, 0x00397C99, 0x00387C98, 0x00387B98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367A96, 0x00357A96, 0x00357996, 0x00347996, 
        0x00347996, 0x00347895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 
        0x002A728F, 0x0029718F, 0x0029708F, 0x0028708F, 0x0028708E, 0x0026708D, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x00206B89, 0x001F6A89, 
        0x001F6A89, 0x001E6989, 0x001D6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6686,
  0x001B6787, 0x001B6787, 0x001C6787, 0x001C6888, 0x001D6988, 0x001D6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 
        0x00266F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002B7390, 0x002C7391, 0x002D7491, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7593, 0x00307693, 0x00307693, 
        0x00317794, 0x00327794, 0x00327794, 0x00327795, 0x00337895, 0x00337995, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 
        0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 
        0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x004786A0, 0x0023414E, 0x00060B0D, 0x00000000, 0x000D181D, 0x00213D49, 0x00020405, 0x00020405, 0x00356174, 
        0x004B8AA3, 0x00122228, 0x00000000, 0x00132228, 0x004C89A2, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x00315666, 0x00132127, 0x00000000, 0x00000000, 0x001A2E36, 0x00396476, 0x004D879F, 0x00528EA7, 0x00528EA7, 
        0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005690A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AA, 0x005792AB, 
        0x005892AB, 0x005893AB, 0x005892AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005994AC, 0x005994AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005B94AC, 0x005B95AD, 0x005B95AD, 0x005B95AD, 
        0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x002B4550, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002B4651, 
        0x005D95AD, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x003C606F, 0x00000000, 0x00000000, 0x00304D59, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 
        0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x00588EA3, 0x00162328, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00477385, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005D96AE, 
        0x0032515D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233942, 0x005991A8, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 
        0x005993AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005892AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005691A9, 0x005590A9, 0x005590A9, 
        0x005590A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x00528EA7, 0x00518CA5, 0x003F6D80, 0x00233D49, 0x00000000, 0x00000000, 0x000E181D, 0x00294855, 0x004B869F, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 
        0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x003F7287, 0x00060B0E, 0x00000000, 0x0025434F, 0x004B89A3, 0x00264654, 0x00000000, 0x00080F12, 0x00081013, 0x00000000, 0x00060C0E, 0x0023414E, 0x004785A0, 0x004887A1, 0x004787A1, 0x004786A1, 
        0x004786A1, 0x004686A0, 0x004685A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003E809C, 
        0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A96, 0x00357A96, 
        0x00347996, 0x00347996, 0x00347895, 0x00337895, 0x00327895, 0x00327894, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7492, 0x002C7391, 0x002B7391, 0x002B7391, 0x002B7290, 
        0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00276F8D, 0x00266F8D, 0x00256F8D, 0x00256E8D, 0x00256D8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00206B8A, 0x00206B8A, 
        0x001F6A89, 0x001F6A89, 0x001E6A89, 0x001E6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001B6787, 0x001B6787,
  0x001B6787, 0x001B6887, 0x001C6888, 0x001D6988, 0x001D6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256F8D, 0x00266F8D, 0x00266F8D, 
        0x00276F8E, 0x0028708E, 0x0028708F, 0x0028708F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00317794, 0x00307694, 
        0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A96, 0x00377A97, 0x00377B97, 0x00377B98, 0x00377B98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 
        0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9A, 0x003D809B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829C, 0x0041829D, 0x0041829E, 0x0042839D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849E, 0x0044849F, 
        0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x004887A1, 0x0037677B, 0x00070E11, 0x00000000, 0x00000000, 0x00000000, 0x00336072, 0x004B89A3, 0x00112026, 0x00000000, 0x0014252C, 
        0x0048849C, 0x0042798F, 0x00000000, 0x00000000, 0x00335B6C, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00386376, 0x000A1316, 0x00000101, 0x00000000, 0x0017282F, 0x0045798F, 0x00508CA5, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538FA7, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005892AB, 
        0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005A94AC, 0x005B94AC, 0x005B94AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 
        0x005C95AD, 0x005D95AD, 0x005C96AD, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E96AE, 0x000C1417, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x004F7F93, 0x005E97AE, 0x005E97AF, 0x005E97AE, 0x005E97AF, 0x004E7D90, 0x000A1013, 0x00000000, 0x0017242A, 0x005B91A8, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AE, 0x005F97AF, 0x005F97AF, 
        0x005E97AE, 0x005E97AF, 0x005E97AE, 0x005E97AF, 0x00588EA4, 0x00162328, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00477385, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 
        0x0032515E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233942, 0x005992A9, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B94AD, 0x005B94AC, 0x005B95AC, 0x005B94AC, 0x005A94AC, 
        0x005A94AC, 0x005A93AC, 0x005993AB, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005692AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005691AA, 0x005591A9, 
        0x005590A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA8, 0x00528EA7, 0x00518CA5, 0x004B839A, 0x00223D48, 0x00000000, 0x00000000, 0x00040809, 0x002B4D5B, 0x004E8AA4, 0x004F8CA6, 
        0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D89A3, 0x001F3842, 0x00000000, 0x00050A0C, 0x004A87A1, 0x0041768C, 0x00040809, 0x00000101, 0x00294B5A, 0x004987A1, 0x00122229, 0x00000000, 0x00000000, 0x00080E11, 0x0037687B, 0x004887A1, 0x004887A1, 
        0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 
        0x003F809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A96, 
        0x00357A96, 0x00347996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317694, 0x00307694, 0x00307693, 0x002F7593, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7491, 0x002C7391, 0x002B7390, 
        0x002B7290, 0x002A7290, 0x002A7190, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x00276F8E, 0x00266F8E, 0x00266F8D, 0x00256F8D, 0x00256E8C, 0x00246E8C, 0x00246E8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00206B8A, 
        0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001D6988, 0x001D6888, 0x001D6888, 0x001C6787, 0x001B6787,
  0x001C6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6988, 0x001F6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216B8B, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00236D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 
        0x0028708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002A7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00317693, 0x00317694, 0x00317794, 
        0x00327894, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357A96, 0x00357A97, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 
        0x003C7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0044849F, 
        0x0045859F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00407991, 0x00213E4A, 0x00000000, 0x00000101, 0x00101F25, 0x000F1C21, 0x00000000, 0x000C171B, 0x004986A0, 0x0040748A, 0x00000000, 0x00000000, 
        0x00345D6F, 0x004D8BA4, 0x0023404D, 0x00000000, 0x00030607, 0x004B859E, 0x004D88A2, 0x003D6C80, 0x00132127, 0x00000000, 0x00030607, 0x00142229, 0x003F6E82, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x00538FA8, 
        0x00548FA8, 0x005490A8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x004C8198, 0x0027424E, 0x002B4956, 0x005791AA, 0x005792AA, 0x005792AB, 0x005892AB, 0x005892AA, 0x005893AB, 0x005893AB, 0x005893AB, 0x005993AB, 
        0x005993AB, 0x005993AC, 0x005A94AC, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B95AC, 0x005B95AD, 0x005B95AD, 0x005B94AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 
        0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005D96AE, 0x005E96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005E97AF, 0x004F7F93, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x0010191D, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005B91A8, 0x001C2D34, 0x00000000, 0x0005090A, 0x00507F94, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 
        0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005F97AF, 0x00598EA4, 0x00162329, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00477385, 0x005F97AF, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 
        0x0032515E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233942, 0x005A92A9, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005B94AD, 
        0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005994AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691A9, 
        0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x005490A8, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538EA7, 0x00528EA7, 0x00528EA7, 0x004A8097, 0x001C323B, 0x00060C0E, 0x00000000, 0x00091012, 0x00355E70, 
        0x0049829A, 0x004F8CA5, 0x004F8CA5, 0x003F7187, 0x00000000, 0x00000000, 0x00366375, 0x004D8BA4, 0x001C333D, 0x00000000, 0x000C161A, 0x0047849B, 0x00437B93, 0x00010303, 0x00000101, 0x00091114, 0x00000101, 0x00000000, 0x00213F4B, 0x00407991, 
        0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0041829D, 0x0040819C, 0x0040819C, 
        0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367A97, 
        0x00357A97, 0x00357A96, 0x00347996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327795, 0x00317794, 0x00317794, 0x00317693, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 
        0x002B7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0028708E, 0x00276F8E, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00246E8D, 0x00246E8C, 0x00236D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 
        0x00206B8A, 0x001F6A8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001D6988, 0x001D6888, 0x001C6887, 0x001C6787,
  0x001C6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6A89, 0x001F6A89, 0x001F6B8A, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00236D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0028708E, 
        0x0028708F, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002F7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307694, 0x00317794, 0x00327794, 0x00327795, 
        0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357A96, 0x00367A96, 0x00367A96, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 
        0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 
        0x004585A0, 0x004586A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A1, 0x002D5566, 0x000C161B, 0x00000000, 0x000A1316, 0x002C5363, 0x004988A2, 0x0039697D, 0x00010203, 0x00010203, 0x002D5161, 0x004C8AA4, 0x00264451, 0x00000000, 
        0x000A1316, 0x004C88A1, 0x00447B91, 0x000B1418, 0x00000000, 0x00192C34, 0x001B2F38, 0x00000000, 0x00000000, 0x001C313A, 0x003B687B, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 
        0x005590A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x00528BA3, 0x0030515F, 0x000C1519, 0x001C2F37, 0x00457588, 0x005892AB, 0x005892AB, 0x005992AB, 0x005893AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005A95AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005C96AD, 0x005C96AE, 0x005C96AE, 0x005D96AE, 0x005C96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 
        0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005F97AF, 0x006097AF, 0x006098AF, 0x002E4955, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x002D4853, 0x006098AF, 0x006098B0, 0x002E4954, 0x00000000, 0x00000000, 0x00426878, 0x006098B0, 0x006098B0, 0x006098B0, 0x006099B0, 0x006098B0, 0x006098B0, 0x006099B0, 0x006098B0, 0x006098B0, 0x006198B0, 0x006098B0, 0x006098B0, 
        0x006099B0, 0x006098B0, 0x006098B0, 0x006198B0, 0x005A8FA5, 0x00162329, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00497486, 0x006098AF, 0x005F97AF, 0x005F98AF, 0x006097AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 
        0x0033515E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00243A43, 0x005B93AA, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C96AD, 0x005C96AE, 0x005C95AD, 0x005C95AD, 0x005C95AD, 
        0x005C95AD, 0x005B95AC, 0x005B95AD, 0x005A94AD, 0x005B94AC, 0x005B94AC, 0x005A93AC, 0x005994AC, 0x005A94AC, 0x005994AC, 0x005994AB, 0x005893AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005892AA, 0x005792AA, 0x005792AA, 
        0x005692AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00538FA8, 0x00528EA7, 0x00528EA7, 0x00427388, 0x0024404B, 0x00030607, 0x00000000, 
        0x00111E24, 0x00315767, 0x004F8CA6, 0x00101D22, 0x00000000, 0x001A2E37, 0x004E8BA5, 0x003D6D82, 0x00030708, 0x00000000, 0x00345F71, 0x004C8AA4, 0x00172B33, 0x00000000, 0x000E1A1F, 0x0041788F, 0x002C5262, 0x000A1216, 0x00000000, 0x000C161B, 
        0x002E5565, 0x004887A1, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 
        0x0040819C, 0x003F819C, 0x003F819C, 0x003E809B, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00377C98, 0x00377B97, 0x00377B97, 
        0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327795, 0x00327794, 0x00317794, 0x00317793, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 
        0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028708F, 0x0028708E, 0x00276F8D, 0x00266F8D, 0x00266F8D, 0x00256F8D, 0x00256E8D, 0x00246D8C, 0x00246D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216C8B, 
        0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001D6988, 0x001D6888, 0x001C6888,
  0x001D6888, 0x001D6888, 0x001E6988, 0x001E6989, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708E, 
        0x0028708F, 0x0029718F, 0x0029728F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 
        0x00337895, 0x00347995, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D98, 0x00397D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 
        0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 
        0x004686A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004887A1, 0x0044819B, 0x00162931, 0x00010203, 0x00000000, 0x001C343E, 0x00437C93, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x001C323C, 0x00000000, 0x000A1216, 0x00467E95, 0x0048829A, 0x000B1519, 
        0x00000000, 0x0024414D, 0x004F8CA5, 0x00233F4A, 0x00000000, 0x00000000, 0x00000000, 0x0015262D, 0x0043758B, 0x004F8AA3, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x00548FA8, 0x005590A9, 0x005590A9, 
        0x005591A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x00406C7E, 0x000E181C, 0x00000000, 0x002D4C59, 0x005791AA, 0x005892AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005A93AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005B95AD, 0x005B94AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 
        0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006098AF, 0x006098B0, 0x006098B0, 0x00578A9F, 0x000E171A, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00070B0D, 0x004F7D90, 0x00416676, 0x00000000, 0x00000000, 0x00324F5B, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 
        0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x005B90A5, 0x00162429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00497586, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x006098AF, 0x006098AF, 0x006098AF, 
        0x0033525E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00243A43, 0x005C93AA, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AE, 0x005C95AD, 
        0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005B94AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AA, 0x005892AA, 
        0x005792AA, 0x005792AA, 0x005791AA, 0x005791AA, 0x005691A9, 0x005691A9, 0x005591A9, 0x005591A9, 0x005590A9, 0x005590A8, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538EA8, 0x00528EA7, 0x00518CA5, 0x00477D94, 0x00203943, 
        0x00000000, 0x00000101, 0x00091114, 0x00000000, 0x00060C0E, 0x003F7084, 0x004F8CA5, 0x0015262D, 0x00000000, 0x00182B33, 0x004D8BA4, 0x00355F71, 0x00020506, 0x00010202, 0x002F5565, 0x004B89A3, 0x004B89A3, 0x00427B93, 0x001B333C, 0x00000000, 
        0x00010203, 0x00162A32, 0x0044819A, 0x004887A1, 0x004787A1, 0x004786A0, 0x004786A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 
        0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003E7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00377B97, 
        0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491, 
        0x002C7491, 0x002C7390, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246D8C, 0x00246D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 
        0x00226C8A, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001E6A89, 0x001E6989, 0x001D6888, 0x001D6888,
  0x001D6888, 0x001E6989, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246E8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x0027708D, 0x0028708E, 0x0028708E, 0x0028718E, 
        0x0029718F, 0x002A718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307694, 0x00317794, 0x00317794, 0x00327894, 0x00327895, 0x00337895, 
        0x00347995, 0x00347996, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9B, 0x003C7F9A, 0x003D7F9B, 
        0x003E7F9B, 0x003E809C, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042829E, 0x0042829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 
        0x004786A1, 0x004787A1, 0x004787A1, 0x0047859F, 0x00356478, 0x00040708, 0x00000000, 0x00050A0C, 0x00335D70, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004A859E, 0x00030507, 0x00000000, 0x00294A58, 0x004E8BA5, 0x00305766, 
        0x00000101, 0x00000000, 0x00233E4A, 0x00020304, 0x00010202, 0x000A1216, 0x00386273, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00538FA7, 0x00538FA7, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005690A9, 
        0x005691A9, 0x005691A9, 0x005590A9, 0x004E8398, 0x001D313A, 0x00000000, 0x00000000, 0x00152329, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005A93AB, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AC, 
        0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 
        0x005F97AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098AF, 0x006098AF, 0x006198B0, 0x006098B0, 0x006098B0, 0x006198B0, 0x006099B0, 0x006199B0, 0x006199B0, 0x00406574, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00162328, 0x00040708, 0x00000000, 0x0018262C, 0x005B90A5, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x006299B0, 0x006199B1, 0x006299B0, 0x006199B0, 0x006299B1, 0x006199B0, 0x006299B0, 0x006199B1, 0x006199B0, 
        0x006299B0, 0x006199B0, 0x006199B1, 0x006299B0, 0x005B90A5, 0x00172429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004A7586, 0x006199B0, 0x006199B0, 0x006199B0, 0x006198B0, 0x006198B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098B0, 
        0x0033525F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00243A43, 0x005C93AA, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 
        0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005993AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 
        0x005892AA, 0x005792AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538EA8, 0x00528EA7, 0x00528EA7, 
        0x0045798F, 0x00132228, 0x00010303, 0x00000000, 0x000E191E, 0x00447990, 0x00366173, 0x00000000, 0x00020304, 0x00467C94, 0x004A849D, 0x0015262D, 0x00000000, 0x000E191E, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x004A89A3, 0x00335D70, 
        0x00050A0C, 0x00000000, 0x00040708, 0x00356477, 0x0047859F, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829E, 
        0x0041829D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00387B98, 
        0x00377B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7593, 0x002F7592, 0x002E7492, 0x002D7492, 
        0x002D7491, 0x002C7391, 0x002B7391, 0x002B7291, 0x002A7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0028708E, 0x0026708E, 0x00266F8D, 0x00266E8D, 0x00256E8D, 0x00246E8C, 0x00246E8C, 0x00246D8C, 0x00236D8B, 0x00226C8B, 
        0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6888,
  0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00226D8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028718E, 0x0029718F, 
        0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317693, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347995, 
        0x00347996, 0x00347996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9A, 0x003D7F9B, 0x003D809B, 
        0x003E809B, 0x003F819C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 
        0x004786A1, 0x004887A1, 0x00417A92, 0x001D3742, 0x00000000, 0x00000000, 0x001D3540, 0x00447E96, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x00305666, 0x00000000, 0x00000000, 0x0043798F, 0x00467C92, 
        0x000A1215, 0x00000000, 0x00000000, 0x000D171B, 0x002D4F5E, 0x004F8AA3, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005490A8, 0x005590A9, 0x005590A9, 0x005591A9, 0x005690A9, 0x005691AA, 
        0x005691AA, 0x004C8198, 0x002C4A56, 0x0005090A, 0x00000000, 0x00000000, 0x00000000, 0x00355968, 0x005993AB, 0x005993AB, 0x005993AC, 0x005994AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AD, 0x005B95AC, 0x005B95AD, 0x005B95AD, 
        0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005C96AD, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005E97AF, 0x005E97AF, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 
        0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x00233840, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060A0C, 0x004F7C8E, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 
        0x00629AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x005C90A5, 0x00172429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004A7586, 0x006299B1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x006199B0, 0x006199B0, 0x006099B0, 
        0x0034525F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00253A43, 0x005D94AA, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005F97AF, 0x005F97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 
        0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C96AE, 0x005C95AD, 0x005D95AD, 0x005C95AD, 0x005C95AD, 0x005B94AD, 0x005B95AD, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005992AB, 
        0x005993AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 
        0x00528EA7, 0x00528EA7, 0x00365E6F, 0x0014242B, 0x00000000, 0x00060B0D, 0x00070D10, 0x00000000, 0x00294A57, 0x004F8CA5, 0x00345C6E, 0x00000000, 0x00000000, 0x003F7186, 0x004C8BA4, 0x004C8AA4, 0x004C8AA3, 0x004C8AA3, 0x004B89A3, 0x004A89A3, 
        0x00447E96, 0x001D3540, 0x00000000, 0x00000000, 0x001E3742, 0x00417A93, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0043839E, 0x0042839E, 
        0x0041839D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003E819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00387C98, 
        0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7492, 
        0x002E7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7290, 0x002A7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029708F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8C, 0x00256E8C, 0x00246D8C, 0x00236D8C, 0x00236C8B, 
        0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988,
  0x001E6988, 0x001F6989, 0x00206A8A, 0x00206A8A, 0x00206B8A, 0x00216B8B, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x0029718F, 
        0x002A7190, 0x002B7290, 0x002B7390, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7593, 0x00307693, 0x00317693, 0x00317693, 0x00327794, 0x00327894, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 
        0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 
        0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004787A1, 
        0x004887A2, 0x00346073, 0x00091114, 0x00000000, 0x00070D0F, 0x0037677A, 0x004A87A1, 0x004B89A3, 0x004B8AA3, 0x004C89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x0049849B, 0x00122127, 0x00000000, 0x000E191E, 0x00132127, 
        0x00000000, 0x00000000, 0x002C4D5B, 0x004A8198, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005791AA, 
        0x00315360, 0x000B1316, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00294550, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005B95AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 
        0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006198B0, 
        0x006199B0, 0x006198B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x005D92A8, 0x000D1518, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003C5D6B, 0x00639AB1, 0x00639BB1, 0x00639AB1, 0x00649AB1, 0x00639BB1, 0x00639AB1, 0x00639BB1, 0x00639AB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639BB1, 0x00639AB1, 0x00639AB1, 
        0x00639BB1, 0x00639BB1, 0x00639AB1, 0x00639AB1, 0x005D90A6, 0x00172429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004A7587, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB0, 0x00629AB1, 0x006299B1, 
        0x0035525F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00253A43, 0x005E95AB, 0x006199B0, 0x006098B0, 0x006099B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 
        0x005E97AE, 0x005E97AF, 0x005E97AE, 0x005D97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B94AD, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 
        0x005993AC, 0x005993AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00528EA7, 0x00528EA7, 0x004D869D, 0x00376071, 0x00070D0F, 0x00000000, 0x00010203, 0x002A4A57, 0x004A839C, 0x00070D0F, 0x00000000, 0x0024404D, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 
        0x004B89A3, 0x004A87A1, 0x0037667A, 0x00060C0F, 0x00000000, 0x00091114, 0x00336074, 0x004887A1, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0043839E, 
        0x0042839E, 0x0042829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x00397D99, 0x003A7D99, 0x00397C99, 
        0x00397C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00357996, 0x00347996, 0x00347996, 0x00347895, 0x00337895, 0x00327895, 0x00327894, 0x00317794, 0x00317794, 0x00307693, 0x002F7693, 0x002F7593, 0x002F7592, 
        0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x0029728F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00256F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 
        0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216C8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001E6989,
  0x001E6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A7190, 
        0x002B7290, 0x002B7390, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317794, 0x00317794, 0x00317794, 0x00327894, 0x00327895, 0x00337895, 0x00347996, 0x00347995, 0x00357996, 
        0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 
        0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x004787A1, 0x0046849D, 
        0x00213E4A, 0x00000000, 0x00000000, 0x00172B34, 0x0047859E, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004E8CA5, 0x004F8CA5, 0x00325869, 0x00020304, 0x00000000, 0x00000000, 
        0x00172931, 0x004C859D, 0x00518EA7, 0x00528EA7, 0x00528FA7, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x00548FA9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x00497B8F, 0x00111D22, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040608, 0x005A94AC, 0x005A94AC, 0x005B95AC, 0x005B94AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AD, 0x005D96AE, 0x005D96AE, 
        0x005D96AE, 0x005D97AE, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x005E97AF, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006198AF, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 
        0x006199B0, 0x006299B0, 0x006199B1, 0x006299B0, 0x006299B0, 0x00629AB1, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB2, 0x00639AB1, 0x00476E7F, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0017252A, 0x00649BB2, 0x00649AB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x005E91A7, 0x00172429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004B7587, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 
        0x0035525F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00253A43, 0x005E95AB, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 
        0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 
        0x005A94AC, 0x005994AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005690A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00548FA8, 
        0x00548FA8, 0x00538FA8, 0x00528FA8, 0x00528FA7, 0x00528EA7, 0x00518DA6, 0x00223D48, 0x00000000, 0x00000000, 0x00040809, 0x00000000, 0x00091114, 0x00477E96, 0x004E8CA5, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 
        0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x0047859E, 0x00172B33, 0x00000000, 0x00000000, 0x00213E4A, 0x0046849E, 0x004887A1, 0x004787A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043849F, 0x0043849E, 
        0x0043839E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397D99, 
        0x00397D98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347996, 0x00337895, 0x00327895, 0x00327894, 0x00327794, 0x00317694, 0x00317693, 0x00307693, 0x002F7693, 0x002F7592, 
        0x002F7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0028708E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 
        0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89,
  0x001F6A89, 0x00206A89, 0x00206B8A, 0x00216B8A, 0x00216B8B, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029708F, 0x0029718F, 0x002A7290, 0x002A7290, 
        0x002B7290, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002F7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307694, 0x00317793, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 
        0x00367A96, 0x00367A97, 0x00367B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 
        0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x003B6F85, 0x0014262D, 
        0x00000000, 0x00080E11, 0x00294D5C, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004C879F, 0x00335B6C, 0x000A1114, 0x00000000, 0x000F1B1F, 0x00355C6D, 
        0x00518EA7, 0x00518EA7, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005692AA, 0x00497B8F, 0x00233A44, 0x00070C0E, 0x00142126, 
        0x001A2B32, 0x00132025, 0x00010102, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0031505D, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 
        0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006098B0, 0x006099B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x006299B1, 
        0x006299B1, 0x006299B0, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x006298AF, 0x0022353D, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x003D606E, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00649BB2, 0x00659BB2, 0x00649BB2, 0x00659BB2, 0x00649BB2, 0x00659BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659BB2, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x005E91A7, 0x00172429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004C7688, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639BB2, 0x00649BB1, 0x00639AB1, 0x00639AB2, 0x00639AB1, 0x00639AB1, 
        0x0035535F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00253B44, 0x005F96AC, 0x00629AB1, 0x006299B1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006198B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 
        0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AE, 0x005C96AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005B95AC, 
        0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005994AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005189A1, 0x005591A9, 0x005590A9, 0x005490A9, 
        0x00548FA8, 0x00548FA9, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00528EA7, 0x00427388, 0x0016272E, 0x00000000, 0x00000000, 0x00192C34, 0x00487F97, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA5, 0x004C8AA4, 
        0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x004A89A3, 0x00294C5B, 0x00070E11, 0x00000000, 0x0014262D, 0x003B6F84, 0x004887A1, 0x004887A1, 0x004786A0, 0x004786A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 
        0x0043839F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 
        0x00397D99, 0x00397D98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357996, 0x00357996, 0x00347995, 0x00337995, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317793, 0x00307693, 0x002F7593, 
        0x002F7593, 0x002E7592, 0x002D7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7290, 0x002A7290, 0x002A7290, 0x002A718F, 0x0028718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00256F8D, 0x00246E8C, 0x00246E8C, 
        0x00246D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89,
  0x00206A89, 0x00206B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0027708E, 0x0029708F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 
        0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 
        0x00367B97, 0x00377B97, 0x00377C97, 0x00387B98, 0x00397C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819D, 
        0x0040829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0045849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x002A4F5E, 0x00070D10, 0x00000000, 
        0x00000000, 0x00162830, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x003E6F83, 0x0015262C, 0x00000000, 0x00030506, 0x002E505E, 0x004A8198, 0x00528EA7, 
        0x00528EA8, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x00548EA6, 0x0027424E, 0x000A1013, 0x0029444F, 0x004A7A8E, 0x00568FA6, 
        0x005993AC, 0x00558AA2, 0x002C4854, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090F12, 0x0051849A, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 
        0x005F98AF, 0x005F98AF, 0x005F97AF, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006099B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 
        0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659BB2, 0x00659BB2, 0x00659BB2, 0x00659BB2, 0x00659CB2, 0x00649AB1, 0x00243840, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E1619, 0x005C8DA2, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00659CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00669CB3, 
        0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x005F92A8, 0x0017242A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004D7788, 0x00659CB2, 0x00659CB2, 0x00659BB2, 0x00659BB2, 0x00649BB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00365360, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00263B44, 0x006096AC, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 
        0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005E97AF, 0x005E97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AE, 0x005C95AD, 0x005C95AD, 
        0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x0017282F, 0x0027434E, 0x00528CA3, 0x005591A9, 
        0x005590A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538EA7, 0x004F88A1, 0x00375F70, 0x000B1317, 0x00000000, 0x000E181D, 0x00345C6D, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 
        0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x003B6E83, 0x00000000, 0x00000000, 0x00070D10, 0x002A505F, 0x004887A2, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044859F, 
        0x0044849F, 0x0043849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 
        0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00357996, 0x00347995, 0x00347895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 
        0x002F7693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002B7290, 0x002A7190, 0x0029718F, 0x0029718F, 0x0029708F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 
        0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00206B8A, 0x00206A89,
  0x00206A8A, 0x00206B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00256E8D, 0x00256E8D, 0x00256F8D, 0x00276F8D, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A718F, 0x002B7290, 0x002B7290, 0x002C7390, 
        0x002C7391, 0x002D7491, 0x002D7491, 0x002D7492, 0x002F7592, 0x002F7593, 0x002F7593, 0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 
        0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00397C99, 0x00397C99, 0x003A7D99, 0x003A7D9A, 0x003B7E9A, 0x003B7E9A, 0x003C7F9B, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 
        0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044859F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A0, 0x004887A1, 0x0046849E, 0x001D3742, 0x00000101, 0x00000000, 0x0014242B, 
        0x0005090B, 0x00000000, 0x002B4E5D, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA6, 0x004F8CA6, 0x002A4A58, 0x00020304, 0x00000000, 0x00122025, 0x00477D94, 0x00528EA7, 0x00528EA7, 0x00528EA7, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005692AA, 0x005791AA, 0x005792AA, 0x003B6374, 0x00060B0D, 0x00091012, 0x0048778A, 0x005892AA, 0x005993AB, 0x005993AC, 
        0x005A94AC, 0x005A94AC, 0x00568EA5, 0x0016242A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002A4550, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005F97AE, 0x005F97AF, 0x005F97AF, 0x005F97AF, 
        0x005F98AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00649CB2, 0x00659BB2, 0x00659BB2, 0x00659CB3, 0x00659CB2, 0x00659CB2, 0x00659CB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00446978, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002E4650, 0x00669CB3, 0x00669DB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669DB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669DB3, 
        0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x006092A8, 0x0018242A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004E7788, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00659CB2, 0x00659CB2, 0x00659BB2, 0x00659BB2, 
        0x00365460, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00263B44, 0x006197AD, 0x00649BB2, 0x00639BB1, 0x00639BB1, 0x00639AB2, 0x00639AB1, 0x00629AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006299B0, 0x006299B1, 0x006199B0, 
        0x006199B0, 0x006199B0, 0x006198B0, 0x006099B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AE, 
        0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x004B7E93, 0x00111D22, 0x00080E11, 0x00406C7D, 
        0x005591A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00528EA7, 0x004E879F, 0x00223C46, 0x00000000, 0x00010202, 0x001A2F37, 0x004C859E, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 
        0x004E8BA5, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00192F38, 0x00000000, 0x00010303, 0x00000000, 0x00000101, 0x001D3742, 0x0046849F, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 
        0x0045859F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 
        0x003B7E99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347995, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317694, 
        0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7390, 0x002B7390, 0x002B7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 
        0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216C8B, 0x00206B8A, 0x00206A89,
  0x00206B8A, 0x00216B8B, 0x00216C8A, 0x00226C8B, 0x00226D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 
        0x002D7491, 0x002D7491, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327795, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 
        0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003D7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003E809C, 0x003F809C, 0x0040819C, 0x0040829D, 0x0040829D, 0x0041829D, 
        0x0042829E, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x003E758C, 0x00112027, 0x00000000, 0x00060C0F, 0x00315B6D, 0x004A89A3, 
        0x00203B46, 0x00000000, 0x00060B0E, 0x003D6F84, 0x004D8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x00417389, 0x00121F25, 0x00000000, 0x00070D10, 0x002E515F, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538FA8, 
        0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005690A8, 0x0047788C, 0x001B2E36, 0x00000000, 0x00070D0F, 0x004F8499, 0x005993AB, 0x005993AC, 0x005A93AC, 0x005A94AC, 
        0x005A94AC, 0x005B94AC, 0x005B95AC, 0x00477588, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060B0C, 0x004F7F94, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006098B0, 
        0x006098AF, 0x006098B0, 0x006198B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639BB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x0058889B, 0x00040607, 0x00000000, 
        0x002C434D, 0x00141F23, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00517C8E, 0x00679DB3, 0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB3, 
        0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00679DB3, 0x006093A9, 0x0018242A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004E7788, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 
        0x00365460, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00263B44, 0x006197AD, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B1, 
        0x006299B1, 0x006199B0, 0x006199B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x005E97AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 
        0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A95AC, 0x005A94AC, 0x005A93AC, 0x005A94AC, 0x005993AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005893AB, 0x005892AA, 0x005892AB, 0x005691A9, 0x001D313A, 0x00000000, 
        0x001C2F37, 0x0046788C, 0x005590A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA8, 0x00528EA7, 0x00528EA7, 0x003A6577, 0x000D171B, 0x00000000, 0x00080F12, 0x003A6779, 0x004D89A2, 0x004F8CA5, 0x004E8CA5, 
        0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x002E5363, 0x00000000, 0x00020405, 0x00366477, 0x00315B6C, 0x00060C0F, 0x00000000, 0x00112027, 0x003E758C, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004585A0, 
        0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042829E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 
        0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397D98, 0x00387C98, 0x00387B98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00357996, 0x00357996, 0x00347995, 0x00337895, 0x00327895, 0x00327895, 0x00317794, 0x00317693, 
        0x00317693, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7491, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 
        0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216C8A, 0x00206B8A,
  0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00246E8D, 0x00256E8D, 0x00266E8D, 0x00266F8E, 0x0027708E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7190, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 
        0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 
        0x00387C98, 0x00387C98, 0x00397D98, 0x00397D99, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829E, 0x0042839E, 
        0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00305A6C, 0x00070D10, 0x00000000, 0x0014262E, 0x0040758B, 0x004B89A3, 0x004B89A3, 
        0x0048829B, 0x000F1B20, 0x00000000, 0x0014252C, 0x004A869E, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00284653, 0x00030607, 0x00000000, 0x001F3640, 0x00467B90, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x004C7F94, 0x00243C46, 0x00040708, 0x00000000, 0x00000000, 0x00457386, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AC, 
        0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x0029434E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0020333B, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006099B0, 0x006199B0, 
        0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649AB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB2, 0x00659CB2, 
        0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669CB3, 0x00679DB3, 0x00679DB3, 0x00669DB3, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x006194AA, 0x0011191D, 0x00000000, 0x001A282D, 
        0x00659AAF, 0x00517B8D, 0x00030405, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D1417, 0x006396AC, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 
        0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x006194A9, 0x0018252A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004E7889, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 
        0x00375460, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00263B44, 0x006298AE, 0x00659CB3, 0x00659CB3, 0x00649CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB1, 0x00639BB2, 0x00639AB1, 0x00639AB1, 
        0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB0, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005F97AE, 0x005E97AE, 0x005E96AE, 
        0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005792AB, 0x005289A0, 0x00091013, 
        0x00000000, 0x0005090B, 0x00253F4A, 0x004C8095, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x004D869E, 0x00294855, 0x00000101, 0x00000000, 0x001E353F, 0x00487F96, 0x00508CA5, 
        0x004F8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x003E7084, 0x00060B0D, 0x00000000, 0x00203A45, 0x004A88A2, 0x004B89A3, 0x003F758B, 0x0015262E, 0x00000000, 0x00070E11, 0x00305A6C, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 
        0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 
        0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D98, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 
        0x00317794, 0x00317793, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8E, 
        0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A,
  0x00216B8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 
        0x002E7491, 0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327795, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 
        0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7D9A, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 
        0x0043839F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A1, 0x00244553, 0x00000101, 0x00000000, 0x00213E4A, 0x004886A0, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 
        0x004C8AA4, 0x00437990, 0x00020405, 0x00000000, 0x00264450, 0x004E8CA5, 0x004F8CA5, 0x00457B92, 0x000D171B, 0x00000000, 0x00030607, 0x003B687B, 0x00508CA5, 0x00528EA7, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 
        0x005590A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AB, 0x002F4E5B, 0x0005090B, 0x00000000, 0x00000000, 0x00000000, 0x00223842, 0x005992AA, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005B95AD, 
        0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005B93AA, 0x00090F12, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00467081, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006099B0, 0x006199B0, 0x006199B0, 
        0x006199B0, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639BB1, 0x00639BB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649CB2, 0x00659CB2, 0x00659BB2, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00669CB3, 
        0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00679DB3, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x0023353C, 0x00000000, 0x00090E10, 0x00547F91, 
        0x00689EB4, 0x00679CB3, 0x002B424B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002C434C, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00689EB5, 0x00689EB4, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00689EB5, 0x00689EB5, 0x00689EB5, 
        0x00699EB5, 0x00689EB5, 0x00699EB5, 0x00689EB4, 0x006194A9, 0x0018252A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004F7889, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 
        0x00375461, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00273B44, 0x006398AE, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB1, 0x00639BB2, 
        0x00639AB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006299B1, 0x006299B0, 0x006199B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 
        0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x00243D47, 
        0x00000000, 0x00000000, 0x00000000, 0x00070B0E, 0x002F505E, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x00528EA7, 0x0044778C, 0x000B1316, 0x00000000, 0x00070C0E, 0x003C6B7E, 
        0x004F8DA6, 0x004F8CA5, 0x004F8CA5, 0x004B879F, 0x0014232A, 0x00000000, 0x000C161A, 0x004A87A1, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x004886A0, 0x00213E4A, 0x00000000, 0x00000101, 0x00254653, 0x004887A2, 0x004887A1, 0x004786A1, 0x004786A1, 
        0x004786A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041839D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 
        0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00357996, 0x00347996, 0x00347995, 0x00337995, 0x00327895, 0x00327895, 
        0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x00276F8E, 
        0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216C8B,
  0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00236D8C, 0x00246D8C, 0x00256E8D, 0x00256F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028718E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7390, 0x002C7491, 0x002D7491, 0x002D7492, 
        0x002E7592, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 
        0x00397D99, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 
        0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x0045819A, 0x00182E37, 0x00000000, 0x00030607, 0x00305A6B, 0x004A89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 
        0x004D8AA4, 0x004D8BA4, 0x00335B6C, 0x00000000, 0x00000000, 0x00386375, 0x00355E6F, 0x00010202, 0x00000101, 0x0015252C, 0x004A8299, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005490A9, 0x005590A9, 
        0x005591A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x00548EA6, 0x00426E80, 0x000B1316, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00426D7E, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 
        0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E96AE, 0x00406776, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000A1012, 0x006098AF, 0x006099AF, 0x006198B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B1, 0x00629AB1, 
        0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 
        0x00669DB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00416370, 0x00010102, 0x00000000, 0x003A5764, 0x00689EB5, 
        0x00699EB5, 0x00699FB5, 0x005C8C9F, 0x000B1013, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080C0E, 0x00527D8E, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699FB5, 
        0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x006294AA, 0x0018252A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004F7889, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 
        0x00375561, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00273C45, 0x006399AE, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649CB2, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006198B0, 0x006098AF, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F97AF, 
        0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x001D3139, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00111D22, 0x00457588, 0x00538DA5, 0x005590A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA8, 0x00528EA7, 0x00528EA7, 0x00223C48, 0x00010303, 0x00000000, 
        0x0025424E, 0x004C87A0, 0x004F8CA6, 0x00284956, 0x00000000, 0x00020405, 0x00437A90, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x004A89A3, 0x0030596B, 0x00030607, 0x00000000, 0x00192E37, 0x0045819B, 0x004887A1, 0x004786A1, 
        0x004787A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E7F9B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00327895, 
        0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x002F7693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7391, 0x002C7491, 0x002B7391, 0x002B7390, 0x002B7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 
        0x0027708D, 0x00266F8D, 0x00256F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236C8B, 0x00226C8B,
  0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7592, 
        0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00347895, 0x00347995, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C99, 
        0x00397D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E7F9B, 0x003E809C, 0x003E819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 
        0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x003C7288, 0x00101E24, 0x00000000, 0x000C171B, 0x0039697E, 0x004A89A3, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 
        0x004D8BA4, 0x004E8BA5, 0x004C87A1, 0x001F3741, 0x00000000, 0x00020405, 0x00000000, 0x00070C0E, 0x002D4F5D, 0x00528EA7, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 
        0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x004B7D92, 0x001C2E36, 0x000A1114, 0x001C3038, 0x001A2B32, 0x00020405, 0x00000000, 0x00000000, 0x000E171A, 0x004F8398, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 
        0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005A8FA6, 0x0018262C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0032505C, 0x006199B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 
        0x00639AB1, 0x00649AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00669DB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 
        0x00679DB4, 0x00689DB4, 0x00689DB4, 0x00689DB4, 0x00689DB4, 0x00689EB4, 0x00689EB4, 0x00699EB4, 0x00689EB4, 0x00699EB4, 0x00699EB4, 0x00689EB4, 0x00699EB4, 0x00699EB5, 0x0059869A, 0x00080C0E, 0x00000000, 0x00273B44, 0x00699FB5, 0x006A9FB5, 
        0x00699FB5, 0x00699FB5, 0x00699FB5, 0x0040616F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001E2E34, 0x00699EB4, 0x006A9FB5, 0x006AA0B5, 0x006A9FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 
        0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x006395AA, 0x0018252A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0050788A, 0x00699EB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB5, 0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00699EB4, 
        0x00385561, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00273C45, 0x006499AF, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659CB2, 0x00659CB2, 0x00659CB2, 
        0x00649BB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x006098AF, 
        0x005F97AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AE, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B94AD, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x004F849A, 0x0005090A, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001F343D, 0x00457487, 0x005690A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00528EA7, 0x00386374, 0x000E191E, 
        0x00000000, 0x0014242A, 0x002F5463, 0x00000000, 0x00000000, 0x00325A6A, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B8AA3, 0x004A89A3, 0x00396A7E, 0x000C161B, 0x00000000, 0x00101E24, 0x003C7289, 0x004887A1, 
        0x004787A1, 0x004786A1, 0x004685A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042829E, 0x0042829E, 0x0040829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 
        0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 
        0x00337895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002D7492, 0x002D7491, 0x002D7391, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 
        0x0027708E, 0x00266F8E, 0x00266F8D, 0x00256E8C, 0x00256E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226D8B,
  0x00226D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0027708E, 0x0028718E, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7592, 0x002E7592, 
        0x002F7592, 0x002F7693, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B98, 0x00377C97, 0x00387B98, 0x00397C98, 0x00397C99, 0x00397D99, 
        0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829C, 0x0040819D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849E, 0x0044849F, 
        0x004485A0, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x0038677B, 0x00060B0D, 0x00000000, 0x00162930, 0x00447E95, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 
        0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x00315767, 0x00010303, 0x00000000, 0x00132228, 0x0044768C, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 
        0x005792AA, 0x005792AA, 0x005792AB, 0x005892AB, 0x004F859A, 0x002A4551, 0x004F8398, 0x00568FA7, 0x00568EA5, 0x00304F5C, 0x00000000, 0x00000000, 0x0017262C, 0x005B93AB, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 
        0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x00436B7B, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D1417, 0x0056879C, 0x00629AB1, 0x00639AB1, 0x00629AB1, 0x00639BB1, 0x00639AB1, 0x00639BB1, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 
        0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x000E1619, 0x00000000, 0x00172328, 0x006699AF, 0x006A9FB6, 0x006A9FB6, 
        0x006AA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB6, 0x00203037, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003F5F6C, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006496AB, 0x0018252A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0051798B, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 
        0x00385661, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00273C45, 0x00659AAF, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00689DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 
        0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659BB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB2, 0x00639BB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006099B0, 
        0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x002B4753, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E181C, 0x001F343D, 0x00132026, 0x00040608, 0x00223A44, 0x00518AA2, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x004B8299, 
        0x00243E4A, 0x00000000, 0x00010202, 0x00000000, 0x00213B46, 0x004D89A2, 0x004F8BA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B8AA4, 0x004B89A3, 0x00447E96, 0x00162830, 0x00000000, 0x00060C0E, 0x0038697D, 
        0x004887A1, 0x004787A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 
        0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A97, 0x00347996, 0x00347995, 0x00347995, 
        0x00337895, 0x00337894, 0x00327794, 0x00327794, 0x00307794, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7491, 0x002C7390, 0x002B7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028718F, 
        0x0027708E, 0x00276F8E, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00236D8C, 0x00236D8B,
  0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0029708F, 0x0029718F, 0x0029728F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7592, 0x002E7592, 0x002F7592, 
        0x00307693, 0x00307693, 0x00307794, 0x00317794, 0x00327794, 0x00327795, 0x00337895, 0x00347895, 0x00347996, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003A7D99, 
        0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 
        0x004585A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x002D5566, 0x00000000, 0x00000000, 0x00203B46, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 
        0x004F8CA5, 0x004E8AA3, 0x002E5261, 0x00000000, 0x00000000, 0x00203741, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005791AA, 
        0x005792AA, 0x005792AA, 0x005892AB, 0x005992AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x004A798D, 0x00080E10, 0x00000000, 0x00253C46, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 
        0x005E97AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006198B0, 0x001A292F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00314D58, 0x00639AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB5, 
        0x00699EB4, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x00213239, 0x00000000, 0x00070B0C, 0x00578395, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006191A5, 0x00050708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x006091A4, 0x006CA0B6, 0x006CA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006496AB, 0x0019252A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00517A8B, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x006BA0B5, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 
        0x00395661, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00283C45, 0x00669AB0, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00689DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00669DB3, 
        0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB0, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 
        0x006198B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x004F8196, 0x000B1215, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00243C46, 0x005892AB, 0x005892AB, 0x005792AA, 0x004A7C92, 0x00111E23, 0x00213841, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 
        0x00528EA7, 0x00325766, 0x00040708, 0x00000000, 0x001C323B, 0x004A849C, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA4, 0x004B89A3, 0x004A89A3, 0x001F3B46, 0x00000000, 0x00000000, 
        0x002E5566, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004586A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F809C, 
        0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 
        0x00347895, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7491, 0x002C7491, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 
        0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8E, 0x00256F8D, 0x00256E8D, 0x00256E8C, 0x00246D8C, 0x00236D8B,
  0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 
        0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7E99, 
        0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 
        0x004586A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x004786A0, 0x00254654, 0x00000000, 0x00020405, 0x00274956, 0x004A89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 
        0x00467C93, 0x001C313B, 0x00000000, 0x00091012, 0x00365E6F, 0x00518DA7, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005591AA, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 
        0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x004C7C90, 0x00090F12, 0x00000101, 0x00355663, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005F97AF, 
        0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006099B0, 0x006099B0, 0x006199B0, 0x00588BA0, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0056869A, 0x00649AB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 
        0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00669DB4, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00689EB5, 0x00699EB5, 0x00699EB5, 
        0x00699FB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006A9FB6, 0x006A9FB6, 0x006AA0B6, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x0040606D, 0x00010202, 0x00000000, 0x003B5864, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006CA0B6, 0x006CA0B7, 0x006CA0B6, 0x006B9FB6, 0x003B5864, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001E2C32, 0x006B9FB5, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 
        0x006CA1B6, 0x006CA0B6, 0x006CA1B6, 0x006CA0B6, 0x006596AC, 0x0019252A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00517A8B, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006AA0B6, 0x006A9FB5, 
        0x00395662, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00283D45, 0x00669BB0, 0x00699EB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB5, 0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00679EB4, 0x00679DB4, 0x00679DB4, 
        0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB2, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 
        0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D97AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x002A4450, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x0016242B, 0x005993AC, 0x005893AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005791AA, 0x00538DA5, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00528EA7, 0x00528EA7, 0x003F6F83, 0x00101D22, 0x00000000, 0x00111E23, 0x003F6F84, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x004A89A3, 0x00274856, 0x00020405, 
        0x00000000, 0x00264755, 0x004786A0, 0x004787A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 
        0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B98, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00357996, 
        0x00347996, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7592, 0x002D7491, 0x002C7491, 0x002C7391, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 
        0x0028718F, 0x0028708F, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8C, 0x00236D8C,
  0x00246E8C, 0x00246E8C, 0x00266E8D, 0x00266F8D, 0x00276F8D, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002C7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7492, 0x002F7592, 0x002F7693, 0x00307693, 
        0x00307693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337995, 0x00347896, 0x00347996, 0x00357996, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003A7E9A, 0x003B7E9A, 
        0x003B7E9A, 0x003C7F9A, 0x003D7F9A, 0x003D7F9B, 0x003E7F9B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 
        0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A2, 0x00193039, 0x00000000, 0x00030607, 0x00366476, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x003E6C80, 
        0x000D171B, 0x00000000, 0x0015252C, 0x00467A90, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691A9, 0x005792AA, 0x0049798E, 0x005892AA, 0x005892AB, 
        0x005993AB, 0x005993AC, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005B95AD, 0x005B95AD, 0x00477385, 0x00060B0C, 0x00010102, 0x00436D7E, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F97AE, 0x005F98AF, 0x005F98AF, 0x005F98AF, 
        0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x006299B1, 0x00629AB1, 0x00395967, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00152025, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 
        0x00669DB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 
        0x006A9FB6, 0x006A9FB6, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B6, 0x005B899B, 0x00070B0C, 0x00000000, 0x0022333A, 0x006CA1B7, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 
        0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006798AD, 0x00131C20, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x00466876, 0x006DA2B7, 0x006DA1B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 
        0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006697AC, 0x0019252B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00537B8B, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA0B6, 0x006CA0B7, 0x006CA0B6, 0x006CA0B6, 0x006BA0B6, 
        0x00395662, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00283D45, 0x00689CB1, 0x006AA0B5, 0x006A9FB6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 
        0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00659CB2, 0x00659CB2, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 
        0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x004D7D91, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00020405, 0x0052879D, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00548FA8, 
        0x00538FA8, 0x00528FA8, 0x00528EA7, 0x004C859C, 0x00243F4A, 0x00000000, 0x00060B0D, 0x002E5260, 0x00508DA6, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A4, 0x004B89A3, 0x00356376, 
        0x00030607, 0x00000000, 0x001A3039, 0x004987A2, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 
        0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D98, 0x00397C98, 0x00387B98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367A96, 0x00357A96, 
        0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317793, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592, 0x002E7592, 0x002D7491, 0x002D7391, 0x002C7391, 0x002C7391, 0x002B7290, 0x002A7290, 0x002A718F, 
        0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266E8D, 0x00256E8C, 0x00246E8C,
  0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x00276F8E, 0x0028708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 
        0x00317694, 0x00327794, 0x00327794, 0x00337895, 0x00337995, 0x00347895, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377C98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 
        0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 
        0x004786A1, 0x004786A1, 0x004887A1, 0x0044819A, 0x000F1C21, 0x00000000, 0x00081013, 0x003E7389, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x00355C6E, 0x00000000, 
        0x00000000, 0x0025414D, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x00558FA6, 0x00294652, 0x00000000, 0x0047778B, 0x005993AB, 
        0x005993AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B94AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x003F6878, 0x00020405, 0x00010202, 0x00518398, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098B0, 
        0x006099B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x005C8FA4, 0x00131E22, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003E616F, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 
        0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00689EB5, 0x00699EB4, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006AA0B6, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B7, 0x006CA1B7, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x0010171B, 0x00000000, 0x000B1113, 0x006CA0B6, 0x006DA1B7, 0x006DA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA2B7, 
        0x006DA2B7, 0x006DA2B7, 0x006DA2B7, 0x006DA2B8, 0x006DA2B7, 0x006DA2B8, 0x00517889, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000F1619, 0x006697AB, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006EA2B8, 
        0x006EA2B7, 0x006DA2B8, 0x006EA2B8, 0x006DA2B8, 0x006698AD, 0x0019262B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00537B8B, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 
        0x003A5663, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00293D45, 0x00689CB1, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB4, 0x00699EB5, 
        0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00679DB3, 0x00679DB4, 0x00679DB3, 0x00669CB4, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB2, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 
        0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98B0, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x000F191D, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00385B6A, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA9, 
        0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00528EA7, 0x00335A6A, 0x00000000, 0x00000000, 0x0025414C, 0x004F8BA5, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 
        0x003E7288, 0x00081013, 0x00000000, 0x000F1D22, 0x0046819A, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0040829D, 
        0x0040819D, 0x003F819C, 0x003F809C, 0x003F809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00387B98, 0x00377B98, 0x00377B97, 0x00367A96, 0x00367A96, 
        0x00357A96, 0x00347995, 0x00347996, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002B7290, 0x002A7290, 
        0x002A718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x00276F8E, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00246E8C,
  0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7190, 0x002A7290, 0x002B7290, 0x002C7390, 0x002C7391, 0x002D7391, 0x002D7491, 0x002E7592, 0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00317693, 
        0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 
        0x003D7F9A, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A1, 
        0x004787A1, 0x004887A1, 0x003F778E, 0x00111F26, 0x00000000, 0x00060C0F, 0x0040758B, 0x004B89A3, 0x004B89A3, 0x004B89A4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004B859E, 0x00233E4A, 0x00000000, 0x00050A0C, 
        0x00345B6C, 0x00518EA7, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691A9, 0x00538BA2, 0x003C6576, 0x000B1417, 0x00030607, 0x00416C7E, 0x005893AB, 0x005993AB, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AD, 0x00375A68, 0x00000000, 0x00020405, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 
        0x006199B0, 0x006299B0, 0x006199B1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x003E616F, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0010181C, 0x005E90A6, 0x00669DB3, 0x00679DB3, 0x00679DB4, 
        0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006AA0B6, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x0025363E, 0x00000000, 0x00040607, 0x00598495, 0x006DA2B7, 0x006DA1B8, 0x006DA2B8, 0x006EA2B7, 0x006EA2B7, 0x006EA2B8, 
        0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x002B4048, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002C414A, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 
        0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006798AD, 0x0019252A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00547B8C, 0x006EA2B7, 0x006EA1B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 
        0x003A5662, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00293D45, 0x00689DB1, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 
        0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00689DB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00639BB1, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006199B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x00395B69, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00131E23, 0x00558BA2, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005590A9, 0x005490A9, 
        0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538EA7, 0x00528EA7, 0x00427488, 0x000C1518, 0x00000000, 0x00172930, 0x00477D95, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B8AA4, 0x004B89A3, 
        0x004B89A3, 0x003E748A, 0x000D191D, 0x00000000, 0x00112026, 0x003F778E, 0x004887A1, 0x004787A1, 0x004686A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045849F, 0x0044859F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 
        0x0041829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00367B97, 0x00367A97, 
        0x00357A97, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317694, 0x00307693, 0x00307693, 0x002F7592, 0x002F7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002A7290, 
        0x002A728F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0028708E, 0x00276F8E, 0x00266F8E, 0x00266F8D, 0x00256E8D,
  0x00266E8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x0029728F, 0x002A7190, 0x002B7390, 0x002B7390, 0x002C7391, 0x002C7491, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 
        0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E99, 0x003C7E9A, 0x003C7E9A, 0x003D7F9B, 
        0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 
        0x004887A1, 0x003D7188, 0x000C171B, 0x00000000, 0x00000000, 0x00070E11, 0x003A6A7E, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x00497F97, 0x0015262D, 0x00000000, 0x000E191D, 0x00407084, 
        0x00518EA7, 0x00528EA8, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x003F6A7C, 0x0017282E, 0x00000000, 0x00020404, 0x003C6373, 0x005993AB, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C96AE, 0x005D96AE, 0x005D96AE, 0x005D94AC, 0x002E4A55, 0x00000000, 0x000C1316, 0x005F98AF, 0x005F98AF, 0x006098B0, 0x006098B0, 0x006198B0, 0x006199B0, 0x006199B0, 0x006299B0, 
        0x006299B1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00649CB2, 0x006399AF, 0x00152125, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003A5865, 0x00679CB3, 0x00689DB4, 0x00679EB4, 
        0x00689EB5, 0x00699EB5, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 
        0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B7, 0x006DA2B7, 0x006EA2B7, 0x006DA2B8, 0x00354F5A, 0x00000000, 0x00010102, 0x0038535F, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B8, 
        0x006FA3B8, 0x006FA3B9, 0x006EA3B8, 0x006FA3B8, 0x006FA3B9, 0x006FA3B8, 0x006FA3B9, 0x00699BB0, 0x000E1517, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0042606C, 0x006FA3B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B9, 0x006FA3B9, 
        0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006898AC, 0x00172126, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00527989, 0x006FA2B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 
        0x0036505A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00283B43, 0x006A9CB1, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 
        0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 
        0x00659BB2, 0x00649BB2, 0x00649AB2, 0x00649BB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x00578A9F, 0x0010191D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00010203, 0x003B5F6F, 0x005C96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005591A9, 
        0x005590A9, 0x005490A9, 0x00548FA9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x004A8097, 0x001A2E36, 0x00000000, 0x000C1519, 0x003D6B7E, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 
        0x004B89A3, 0x004B89A3, 0x001F3944, 0x00000000, 0x00000000, 0x000C171B, 0x003C7188, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 
        0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 
        0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00337995, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391, 0x002C7390, 0x002B7390, 
        0x002A7290, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028708F, 0x0028708E, 0x00276F8D, 0x00266F8D, 0x00266F8D,
  0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7390, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 
        0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 
        0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 
        0x003A6B80, 0x00060B0D, 0x00000000, 0x001C333D, 0x00101E23, 0x00000000, 0x00091114, 0x0040758B, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x0042768B, 0x00070C0E, 0x00000000, 0x001B3038, 0x004D88A0, 0x00518EA7, 
        0x00528EA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x0050869D, 0x001A2D34, 0x00010203, 0x00000000, 0x00000000, 0x000A1013, 0x00548AA1, 0x005A94AC, 0x005A94AC, 0x005A94AC, 
        0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005B93A9, 0x0022373F, 0x00000000, 0x001E3037, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x006299B1, 
        0x00639AB1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00527E90, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090B, 0x006295AA, 0x00689EB4, 0x00689EB4, 
        0x00699EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 
        0x006DA1B7, 0x006DA2B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x0041606D, 0x00000000, 0x00000000, 0x000D1417, 0x00699BAF, 0x006FA3B8, 0x006FA3B8, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 
        0x0070A3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A3B9, 0x0043626F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070A0C, 0x00577F91, 0x0070A3B9, 0x0070A4B9, 0x0070A3B9, 0x0070A4B9, 
        0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x006796AA, 0x0010181B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00496B79, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 
        0x002A3E47, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0022333A, 0x00699CB0, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 
        0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 
        0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006098AF, 0x00365563, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00121E22, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C96AE, 0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 
        0x005691A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x00518EA7, 0x00284754, 0x00000000, 0x00020405, 0x00386375, 0x00508CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x002B505F, 0x00020405, 0x00000101, 0x00060B0D, 0x00000000, 0x00060B0D, 0x003A6B80, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 
        0x0042839E, 0x0041829D, 0x0040829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387B97, 0x00377B98, 
        0x00377B97, 0x00367A97, 0x00357A97, 0x00357996, 0x00347996, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x002F7693, 0x002F7693, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7391, 
        0x002B7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0028718E, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D,
  0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7492, 0x002E7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327894, 
        0x00337895, 0x00337895, 0x00347995, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 
        0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0041819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004686A1, 0x004887A1, 0x004887A1, 0x0038697E, 
        0x00060B0D, 0x00000000, 0x00192E37, 0x004B89A3, 0x0047839B, 0x000A1216, 0x00000000, 0x000D171C, 0x00467F97, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x00396578, 0x00020304, 0x00010202, 0x00223C46, 0x00518DA6, 0x00528EA7, 0x00528EA7, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x0050879E, 0x00345766, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0005090B, 0x00447082, 0x005A94AC, 0x005B94AC, 0x005B95AC, 
        0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AF, 0x005E97AE, 0x005A90A7, 0x00162429, 0x00000000, 0x002F4A56, 0x006098B0, 0x006198B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 
        0x00639AB1, 0x00639BB2, 0x00649BB1, 0x00649BB2, 0x00659BB2, 0x00649CB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00283D46, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002A3F49, 0x00699EB5, 0x00699FB5, 
        0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA0B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B8, 
        0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA3B8, 0x006B9CB2, 0x003A5661, 0x00000000, 0x00000000, 0x00000000, 0x001F2E34, 0x006FA3B9, 0x0070A3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 
        0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4B9, 0x00547B8B, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00172226, 0x006593A6, 0x0070A4B9, 0x0071A4B9, 0x0070A4B9, 
        0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0070A4B9, 0x006391A3, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00344C57, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 
        0x00151F23, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00162024, 0x006799AD, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00679DB3, 0x00669DB3, 0x00669CB3, 
        0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649AB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x00598DA2, 0x00050809, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x004D7B8F, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AC, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AA, 0x005792AB, 0x005792AA, 0x005691AA, 
        0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00528EA7, 0x00345C6C, 0x00020405, 0x00000000, 0x002D505E, 0x004E8BA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 
        0x00386477, 0x00030708, 0x00000000, 0x00192E36, 0x004A87A1, 0x00192E37, 0x00000000, 0x00060B0D, 0x00386A7E, 0x004887A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044859F, 0x0044859F, 0x0044849F, 0x0043839E, 0x0043839E, 
        0x0042839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B97, 
        0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 
        0x002B7390, 0x002B7290, 0x002A7290, 0x002A728F, 0x0028718F, 0x0028718E, 0x0028708E, 0x0027708E, 0x00266F8D,
  0x00276F8E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7390, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 
        0x00337895, 0x00347995, 0x00357996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7E99, 0x003B7D99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 
        0x003E819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x00356376, 0x00060B0D, 
        0x00000000, 0x00213E4A, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x0040758C, 0x000B1519, 0x00000000, 0x00111F24, 0x00477F96, 0x004E8BA5, 0x004F8CA5, 0x002D505F, 0x00020304, 0x00010303, 0x002E5160, 0x00518EA7, 0x00528EA7, 0x00528EA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005691A9, 0x00548FA7, 0x00375D6E, 0x00132025, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D1518, 0x003B6171, 0x005B95AD, 0x005C95AD, 
        0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005E97AF, 0x005F97AF, 0x00598EA4, 0x000A1113, 0x00000000, 0x00406776, 0x006199B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB3, 0x006193A8, 0x00090E10, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00517B8C, 0x006A9FB5, 
        0x006A9FB5, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B8, 0x006EA2B7, 0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 
        0x006EA2B8, 0x006FA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x00517888, 0x001E2C32, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00141E22, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A4BA, 0x0071A4B9, 
        0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A4BA, 0x0071A4BA, 0x0072A4B9, 0x0071A4B9, 0x00405D69, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001C292E, 0x005A8294, 0x0071A4BA, 0x0071A4BA, 
        0x0072A4BA, 0x0072A4BA, 0x0071A5BA, 0x0072A4BA, 0x00364E58, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000A0F11, 0x00618EA1, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x00537A8B, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00456774, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006EA2B7, 0x006DA2B7, 0x006DA2B8, 0x006EA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006CA1B7, 
        0x006CA0B6, 0x006BA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x00699EB5, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669DB4, 
        0x00679CB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639BB1, 0x00629AB1, 0x00639AB1, 0x00629AB1, 0x0021343D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002B454F, 
        0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C96AD, 0x005C95AD, 0x005C94AD, 0x005B94AD, 0x005A94AC, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005792AA, 
        0x005691AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x00528EA7, 0x003C687A, 0x00091012, 0x00000000, 0x00213A45, 0x004C89A1, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x003C6B7F, 
        0x00060A0C, 0x00000000, 0x00192D36, 0x004A86A0, 0x004B89A3, 0x004B89A3, 0x00213E4A, 0x00000000, 0x00060B0D, 0x00356477, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A1, 0x004685A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839E, 
        0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003B7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397D98, 0x00397C98, 0x00387B98, 
        0x00387B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391, 
        0x002C7391, 0x002B7390, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028718E, 0x0027708E, 0x0027708E,
  0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x0029718F, 0x002B7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002F7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 
        0x00347895, 0x00347996, 0x00357996, 0x00367A96, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E99, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 
        0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x004887A1, 0x00325C6F, 0x00040708, 0x00000000, 
        0x00284958, 0x004A87A1, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x003C6C7F, 0x00060B0D, 0x00000000, 0x0016272E, 0x004B869F, 0x001F3741, 0x00000000, 0x0005090B, 0x003E6E81, 0x00518EA7, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00538FA8, 
        0x00548FA9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x0047788D, 0x00142228, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030506, 0x00131E23, 0x00447082, 
        0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x00588BA1, 0x00000000, 0x00000000, 0x00538497, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB1, 0x00649BB2, 0x00649BB2, 
        0x00649BB2, 0x00659CB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x003C5C69, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00141E22, 0x00699DB3, 
        0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B8, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA2B8, 0x006FA3B9, 
        0x006FA3B8, 0x006FA2B8, 0x00618DA1, 0x00446371, 0x001A262B, 0x00050708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x001F2D32, 0x004C6F7D, 0x00608B9E, 0x006FA1B7, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 
        0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x006796A9, 0x00598292, 0x00344C56, 0x00040506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080C0D, 0x0024343B, 0x004D6F7E, 
        0x005A8394, 0x006592A4, 0x00517584, 0x00202E34, 0x00010102, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1214, 0x0038525D, 0x005D8698, 0x006593A7, 0x006491A4, 0x006593A6, 0x005A8394, 0x00354D57, 0x00080C0E, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030506, 0x0022333A, 0x00517786, 0x006291A3, 0x006493A6, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006EA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 
        0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679EB4, 
        0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00476E7F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1316, 0x00588CA2, 
        0x006098B0, 0x005F98AF, 0x005F98AF, 0x005E97AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AB, 
        0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00487F95, 0x000E191D, 0x00000000, 0x0014232A, 0x004F8BA4, 0x004F8CA6, 0x00407286, 0x00060B0D, 
        0x00000000, 0x0015262D, 0x00478099, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x004A87A1, 0x00274957, 0x00000000, 0x00040809, 0x00325D6F, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 
        0x0043849F, 0x0043839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819C, 0x003E819C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00397C98, 
        0x00387C98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00357A97, 0x00357996, 0x00357996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7492, 0x002E7492, 0x002D7491, 
        0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E,
  0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A728F, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00347995, 
        0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D9A, 0x003B7E9A, 0x003B7E9A, 0x003D7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003E809C, 0x003F819C, 
        0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x00356377, 0x00040708, 0x00000101, 0x00223F4B, 
        0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x00356071, 0x00010203, 0x00000000, 0x0004080A, 0x00000000, 0x00091114, 0x0043758A, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x005590A9, 0x005590A9, 0x005490A8, 0x005088A0, 0x00253E49, 0x00000000, 0x00010102, 0x00020304, 0x00010203, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x0018272D, 0x004E7D92, 0x005C94AB, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x004F7B8F, 0x00000000, 0x00000000, 0x006198AF, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 
        0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00699EB4, 0x00699EB5, 0x006092A6, 0x00131D21, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x0041616F, 
        0x006BA0B6, 0x006CA1B6, 0x006CA0B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 
        0x0070A3B9, 0x006A9AAF, 0x001D2B31, 0x00020303, 0x00040707, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00040708, 0x00030405, 0x0006090A, 0x005E899A, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 
        0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A5BA, 0x006E9EB2, 0x001F2D33, 0x00000101, 0x00040506, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00040607, 0x00030405, 
        0x00020303, 0x00010202, 0x00020304, 0x00040708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00030505, 0x00020303, 0x00010202, 0x00010202, 0x00010202, 0x00020303, 0x00030506, 0x00050708, 
        0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00050708, 0x00040607, 0x00020304, 0x00010202, 0x00050809, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 0x00689EB4, 
        0x00679DB4, 0x00689DB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x006197AD, 0x00121C20, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00395A67, 0x006199B0, 
        0x006198B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005893AB, 0x005893AB, 
        0x005892AB, 0x005792AB, 0x005791AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x00528EA7, 0x004E89A1, 0x0016282F, 0x00000000, 0x000A1114, 0x00427489, 0x000E191D, 0x00000000, 
        0x000C161B, 0x00447B92, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x00223F4C, 0x00000101, 0x00040708, 0x00356477, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 
        0x0044849F, 0x0043839F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F809C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 
        0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347995, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7492, 
        0x002D7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718E, 0x0027708E,
  0x0028708E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7492, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00347996, 
        0x00347996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819C, 
        0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x00356376, 0x0004090A, 0x00000000, 0x00254552, 0x004A89A3, 
        0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x002D5160, 0x00000000, 0x00000000, 0x00122026, 0x00467A90, 0x00518EA7, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005590A9, 
        0x005590A9, 0x005590A9, 0x00497B91, 0x000D171B, 0x00111D22, 0x00253E49, 0x00345765, 0x0039606F, 0x00375B6A, 0x002A4651, 0x001A2B32, 0x000A1114, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x001E3138, 0x00436C7C, 0x005D95AB, 0x006098B0, 0x006099B0, 0x006199B0, 0x003D616F, 0x00000000, 0x000A1012, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649CB2, 0x00659CB2, 0x00659CB3, 
        0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x00436574, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00131D21, 
        0x006596AB, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006EA3B8, 0x006FA3B8, 0x006FA3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 
        0x0070A4B9, 0x0070A3B8, 0x006B9CB1, 0x006999AD, 0x006999AE, 0x00699AAE, 0x00699AAE, 0x006A99AE, 0x00699AAE, 0x006A9AAE, 0x006A9AAE, 0x006A9AAE, 0x006A9AAE, 0x006A9AAE, 0x006B9BAF, 0x0071A3B7, 0x0073A6BB, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 
        0x0073A6BB, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x006D9EB2, 0x006B9BAF, 0x006B9BAF, 0x006C9BAF, 0x006B9BAF, 0x006C9BAF, 0x006B9BAF, 0x006C9BAF, 0x006B9BAF, 0x006C9BAF, 0x006B9BAF, 0x006C9BAF, 0x006C9BAF, 0x006C9BAF, 0x006C9BAF, 
        0x006B9BAF, 0x006B9BAF, 0x006B9BAF, 0x006B9BAF, 0x006B9BAF, 0x006B9BAF, 0x006B9BAF, 0x006B9BAF, 0x006B9AAF, 0x006B9AAF, 0x006B9AAF, 0x006B9AAE, 0x006A9AAE, 0x006B9AAE, 0x006A9AAE, 0x006A9AAF, 0x006A9AAE, 0x006A9AAE, 0x006A9AAE, 0x006A9AAE, 
        0x006A9AAE, 0x006A9AAE, 0x006999AE, 0x006999AE, 0x006999AE, 0x006999AD, 0x006999AD, 0x006899AD, 0x006899AD, 0x006899AD, 0x006999AE, 0x0070A4B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 
        0x006EA2B8, 0x006EA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B7, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B5, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 
        0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00649CB2, 0x003D5E6C, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121C20, 0x005B8FA4, 0x006199B0, 
        0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005993AC, 0x005993AB, 
        0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA9, 0x005490A8, 0x00538FA8, 0x00528EA8, 0x00528EA7, 0x004E879F, 0x001E353E, 0x00000000, 0x00000000, 0x00000000, 0x000C1519, 
        0x00407185, 0x004E8CA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B8AA4, 0x004B89A3, 0x004B89A3, 0x00254451, 0x00000000, 0x0004090A, 0x00356478, 0x004887A1, 0x004787A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 
        0x0044859F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397C99, 
        0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00337896, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592, 0x002E7492, 
        0x002D7491, 0x002C7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028708E,
  0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002B7391, 0x002C7491, 0x002D7391, 0x002D7492, 0x002E7592, 0x002F7593, 0x002F7593, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00327895, 0x00337895, 0x00337895, 0x00347996, 0x00357996, 
        0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819D, 
        0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x00315C6F, 0x00040708, 0x00000000, 0x002B505F, 0x004B89A3, 0x004B89A3, 
        0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA4, 0x004E8BA5, 0x004F8CA5, 0x00488098, 0x00101D23, 0x00000000, 0x001A2E37, 0x004B839B, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005590A9, 
        0x005691AA, 0x005691A9, 0x005189A0, 0x00447285, 0x0052889F, 0x005893AB, 0x005893AB, 0x005993AB, 0x005994AC, 0x005A93AC, 0x005890A7, 0x004E7F93, 0x003C6272, 0x00152228, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00030506, 0x00152227, 0x003F6473, 0x006199B0, 0x006299B1, 0x002B444F, 0x00000000, 0x001A282E, 0x00639BB1, 0x00649AB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00669DB3, 
        0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x001A282D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x003B5763, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 
        0x0071A5BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0074A6BC, 
        0x0074A7BB, 0x0074A6BC, 0x0074A6BB, 0x0074A6BC, 0x0074A7BC, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0075A7BB, 0x0075A7BC, 0x0074A7BC, 0x0074A7BC, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A7BC, 0x0074A7BC, 0x0074A6BC, 0x0074A6BB, 0x0074A7BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 
        0x0073A5BA, 0x0072A5BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 
        0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 
        0x00699EB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x006194AA, 0x000E1619, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00446A7A, 0x00629AB1, 0x006299B1, 
        0x006299B1, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005A94AC, 
        0x005993AC, 0x005993AB, 0x005893AB, 0x005892AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005591A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00508BA4, 0x002A4A57, 0x00000000, 0x00000000, 0x00355E6E, 
        0x00508CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x002B505F, 0x00000000, 0x00040708, 0x00325D6F, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 
        0x004485A0, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 
        0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337895, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317793, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 
        0x002E7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x0029718F, 0x0029718F,
  0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7491, 0x002D7491, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307694, 0x00317794, 0x00317794, 0x00327894, 0x00327895, 0x00337895, 0x00347996, 0x00347996, 0x00357A96, 
        0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003B7D99, 0x003B7E99, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003E809B, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 
        0x0042829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00356477, 0x00040809, 0x00000101, 0x00254552, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 
        0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x00457A90, 0x000B1518, 0x00000000, 0x001A2D35, 0x004E8AA2, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 
        0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x004B798C, 0x00152228, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00111B1F, 0x00507E91, 0x001B2A31, 0x00000000, 0x00294049, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB3, 
        0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B7, 0x006292A5, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x006797AC, 0x006EA2B8, 0x006FA2B8, 0x006FA2B8, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 
        0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0073A6BA, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0074A6BB, 0x0074A6BC, 0x0075A7BC, 0x0074A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0074A6BB, 
        0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BA, 0x0073A5BB, 0x0072A5BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0072A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x006FA3B9, 
        0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 
        0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669DB4, 0x00669DB3, 0x0035525E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001A292F, 0x00639BB2, 0x00639AB1, 0x00639AB1, 
        0x00629AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00518DA6, 0x002F5260, 0x00000101, 0x00000101, 
        0x003B697C, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C89A3, 0x004B89A3, 0x004B89A3, 0x00254452, 0x00000101, 0x00040809, 0x00356478, 0x004887A1, 0x004787A1, 0x004787A1, 0x004686A0, 0x004686A0, 
        0x004585A0, 0x0044849F, 0x0044849F, 0x0044849F, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041839D, 0x0040829D, 0x0040829D, 0x0040819C, 0x003F809C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 
        0x003A7D99, 0x00397D98, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00377B97, 0x00357A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x002F7693, 0x002F7593, 0x002F7592, 
        0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x0029718F, 0x0029718F,
  0x0029718F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002B7391, 0x002D7491, 0x002D7491, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 
        0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397D98, 0x00397D99, 0x003A7D99, 0x003B7E9A, 0x003B7E99, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 
        0x0042839E, 0x0042839E, 0x0042839E, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x004787A1, 0x0038697F, 0x00060B0D, 0x00000000, 0x00223F4B, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 
        0x004C8AA4, 0x004D8BA4, 0x004E8BA4, 0x004E8CA5, 0x004F8CA5, 0x0042768B, 0x000C161A, 0x00000000, 0x001C3139, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 
        0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x00467183, 0x001B2B32, 0x00060A0C, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00000000, 0x00375663, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 
        0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006B9FB6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x00354F5A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x001F2D33, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 
        0x0073A5BA, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BC, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0076A7BD, 0x0076A8BD, 0x0076A8BC, 0x0075A8BC, 0x0076A8BC, 0x0076A8BC, 0x0076A7BC, 0x0076A8BC, 0x0076A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BC, 
        0x0076A7BC, 0x0076A8BC, 0x0076A7BC, 0x0076A7BC, 0x0075A8BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BC, 0x0074A6BC, 0x0074A6BB, 
        0x0074A7BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A5BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A4BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 
        0x0070A4B9, 0x0070A3B8, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x005B8B9F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010303, 0x005A8CA1, 0x00649BB2, 0x00649BB2, 0x00639AB1, 
        0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 
        0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x00528EA7, 0x002D4D5B, 0x00020304, 
        0x00010303, 0x00376172, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x00223F4B, 0x00000000, 0x00060C0E, 0x00386A7E, 0x004887A1, 0x004787A1, 0x004786A0, 0x004686A0, 
        0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E99, 
        0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00357996, 0x00347895, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317794, 0x00317693, 0x002F7693, 0x002F7592, 
        0x002F7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x0029718F,
  0x002A718F, 0x002A7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00367A96, 0x00367A97, 
        0x00367B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003C7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042829E, 
        0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x00396B80, 0x00060B0D, 0x00000000, 0x00284958, 0x004B89A3, 0x004B89A3, 0x004C89A4, 0x004C8AA4, 0x004D8AA4, 
        0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x003F6F84, 0x000A1114, 0x00000000, 0x00284754, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005791AA, 0x005792AA, 
        0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AE, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x004A7587, 0x0029414B, 
        0x00010203, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00111A1E, 0x00395865, 0x006397AE, 0x00659DB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 
        0x00699EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B8, 0x006190A3, 0x000F1619, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000101, 0x00466876, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A5BB, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 
        0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BC, 0x0074A7BC, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 
        0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 
        0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0075A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BA, 0x0072A6BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 
        0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA2B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B7, 0x006CA0B6, 
        0x006BA0B6, 0x006AA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x001A282D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0035515D, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 
        0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 
        0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005690A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x00528EA7, 0x00375F70, 
        0x00010203, 0x00020405, 0x00345C6D, 0x00508DA6, 0x004E8BA4, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x00274957, 0x00000000, 0x00060B0D, 0x003A6C81, 0x004887A1, 0x004787A1, 0x004786A1, 
        0x004686A0, 0x004685A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 
        0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00387C98, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00347996, 0x00347996, 0x00337895, 0x00327894, 0x00327794, 0x00327794, 0x00317694, 0x00307693, 0x00307693, 
        0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002A7290, 0x002A7290,
  0x002A7290, 0x002B7290, 0x002C7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002F7592, 0x00307693, 0x00307693, 0x00307693, 0x00317694, 0x00327794, 0x00327895, 0x00327895, 0x00347895, 0x00347995, 0x00357996, 0x00357A96, 0x00367A97, 0x00367B97, 
        0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E7F9B, 0x003E809C, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 
        0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x003D7288, 0x00060B0D, 0x00000000, 0x00213E4A, 0x004A87A1, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 
        0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x003F7084, 0x00070C0E, 0x00000000, 0x00294755, 0x00508DA6, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 
        0x005893AB, 0x005893AB, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006098B0, 0x006098B0, 0x006097AE, 
        0x00598CA1, 0x00283F48, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x000A1012, 0x003F616E, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 
        0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x003A5661, 0x00010102, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x000D1315, 0x00608D9F, 0x0070A4BA, 0x0071A4BA, 0x0071A4BA, 0x006390A3, 0x00213036, 0x00527786, 0x0072A5BA, 0x0072A5BA, 0x0072A5BB, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BC, 
        0x0074A7BC, 0x0075A7BC, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 
        0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0078A9BD, 0x0077A9BD, 0x0078A9BD, 
        0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 
        0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A5BA, 0x0072A5BB, 0x0072A5BB, 0x0072A5BA, 0x0072A5BA, 
        0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 
        0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00456877, 0x00030405, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0010181C, 0x005A899D, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 
        0x00649BB2, 0x00639BB2, 0x00649AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006198B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005D97AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 
        0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00528EA7, 
        0x003D6A7D, 0x00030607, 0x00000000, 0x00315767, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004B89A3, 0x004B89A3, 0x004A87A1, 0x00213D49, 0x00000000, 0x00060B0D, 0x003D7288, 0x004887A1, 0x004787A1, 
        0x004786A1, 0x004686A0, 0x004586A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042829D, 0x0041829E, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 
        0x003B7E9A, 0x003B7D9A, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347995, 0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 
        0x002F7693, 0x002F7592, 0x002E7492, 0x002E7492, 0x002D7391, 0x002C7491, 0x002C7391, 0x002B7290, 0x002A7290,
  0x002A7290, 0x002C7290, 0x002C7391, 0x002C7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317694, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347996, 0x00357996, 0x00357996, 0x00367A97, 0x00367A97, 0x00367B97, 
        0x00387B98, 0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7E99, 0x003B7E99, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 
        0x0043849E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x003F778E, 0x000C171B, 0x00000000, 0x00182D36, 0x004A89A3, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 
        0x004E8CA5, 0x004F8CA5, 0x0041748A, 0x00091114, 0x00000000, 0x0025414D, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538FA7, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005892AA, 
        0x005993AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D95AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006098B0, 0x006199AF, 0x006198B0, 0x006199B0, 
        0x00629AB0, 0x00629AB1, 0x00588BA0, 0x0023363F, 0x00080D10, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1315, 0x00456978, 0x006293A8, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 
        0x006A9FB5, 0x006A9FB6, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006C9FB4, 0x000C1215, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00070A0B, 0x00324953, 0x0036505A, 0x001D2A2F, 0x00050809, 0x002D424A, 0x006A9BAE, 0x0073A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A7BC, 0x0076A8BD, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 
        0x0078A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 
        0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BD, 0x0078A9BD, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 
        0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0075A6BB, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A5BA, 0x0073A5BA, 
        0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 
        0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B5, 0x006AA0B5, 0x006395AA, 0x0019262B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00385562, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB2, 
        0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB0, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 
        0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AB, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA7, 
        0x00528EA7, 0x00376071, 0x0005080A, 0x00000000, 0x00345B6C, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x00182D36, 0x00000000, 0x000C181C, 0x003F778E, 0x004787A1, 
        0x004787A1, 0x004786A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 
        0x003C7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317694, 0x00307694, 
        0x00307693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002B7290,
  0x002B7390, 0x002C7390, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B98, 
        0x00387C98, 0x00397C98, 0x00397D99, 0x00397D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 
        0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x0044819B, 0x00112026, 0x00000000, 0x001E3742, 0x004A88A3, 0x004B89A3, 0x004B89A4, 0x004C8AA3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 
        0x004F8CA5, 0x003F7084, 0x00091114, 0x00000000, 0x002C4D5B, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AB, 0x005893AB, 0x005893AB, 
        0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005C95AD, 0x005C95AD, 0x005C95AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 
        0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00528093, 0x00314C57, 0x000B1214, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00141E22, 0x00395763, 0x006192A6, 0x006A9FB6, 
        0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006DA2B8, 0x006EA2B8, 0x006EA3B8, 0x006FA3B8, 0x006FA2B8, 0x0070A3B9, 0x006FA3B9, 0x0070A3B9, 0x00466572, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00293C43, 0x005D8697, 0x0073A6BB, 0x0074A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A7BC, 
        0x0075A7BC, 0x0076A8BD, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0078AABE, 0x0079AABE, 
        0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 
        0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0079A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079A9BE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BE, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0078A8BD, 0x0077A9BD, 0x0077A9BD, 
        0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0075A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 
        0x0073A6BB, 0x0073A5BB, 0x0073A5BB, 0x0072A5BB, 0x0072A5BA, 0x0071A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006FA3B8, 0x006EA3B8, 0x006DA2B8, 0x006DA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x00436574, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00111A1D, 0x00679DB4, 0x00689EB4, 0x00679EB4, 0x00669DB4, 0x00669DB3, 0x00669CB3, 
        0x00659CB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F97AE, 0x005E97AE, 0x005D97AE, 0x005D96AE, 
        0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B94AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005691A9, 0x005691A9, 0x005591A9, 0x005490A8, 0x005490A8, 0x00548FA8, 0x00538FA8, 
        0x00538EA7, 0x00528EA7, 0x00396475, 0x00030607, 0x00020304, 0x00345C6C, 0x004F8CA6, 0x004E8BA4, 0x004F8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x004988A2, 0x001C333E, 0x00000000, 0x00112026, 0x0044829B, 
        0x004887A1, 0x004787A1, 0x004786A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003D809B, 0x003C7F9B, 
        0x003C7F9A, 0x003C7E9A, 0x003B7D9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 0x00327894, 0x00327794, 0x00317793, 
        0x00307693, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7492, 0x002C7391, 0x002B7391, 0x002B7390,
  0x002B7390, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002F7593, 0x002F7593, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00347895, 0x00347995, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C97, 
        0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 
        0x0044859F, 0x0045859F, 0x004585A0, 0x004586A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A2, 0x000F1C21, 0x00000000, 0x00000000, 0x00213E4A, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 
        0x003E6F84, 0x00070C0E, 0x00000000, 0x002C4D5B, 0x00518DA6, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005791AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005993AB, 
        0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E96AE, 0x005E96AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00629AB1, 
        0x00639AB1, 0x00639BB1, 0x00639BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x006092A8, 0x00203138, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x000C1214, 0x0036505C, 
        0x006A9EB4, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x00040607, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00161F23, 0x005C8697, 0x0071A3B8, 0x0074A6BB, 0x0074A6BB, 0x0074A6BC, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 
        0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 
        0x0079AABE, 0x0079AABE, 0x0079AABE, 0x007AAABE, 0x007AAABF, 0x007AAABF, 0x007AABBF, 0x007AAABF, 0x0078A8BC, 0x0074A2B6, 0x0072A0B3, 0x00709DB0, 0x00709DB0, 0x00719FB2, 0x0074A2B6, 0x0078A7BC, 0x007AAABF, 0x007AAABF, 0x007AABBF, 0x007AAABF, 
        0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AABBE, 0x007AAABF, 0x0079AABE, 0x0079AABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 
        0x0078A9BD, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 
        0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 
        0x006EA2B8, 0x006EA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006A9DB3, 0x00050809, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00568295, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00679DB3, 0x00669DB4, 
        0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 
        0x005D96AE, 0x005C95AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A8, 0x00548FA8, 
        0x00538FA8, 0x00528EA8, 0x00528EA7, 0x003F6E82, 0x00030607, 0x00000000, 0x00325969, 0x00508CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00427A91, 0x0004080A, 0x00000000, 0x000F1C21, 
        0x004987A2, 0x004887A1, 0x004786A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849E, 0x0043839F, 0x0043839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 
        0x00317793, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 0x002B7391,
  0x002C7391, 0x002C7391, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 
        0x00397C99, 0x003A7D98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 
        0x0045859F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004786A0, 0x001A3039, 0x00000000, 0x0004080A, 0x00030607, 0x00000000, 0x00182D35, 0x0049869F, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x0042768C, 
        0x000A1114, 0x00000000, 0x0025414D, 0x00528EA7, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 
        0x005A94AC, 0x005B94AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x001E2E35, 0x00000000, 0x00060A0C, 0x00060A0C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x0005080A, 0x0042626F, 0x00679AAF, 0x006CA0B6, 0x006DA2B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA3B8, 0x006FA3B9, 0x006FA3B8, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0071A5BA, 0x0071A4BA, 0x00182328, 0x00000000, 
        0x00000000, 0x00000000, 0x00090D0F, 0x00456370, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 
        0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079A9BE, 0x0079AABE, 0x0079AABE, 0x0078A8BC, 0x0075A5B8, 0x0073A2B6, 0x0072A0B4, 0x006F9CAE, 0x006791A3, 0x00587C8B, 0x00486571, 
        0x00374D56, 0x002C3E45, 0x00212F35, 0x00161E22, 0x000C1113, 0x00060809, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x000B0F11, 
        0x00121A1D, 0x00202C32, 0x002B3C43, 0x00364B54, 0x0045616C, 0x00547684, 0x00648D9E, 0x006E9AAD, 0x0072A0B3, 0x0074A2B6, 0x0076A4B9, 0x0078A8BB, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 
        0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BD, 0x0076A7BC, 0x0075A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BB, 
        0x0074A6BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA2B8, 
        0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x002A3F47, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002A3F48, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 
        0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB0, 0x006199B0, 0x006199B0, 0x006198B0, 0x006098B0, 0x005F98AF, 0x005F98AF, 0x005F97AE, 0x005E97AE, 
        0x005E96AE, 0x005D96AE, 0x005C96AD, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x005490A8, 
        0x00548FA8, 0x00538FA8, 0x00528FA7, 0x00528EA7, 0x00396475, 0x0005080A, 0x00000000, 0x00355E6F, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x0041798F, 0x00080F12, 0x00000000, 0x00010303, 0x00000000, 
        0x001A3039, 0x004786A0, 0x004787A1, 0x004787A1, 0x004686A0, 0x004685A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0042839E, 0x0042829E, 0x0041829E, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003E809B, 
        0x003D809B, 0x003C7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x003A7D99, 0x00397D98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347996, 0x00347895, 0x00327895, 0x00327894, 0x00327794, 
        0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7391, 0x002C7391,
  0x002C7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347996, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 
        0x00397D98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 
        0x004585A0, 0x004586A0, 0x004786A0, 0x004786A0, 0x004786A1, 0x004887A1, 0x00264654, 0x00000000, 0x00081013, 0x003D7187, 0x002D5262, 0x00010303, 0x00000000, 0x00162931, 0x00467F95, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x00457A91, 0x000C161A, 
        0x00000000, 0x00294754, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 
        0x005B94AD, 0x005B95AC, 0x005C95AD, 0x005C96AD, 0x005D96AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x000F171A, 0x00000000, 0x00344F5A, 0x00588799, 0x002B424B, 0x000B1113, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x000E1619, 0x003C5A66, 0x005E8C9F, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x006999AC, 0x00000000, 0x00000000, 
        0x00090D0F, 0x00324751, 0x006895A7, 0x0074A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 
        0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x006F9CAF, 0x00628A9B, 0x00557886, 0x00496672, 0x003A515B, 0x002A3A41, 0x001B262B, 0x000C1113, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030505, 0x000A0E0F, 0x000D1214, 0x0011181A, 0x00151D21, 0x00080C0D, 0x00000000, 0x00040607, 0x00182125, 0x00040607, 0x00000000, 0x000A0E0F, 0x00121A1D, 0x00000000, 0x00000000, 0x00020404, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080C0D, 0x00182226, 0x0026353B, 0x00364C55, 0x0046626E, 0x00537482, 0x00608696, 0x006D98AA, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x007AAABE, 
        0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A7BC, 0x0076A8BC, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B8, 
        0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x00557E8E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090D0F, 0x005D8B9F, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 
        0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006198B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 
        0x005E97AF, 0x005E96AE, 0x005E96AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005490A9, 
        0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00528EA7, 0x00365F6F, 0x00020405, 0x00030607, 0x00396577, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA4, 0x004D8BA4, 0x0039677B, 0x00080E11, 0x00000000, 0x000C161A, 0x002F5767, 0x00081013, 
        0x00000000, 0x00264655, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0041839E, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 
        0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 
        0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391,
  0x002D7491, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00307694, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00337895, 0x00347996, 0x00357A96, 0x00357A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C99, 
        0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x0045859F, 
        0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A2, 0x002D5566, 0x00000000, 0x00030607, 0x003E7389, 0x004B89A3, 0x004B8AA3, 0x00345F71, 0x00010202, 0x00000000, 0x000E1A1F, 0x00467F96, 0x004F8CA5, 0x00488098, 0x000B1518, 0x00000000, 
        0x00294754, 0x00518DA6, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 
        0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x006194AA, 0x00090E10, 0x00020303, 0x003E5E6B, 0x006A9FB5, 0x006A9FB5, 0x005B889B, 0x0036515D, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D1316, 0x002C4149, 0x006391A5, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0070A1B6, 0x001A252A, 0x00000000, 0x00293B43, 
        0x005F899A, 0x0074A7BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079A9BE, 
        0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x006B96A9, 0x004E6E7B, 0x0032474F, 0x001B262A, 0x00121A1D, 0x000B1012, 0x00030505, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000F1618, 0x001F2C31, 0x002F4249, 0x00395059, 
        0x00030405, 0x00070A0C, 0x004D6B77, 0x00638A9A, 0x00668D9E, 0x006992A3, 0x006A94A5, 0x006C97A8, 0x00729EB0, 0x002D3E46, 0x00000000, 0x00192327, 0x0079A7BB, 0x00172024, 0x00000000, 0x00384E57, 0x00719DB0, 0x00020303, 0x00000000, 0x004B6874, 
        0x00648A9B, 0x005F8494, 0x00587B89, 0x004F6D7A, 0x00405964, 0x00344850, 0x00151E21, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x000A0E0F, 0x0011181A, 0x00192428, 0x002D3F47, 0x00486571, 0x00658E9E, 
        0x007AAABF, 0x007AABBF, 0x007AAABF, 0x0079ABBF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0076A8BD, 
        0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A6BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A4BA, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 
        0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006A9CB1, 0x001E2D33, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00344D57, 0x006BA0B6, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 
        0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB1, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x00629AB0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 
        0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D95AD, 0x005C95AD, 0x005B94AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 
        0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00538EA8, 0x00528EA7, 0x003B6779, 0x00000000, 0x00040708, 0x00407286, 0x004F8DA6, 0x004E8BA4, 0x004E8CA5, 0x00366072, 0x00060A0C, 0x00000000, 0x000C161B, 0x0040758B, 0x004B89A3, 0x003E7288, 
        0x00030607, 0x00000000, 0x002E5666, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A0, 0x004585A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0041829D, 0x0040819C, 0x003F819C, 0x003F809C, 
        0x003E809C, 0x003E7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00377B97, 0x00357A96, 0x00357996, 0x00357996, 0x00337895, 0x00337895, 0x00337895, 
        0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491,
  0x002D7492, 0x002D7492, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377C98, 0x00387C98, 0x00397C99, 0x003A7D99, 
        0x003A7E99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0043849F, 0x0044859F, 0x004585A0, 0x004585A0, 
        0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x0037677C, 0x00000000, 0x00020405, 0x00366477, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x003C6C80, 0x0005090A, 0x00000000, 0x00070C0E, 0x003D6C7F, 0x00101D23, 0x00000000, 0x001C313A, 
        0x00518EA7, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00548FA9, 0x005490A8, 0x005590A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AB, 0x005893AB, 0x005993AB, 0x005994AC, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 
        0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659BB2, 
        0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00568294, 0x00070B0C, 0x00030506, 0x004B7181, 0x006A9FB5, 0x006A9FB6, 0x006A9FB6, 0x006BA0B6, 0x00679AB0, 0x002D444E, 0x00020303, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00273A42, 0x005E8A9C, 0x0071A4B9, 0x0070A3B9, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0072A3B9, 0x005C8597, 0x00131B1F, 0x000A0F11, 0x00577C8C, 0x0074A7BB, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0078A9BD, 0x0078A8BD, 
        0x0072A1B5, 0x00527482, 0x002C3E45, 0x000A0E0F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x000B0F11, 0x00243238, 0x003D5660, 0x00567886, 0x006E99AA, 0x007BABBF, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 
        0x00090D0F, 0x00070A0B, 0x005D8190, 0x007CACC0, 0x007DACC0, 0x007DACC0, 0x007CACC0, 0x007DACC0, 0x007DACC0, 0x0032464E, 0x00000000, 0x001C282C, 0x007DADC1, 0x00192327, 0x00000000, 0x003F5861, 0x007DADC0, 0x00020404, 0x00000000, 0x005C7E8D, 
        0x007CACC0, 0x007DACC0, 0x007CACC0, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x003C535D, 0x00000000, 0x00253339, 0x00709CAE, 0x005C808F, 0x00435D68, 0x002A3A41, 0x000F1518, 0x00020303, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00030405, 0x00212F35, 0x00496773, 0x006E9AAD, 0x0079A9BD, 0x0079A9BD, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 
        0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0070A3B8, 0x0071A4B9, 
        0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x00476977, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090E10, 0x006597AC, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00699FB5, 
        0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006098AF, 0x006098AF, 
        0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C96AD, 0x005B95AD, 0x005B94AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 
        0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA7, 0x00528EA7, 0x00335969, 0x00010202, 0x00010303, 0x0044778D, 0x004F8CA6, 0x00325B6B, 0x00000000, 0x00000000, 0x00101C22, 0x0049859E, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 
        0x00356376, 0x00020405, 0x00000000, 0x0038697D, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0041839E, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F819C, 
        0x003F809B, 0x003E809B, 0x003D7F9B, 0x003D7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A96, 0x00357A96, 0x00347A96, 0x00347995, 0x00337895, 0x00337895, 
        0x00337895, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7492, 0x002D7492,
  0x002D7491, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317793, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367B97, 0x00377B97, 0x00387B97, 0x00387C98, 0x00397C99, 0x00397D98, 0x003A7D99, 
        0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x004485A0, 0x0045859F, 0x004685A0, 
        0x004686A1, 0x004786A1, 0x004887A1, 0x003C7289, 0x00060B0D, 0x00000000, 0x00274956, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x003C6B80, 0x000B1417, 0x00000000, 0x00000000, 0x00000000, 0x00192D35, 0x00518EA7, 
        0x00528EA7, 0x00528EA8, 0x00538FA7, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x005893AB, 0x005993AB, 0x005A93AC, 0x005A93AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 
        0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x005F98B0, 0x006098AF, 0x006199B0, 0x006199B0, 0x006199B1, 0x00629AB0, 0x00639AB1, 0x00639BB1, 0x00639BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 
        0x00669CB3, 0x00669CB3, 0x00679CB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x004A7081, 0x00040607, 0x00050809, 0x00588597, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B7, 0x006CA1B7, 0x005E8C9F, 0x00293D45, 0x000B1114, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00172125, 0x003B5661, 0x004E7180, 0x00517484, 0x00415E69, 0x001D2A30, 0x0006090B, 0x0039525D, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0076A6BA, 0x006791A2, 0x00577A89, 0x003A525C, 0x00182226, 
        0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x000E1416, 0x001B262A, 0x001F2C31, 0x00000000, 0x0011181B, 0x006C96A7, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 
        0x00131A1D, 0x00030405, 0x00547482, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x0032454D, 0x00000000, 0x001C282C, 0x007EADC1, 0x00192328, 0x00000000, 0x003F5761, 0x007DADC1, 0x00010203, 0x00000000, 0x005B7E8D, 
        0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC0, 0x007DADC1, 0x002C3D44, 0x00000000, 0x002E4047, 0x007CACC1, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x0078A6B9, 0x00608695, 0x00486470, 0x002F4249, 0x001D292D, 0x000C1113, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0011181A, 0x00334750, 0x00527481, 0x00648D9E, 0x0074A2B6, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 
        0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A7BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x00628EA0, 0x00364E58, 0x005E899C, 
        0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x00578091, 0x0006080A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00436572, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 
        0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006199B1, 0x006299B0, 0x006199B0, 0x006198B0, 
        0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005A93AB, 0x005993AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 
        0x005691AA, 0x005590A9, 0x005590A8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x00528EA7, 0x00294956, 0x00000000, 0x000A1316, 0x00284653, 0x00000000, 0x00000000, 0x00192D35, 0x0049859C, 0x004D8AA4, 0x004C8AA4, 0x004C89A3, 0x004B89A3, 
        0x004B89A3, 0x00274856, 0x00000000, 0x00060C0E, 0x003D7289, 0x004787A1, 0x004786A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849E, 0x0043849E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 
        0x003F819C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357996, 0x00347995, 0x00337895, 
        0x00337895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002D7492,
  0x002E7592, 0x002E7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347996, 0x00347996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 
        0x003B7E99, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E7F9B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004686A0, 
        0x004786A1, 0x004887A1, 0x0045819A, 0x00101E24, 0x00000000, 0x00203B46, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x0043778D, 0x00000101, 0x00000000, 0x001A2E37, 0x004E8AA2, 0x00528EA7, 
        0x00528EA7, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 
        0x005D96AE, 0x005D97AE, 0x005E97AE, 0x005F97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B1, 0x006299B1, 0x00639AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 
        0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x003F5F6C, 0x00020303, 0x00070B0C, 0x006699AE, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B7, 0x006EA2B8, 0x005B8799, 0x0038525D, 
        0x00050809, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00364D57, 0x00648FA2, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 
        0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x00618898, 0x003C545F, 0x00212E34, 0x000F1517, 0x00000000, 0x00000000, 0x00000000, 
        0x00090D0E, 0x0027363C, 0x0044606B, 0x005A7D8C, 0x006891A1, 0x0077A5B9, 0x0074A1B3, 0x00010203, 0x000C1012, 0x00668E9E, 0x007DADC1, 0x007DADC0, 0x007DADC1, 0x007DADC0, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007EADC1, 
        0x00202D31, 0x00000000, 0x004C6874, 0x007EADC1, 0x007EAEC1, 0x007EAEC1, 0x007EAEC1, 0x007EAEC1, 0x007EAEC1, 0x0032464D, 0x00000000, 0x001C272B, 0x007EAEC1, 0x001A2428, 0x00000000, 0x003F5761, 0x007EAEC2, 0x00020303, 0x00000000, 0x005C7F8D, 
        0x007EAEC1, 0x007EAEC1, 0x007EAEC1, 0x007EADC1, 0x007EAEC1, 0x007EADC1, 0x001F2A2F, 0x00000000, 0x00384E57, 0x007EADC1, 0x007EADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007CACC0, 0x003D545E, 
        0x00000000, 0x000E1315, 0x002D3E46, 0x00101619, 0x00000000, 0x00000000, 0x00000000, 0x000B1012, 0x001D282D, 0x00364B54, 0x005B7E8D, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x007AAABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 
        0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x006897AA, 0x002F444D, 0x000C1113, 
        0x0023333A, 0x00354D57, 0x002A3D45, 0x00080C0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001A272C, 0x006EA2B8, 0x006EA2B7, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 
        0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006299B1, 0x006199B0, 
        0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 
        0x005791AA, 0x005690A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x00528EA7, 0x00294855, 0x00000000, 0x00000000, 0x00000000, 0x00233E4A, 0x004A849C, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 
        0x004B89A3, 0x004B89A3, 0x001F3B46, 0x00000000, 0x00101E24, 0x0045829C, 0x004887A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 
        0x003F819C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00347996, 0x00347995, 
        0x00337895, 0x00327895, 0x00327894, 0x00317794, 0x00307794, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7592,
  0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00317693, 0x00317794, 0x00327795, 0x00337895, 0x00337895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003A7E9A, 
        0x003C7E9A, 0x003C7F9A, 0x003D7F9A, 0x003D7F9B, 0x003E809C, 0x003F809B, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A0, 
        0x004887A1, 0x004887A1, 0x00182E37, 0x00000000, 0x00162931, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x001F3741, 0x00000000, 0x00122026, 0x004C839B, 0x00528EA7, 0x00528EA7, 
        0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005690A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AD, 
        0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669DB3, 0x00669DB3, 0x00679DB3, 
        0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x00334D58, 0x00000000, 0x000D1316, 0x006BA0B6, 0x006CA1B6, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006DA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006EA2B7, 
        0x006B9BB1, 0x00344C56, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001B272C, 0x006592A4, 0x0074A5BA, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BD, 
        0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078AABE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x00709CAF, 0x003F5863, 0x0010171A, 0x00020404, 0x00000101, 0x00000000, 0x00000000, 0x000D1315, 0x00384E58, 0x00638B9B, 
        0x0077A5B9, 0x007AA9BC, 0x007BABBF, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007DACC0, 0x0011181B, 0x00020303, 0x00577886, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007EAEC1, 0x007EADC1, 0x007EAEC1, 0x007EAEC1, 0x007EAEC2, 
        0x0030424A, 0x00000000, 0x00435C66, 0x007FAEC2, 0x007FAEC2, 0x007EAEC2, 0x007FAEC1, 0x007FAEC2, 0x007FAEC2, 0x0033464E, 0x00000000, 0x001D282C, 0x007FAEC2, 0x001A2428, 0x00000000, 0x00405862, 0x007FAEC2, 0x00020404, 0x00000000, 0x005D7F8E, 
        0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007EAEC1, 0x00161E22, 0x00010202, 0x00455F69, 0x007EAEC1, 0x007EAEC1, 0x007EAEC1, 0x007EADC1, 0x007EADC1, 0x007EADC1, 0x007EADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x002C3D44, 
        0x00000000, 0x0028383E, 0x007CACC0, 0x0079A7BB, 0x006B95A7, 0x00435D68, 0x00161F22, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x000A0E10, 0x00344850, 0x006791A2, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0079AABF, 0x0079AABE, 
        0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x00638EA0, 
        0x00172125, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00598395, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00659CB3, 0x00659BB2, 0x00659CB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006299B0, 
        0x006199B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005B95AC, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AC, 0x005893AB, 0x005892AB, 0x005792AA, 
        0x005791AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x00518CA5, 0x0026434F, 0x00000000, 0x00091114, 0x00508DA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00162830, 0x00000000, 0x00192F38, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004485A0, 0x0044849F, 0x0043839F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 
        0x0040819D, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 
        0x00347995, 0x00337895, 0x00327894, 0x00327794, 0x00317694, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592,
  0x002E7592, 0x00307693, 0x00307693, 0x00307794, 0x00317794, 0x00327795, 0x00327895, 0x00337895, 0x00347996, 0x00357996, 0x00357996, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7E9A, 0x003B7E9A, 
        0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A0, 0x004786A1, 
        0x004887A1, 0x00254553, 0x00000000, 0x000C171B, 0x00447E96, 0x004B89A3, 0x004C89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x002D505F, 0x00000000, 0x00091114, 0x00467B90, 0x00528EA7, 0x00528EA7, 0x00538FA8, 
        0x00548FA8, 0x005490A8, 0x005490A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AB, 0x005892AB, 0x005892AB, 0x005993AB, 0x005994AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C96AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 
        0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB4, 0x00669DB3, 0x00679DB4, 
        0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00689DB2, 0x00283C45, 0x00000000, 0x001C2A30, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 
        0x0070A4B9, 0x0071A4B9, 0x005B8596, 0x000C1215, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000F1518, 0x00486875, 0x0075A6BC, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 
        0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0076A6BA, 0x006A96A7, 0x00517280, 0x00202D32, 0x00000000, 0x00000000, 0x00000000, 0x00090C0E, 0x00000000, 0x00101619, 0x00618898, 0x007CACC0, 0x007CACC0, 0x007CACC0, 
        0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007DADC0, 0x007DADC0, 0x007DADC1, 0x007DADC1, 0x002F4149, 0x00000000, 0x00455E69, 0x007DACC0, 0x007EADC1, 0x007EAEC1, 0x007EAEC2, 0x007EAEC1, 0x007FAEC1, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 
        0x003D535D, 0x00000000, 0x0034474F, 0x007DABBF, 0x007FAFC2, 0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 0x007FAEC2, 0x0033464E, 0x00000000, 0x001D282C, 0x0080AFC2, 0x001B2529, 0x00000000, 0x00415963, 0x0080AEC2, 0x00030404, 0x00000000, 0x005D818F, 
        0x007FAFC2, 0x0080AEC2, 0x007FAFC2, 0x007FAEC2, 0x007FAEC2, 0x0079A6B9, 0x00101719, 0x00020303, 0x00516F7C, 0x007FAEC2, 0x007FAEC1, 0x007FAEC2, 0x007FAEC2, 0x007EAEC1, 0x007FAEC1, 0x007EAEC2, 0x007EADC1, 0x007EADC1, 0x007BA8BC, 0x00192327, 
        0x00000000, 0x00415A65, 0x007DADC1, 0x007DADC0, 0x007DADC1, 0x007DADC1, 0x007CACC0, 0x00719DB0, 0x0047636F, 0x001E2B30, 0x000D1215, 0x00020303, 0x00000000, 0x00000000, 0x00141C20, 0x00486470, 0x006791A2, 0x0075A4B7, 0x007AAABF, 0x0079AABF, 
        0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 
        0x0073A6BB, 0x00456471, 0x0010171A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001A272C, 0x006A9BAF, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 
        0x006299B0, 0x006199B0, 0x006099B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A93AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 
        0x005792AA, 0x005791AA, 0x005691A9, 0x005691A9, 0x005591A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538EA8, 0x00528EA7, 0x004E88A0, 0x00182B33, 0x00000000, 0x001A2E36, 0x004E8BA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 
        0x004C8AA4, 0x004C89A3, 0x004B89A3, 0x00447E96, 0x000C161B, 0x00000000, 0x00254653, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A1, 0x004585A0, 0x004585A0, 0x004584A0, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041839D, 0x0041829D, 
        0x0041829D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E99, 0x003B7D99, 0x00397D98, 0x00397C98, 0x00387C98, 0x00377C98, 0x00377B97, 0x00377B97, 0x00367A96, 0x00357A96, 0x00357996, 
        0x00347996, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317793, 0x00307694, 0x002F7693, 0x002F7592,
  0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 
        0x003C7E9A, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 
        0x00305A6C, 0x00000101, 0x00030607, 0x00396A7E, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x00396578, 0x00020304, 0x0005090B, 0x0043758A, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 
        0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 
        0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B1, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 
        0x00689EB4, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006B9FB6, 0x006597AC, 0x001D2C32, 0x00000000, 0x00304751, 0x006DA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B9, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 
        0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x003D5964, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090D0E, 0x003E5965, 0x006D9CB0, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 
        0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0075A4B8, 0x0050707D, 0x002C3E46, 0x000D1214, 0x00000000, 0x00000000, 0x00070A0B, 0x00293A41, 0x004A6773, 0x00618797, 0x00020404, 0x00090D0F, 0x00658C9C, 0x007CACC1, 0x007DACC1, 0x007DADC1, 
        0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007EADC1, 0x007EADC1, 0x007EAEC1, 0x007EAEC2, 0x00547481, 0x00000000, 0x002E4047, 0x007CA9BD, 0x007FAEC2, 0x007FAEC2, 0x007FAFC2, 0x0080AEC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x007FAFC2, 0x007FAFC2, 
        0x004D6975, 0x00000000, 0x0027353B, 0x006E95A6, 0x006D95A6, 0x00678C9C, 0x00638695, 0x005F8392, 0x005F8392, 0x00233036, 0x00000000, 0x00131A1D, 0x00618493, 0x0012191C, 0x00000000, 0x0032434B, 0x00688E9D, 0x00020203, 0x00000000, 0x00587784, 
        0x007DAABD, 0x0080AFC3, 0x0080AFC3, 0x0081AFC3, 0x0080AFC3, 0x00739DAF, 0x000D1214, 0x00030405, 0x005F8290, 0x0080AFC2, 0x007FAFC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x007FAFC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x006D95A6, 0x000F1517, 
        0x00000000, 0x005E818F, 0x007EADC1, 0x007EADC1, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007DADC1, 0x007DADC1, 0x007DADC0, 0x006C95A6, 0x0051717E, 0x00172124, 0x00000000, 0x00000000, 0x00000000, 0x00070A0B, 0x0025343B, 0x00486470, 0x006F9BAD, 
        0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 
        0x0074A6BB, 0x0074A6BB, 0x006795A8, 0x003B5661, 0x00090D0F, 0x00000000, 0x00000000, 0x00000000, 0x002A3D44, 0x006EA0B4, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 
        0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649AB1, 0x00639AB1, 
        0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AB, 0x005993AB, 0x005993AB, 
        0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x004C839B, 0x000F1A1F, 0x00000000, 0x00284753, 0x00508CA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 
        0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x0039697E, 0x00030607, 0x00000101, 0x00305A6C, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041839E, 
        0x0041829D, 0x0040829D, 0x0040819C, 0x003F809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00367B97, 0x00367A97, 0x00367A96, 0x00357996, 
        0x00357996, 0x00347995, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7693,
  0x002F7693, 0x00307693, 0x00317694, 0x00327794, 0x00327794, 0x00337895, 0x00337995, 0x00347995, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 
        0x003D7F9A, 0x003D809B, 0x003E809C, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x003E758C, 
        0x00070D10, 0x00000000, 0x0030596A, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA6, 0x0042778C, 0x00020304, 0x00010303, 0x003E6D81, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 
        0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 
        0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006192A6, 0x00131C20, 0x00000000, 0x00436472, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 
        0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x00456471, 0x00000101, 0x00000000, 0x00000000, 0x0030454E, 0x006C9AAD, 0x0074A6BB, 0x0075A7BC, 0x0075A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 
        0x0079AABE, 0x0079AABE, 0x00719FB2, 0x0039505A, 0x000C1113, 0x00030405, 0x00000000, 0x00000000, 0x00161F23, 0x004F6D7B, 0x00709BAD, 0x0078A6B9, 0x007CACC0, 0x007CACC0, 0x00253339, 0x00000000, 0x004A6672, 0x007DACC0, 0x007DADC1, 0x007EADC1, 
        0x007EADC1, 0x007EAEC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC1, 0x007FAEC2, 0x006F98A9, 0x00000000, 0x00101619, 0x007AA8BA, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x007AA7B9, 0x00688E9E, 0x0053727F, 0x00415964, 0x0031424A, 0x00222F34, 
        0x000F1416, 0x00000000, 0x00030405, 0x000A0D0F, 0x00090D0E, 0x00080B0C, 0x0007090A, 0x00060809, 0x00060809, 0x00010202, 0x00000000, 0x00000000, 0x00050708, 0x00000000, 0x00000000, 0x00030404, 0x00070A0B, 0x00000000, 0x00000000, 0x00090C0D, 
        0x000E1315, 0x0012191C, 0x001A2428, 0x0029383E, 0x00394E57, 0x003C525B, 0x00070A0B, 0x00040606, 0x006E96A6, 0x0080AFC3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC3, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x005D818F, 0x00060809, 
        0x00010203, 0x0079A5B8, 0x007FAEC2, 0x007EAEC2, 0x007FAEC2, 0x007EADC1, 0x007EAEC1, 0x007EADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x0079A8BB, 0x001F2C31, 0x00000000, 0x00243339, 0x0027363C, 0x00000000, 0x00000000, 0x00010202, 0x00090C0E, 
        0x002C3E45, 0x006892A3, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 
        0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x006593A5, 0x00293B43, 0x00000000, 0x00000000, 0x000E1517, 0x006A9AAF, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 
        0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00659CB2, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00639AB2, 
        0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D95AD, 0x005C96AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 
        0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x004C849B, 0x00070D0F, 0x00000000, 0x00366071, 0x004F8DA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 
        0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x0030596A, 0x00000000, 0x00070E11, 0x003E758D, 0x004887A1, 0x004787A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 
        0x0041829D, 0x0040829D, 0x0040819D, 0x003F819D, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B98, 0x00367B97, 0x00367A97, 0x00357A96, 
        0x00357996, 0x00347996, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693,
  0x00307693, 0x00317693, 0x00317794, 0x00317794, 0x00327894, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00367B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 
        0x003D7F9B, 0x003E809C, 0x003E809B, 0x003F809C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004887A1, 0x0046849E, 0x00112027, 
        0x00000000, 0x00213E4A, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x00487F96, 0x00070C0E, 0x00010202, 0x002E5160, 0x00518EA7, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 
        0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005B95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 
        0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB4, 0x00699EB5, 
        0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x005E8B9F, 0x00080C0E, 0x00000000, 0x00567F90, 0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 
        0x0072A5BA, 0x0073A5BB, 0x006C9CB0, 0x001B272C, 0x00020303, 0x00141D21, 0x005C8495, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0076A6B9, 
        0x006893A4, 0x0031444D, 0x00000000, 0x00000000, 0x00010202, 0x000A0E0F, 0x002B3D44, 0x00668E9F, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007DACC0, 0x007DADC0, 0x00597C8A, 0x00000000, 0x00243238, 0x007CAABE, 0x007EAEC1, 0x007EADC1, 
        0x007FAEC2, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007EACBF, 0x0077A4B5, 0x00050708, 0x00000000, 0x004B6672, 0x00394E57, 0x001F2B30, 0x00090C0D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 
        0x00060809, 0x0007090A, 0x00080B0D, 0x000A0E10, 0x000C1113, 0x00101618, 0x00131A1D, 0x00182124, 0x001B2428, 0x001B2529, 0x001A2327, 0x001B2428, 0x001B2529, 0x001B2428, 0x00182125, 0x00151D21, 0x0011181A, 0x000C1012, 0x000A0D0F, 0x000A0D0F, 
        0x00080B0C, 0x0007090A, 0x00040506, 0x00010101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x00131A1D, 0x002C3C43, 0x0047616B, 0x00628594, 0x00749DAF, 0x0078A4B6, 0x007CA9BC, 0x0080AFC2, 0x0080AFC2, 0x004C6975, 0x00000000, 
        0x00141C1F, 0x0080AFC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007EAEC2, 0x007EAEC1, 0x007EAEC1, 0x007EADC1, 0x007EADC1, 0x00668D9E, 0x000C1012, 0x00000000, 0x00648B9B, 0x007CADC1, 0x00709CAE, 0x00395059, 0x000E1315, 0x00030405, 
        0x00000000, 0x00000000, 0x00243238, 0x00628999, 0x0075A4B7, 0x007AAABF, 0x007AAABE, 0x0079AABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x00577C8D, 0x0010181B, 0x00000000, 0x002E434C, 0x006FA2B7, 0x0071A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 
        0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 
        0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005D97AE, 0x005D96AE, 0x005D95AD, 0x005C96AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A93AC, 0x005993AC, 
        0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528FA8, 0x00528EA7, 0x0044768A, 0x00040709, 0x00000000, 0x00417388, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 
        0x004E8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004A89A3, 0x00213E4A, 0x00000000, 0x00112027, 0x0046849E, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x0046859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 
        0x0042839E, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F809C, 0x003F809C, 0x003E809B, 0x003D809B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003A7E99, 0x003A7D99, 0x003A7D98, 0x00397C98, 0x00387C98, 0x00387B97, 0x00377B97, 0x00367B97, 0x00367A97, 
        0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317793, 0x00307693,
  0x00307693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00347895, 0x00347995, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 
        0x003D7F9B, 0x003E809B, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x004887A1, 0x001D3742, 0x00000000, 
        0x0015262E, 0x004886A0, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004B859E, 0x0015262D, 0x00000000, 0x00223C47, 0x00518EA7, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 
        0x005591A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 
        0x006098B0, 0x006099B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 
        0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x00598597, 0x00000000, 0x00000000, 0x00699CB1, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 
        0x0073A5BB, 0x005D8698, 0x001C292E, 0x00131B1E, 0x0044616E, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0075A4B8, 0x00527482, 0x00293940, 
        0x00000000, 0x00000000, 0x00000000, 0x001F2B30, 0x0046626E, 0x006F9BAD, 0x007BACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x0078A5B8, 0x00080B0C, 0x00000000, 0x0074A0B1, 0x007FAEC2, 0x007FAEC2, 
        0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 0x00729CAD, 0x005E818F, 0x004B6772, 0x00364A52, 0x001F2B30, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000B0F11, 0x00192327, 0x00253338, 0x00304249, 0x003D525B, 0x0048626D, 0x0054717E, 
        0x005E808E, 0x00688C9C, 0x007097A8, 0x0077A2B4, 0x007EAABD, 0x0082B1C4, 0x0082B1C4, 0x0082B0C4, 0x0083B0C4, 0x0082B1C4, 0x0082B1C4, 0x0082B1C4, 0x0082B1C4, 0x0083B1C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x007AA7B9, 0x00749EAF, 
        0x006C93A2, 0x00648896, 0x00597987, 0x004F6B77, 0x00435A64, 0x00374A53, 0x002A393F, 0x001F2A2F, 0x00131A1D, 0x00040606, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00141C1F, 0x002B3A41, 0x00415963, 0x00557381, 0x002F4047, 0x00000000, 
        0x003D535C, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x0080AEC2, 0x007FAFC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007EAEC1, 0x004F6D79, 0x00000000, 0x000E1416, 0x007EADC1, 0x007DADC1, 0x007DADC0, 0x007DADC1, 0x0077A5BA, 0x00506F7C, 
        0x00293A40, 0x00080C0D, 0x00000000, 0x00000000, 0x001E2A2F, 0x004A6774, 0x006F9CAE, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A4BA, 0x00405D69, 0x000D1315, 0x00212F35, 0x005A8395, 0x0070A2B8, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 
        0x006DA2B7, 0x006DA2B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00679EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 
        0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 
        0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005590A8, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x00528EA7, 0x00355B6C, 0x00000000, 0x00060B0D, 0x0043778C, 0x004F8CA6, 0x004E8BA5, 
        0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x004885A0, 0x0014262D, 0x00000000, 0x001E3843, 0x004887A2, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 
        0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397C99, 0x00397C99, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 
        0x00357A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00327894, 0x00317794, 0x00317794, 0x00307693,
  0x00317694, 0x00317794, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00357996, 0x00357A96, 0x00367A97, 0x00377A97, 0x00377B97, 0x00377C98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 
        0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004685A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x002A4F5E, 0x00000101, 0x00060C0F, 
        0x003F758B, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004D8BA5, 0x004F8CA5, 0x004F8CA5, 0x00233F4A, 0x00000000, 0x001B3038, 0x00508DA6, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005590A9, 
        0x005691AA, 0x005691AA, 0x005792AA, 0x005792AB, 0x005893AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C96AD, 0x005C96AD, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005E97AF, 0x005F98AF, 0x006098B0, 0x006098B0, 
        0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699EB4, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 
        0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x004D7282, 0x00000000, 0x00040607, 0x006EA3B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 
        0x0074A6BB, 0x005C8494, 0x00374F59, 0x006B99AC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x004C6A76, 0x00161F23, 0x00040606, 0x00000000, 
        0x00000000, 0x000B0F11, 0x00000000, 0x004E6C79, 0x007CACC0, 0x007DACC0, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007EADC1, 0x007FAEC2, 0x007DACC0, 0x002E4047, 0x00000000, 0x00445E68, 0x007FAFC2, 0x0080AFC2, 
        0x00648998, 0x003D545D, 0x001E292E, 0x00101518, 0x0007090A, 0x00000000, 0x00000000, 0x00000000, 0x0007090A, 0x00212E33, 0x003F555F, 0x00597886, 0x006A8F9F, 0x00719AAA, 0x0076A1B3, 0x007CA8BB, 0x0081AFC2, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 
        0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0083B1C5, 0x0084B2C4, 0x0084B1C4, 0x0084B2C5, 0x0084B1C4, 0x0084B1C5, 0x0083B1C5, 0x0083B2C5, 0x0083B2C5, 0x0083B1C5, 0x0084B1C4, 
        0x0083B1C4, 0x0084B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x007FACBE, 0x007AA5B6, 0x00759EAF, 0x006E95A6, 0x00648896, 0x004E6974, 0x0032444C, 0x00151D20, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00030405, 0x00000000, 
        0x00202C30, 0x00516F7B, 0x0076A2B3, 0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC3, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x007EACC0, 0x002A3B41, 0x00000000, 0x00405862, 0x007EAEC1, 0x007EAEC1, 0x007EAEC1, 0x007EADC1, 0x007DADC1, 0x007DADC1, 
        0x007AA8BC, 0x006992A2, 0x00405963, 0x00050708, 0x00000000, 0x00010202, 0x000F1518, 0x003C535D, 0x0076A5B9, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BE, 0x0077A8BD, 0x0076A8BD, 
        0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A7BB, 0x0074A6BB, 0x0073A6BB, 0x006896A9, 0x003C5762, 0x001B272C, 0x006694A8, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 
        0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 0x006A9FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 
        0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006299B0, 0x006199B0, 0x006099B0, 0x006098AF, 0x006097AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 
        0x005A94AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00294754, 0x00000000, 0x00132229, 0x004B849C, 0x004F8CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x003F758B, 0x00060C0F, 0x00000101, 0x002A4F5E, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0043849F, 
        0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7E9A, 0x003A7D99, 0x00397D98, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 
        0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337895, 0x00337895, 0x00327895, 0x00317794, 0x00317794,
  0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E7F9B, 
        0x003F809C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x003B6F85, 0x00070D10, 0x00000000, 0x00315B6C, 
        0x004B89A3, 0x004B8AA3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA4, 0x004E8BA5, 0x004F8CA5, 0x00345C6E, 0x00000000, 0x000E191E, 0x004D88A0, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691A9, 
        0x005692AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005993AB, 0x005A93AC, 0x005B94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006098B0, 
        0x006299B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 
        0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x003B5763, 0x00000000, 0x00162024, 0x006FA3B8, 0x006FA3B8, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 
        0x0074A7BB, 0x0074A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0078A9BD, 0x005A7E8D, 0x0012191C, 0x00000000, 0x00000000, 0x00040607, 0x0030444B, 
        0x0074A2B5, 0x00577886, 0x00000000, 0x00182226, 0x007CACC0, 0x007DADC1, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007EADC1, 0x004D6A76, 0x00000000, 0x000F1416, 0x0033464E, 0x0007090A, 
        0x00000000, 0x00000000, 0x00010202, 0x00030404, 0x000C1012, 0x002B3B41, 0x00516E7A, 0x00739BAD, 0x0082B0C4, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C4, 0x0083B1C4, 0x0083B1C5, 
        0x0084B1C5, 0x0084B1C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 
        0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B1C5, 0x0084B2C5, 0x0084B2C5, 0x0083B2C4, 0x0084B1C4, 0x0083B1C4, 0x0083B1C5, 0x0083B1C4, 0x0083B1C4, 0x0080ADC0, 0x00648896, 0x003E555E, 0x001A2427, 0x00040506, 0x00020203, 
        0x00000000, 0x00000000, 0x00000000, 0x00172023, 0x0046606B, 0x00719AAB, 0x007EABBF, 0x007FAEC1, 0x0080AFC3, 0x0080AFC2, 0x0078A5B7, 0x00040606, 0x00000000, 0x006E97A8, 0x007FAEC2, 0x007FAEC2, 0x007EAEC1, 0x007EAEC2, 0x007EAEC1, 0x007EADC1, 
        0x007EADC1, 0x007DADC1, 0x007DADC1, 0x007CABBE, 0x003B525B, 0x00000000, 0x00000000, 0x00000000, 0x00080B0C, 0x004A6774, 0x0077A7BB, 0x0079AABE, 0x007AAABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 
        0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0071A4B9, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 
        0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 
        0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 
        0x005B94AC, 0x005994AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00192D35, 0x00000000, 0x0025414C, 0x00508DA6, 
        0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004C8AA3, 0x004B89A3, 0x00315A6C, 0x00000000, 0x00070D10, 0x003B6F85, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 
        0x0043839E, 0x0042839E, 0x0042839D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397C99, 0x00397D99, 0x00397C98, 0x00377B98, 0x00377B97, 
        0x00367B97, 0x00357A97, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00317794,
  0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00347996, 0x00357996, 0x00357996, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00397C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 
        0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x0046849D, 0x0014262D, 0x00000000, 0x001A3039, 0x004A89A3, 
        0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x003D6C80, 0x00000000, 0x00060A0C, 0x00407184, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 
        0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 
        0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B5, 0x006BA0B6, 0x006BA0B6, 
        0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x00273A42, 0x00000000, 0x00273940, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BC, 
        0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0075A5B8, 0x00547684, 0x001E2A2F, 0x00000000, 0x00000000, 0x00101619, 0x00354A53, 0x006C96A7, 0x007CACC0, 
        0x007CACC0, 0x0077A5B8, 0x00141C1F, 0x00000000, 0x005D8190, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007EAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007DABBE, 0x006A92A2, 0x0053717E, 0x0027353B, 0x00000000, 0x00000000, 0x00000000, 0x00080B0C, 
        0x001A2428, 0x002E3F46, 0x004E6975, 0x006D94A4, 0x0082B0C3, 0x0082B0C4, 0x0083B1C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C5, 0x0083B1C5, 0x0084B1C5, 0x0084B2C4, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 
        0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C5, 0x0085B2C5, 
        0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0084B2C5, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B1C4, 0x0083B1C5, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x007CA8BA, 0x005D7E8B, 
        0x003F555E, 0x00233035, 0x0011181A, 0x00000000, 0x00000000, 0x00000000, 0x00192226, 0x00415962, 0x00618492, 0x0078A4B6, 0x005B7C8A, 0x00000000, 0x001B252A, 0x007EACBF, 0x0080AFC2, 0x0080AFC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007EAEC2, 
        0x007EADC1, 0x007EADC1, 0x007DADC1, 0x007DADC1, 0x003D545E, 0x00000000, 0x00161F22, 0x00192327, 0x00000000, 0x00000000, 0x0011181B, 0x004C6976, 0x00709EB0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078AABE, 0x0077A9BE, 
        0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BA, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 
        0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 
        0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 
        0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00508AA3, 0x00101D22, 0x00000000, 0x00315767, 
        0x004F8DA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004A89A3, 0x00223F4B, 0x00000000, 0x0014262D, 0x0046849E, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 
        0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7E9B, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B98, 
        0x00377B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337895, 0x00337895, 0x00327894, 0x00317794,
  0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 
        0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00213E4A, 0x00000000, 0x00000000, 0x000B1418, 0x002D5363, 
        0x004C89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00467C92, 0x000D171B, 0x00000000, 0x00345B6B, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 
        0x005792AA, 0x005893AB, 0x005893AB, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x006299B1, 
        0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00669CB3, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 
        0x006CA1B7, 0x006DA2B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x0010171A, 0x00000000, 0x00344D57, 0x0070A4B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 
        0x0076A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BD, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x00567988, 0x001E2A2F, 0x00020404, 0x00000000, 0x00070A0B, 0x0046616D, 0x006B96A7, 0x007CACC0, 0x007CACC0, 0x007DACC0, 
        0x007DACC1, 0x007CACC0, 0x00445E69, 0x00000000, 0x00192327, 0x007EAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x00739EAF, 0x0047626C, 0x00233036, 0x000D1214, 0x00000000, 0x00000000, 0x00050607, 0x0029383E, 0x00506C78, 0x00688D9D, 
        0x0078A4B6, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C5, 0x0085B2C5, 0x0085B2C5, 
        0x0085B3C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 
        0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C5, 0x0085B3C5, 0x0085B3C5, 0x0085B2C5, 0x0085B3C5, 0x0085B2C6, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 
        0x0084B2C5, 0x0081AEC0, 0x007199A9, 0x005F818E, 0x00405660, 0x00171F22, 0x00000000, 0x00000000, 0x00040506, 0x00192226, 0x00141C1F, 0x00000000, 0x004D6975, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x0080AFC2, 0x0080AEC2, 0x007FAEC2, 
        0x007FAEC2, 0x007FAEC2, 0x007FAEC1, 0x0076A3B5, 0x00050708, 0x00000000, 0x00618695, 0x0074A1B4, 0x00506F7C, 0x00151D21, 0x00000000, 0x00000000, 0x00161F23, 0x00496571, 0x007BABBF, 0x007AABBF, 0x007AAABE, 0x007AAABF, 0x0079AABE, 0x0079A9BE, 
        0x0078AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A9BD, 0x0076A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0071A4B9, 
        0x0070A3B9, 0x006FA3B8, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 
        0x00679DB3, 0x00659CB3, 0x00659CB3, 0x00659BB2, 0x00649CB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 
        0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x00437488, 0x00060B0D, 0x00020405, 
        0x00396577, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x0047829B, 0x001C343E, 0x00000000, 0x00000000, 0x00213E4A, 0x004887A2, 0x004787A1, 0x004787A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044859F, 
        0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0040829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387B98, 
        0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337995, 0x00337894, 0x00327894,
  0x00327794, 0x00337895, 0x00347995, 0x00347995, 0x00347996, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397C98, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 
        0x0040819C, 0x0040829D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x00346172, 0x00000000, 0x00050A0C, 0x00091013, 0x00000000, 0x00000101, 
        0x001E3741, 0x004B86A0, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004E8AA4, 0x001C313B, 0x00000000, 0x0025414D, 0x00518EA7, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AA, 
        0x005892AB, 0x005893AB, 0x005993AC, 0x005A94AB, 0x005A94AC, 0x005A94AC, 0x005B95AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006198B0, 0x006299B0, 0x006299B1, 0x00629AB1, 
        0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00689DB4, 0x00689EB5, 0x00699EB5, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B6, 0x006DA1B7, 
        0x006DA2B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x006DA0B5, 0x00000000, 0x00000000, 0x00293C44, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 
        0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079A9BE, 0x0079AABE, 0x00709EB0, 0x0025343A, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00030405, 0x00719DB0, 0x007CACC0, 0x007CACC0, 0x007DACC1, 0x007DADC1, 
        0x007DADC1, 0x007EADC1, 0x006991A1, 0x000D1315, 0x00000101, 0x005D808F, 0x007FAEC2, 0x0080AFC2, 0x00658B9A, 0x0027353B, 0x00040606, 0x00010101, 0x00000000, 0x00010101, 0x00222F34, 0x00597885, 0x007CA8BA, 0x0080ADC1, 0x0082B0C3, 0x0083B1C4, 
        0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C5, 0x0084B1C5, 0x0083B1C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C5, 0x0085B3C6, 0x0085B2C6, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 
        0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B3C6, 0x0086B4C6, 0x0086B4C6, 0x0086B4C6, 0x0086B4C6, 0x0087B4C6, 0x0087B3C6, 0x0086B4C6, 0x0086B4C6, 0x0086B3C6, 
        0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B3C6, 0x0085B3C6, 0x0085B3C5, 0x0085B3C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0084B2C5, 
        0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C4, 0x0082B1C3, 0x0081AFC2, 0x007199A9, 0x003F565F, 0x000D1214, 0x00000000, 0x00000000, 0x00000000, 0x000E1416, 0x00465F6A, 0x007AA7B9, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x0080AFC2, 
        0x0080AFC2, 0x007FAEC2, 0x007FAEC2, 0x003E555F, 0x00000000, 0x001E292E, 0x0079A6B9, 0x007EADC1, 0x007DADC1, 0x007CACC0, 0x004E6D79, 0x00080B0C, 0x00000000, 0x00000101, 0x00141C1F, 0x00648B9B, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABF, 
        0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 
        0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B5, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00679EB4, 0x00679DB4, 
        0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB3, 0x00659BB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AD, 
        0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005994AB, 0x005993AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005690A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528FA7, 0x00528EA7, 0x00345B6B, 0x00000000, 
        0x000C161A, 0x00457C92, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x003E7287, 0x000B1519, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00346073, 0x004887A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004585A0, 0x004585A0, 
        0x0044859F, 0x0043849F, 0x0043839F, 0x0042839E, 0x0041839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 
        0x00387C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357996, 0x00347996, 0x00347996, 0x00337895, 0x00327895,
  0x00327895, 0x00347895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A96, 0x00367B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F819C, 0x003F819C, 
        0x0040829D, 0x0041829D, 0x0041829D, 0x0041839E, 0x0043839E, 0x0043839E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x00417A93, 0x00091114, 0x00000000, 0x002A4D5D, 0x004B89A3, 0x001A3039, 0x00010303, 
        0x00000000, 0x00101D22, 0x00407287, 0x004E8CA5, 0x004F8CA5, 0x002E5261, 0x00000000, 0x0015252C, 0x00518DA7, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AB, 
        0x005893AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006198B0, 0x006199B0, 0x00629AB0, 0x00629AB1, 0x00639AB1, 
        0x00649AB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 
        0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x004B6D7C, 0x00000000, 0x00000000, 0x00000000, 0x00598292, 0x006998AC, 0x006491A4, 0x004B6D7B, 0x004E7180, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 
        0x0077A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x00709EB0, 0x0045616C, 0x00010202, 0x00000000, 0x00000000, 0x00233137, 0x00577A88, 0x0011181B, 0x00000000, 0x002E4048, 0x007DACC0, 0x007DADC1, 0x007DADC1, 0x007EADC1, 
        0x007EADC1, 0x007EADC2, 0x007FAEC2, 0x002A3A41, 0x00000000, 0x001F2A2F, 0x004F6D78, 0x00161E21, 0x00000000, 0x00000000, 0x000B0F10, 0x001D282D, 0x0047616B, 0x0078A2B4, 0x0082B0C4, 0x0082B0C4, 0x0083B1C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 
        0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C5, 0x0085B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 
        0x0087B3C6, 0x0086B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 
        0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C6, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C5, 0x0085B2C6, 0x0085B3C6, 0x0085B2C5, 
        0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0083B2C4, 0x0083B1C4, 0x0083B1C4, 0x00628492, 0x002F3F46, 0x0011171A, 0x00020303, 0x00000000, 0x00010101, 0x0033454D, 0x00638796, 0x0078A4B6, 0x0081AFC3, 0x0080AFC2, 
        0x0080AFC3, 0x0080AFC2, 0x0079A6B8, 0x00080B0C, 0x00000000, 0x004D6975, 0x007EAEC1, 0x007EADC1, 0x007EADC1, 0x007DADC1, 0x007DADC1, 0x0077A4B8, 0x0030424A, 0x00000000, 0x00000000, 0x00000000, 0x00364C55, 0x006C96A7, 0x007AABBF, 0x007AAABF, 
        0x007AAABF, 0x0079AABF, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 
        0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 
        0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 
        0x005C96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00223C47, 
        0x00000000, 0x001D333D, 0x004E89A3, 0x004F8CA5, 0x004F8CA5, 0x004B869F, 0x0031596A, 0x00030607, 0x00000000, 0x00070D10, 0x002F5566, 0x00284A58, 0x00000000, 0x00091114, 0x00417A93, 0x004887A1, 0x004787A1, 0x004786A0, 0x004685A0, 0x004585A0, 
        0x004585A0, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397C98, 0x00397C98, 
        0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337895, 0x00337894,
  0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 
        0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004785A0, 0x001E3842, 0x00000000, 0x00172C34, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x0031596A, 
        0x00080F12, 0x00000000, 0x0005090B, 0x002C505F, 0x00355E6F, 0x00000000, 0x00091012, 0x00467A90, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590AA, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 
        0x005993AB, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006099B0, 0x006199B0, 0x00629AB0, 0x00629AB1, 0x00639AB1, 0x00639BB2, 
        0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB4, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 
        0x006EA2B8, 0x006FA3B9, 0x006FA3B8, 0x0070A3B9, 0x001D2B30, 0x00000000, 0x00000000, 0x00000000, 0x00040506, 0x00172226, 0x00070A0B, 0x00161F23, 0x00547988, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 
        0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x004E6E7B, 0x00172024, 0x00000000, 0x00000000, 0x00060809, 0x00000000, 0x003B525C, 0x007CACC0, 0x00435D67, 0x00000000, 0x00070A0C, 0x00628796, 0x007EADC1, 0x007EAEC1, 0x007EAEC2, 
        0x007FAEC2, 0x007FAEC2, 0x007FAFC2, 0x00405862, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001B2529, 0x00455E68, 0x00678C9C, 0x0081AFC3, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0084B2C5, 
        0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B3C6, 0x0087B3C7, 0x0087B4C7, 0x0087B4C7, 0x0086B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 
        0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0087B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 
        0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B4C6, 0x0087B4C6, 0x0087B3C6, 0x0086B3C6, 0x0086B3C6, 
        0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B3C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0077A1B2, 0x00587884, 0x0032444C, 0x00080B0C, 0x00000000, 0x00000000, 0x00202B30, 0x0046606B, 0x0076A0B2, 
        0x0081B0C3, 0x0081AFC3, 0x0047626D, 0x00000000, 0x00101719, 0x00719BAB, 0x007FAFC2, 0x007EAEC2, 0x007FAEC1, 0x007EAEC1, 0x007EADC1, 0x007DADC1, 0x00455F6A, 0x00000000, 0x00010203, 0x00010202, 0x00000000, 0x000D1315, 0x00415A65, 0x0079A8BC, 
        0x007AABBF, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 
        0x0072A5BA, 0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00699EB5, 
        0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB4, 0x00669CB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00649BB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B1, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 
        0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA7, 0x00518CA5, 
        0x00172931, 0x00000000, 0x002B4D5B, 0x004F8CA6, 0x00457A90, 0x001A2F38, 0x00000000, 0x00000000, 0x00182B33, 0x003E7186, 0x004B89A3, 0x004A89A3, 0x00172B33, 0x00000000, 0x001E3843, 0x0047859F, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 
        0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819C, 0x0040819C, 0x003F809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397D99, 
        0x00387C98, 0x00387C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337895,
  0x00337995, 0x00347896, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040819D, 
        0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045849F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x00356578, 0x00000000, 0x00070D0F, 0x0047859E, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 
        0x00457B91, 0x00122026, 0x00000000, 0x00010303, 0x00020405, 0x00000000, 0x00365E6F, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005892AB, 0x005893AB, 0x005993AB, 
        0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x00639AB1, 0x00649AB1, 0x00649BB2, 
        0x00649CB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B6, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 
        0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x005F8C9E, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040506, 0x00496976, 0x006E9EB2, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A8BD, 
        0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x006F9CAF, 0x00202C32, 0x00010202, 0x00000000, 0x00060809, 0x005A7D8C, 0x004C6A76, 0x00020404, 0x00050708, 0x00638A99, 0x007DADC1, 0x000F1517, 0x00000000, 0x002A3A41, 0x007DABBD, 0x007FAEC2, 0x007FAEC2, 
        0x0080AFC2, 0x005C7E8C, 0x001B2529, 0x00040606, 0x00000000, 0x00000000, 0x0027353B, 0x00668B9A, 0x007CA9BC, 0x0081AFC3, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C5, 0x0084B2C5, 0x0084B1C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0084B2C5, 
        0x0085B3C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 
        0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 
        0x0089B5C8, 0x0089B5C7, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B4C6, 
        0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B2C5, 0x0085B2C6, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0080ACC0, 0x0076A1B2, 0x004B6570, 0x000B0F10, 0x00000000, 0x00010101, 0x00090C0D, 
        0x00374A52, 0x00719AAB, 0x00202C30, 0x00000000, 0x00374B54, 0x0080AFC3, 0x0080AFC2, 0x0080AEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x006C95A5, 0x00101618, 0x00000000, 0x002F4148, 0x006991A1, 0x0011181B, 0x00000000, 0x00000000, 0x00131A1E, 
        0x00638A9B, 0x007BABBF, 0x007AAABF, 0x007AAABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A8BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0074A6BB, 0x0073A5BB, 0x0073A6BB, 
        0x0072A5BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 
        0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AF, 0x005E97AE, 
        0x005E97AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 
        0x0045788E, 0x00091114, 0x00000000, 0x002D505E, 0x000D171B, 0x00000000, 0x00000000, 0x00274754, 0x0049859D, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x0047859E, 0x00060C0F, 0x00000000, 0x00356579, 0x004887A1, 0x004887A1, 0x004686A1, 0x004686A0, 
        0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 
        0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347995, 0x00337895,
  0x00347995, 0x00347996, 0x00357996, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F809C, 0x0040819C, 0x0040829C, 0x0041829D, 
        0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x0044819A, 0x00030708, 0x00000000, 0x0037677A, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 
        0x004E8BA5, 0x004E8BA5, 0x0024404C, 0x00000000, 0x00000000, 0x00203842, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005692AA, 0x005892AA, 0x005893AB, 0x005993AB, 0x005993AB, 
        0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006099B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 
        0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006B9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 
        0x006FA3B9, 0x006FA3B9, 0x0070A4B9, 0x002E444D, 0x00000000, 0x00000000, 0x00000000, 0x00040708, 0x0024343B, 0x006C9AAE, 0x0074A7BB, 0x0074A7BB, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 
        0x0078A9BE, 0x0075A4B8, 0x0050717E, 0x0006090A, 0x00000000, 0x00040606, 0x00010203, 0x00000000, 0x00658C9D, 0x007BAABE, 0x00182125, 0x00000000, 0x0028373E, 0x007DADC1, 0x00638898, 0x00000000, 0x00000000, 0x00608493, 0x007AA7BB, 0x005D7F8D, 
        0x00172023, 0x00000000, 0x00000000, 0x000A0D0F, 0x00304148, 0x006E97A7, 0x0082B0C3, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C6, 0x0086B3C6, 
        0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C8, 0x0089B5C7, 0x0089B5C7, 0x0089B5C7, 0x0089B5C7, 
        0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x0089B6C8, 0x0089B6C8, 0x0089B6C8, 0x0089B6C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B6C8, 0x0089B6C8, 0x0089B6C8, 
        0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C7, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 
        0x0087B4C7, 0x0087B4C7, 0x0087B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B3C5, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0083B2C5, 0x0084B1C5, 0x0054727E, 0x00192225, 0x00050607, 
        0x00000000, 0x00000000, 0x00010101, 0x00010202, 0x00749FB0, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x0080AFC2, 0x007FAEC2, 0x007EACC0, 0x003D545E, 0x00000000, 0x00080B0C, 0x00729EB0, 0x0077A4B7, 0x000B0F11, 0x00000000, 0x00050708, 0x00000000, 
        0x00000000, 0x003C545E, 0x0072A0B3, 0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0073A6BB, 
        0x0073A6BB, 0x0073A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 
        0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 
        0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x005490A8, 0x00538FA8, 0x00538FA8, 
        0x00528FA7, 0x00325868, 0x00010203, 0x00000000, 0x00000000, 0x00080F12, 0x00376275, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x0037667A, 0x00000000, 0x00030608, 0x0045819B, 0x004887A1, 0x004786A1, 0x004686A0, 
        0x004685A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0044849E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003E819C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 
        0x00397D99, 0x00387C98, 0x00377C98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347995,
  0x00347995, 0x00357996, 0x00357A96, 0x00367B97, 0x00377B97, 0x00387B98, 0x00387B98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 
        0x0041839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x00162932, 0x00000000, 0x001D3540, 0x004987A1, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 
        0x004E8BA5, 0x004F8CA5, 0x00366071, 0x00000000, 0x00132228, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x005691AA, 0x005692AA, 0x005792AB, 0x005892AB, 0x005993AB, 0x005993AB, 0x005A94AC, 
        0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005C96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 
        0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA3B8, 0x006FA3B9, 
        0x0070A3B9, 0x0071A4B9, 0x005A8394, 0x00080C0D, 0x00000000, 0x00000000, 0x00223138, 0x00557B8B, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078AABE, 0x0079AABE, 
        0x00638C9C, 0x00293A41, 0x00000000, 0x00000000, 0x00222F35, 0x00547684, 0x00212E33, 0x00000000, 0x001C272B, 0x007DACC0, 0x005E8291, 0x00000000, 0x00030405, 0x005C808E, 0x007EAEC1, 0x00344850, 0x00000000, 0x0012181B, 0x00253238, 0x00000000, 
        0x00000000, 0x00172023, 0x00435C66, 0x00729BAC, 0x0082B0C4, 0x0083B1C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B1C5, 0x0085B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 0x0087B3C6, 
        0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0086B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x0089B5C8, 
        0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C8, 0x008AB6C8, 0x008BB6C8, 0x008BB6C8, 0x008BB6C8, 0x008AB6C8, 0x008AB6C8, 
        0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 
        0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0087B4C6, 0x0087B4C7, 0x0087B4C6, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B2C5, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0083B1C5, 0x005C7C8A, 
        0x002F3F46, 0x00050708, 0x00000000, 0x00030404, 0x003B5059, 0x006B90A0, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC3, 0x006F98A8, 0x00040606, 0x00000000, 0x004D6B77, 0x007EAEC1, 0x00374C55, 0x00000000, 0x000E1416, 0x005B7E8C, 0x0025343A, 
        0x00000000, 0x00000000, 0x001B262A, 0x00587B89, 0x007AABBF, 0x007AAABF, 0x007AAABE, 0x0079AABF, 0x0079AABE, 0x0079A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0073A6BB, 
        0x0073A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 
        0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006198B0, 0x006098B0, 0x006098AF, 0x005F97AF, 
        0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 
        0x00528FA8, 0x00528EA7, 0x00213943, 0x00000000, 0x000C161A, 0x00487F95, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004A87A1, 0x001D3540, 0x00000000, 0x00162A32, 0x004887A2, 0x004887A1, 0x004786A1, 
        0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0041829E, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 
        0x00397D99, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00357A96, 0x00357996, 0x00347996,
  0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829E, 
        0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x002D5566, 0x00010203, 0x00050A0C, 0x00447E96, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 
        0x004F8CA5, 0x00467B92, 0x00010202, 0x00070C0E, 0x0044768C, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AE, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 
        0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 
        0x0071A4B9, 0x0071A4BA, 0x00151E23, 0x00000000, 0x000D1416, 0x00547989, 0x006FA0B5, 0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079A9BE, 0x0079AABE, 0x00486672, 
        0x000B1012, 0x00000000, 0x00030505, 0x004B6976, 0x0075A3B6, 0x007CACC0, 0x00547583, 0x00020303, 0x00020404, 0x004F6D7A, 0x007EADC1, 0x0030424A, 0x00000000, 0x001A2428, 0x007FAEC2, 0x004C6873, 0x00010101, 0x00000000, 0x00000000, 0x0012181B, 
        0x00577683, 0x0077A2B3, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C4, 0x0084B1C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C6, 0x0087B4C7, 
        0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 
        0x008BB6C9, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008BB6C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 
        0x0089B5C7, 0x0088B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C5, 0x0085B2C5, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 
        0x0080ADC0, 0x006D93A3, 0x0033464D, 0x00000000, 0x00000000, 0x00090D0E, 0x0031424A, 0x0078A3B5, 0x0081B0C3, 0x0081B0C3, 0x0028373D, 0x00000000, 0x00202B30, 0x007CABBE, 0x006A92A2, 0x000A0E0F, 0x00000000, 0x004A6571, 0x007DADC1, 0x002B3C43, 
        0x00000000, 0x00000000, 0x00000000, 0x00060809, 0x00344850, 0x0078A8BC, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BC, 0x0076A8BD, 0x0075A8BC, 0x0075A7BC, 0x0075A7BC, 
        0x0074A7BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 
        0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098AF, 0x006098AF, 
        0x005F98AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005893AB, 0x005893AB, 0x005892AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00548FA8, 
        0x00538FA8, 0x00528FA7, 0x00508BA3, 0x00111E23, 0x00000000, 0x003A6678, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00447E96, 0x00050A0C, 0x00010203, 0x002D5566, 0x004887A1, 0x004787A1, 
        0x004786A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 
        0x003A7D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357996, 0x00357996,
  0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042829D, 
        0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x00407991, 0x000C161B, 0x00000000, 0x00335F70, 0x004A89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004E8BA4, 0x004E8BA5, 0x004E8BA5, 
        0x004F8CA6, 0x000D171B, 0x00000101, 0x002D4F5D, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x00548FA9, 0x005490A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AB, 0x005892AB, 0x005893AB, 0x005994AC, 0x005A94AC, 0x005A94AC, 
        0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 
        0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 
        0x006B9BB0, 0x00141D21, 0x00030405, 0x0039525C, 0x0073A6BB, 0x0073A6BB, 0x0074A7BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0075A4B8, 0x002C3E45, 0x00000000, 
        0x00000000, 0x00141C1F, 0x006A94A4, 0x007BACC0, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x001F2B30, 0x00000000, 0x001C272B, 0x0076A1B4, 0x0077A3B5, 0x00070A0C, 0x00000000, 0x00131A1C, 0x00000000, 0x00000000, 0x00080B0C, 0x0049646F, 0x0082B0C3, 
        0x0082B0C4, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 
        0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B6C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008AB6C8, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008CB7C9, 
        0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008BB6C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 
        0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0086B3C5, 0x0085B2C5, 0x0085B2C5, 
        0x0084B2C5, 0x0084B2C5, 0x0083B1C5, 0x00749DAE, 0x0027343A, 0x00020203, 0x00000000, 0x00040506, 0x004C6874, 0x005C7D8B, 0x00000000, 0x00010202, 0x005B7D8B, 0x007FAEC1, 0x0032444C, 0x00000000, 0x00172023, 0x007FAEC2, 0x005F8392, 0x0006090A, 
        0x00010202, 0x003A505A, 0x00293940, 0x00010203, 0x00000000, 0x001A2429, 0x006E99AB, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 
        0x006BA0B5, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098AF, 
        0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005490A9, 0x005490A8, 
        0x00548FA8, 0x00538FA8, 0x00528EA7, 0x0044778C, 0x00030506, 0x00010303, 0x004C859E, 0x00508CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x00335E6F, 0x00000000, 0x000C161B, 0x00407991, 0x004887A1, 
        0x004787A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003E7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 
        0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357996,
  0x00357A96, 0x00367A97, 0x00377A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003B7D9A, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 
        0x0043839E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004686A1, 0x004886A1, 0x004887A1, 0x00213E4A, 0x00000000, 0x001C343D, 0x004A89A3, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 
        0x00284653, 0x00000000, 0x0015252B, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AB, 0x005892AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 
        0x005C95AD, 0x005C95AD, 0x005D96AD, 0x005D97AE, 0x005E97AE, 0x005F97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB0, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 
        0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006B9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 
        0x00486976, 0x0025353C, 0x00608A9C, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x005A7F8E, 0x0010171A, 0x00000000, 0x00070A0B, 
        0x003B535C, 0x007BABC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x006E97A8, 0x00010203, 0x00000000, 0x004E6B77, 0x006C94A5, 0x00222E33, 0x00000000, 0x00000000, 0x0011181A, 0x00415962, 0x007BA9BB, 0x0082B0C4, 0x0082B1C4, 
        0x0082B1C4, 0x0083B1C4, 0x0083B2C4, 0x0084B2C4, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B3C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 
        0x0088B5C8, 0x0089B5C7, 0x0089B5C8, 0x0089B6C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 
        0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008CB7CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8C9, 0x008CB7CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8C9, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7CA, 
        0x008CB8CA, 0x008CB7CA, 0x008CB7CA, 0x008CB7CA, 0x008CB7C9, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008BB6C8, 0x008AB6C8, 0x008AB6C8, 
        0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0087B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C5, 
        0x0085B2C5, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x00628492, 0x0028363B, 0x00020303, 0x00000000, 0x00000000, 0x00000000, 0x0029383E, 0x0081B0C3, 0x00688E9F, 0x00000000, 0x00000000, 0x00678E9E, 0x007DABBE, 0x002C3C43, 0x00000000, 
        0x00131A1D, 0x007AA8BB, 0x007DADC1, 0x004C6976, 0x00101618, 0x00000000, 0x00050809, 0x004E6C79, 0x0078A8BC, 0x007AAABF, 0x007AAABF, 0x0079AABF, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006DA1B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 
        0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 
        0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 
        0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x002A4A57, 0x00000000, 0x0015252B, 0x00508CA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004A89A3, 0x001B333D, 0x00000000, 0x00213F4B, 0x004887A1, 
        0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839D, 0x0041829D, 0x0040829C, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 
        0x003B7D99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96,
  0x00367A96, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 0x0040819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 
        0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004887A1, 0x0037677B, 0x00000000, 0x000A1316, 0x00437C93, 0x004B89A3, 0x004C89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA6, 0x00417389, 
        0x00030607, 0x00030607, 0x004A8199, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 
        0x005C95AE, 0x005D96AD, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639AB2, 0x00639BB2, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 
        0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4B9, 0x0072A5BA, 
        0x0070A2B7, 0x0073A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x003C555F, 0x00060809, 0x00000000, 0x00000000, 0x00090D0F, 
        0x006B95A6, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x00455F6A, 0x00000000, 0x000A0D0F, 0x00101619, 0x00000000, 0x00020303, 0x00425A64, 0x00729BAC, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 
        0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 
        0x0089B6C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB8CA, 0x008CB7CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 
        0x008DB9CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0086B3C6, 0x0086B3C6, 
        0x0086B3C6, 0x0086B3C6, 0x0085B2C6, 0x0085B2C6, 0x0085B3C5, 0x0084B2C5, 0x0080ADBF, 0x00618290, 0x001E292E, 0x00000000, 0x00000000, 0x00182124, 0x00698E9D, 0x00182125, 0x00000000, 0x00394E57, 0x0080AFC2, 0x005B7C8A, 0x00000000, 0x00000000, 
        0x005E8190, 0x007EAEC2, 0x007EADC1, 0x007EADC1, 0x006C95A7, 0x0027363C, 0x00000000, 0x00010202, 0x002B3D44, 0x0077A6BA, 0x007BABBF, 0x007AABBF, 0x007AAABE, 0x0079AABF, 0x0078AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 
        0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 
        0x006CA0B7, 0x006BA0B6, 0x006A9FB6, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 
        0x006199B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 
        0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x00508BA3, 0x000F1B20, 0x00000000, 0x002D505E, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA3, 0x004B89A3, 0x00427B93, 0x000A1216, 0x00000000, 0x0038677C, 
        0x004887A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 
        0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A96,
  0x00367A97, 0x00367A97, 0x00377B98, 0x00377C98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003A7E99, 0x003B7D9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043839E, 
        0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004786A0, 0x00070E11, 0x00000101, 0x002C5363, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004E8CA5, 0x004F8CA5, 0x00122025, 
        0x00000000, 0x003B687B, 0x00518EA7, 0x00538EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005792AA, 0x005792AA, 0x004F849A, 0x001F333C, 0x0052889E, 0x005993AC, 0x005A94AC, 0x005B95AC, 0x005C95AD, 0x005C95AD, 
        0x005D96AD, 0x005D96AE, 0x005E96AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 
        0x00689EB4, 0x00699EB5, 0x00699EB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA1B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 
        0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078AABE, 0x0075A4B8, 0x001F2B30, 0x00000000, 0x00000000, 0x0031454D, 0x002A3B42, 0x00000000, 
        0x00202C31, 0x007DACC0, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x00648998, 0x00040506, 0x00000000, 0x00000000, 0x00243137, 0x00739DAE, 0x0082B0C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 
        0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 
        0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8C9, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008DB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 
        0x008EB9CB, 0x008EB9CB, 0x008DB9CA, 0x008EB9CB, 0x008EB9CA, 0x008DB8CB, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008CB8C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 
        0x0087B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B2C5, 0x0084B2C5, 0x0084B1C5, 0x0084B2C5, 0x00506C78, 0x00040506, 0x00000000, 0x00010101, 0x00000000, 0x00101619, 0x006F97A8, 0x0081B0C3, 0x00161E22, 0x00000000, 0x002D3E45, 
        0x007FAEC2, 0x007FAEC2, 0x007EAEC2, 0x007EAEC1, 0x007EADC1, 0x007DADC1, 0x00435D68, 0x00000000, 0x00000000, 0x000D1315, 0x006D98AA, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A8BD, 0x0077A8BD, 
        0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 
        0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00649AB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006199B0, 
        0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 
        0x005590A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00497E95, 0x00000000, 0x00080E11, 0x00457A90, 0x004F8CA6, 0x004F8CA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA3, 0x004B8AA3, 0x004B89A3, 0x002C5262, 0x00000101, 0x00080E11, 
        0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F809C, 0x003E809C, 0x003E809C, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 
        0x003C7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00387C98, 0x00387C98, 0x00387B97, 0x00367B97, 0x00367A96,
  0x00367A97, 0x00377B97, 0x00387B97, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003C7E9A, 0x003C7F9A, 0x003D7F9A, 0x003D809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 
        0x0044849F, 0x0045859F, 0x0045859F, 0x004686A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x0023424E, 0x00000000, 0x00122228, 0x004986A0, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x002A4A58, 0x00000000, 
        0x001F363F, 0x00508CA5, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AA, 0x0028424D, 0x0018272E, 0x00558DA5, 0x005A94AC, 0x005B94AC, 0x005B94AD, 0x005C95AD, 0x005C95AD, 
        0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649AB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 
        0x00689EB5, 0x00699EB5, 0x006A9FB5, 0x006BA0B5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A5BA, 0x0071A5BA, 0x0072A5BA, 0x0073A6BB, 
        0x0073A6BB, 0x0073A6BB, 0x0074A6BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078AABE, 0x00618999, 0x00141C20, 0x00000000, 0x00080C0D, 0x00476370, 0x007BABC0, 0x00719DB0, 0x0011181B, 
        0x00000000, 0x003C535D, 0x007EADC1, 0x007EAEC1, 0x007EAEC1, 0x007EAEC2, 0x00739FB0, 0x003D535C, 0x00000000, 0x00000000, 0x00141B1E, 0x00516F7B, 0x0082B0C4, 0x0082B0C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C4, 0x0084B2C5, 0x0085B2C5, 
        0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 
        0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB7C9, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CB, 0x008EB9CB, 
        0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 
        0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8C9, 
        0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 
        0x0087B4C6, 0x0087B4C6, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B2C6, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x007CA7BA, 0x0032444B, 0x00060809, 0x00000000, 0x0011171A, 0x00648897, 0x003B5059, 0x00000000, 0x00080B0D, 0x007099AA, 
        0x0080AFC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007EADC1, 0x007EADC1, 0x007DADC1, 0x00172024, 0x00000000, 0x00000000, 0x00050708, 0x00547684, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A8BD, 
        0x0077A8BD, 0x0077A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 
        0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 
        0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005993AC, 0x005993AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 
        0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00325666, 0x00000000, 0x001C313A, 0x00508CA6, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x0049869F, 0x00122128, 0x00000000, 
        0x0023424F, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 
        0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97,
  0x00377A97, 0x00377B97, 0x00387B98, 0x00397C98, 0x00397D98, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D809B, 0x003E809B, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839D, 0x0043839E, 0x0043849F, 0x0044849F, 
        0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x003C7188, 0x00060B0D, 0x00000000, 0x00182D36, 0x0048849D, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x003E6F84, 0x00020304, 0x00070D10, 
        0x00467B90, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x0047778B, 0x00000000, 0x00325361, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005D96AD, 0x005D96AD, 
        0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 
        0x00699EB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 
        0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BD, 0x0078AABE, 0x0079AABE, 0x004B6A77, 0x000B1011, 0x00000000, 0x00172023, 0x005F8495, 0x007CACC0, 0x007CACC0, 0x007DADC0, 0x00567885, 
        0x00030506, 0x00020303, 0x00557683, 0x007FAEC2, 0x007FAFC2, 0x00567682, 0x00161E22, 0x00000000, 0x00030405, 0x00425B64, 0x0077A2B3, 0x0082B1C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C4, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B2C6, 
        0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x008AB5C8, 0x008AB6C9, 0x008AB6C9, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008DB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 
        0x008FBACB, 0x008FBACB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x008FBACB, 0x0090BACB, 0x008FBACC, 0x008FBACC, 0x0090BACB, 0x0090BACC, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 
        0x0090BACC, 0x008FBACC, 0x008FBACC, 0x008FBACC, 0x008FBACC, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CB, 0x008DB9CA, 0x008DB8CA, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 
        0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x00628593, 0x00212D32, 0x00000000, 0x0007090A, 0x00010101, 0x00020203, 0x00455E68, 0x0080AFC2, 
        0x0081B0C3, 0x0080AFC2, 0x0080AEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC1, 0x002F4148, 0x00000000, 0x00131B1E, 0x00222F34, 0x00000000, 0x00030506, 0x003B525C, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 
        0x0078A9BE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006DA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00629AB1, 
        0x006299B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005691AA, 
        0x005591A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA7, 0x00508BA4, 0x00182A32, 0x00000000, 0x00335A6A, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00274856, 0x00000000, 
        0x00060B0D, 0x003D7288, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003D809B, 0x003D7F9B, 
        0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397D98, 0x00387C98, 0x00387B97, 0x00367B97,
  0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x003A7D98, 0x003A7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0043849F, 0x0044849F, 
        0x0044859F, 0x004685A0, 0x004686A0, 0x004786A0, 0x004887A1, 0x004887A2, 0x001C343E, 0x00000000, 0x00000000, 0x00000101, 0x00070D0F, 0x00305768, 0x004D8AA4, 0x004D8AA4, 0x004E8BA5, 0x004F8CA5, 0x004C879F, 0x0015252C, 0x00000000, 0x002E5160, 
        0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x00101B20, 0x00020405, 0x003E6676, 0x005B94AC, 0x005B95AC, 0x005B95AD, 0x005C96AE, 0x005D96AE, 0x005D96AE, 
        0x005E97AF, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 
        0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 
        0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x00374D56, 0x00010202, 0x00000000, 0x00293940, 0x0074A2B5, 0x007CACC0, 0x007CACC0, 0x007DADC0, 0x007DADC1, 0x007DADC1, 
        0x00364B53, 0x00000000, 0x0011181B, 0x0068909F, 0x002C3D43, 0x00010101, 0x00000000, 0x001C262A, 0x007099AA, 0x0081B0C3, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 
        0x0086B3C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 
        0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 0x008FBACB, 0x008FBACC, 0x008FBACC, 0x0090BACC, 
        0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0090BACC, 0x0090BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 
        0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACB, 0x008FBACC, 0x0090BACB, 0x008FBACC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 
        0x008EB9CA, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 
        0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B3C5, 0x0085B2C5, 0x0084B2C5, 0x007FACBE, 0x004E6975, 0x00030404, 0x00000000, 0x00050607, 0x00577683, 0x0081B0C3, 
        0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x004D6975, 0x00010203, 0x00030405, 0x00506F7C, 0x007BAABE, 0x00415A64, 0x00000000, 0x00000000, 0x00212E33, 0x0079A8BD, 0x007AABBF, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0079A9BE, 
        0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A4BA, 0x0071A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x006EA3B8, 0x006EA2B8, 
        0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 
        0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AA, 0x005791AA, 
        0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x003F6E82, 0x0005090B, 0x00040709, 0x00488097, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x0048829B, 0x001A2F38, 0x00020405, 0x00000000, 
        0x00000000, 0x001C343E, 0x004887A1, 0x004887A1, 0x004786A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839F, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397C98, 0x00397C98, 0x00377C98, 0x00377B97,
  0x00377B97, 0x00387C98, 0x00397C98, 0x00397C99, 0x00397D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E7F9B, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829E, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044859F, 
        0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x00396C81, 0x00000000, 0x000C171B, 0x001C353F, 0x00060B0D, 0x00000000, 0x00000000, 0x00111F25, 0x003E7084, 0x004D89A3, 0x004F8CA5, 0x00335B6C, 0x00000000, 0x00122025, 0x00518EA7, 
        0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x00365A69, 0x00010202, 0x00040608, 0x0040697A, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C96AE, 0x005D96AE, 0x005D96AE, 
        0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB1, 0x00649BB2, 0x00659BB3, 0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 
        0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x0072A1B4, 0x00324750, 0x00000000, 0x00020404, 0x00334750, 0x007AA9BE, 0x007CACC0, 0x007CACC0, 0x007DACC1, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 
        0x007FAEC2, 0x00161F22, 0x00000000, 0x00000000, 0x00000000, 0x00080B0D, 0x00425964, 0x0081B0C3, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 
        0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 
        0x0090BACC, 0x0090BBCC, 0x0091BACC, 0x0090BBCC, 0x0090BBCC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 
        0x0090BBCC, 0x0091BBCC, 0x0090BBCC, 0x0091BACC, 0x0090BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 
        0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 
        0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C6, 0x0087B4C6, 0x0087B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B3C6, 0x0085B2C5, 0x0084B2C5, 0x0084B2C5, 0x006C91A0, 0x00182124, 0x00000000, 0x00000000, 0x00445C66, 
        0x007BA7B9, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x006B93A3, 0x000E1416, 0x00000000, 0x002B3C42, 0x007EAEC1, 0x007EADC1, 0x007DADC1, 0x004D6B77, 0x00070A0C, 0x00000000, 0x001C272C, 0x006D98AA, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 
        0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A6BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA2B8, 
        0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00639AB1, 
        0x00639AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005B94AC, 0x005A93AC, 0x005993AB, 0x00467386, 0x001F343D, 0x005690A8, 
        0x005691AA, 0x005590A9, 0x005591A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00223D48, 0x00000000, 0x001C323B, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x0049839B, 0x00305666, 0x00020304, 0x00000000, 0x00010303, 0x000B1519, 
        0x000A1317, 0x00000000, 0x003A6D82, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B97,
  0x00387B98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x004585A0, 
        0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x0047859F, 0x00091215, 0x00000000, 0x002C5161, 0x004A89A3, 0x003F748A, 0x001E3641, 0x00010303, 0x00000000, 0x00020405, 0x001F3842, 0x003C6B7E, 0x00091012, 0x00030506, 0x00477C94, 0x00528EA7, 
        0x00538EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AB, 0x0051869D, 0x00101B20, 0x00000000, 0x00030506, 0x003C6373, 0x005B95AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AE, 
        0x005F97AF, 0x005F98AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9EB5, 0x006A9FB6, 
        0x006B9FB6, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A5BA, 0x0072A5BA, 0x0072A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x006D99AB, 0x0025343B, 0x00000000, 0x00050808, 0x00496672, 0x007BACC0, 0x007CACC0, 0x007CACC0, 0x007DACC1, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 
        0x007FAEC2, 0x0033464D, 0x00000000, 0x00000000, 0x00212D32, 0x00638795, 0x0082B0C3, 0x0083B0C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 
        0x0087B4C7, 0x0088B4C7, 0x0088B5C8, 0x0089B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x0089B6C8, 0x008BB6C8, 0x008AB6C9, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 
        0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 0x008FB9CC, 0x0090BACB, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 
        0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0092BBCC, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0091BCCD, 0x0091BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0091BCCD, 0x0091BCCD, 0x0092BCCD, 0x0091BCCD, 0x0091BCCC, 0x0091BCCD, 
        0x0092BCCD, 0x0091BCCD, 0x0092BCCD, 0x0092BBCC, 0x0092BBCD, 0x0092BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BBCD, 0x0091BBCC, 0x0090BBCC, 0x0091BACD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACC, 0x0090BACC, 0x008FBACB, 
        0x008FB9CB, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB9CB, 0x008EB8CB, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008DB8C9, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB6C8, 0x008BB6C8, 0x008AB6C9, 
        0x008AB6C8, 0x0089B6C8, 0x008AB5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B2C5, 0x0085B2C5, 0x0084B2C5, 0x0080ADC0, 0x00435B65, 0x0007090A, 0x00000000, 
        0x00212D31, 0x00678C9B, 0x0081B0C3, 0x0081AFC3, 0x002B3B41, 0x00000000, 0x00161E22, 0x0079A5B8, 0x007FAEC2, 0x007FAEC2, 0x007EADC1, 0x007EADC1, 0x005B7E8C, 0x00101618, 0x00000000, 0x00161F23, 0x00628898, 0x007BABBF, 0x007AABBF, 0x007AAABF, 
        0x007AAABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 
        0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B8, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00669DB4, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 
        0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x0053899F, 0x000C1518, 0x00355968, 
        0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA7, 0x00508BA4, 0x000B1418, 0x00010203, 0x003B697B, 0x004F8CA6, 0x00335B6B, 0x00101D22, 0x00000000, 0x00000000, 0x000E191E, 0x002E5363, 0x004987A1, 
        0x00325E6F, 0x00000000, 0x000A1216, 0x004786A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042829E, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003F809B, 0x003E809B, 
        0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00387C98, 0x00387C98,
  0x00387C98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003C7E9A, 0x003C7F9A, 0x003C7F9B, 0x003E7F9B, 0x003E809B, 0x003E819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 
        0x004685A0, 0x004786A0, 0x004786A1, 0x004887A1, 0x00244351, 0x00000000, 0x00000000, 0x00060B0E, 0x00233F4C, 0x004C8AA4, 0x004C8AA4, 0x003F7287, 0x0015262D, 0x00000000, 0x00000000, 0x0004080A, 0x00000000, 0x002E505E, 0x00528EA7, 0x00528EA7, 
        0x00538EA8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005893AB, 0x00335563, 0x00000000, 0x00000000, 0x00000000, 0x0032515F, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 
        0x005F98AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 
        0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x006FA3B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BA, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x006791A2, 0x00141C1F, 0x00000000, 0x000C1113, 0x005E8392, 0x007CACC0, 0x007CACC0, 0x007DADC0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x00739DAF, 
        0x00212D32, 0x00010202, 0x00000000, 0x00425B64, 0x007AA5B7, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C4, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 
        0x0088B5C7, 0x0088B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CA, 0x008EB9CB, 
        0x008FB9CB, 0x008EBACB, 0x008FB9CB, 0x008FBACC, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BBCD, 
        0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0092BCCE, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCD, 0x0092BCCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0093BCCD, 0x0092BCCD, 
        0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 
        0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008BB6C8, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B2C5, 0x0085B2C5, 0x0085B2C5, 0x006A8E9E, 0x0012181B, 
        0x00000000, 0x00090C0D, 0x00567481, 0x0048636E, 0x00000000, 0x00090C0D, 0x006C94A5, 0x0080AFC2, 0x007FAEC2, 0x007FAEC2, 0x007EAEC2, 0x007EADC1, 0x007EADC1, 0x006E98AA, 0x001B262A, 0x00000000, 0x00090C0E, 0x00587B89, 0x007BABBF, 0x007AABBF, 
        0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0073A6BB, 0x0073A5BB, 0x0072A6BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 
        0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB3, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 
        0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006099B0, 0x006098B0, 0x006098AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x00345765, 0x00040809, 
        0x004F859C, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00427388, 0x00000000, 0x00101C21, 0x00111F25, 0x00020304, 0x00000000, 0x00000000, 0x00284956, 0x00478099, 0x004C8AA4, 0x003F7389, 
        0x00111F25, 0x00000000, 0x00000000, 0x00244451, 0x004887A1, 0x004786A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 
        0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98,
  0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0043839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004585A0, 
        0x004686A0, 0x004786A1, 0x004787A1, 0x003E768C, 0x00091114, 0x00000101, 0x000B1418, 0x00000101, 0x00000000, 0x00070E10, 0x00386577, 0x004B88A1, 0x004E8BA5, 0x00335B6C, 0x0005090B, 0x00000000, 0x000F1B1F, 0x00498197, 0x00528EA7, 0x00528EA8, 
        0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x00528AA0, 0x00020405, 0x00000000, 0x00000000, 0x00000000, 0x00223740, 0x005A92A9, 0x005C96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x005F97AF, 
        0x006098AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659BB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 
        0x006CA0B6, 0x006CA0B7, 0x006CA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0077A8BD, 0x0077A9BE, 0x0078AABE, 0x0078AABE, 0x006792A3, 0x0011181A, 0x00000000, 0x00010202, 0x00445F6A, 0x007CACC0, 0x007CACC0, 0x007CADC0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x006991A1, 0x00101518, 
        0x00000000, 0x00090D0E, 0x00597A87, 0x0082B0C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 
        0x0089B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 
        0x008FBACB, 0x008FB9CB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0092BCCD, 
        0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCD, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BDCD, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCE, 
        0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0093BCCE, 0x0092BCCD, 0x0093BCCD, 0x0092BCCD, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 
        0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FB9CC, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x0085B2C5, 0x0085B2C6, 0x0085B2C5, 0x0084B1C5, 
        0x002C3C42, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00547380, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x0080AEC2, 0x007FAEC2, 0x007FAEC2, 0x007EAEC1, 0x007EADC1, 0x0074A0B3, 0x001E2A2F, 0x00000000, 0x00040607, 0x00557785, 0x007BABBF, 
        0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 
        0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679CB3, 0x00669CB3, 0x00659CB2, 0x00659BB2, 
        0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005A93AC, 0x004E8196, 0x00000000, 
        0x00223943, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00518DA6, 0x00223C46, 0x00000000, 0x00000000, 0x00010303, 0x00162930, 0x00477F96, 0x004E8BA5, 0x00478199, 0x0024424F, 0x00000000, 
        0x00000000, 0x00020405, 0x00000101, 0x00091114, 0x003E768C, 0x004887A1, 0x004786A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0041829D, 0x0040819C, 0x003F809C, 0x003F809B, 
        0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98,
  0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 
        0x004786A0, 0x004786A1, 0x004786A0, 0x00234350, 0x00000000, 0x00192E37, 0x004B89A3, 0x00284A58, 0x000A1317, 0x00000000, 0x00000000, 0x001A2F38, 0x003B6A7E, 0x004C88A0, 0x00122027, 0x00000000, 0x00355C6D, 0x00528EA7, 0x00528EA7, 0x00538FA8, 
        0x00538FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x001E323A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1518, 0x0054899E, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005E97AF, 0x006098AF, 
        0x006098AF, 0x006199B0, 0x006199B0, 0x00629AB0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006A9FB6, 0x006BA0B6, 
        0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A6BB, 0x0075A6BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BD, 0x0077A8BD, 
        0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x005D8392, 0x000E1417, 0x00000000, 0x00151D20, 0x00000000, 0x000A0E10, 0x005C808F, 0x007DACC1, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x007EACC0, 0x004D6B76, 0x00030404, 0x00000000, 
        0x00233035, 0x007099AA, 0x0082B0C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0084B1C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 
        0x0089B6C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 
        0x008FBACC, 0x008FBACC, 0x0090BACC, 0x0090BBCC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCD, 0x0093BCCE, 0x0093BCCE, 
        0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 
        0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0093BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0093BCCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0092BBCD, 0x0091BBCC, 
        0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 
        0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C6, 0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B3C5, 0x0084B2C5, 
        0x0084B2C5, 0x004D6773, 0x00080B0C, 0x00000000, 0x00101618, 0x006B90A1, 0x0081B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAFC2, 0x007FAEC2, 0x007FAEC2, 0x007EAEC1, 0x007EADC1, 0x0077A5B8, 0x002B3B42, 0x00000000, 0x00040606, 0x004E6C79, 
        0x007BABBF, 0x007AABBF, 0x0079ABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 
        0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB5, 0x00679EB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB2, 
        0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005C95AC, 0x005B94AC, 0x005A94AC, 0x00538AA1, 0x00000000, 
        0x00060A0C, 0x00457488, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x0046798F, 0x00080E11, 0x00000000, 0x00294956, 0x004F8CA5, 0x004A849C, 0x002F5363, 0x000A1215, 0x00000000, 0x00000000, 
        0x0015272E, 0x003B6C81, 0x001A313B, 0x00000000, 0x00244451, 0x004786A0, 0x004887A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F809C, 
        0x003E809C, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7D9A, 0x003A7D99, 0x00397D98, 0x00387C98,
  0x00397C98, 0x00397D98, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004686A0, 
        0x004786A1, 0x004887A1, 0x00427B94, 0x00020506, 0x00000000, 0x000F1D22, 0x003F7389, 0x004C8AA3, 0x00437990, 0x00264451, 0x00000101, 0x00000000, 0x0005090B, 0x000F1C21, 0x00000000, 0x00172931, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 
        0x005490A8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005792AA, 0x005792AA, 0x005892AA, 0x003F687A, 0x00000000, 0x00131F24, 0x00263F4A, 0x00040809, 0x00000000, 0x00000000, 0x00456F81, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x006098AF, 0x006098AF, 
        0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679EB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B6, 
        0x006CA1B7, 0x006DA2B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 
        0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x00557886, 0x000A0E0F, 0x00000000, 0x00243238, 0x006D99AB, 0x00364C55, 0x00000000, 0x000A0E0F, 0x00678FA0, 0x007EADC1, 0x007FAEC1, 0x007FAEC2, 0x007DABBE, 0x0033464E, 0x00010202, 0x00000000, 0x003F565F, 
        0x007CA8BB, 0x0082B1C3, 0x0082B1C4, 0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B3C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x0089B6C8, 
        0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACB, 0x0090BACC, 0x0090BACC, 
        0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 
        0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCE, 0x0094BDCE, 0x0095BDCF, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0094BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECE, 0x0095BECF, 0x0095BECF, 
        0x0095BECF, 0x0094BDCF, 0x0095BDCE, 0x0095BECE, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 
        0x0092BCCD, 0x0092BBCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x0090BACB, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 
        0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B3C6, 0x0086B3C6, 0x0085B3C6, 
        0x0085B2C5, 0x0084B2C5, 0x006A8F9F, 0x0012181B, 0x00000000, 0x00101619, 0x00638896, 0x0082B0C4, 0x0081AFC3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x0080AEC2, 0x007FAEC2, 0x007FAEC1, 0x007EADC1, 0x007EADC1, 0x00202C31, 0x00000000, 0x00020303, 
        0x00415B65, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0071A5BA, 0x0071A4BA, 
        0x0071A4B9, 0x0070A4B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B8, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 
        0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x00395F6E, 0x00000000, 
        0x00000000, 0x001F333C, 0x005691A9, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00294855, 0x00000000, 0x00192D35, 0x003A6679, 0x00101D22, 0x00000000, 0x00000000, 0x000C171B, 0x00356072, 
        0x0049869F, 0x004B89A3, 0x00274856, 0x00000000, 0x00030506, 0x00427B93, 0x004887A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F819C, 
        0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397C99,
  0x00397C99, 0x00397D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0045849F, 0x004585A0, 0x004686A0, 0x004686A0, 
        0x004787A1, 0x004887A1, 0x001C3540, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x00264552, 0x004A859E, 0x004D8BA4, 0x0042778D, 0x00101D22, 0x00000000, 0x00000000, 0x00000000, 0x004C859D, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AB, 0x00548BA3, 0x00111D22, 0x00213740, 0x005A94AC, 0x005B94AC, 0x00568DA4, 0x0005080A, 0x00000000, 0x001E3038, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 
        0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006A9FB6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 
        0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BE, 
        0x0078A9BE, 0x0078AABE, 0x005E8494, 0x00080C0D, 0x00000000, 0x001D282D, 0x0077A5B8, 0x007CACC0, 0x0078A6B9, 0x002A3A40, 0x00000000, 0x00090C0E, 0x006F99AA, 0x007FAEC2, 0x007CAABE, 0x00233035, 0x00000000, 0x00000000, 0x00547380, 0x0082B0C3, 
        0x0082B0C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C6, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 
        0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0090BBCC, 0x0091BBCC, 
        0x0091BBCD, 0x0091BBCC, 0x0092BCCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCD, 0x0093BDCE, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BECE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 
        0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 
        0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0095BECE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BCCE, 0x0094BDCE, 0x0093BCCE, 0x0093BDCE, 
        0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 
        0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B3C6, 0x0086B3C6, 0x0085B3C6, 
        0x0086B3C6, 0x0085B2C6, 0x0085B2C5, 0x0080ADBF, 0x00263439, 0x00000000, 0x00000000, 0x00526F7C, 0x0082B0C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x007FAFC2, 0x007FAEC2, 0x007EAEC1, 0x00506D7A, 0x00000000, 0x00000000, 0x00000000, 
        0x00020303, 0x0045616D, 0x007BABC0, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A8BC, 0x0075A7BC, 0x0075A7BC, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 
        0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006A9FB6, 0x006A9FB6, 0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00679DB3, 0x00669CB3, 
        0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005C96AD, 0x005C95AD, 0x005B94AC, 0x00436E80, 0x00070B0D, 0x00000000, 
        0x00000000, 0x00000000, 0x00457286, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528FA8, 0x00528EA7, 0x00070D10, 0x00000000, 0x00000000, 0x00000000, 0x00020405, 0x00274754, 0x004B87A0, 0x004C89A3, 
        0x003F7389, 0x00101D23, 0x00000000, 0x00000000, 0x00000000, 0x001C3540, 0x004887A2, 0x004887A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829C, 0x003F819C, 
        0x003F819C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397D99,
  0x00397D98, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F819C, 0x003F819D, 0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x004485A0, 0x004685A0, 0x004686A0, 0x004786A1, 
        0x004887A1, 0x003B7086, 0x00000000, 0x000B151A, 0x00264654, 0x000D181D, 0x00000000, 0x00000000, 0x00091114, 0x00345E6F, 0x004B879F, 0x004F8CA5, 0x00172931, 0x00000000, 0x002C4D5B, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x005590A9, 0x005590A9, 0x005691A9, 0x005791AA, 0x005792AA, 0x005892AB, 0x00406A7B, 0x00132025, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x003C6271, 0x00000000, 0x00000000, 0x00568BA1, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 
        0x006299B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 
        0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 
        0x0078AABE, 0x005E8494, 0x00070A0B, 0x00000000, 0x00233137, 0x007AABBF, 0x007CACC0, 0x007CACC0, 0x007DACC0, 0x00729DAF, 0x001D282C, 0x00000000, 0x00192226, 0x005E808F, 0x00151D20, 0x00000000, 0x0012181B, 0x00678C9C, 0x0082B0C3, 0x0082B0C4, 
        0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 
        0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 
        0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 
        0x0095BECF, 0x0096BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BFCF, 0x0096BED0, 0x0096BED0, 0x0096BED0, 0x0096BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BFCF, 0x0096BFCF, 0x0096BECF, 0x0096BFD0, 0x0096BFCF, 
        0x0096BECF, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 
        0x0093BDCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0091BACC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 
        0x008EB9CA, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0086B3C6, 
        0x0086B3C6, 0x0086B3C6, 0x0085B2C5, 0x0084B2C5, 0x0081AFC1, 0x00384C54, 0x00010101, 0x00000000, 0x00455F69, 0x007FADC0, 0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x00567684, 0x00000000, 0x00000000, 0x00354A53, 0x00344951, 
        0x00000000, 0x00000000, 0x004C6976, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 
        0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669CB3, 
        0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x00528499, 0x002E4A56, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x000C1418, 0x005690A8, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x003D6A7D, 0x00000000, 0x00000000, 0x001C323B, 0x0043788E, 0x004E8CA5, 0x0043798F, 0x0024424E, 
        0x00000000, 0x00000000, 0x00020405, 0x0014262E, 0x00091114, 0x00000000, 0x003C7086, 0x004887A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819C, 
        0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99,
  0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 
        0x004887A1, 0x00122128, 0x00000000, 0x00264653, 0x004A89A3, 0x00447E94, 0x002B4E5C, 0x00060B0D, 0x00000000, 0x00000000, 0x0015252C, 0x00325869, 0x00020304, 0x000D171B, 0x004A8198, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 
        0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x0052879E, 0x00508399, 0x005A94AC, 0x005B95AC, 0x005B95AD, 0x005C95AD, 0x00568AA1, 0x000D1619, 0x00000000, 0x0029414C, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 
        0x006299B1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00659CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 
        0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 
        0x00557886, 0x00080C0D, 0x00000000, 0x002C3E45, 0x0076A5B8, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x00709AAB, 0x00141B1F, 0x00000000, 0x00020303, 0x00000000, 0x001E292E, 0x007099A9, 0x0082B0C3, 0x0082B1C4, 0x0083B1C4, 
        0x0083B2C5, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 
        0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 
        0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECE, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BFD0, 0x0096BFD0, 0x0096BFD0, 
        0x0097BFD0, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 
        0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BFCF, 0x0096BED0, 0x0096BFCF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0095BDCF, 
        0x0094BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FBACB, 
        0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 
        0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C5, 0x0085B2C6, 0x0084B2C5, 0x00516D79, 0x00010101, 0x00000000, 0x0032444C, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x00618593, 0x000A0D0F, 0x00000000, 0x0028373D, 0x0079A6B9, 0x007EADC1, 
        0x00445E69, 0x00000000, 0x00000000, 0x00435D68, 0x007BABC0, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0075A8BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 
        0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA0B7, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 
        0x00669DB3, 0x00659CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x00335260, 0x000E161A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x002B4854, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x001D323B, 0x00000000, 0x003A677A, 0x004E89A2, 0x0024414D, 0x000A1216, 0x00000000, 
        0x00000000, 0x000F1C21, 0x00325D6E, 0x004B89A3, 0x00264655, 0x00000000, 0x00122229, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 
        0x0040819C, 0x003F809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99,
  0x003A7D99, 0x003B7D9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809C, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0043839E, 0x0043839E, 0x0043849E, 0x0045849F, 0x004585A0, 0x004585A0, 0x004786A1, 0x004787A1, 0x004787A1, 
        0x00336073, 0x00030607, 0x0004080A, 0x0047839C, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x00478199, 0x001D343E, 0x00000000, 0x00000000, 0x00010202, 0x00010202, 0x002D4F5E, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 
        0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AD, 0x005B95AD, 0x005C96AD, 0x005D96AE, 0x005C95AD, 0x002A444F, 0x00000000, 0x0005090A, 0x005C92A8, 0x006098B0, 0x006199B0, 0x006299B0, 
        0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 
        0x006FA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079A9BE, 0x005D8392, 
        0x000A0E0F, 0x00000000, 0x00233137, 0x0076A5B9, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x0054737F, 0x00000000, 0x00000000, 0x0027363C, 0x007FADBF, 0x0082B0C4, 0x0083B0C4, 0x0083B1C4, 0x0083B1C4, 
        0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCE, 0x0093BCCE, 
        0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BFD0, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 
        0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098BFD1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0098BFD1, 0x0098C0D0, 0x0098C0D0, 
        0x0098BFD0, 0x0097C0D0, 0x0098BFD0, 0x0097C0D0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFCF, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0096BECF, 0x0095BFCF, 0x0096BECF, 0x0095BECF, 
        0x0095BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 
        0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8C9, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 
        0x0087B4C7, 0x0087B4C6, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x0085B2C5, 0x0085B2C5, 0x00648896, 0x00080B0C, 0x00000000, 0x00202C31, 0x007EACBF, 0x0081B0C3, 0x0077A2B4, 0x000F1416, 0x00000000, 0x001B2529, 0x007CAABE, 0x007EAEC1, 0x007EADC1, 
        0x007CAABE, 0x00415A64, 0x00000000, 0x00020404, 0x0045616C, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 
        0x0073A6BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B7, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x00699FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 
        0x00679DB3, 0x00669DB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098AF, 0x004A7789, 0x000D1418, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00090F12, 0x00497B90, 0x005791AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x0044768A, 0x00040709, 0x00070C0E, 0x00091013, 0x00000000, 0x00000000, 0x00030708, 
        0x00325A6A, 0x0049859E, 0x004C8AA4, 0x004B89A3, 0x0047839C, 0x0004080A, 0x00030607, 0x00336174, 0x004887A1, 0x004787A1, 0x004786A1, 0x004685A0, 0x0045859F, 0x0045859F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0041839D, 0x0041829D, 0x0041819D, 
        0x0040819C, 0x003F809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E99, 0x003A7D99,
  0x003A7D99, 0x003C7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004787A1, 0x0046839C, 
        0x00182D36, 0x00000000, 0x002A4E5D, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8CA5, 0x003D6D80, 0x000C161A, 0x00000000, 0x000A1216, 0x004F8AA2, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 
        0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A93AC, 0x005A94AC, 0x005B95AC, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x00467082, 0x00050809, 0x00010203, 0x003A5C6B, 0x006199B0, 0x006199B0, 0x006299B1, 
        0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B8, 0x006EA2B8, 
        0x006FA3B9, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A4BA, 0x0072A5BB, 0x0073A6BA, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079A9BE, 0x006792A3, 0x000E1417, 
        0x00000000, 0x001D282D, 0x007AAABF, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007FAEC1, 0x007FAEC2, 0x00567682, 0x00000000, 0x00000000, 0x00354850, 0x0081B0C3, 0x0082B0C3, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 
        0x0085B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B5C7, 0x0088B4C7, 0x0089B5C8, 0x0089B5C7, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8C9, 0x008CB8CA, 0x008DB8CA, 
        0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BDCD, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 
        0x0094BDCE, 0x0094BDCE, 0x0094BECE, 0x0095BDCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0097BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 
        0x0098C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 0x0099C0D1, 
        0x0098C0D1, 0x0098C0D0, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BECF, 
        0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0095BDCF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 
        0x0090BACB, 0x0090BACC, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 
        0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x0086B3C6, 0x0086B3C6, 0x0085B3C5, 0x0085B2C5, 0x0085B2C5, 0x00648795, 0x000F1417, 0x00000000, 0x0027343A, 0x007097A8, 0x00151D20, 0x00000000, 0x00182125, 0x007AA8BA, 0x0080AFC2, 0x007FAEC2, 0x007EAEC1, 
        0x007EAEC1, 0x007EADC1, 0x00344850, 0x00000000, 0x00040606, 0x00557785, 0x007BABBF, 0x007AABBF, 0x0079ABBF, 0x0079AABF, 0x0078AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 
        0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 
        0x00679DB4, 0x00679DB3, 0x00659CB3, 0x00659CB3, 0x00659BB3, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006299B1, 0x006199B0, 0x00538497, 0x00243A43, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00030506, 0x00020404, 0x00000000, 0x0026404B, 0x005690A8, 0x005791AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00518CA5, 0x00203943, 0x00000000, 0x00000000, 0x00060C0E, 0x00213C47, 0x004C88A1, 
        0x004E8BA5, 0x004C8BA4, 0x004C8AA4, 0x004C8AA3, 0x004A89A3, 0x002A4D5D, 0x00000000, 0x00182E37, 0x0046839D, 0x004787A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 
        0x0040829D, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D809B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003A7E99,
  0x003B7E99, 0x003B7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x003A6D82, 
        0x00000000, 0x000A1216, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004D89A3, 0x001A2F37, 0x00000000, 0x00386273, 0x00518EA7, 0x00528EA7, 0x00538EA7, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 
        0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005D96AE, 0x00111B1F, 0x00000000, 0x001C2C33, 0x005E94AB, 0x006299B1, 0x00639AB1, 
        0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00679EB4, 0x00689EB5, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 
        0x006FA4B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x006791A2, 0x0011181A, 0x00000000, 
        0x00233137, 0x0077A5B8, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x004C6974, 0x00030404, 0x00000000, 0x00405861, 0x0080ADC1, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 
        0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C9, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CB, 
        0x008EB9CA, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACB, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BDCE, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 
        0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BFCF, 0x0096BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098BFD0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D1, 0x0097C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 
        0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D2, 0x0099C1D1, 0x0099C1D2, 0x009AC1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 0x0099C0D1, 0x0099C1D1, 
        0x0099C1D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0098C1D1, 0x0099C1D1, 0x0099C0D1, 0x0099C1D1, 0x0099C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0097C0D0, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0097BFD0, 
        0x0097BFD0, 0x0096BED0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 
        0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008EB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 
        0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B3C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B2C5, 0x006D92A2, 0x00192225, 0x00000000, 0x00090D0E, 0x00000000, 0x00192226, 0x00719BAC, 0x0081B0C3, 0x0080AFC2, 0x0080AFC2, 0x007FAEC2, 
        0x007FAEC2, 0x007EAEC1, 0x007EADC1, 0x00384E56, 0x00000000, 0x0006090A, 0x005A7D8C, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 
        0x0074A6BB, 0x0073A5BA, 0x0073A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 
        0x00689DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00639BB2, 0x00639BB1, 0x00598CA1, 0x002F4A56, 0x00090F11, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000B1215, 
        0x002A4550, 0x003E6676, 0x003C6272, 0x001E3139, 0x00020405, 0x0049798E, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA7, 0x0044778C, 0x00030607, 0x00030607, 0x00376273, 0x004F8CA6, 0x004F8CA5, 
        0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00091215, 0x00000000, 0x003A6D82, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042829E, 0x0041829D, 
        0x0040829D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A,
  0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004586A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x004887A1, 0x00162931, 
        0x00000000, 0x00346174, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8CA5, 0x004F8CA5, 0x003D6C80, 0x00000000, 0x0015262D, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005691AA, 
        0x005791AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005A93AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x00365764, 0x00000000, 0x00060A0C, 0x00517F92, 0x00629AB1, 0x00639AB1, 
        0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB4, 0x00699EB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 
        0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A8BD, 0x0076A8BC, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0078AABE, 0x006D99AB, 0x00131B1E, 0x00000000, 0x001B262A, 
        0x00719CAF, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x004C6874, 0x00000000, 0x00000000, 0x004F6C78, 0x0082B0C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 
        0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 0x008EB9CB, 
        0x008FB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 
        0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 
        0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 
        0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D1, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0099C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 
        0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 
        0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 
        0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0086B4C6, 0x0086B3C6, 0x0085B2C5, 0x0085B2C5, 0x00769FB0, 0x001E282C, 0x00000000, 0x00020203, 0x00618391, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x0080AFC2, 
        0x007FAEC2, 0x007EAEC2, 0x007EAEC1, 0x0079A8BB, 0x00354952, 0x00000000, 0x00060809, 0x005F8494, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BC, 
        0x0074A6BC, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006DA2B7, 0x006DA1B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 
        0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x003E616F, 0x000B1214, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x0031505C, 0x0054899F, 
        0x005A93AB, 0x005B94AC, 0x005A94AC, 0x00568EA6, 0x00223942, 0x0016242A, 0x005792AA, 0x005792AA, 0x005691AA, 0x005591AA, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00233D48, 0x00000000, 0x0026424E, 0x004F8DA6, 0x004F8CA6, 
        0x004E8CA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00346173, 0x00000000, 0x00162A32, 0x004887A2, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0044849F, 0x0044859F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0042829D, 
        0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E99,
  0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F819C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x003A6E84, 0x00000000, 
        0x00101D23, 0x00458098, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x00122027, 0x00000000, 0x0043758B, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005591A9, 0x005691A9, 0x005691AA, 
        0x005792AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AD, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x005F97AE, 0x00010202, 0x00000000, 0x00365561, 0x00629AB1, 0x00639AB1, 
        0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006FA2B8, 0x006FA3B8, 0x0070A3B9, 
        0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0073A6BA, 0x006FA1B5, 0x006FA0B4, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079A9BE, 0x0072A1B4, 0x0025343B, 0x00000000, 0x00000000, 0x00040606, 
        0x0051717E, 0x007BAABE, 0x007DADC0, 0x007DADC1, 0x007EADC1, 0x007FAEC1, 0x007FAEC2, 0x004B6772, 0x00000000, 0x00010202, 0x0052707C, 0x0082B0C4, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 
        0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 
        0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 
        0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098BFD1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D1, 0x009AC1D1, 0x009AC1D2, 
        0x009AC1D2, 0x009AC1D1, 0x009AC1D2, 0x009AC2D2, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009BC2D2, 
        0x009AC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC2D2, 0x009BC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D2, 0x0099C1D1, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 
        0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0092BCCD, 
        0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 
        0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B3C6, 0x0085B3C5, 0x0078A1B3, 0x00192225, 0x00000000, 0x00192226, 0x00749EAE, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 
        0x0080AFC2, 0x007FAFC2, 0x007EAEC1, 0x007EADC1, 0x0078A5B8, 0x00212E34, 0x00000000, 0x000F1518, 0x006993A4, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 
        0x0075A7BC, 0x0073A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B7, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x00699FB5, 0x00699FB5, 
        0x00689EB5, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00659AB1, 0x00568599, 0x00172429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x00162329, 0x00528498, 0x005D96AE, 0x005C95AD, 
        0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005389A1, 0x00070C0E, 0x003A6071, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x00518CA5, 0x00010203, 0x00080F12, 0x00467B91, 0x004F8CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00458098, 0x000F1D23, 0x00000000, 0x003B6F84, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042829E, 
        0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7E9A, 0x003B7E9A,
  0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004887A1, 0x004887A2, 0x00111F26, 0x00000000, 
        0x002A4E5E, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8BA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00386477, 0x00000000, 0x001C313A, 0x004F8AA3, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00548FA9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 
        0x005792AA, 0x005892AB, 0x00436E80, 0x00497A8E, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x002A434D, 0x00000000, 0x000B1214, 0x00639AB1, 0x00649BB2, 
        0x00659BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 
        0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x002C3F47, 0x00405B67, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x00324750, 0x00000000, 0x000D1214, 0x00334750, 0x00000000, 
        0x00000000, 0x00425B66, 0x007EADC1, 0x007EADC1, 0x007FAEC1, 0x007FAEC2, 0x004B6772, 0x00000000, 0x00010202, 0x004C6873, 0x0082B0C4, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0083B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 
        0x0086B4C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C8, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACB, 
        0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCE, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BED0, 0x0096BFD0, 
        0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D2, 0x009AC1D2, 0x009AC1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009BC1D2, 
        0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009CC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 
        0x009BC2D2, 0x009BC2D3, 0x009CC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D2, 0x0099C1D2, 0x0099C1D1, 0x009AC1D1, 0x0099C1D1, 0x0099C0D1, 0x0099C0D1, 
        0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0094BECF, 0x0094BDCE, 0x0093BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCE, 
        0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 
        0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x0085B3C5, 0x0085B2C5, 0x0079A1B3, 0x001F2A2F, 0x00000000, 0x001F2B2F, 0x0076A0B2, 0x0082B0C3, 0x0081B0C3, 0x0080AFC3, 
        0x0080AFC2, 0x0080AFC2, 0x007FAEC1, 0x007EAEC2, 0x007EAEC1, 0x0076A3B6, 0x00151D20, 0x00000000, 0x001D292D, 0x0074A2B4, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 
        0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 
        0x00699EB5, 0x00689EB4, 0x00689DB4, 0x00568397, 0x002C434D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00162328, 0x00406676, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005C96AE, 
        0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x00395E6D, 0x00040708, 0x0052889F, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00305463, 0x00000000, 0x002A4A57, 0x00508CA6, 
        0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x002A4F5E, 0x00000000, 0x00112026, 0x004887A1, 0x004787A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 
        0x0041829D, 0x0041829D, 0x0040819C, 0x003F819C, 0x003E819C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003B7F9A,
  0x003C7E9A, 0x003C7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042839D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x00346376, 0x00020304, 0x00080E11, 
        0x00467F98, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x000A1316, 0x00030607, 0x003B687B, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 
        0x005892AB, 0x00548DA4, 0x00080D10, 0x003C6475, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D95AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x0056879C, 0x00000000, 0x00000000, 0x00466E7E, 0x00649BB2, 
        0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA1B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0070A4B9, 
        0x0071A5BA, 0x0072A5BA, 0x0072A5BB, 0x0072A4BA, 0x0027383F, 0x00040607, 0x00628C9E, 0x0076A7BC, 0x0076A8BC, 0x0076A8BC, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABF, 0x00374D56, 0x00000000, 0x00050808, 0x005E8292, 0x007BABBF, 0x0045606B, 
        0x00000101, 0x00000101, 0x0031444C, 0x007BAABD, 0x007FAEC2, 0x00516E7B, 0x00020303, 0x00000000, 0x0053717E, 0x0082B0C3, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 
        0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 
        0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCF, 0x0094BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 
        0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D1, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009BC2D3, 
        0x009BC2D3, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 
        0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0098BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCE, 0x0095BDCE, 0x0094BDCE, 0x0094BDCE, 
        0x0093BDCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0085B3C6, 0x0085B2C5, 0x0079A4B5, 0x00243136, 0x00000000, 0x00182024, 0x007AA6B8, 0x0082B0C3, 0x0081B0C3, 
        0x0081AFC3, 0x0080AFC3, 0x007FAFC2, 0x007FAFC2, 0x007EAEC1, 0x00688F9F, 0x000D1214, 0x00000000, 0x00000000, 0x00233036, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 
        0x0076A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A5BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 
        0x006A9FB5, 0x00669CB2, 0x002F4852, 0x000A0F11, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060A0B, 0x003F6372, 0x005B90A7, 0x006097AF, 0x005F97AF, 0x005E97AF, 0x005D97AE, 0x005D96AE, 
        0x005C96AE, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x00192A31, 0x0029444F, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00528FA8, 0x004C839B, 0x000D161A, 0x00000101, 0x004B859D, 
        0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00457F98, 0x00070E11, 0x00020304, 0x00346376, 0x004887A1, 0x004786A1, 0x004786A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849E, 0x0042839E, 
        0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F809C, 0x003E809C, 0x003E809B, 0x003C7F9B, 0x003C7E9A,
  0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0043849F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004786A1, 0x004787A1, 0x0047859F, 0x00192E37, 0x00000000, 0x00264553, 
        0x004A89A3, 0x004C89A3, 0x004C8AA4, 0x004C8AA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x00305666, 0x00000101, 0x00142229, 0x00528EA6, 0x00528FA8, 0x00538EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AB, 
        0x005893AB, 0x0020363F, 0x00070C0E, 0x005891A8, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x005F94AC, 0x001D2D34, 0x00000000, 0x00121D21, 0x00649BB2, 
        0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x006FA3B8, 0x0070A2B7, 
        0x0070A3B7, 0x0070A2B7, 0x00577D8E, 0x00121A1D, 0x00000000, 0x00374E58, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x004B6A76, 0x00010202, 0x00020404, 0x00496672, 0x007CACC0, 0x007CACC0, 0x007CACC0, 
        0x00496571, 0x00010202, 0x00000000, 0x002F4149, 0x00577885, 0x00000000, 0x00000000, 0x0053727E, 0x0082B0C3, 0x0082B0C3, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C6, 0x0087B4C7, 
        0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 
        0x0091BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCE, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 
        0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D4, 0x009DC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC3D3, 0x009DC3D3, 0x009DC4D3, 0x009DC3D4, 0x009DC3D3, 0x009DC3D3, 0x009DC3D4, 0x009DC3D4, 0x009DC3D4, 0x009DC3D4, 
        0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 
        0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 
        0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0092BBCC, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x0086B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B2C5, 0x0079A1B3, 0x001A2327, 0x00000000, 0x001D272B, 0x007BA7BA, 0x0082B0C4, 
        0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x0080AFC2, 0x00658A9A, 0x000D1214, 0x00000000, 0x00050809, 0x00060809, 0x00000000, 0x0032464E, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 
        0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x00699DB3, 
        0x00507889, 0x000B1114, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010303, 0x00273E48, 0x006096AE, 0x006199B0, 0x006099B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 
        0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005994AC, 0x0049798D, 0x0005090B, 0x004C7E93, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x002D4F5D, 0x00000000, 0x00203943, 
        0x00508CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x00254552, 0x00000000, 0x00192F38, 0x004786A0, 0x004786A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 
        0x0042839E, 0x0041829D, 0x0041829D, 0x0040819C, 0x003F819C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9A,
  0x003C7F9A, 0x003E7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043839F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x003B6F85, 0x00050A0C, 0x00030608, 0x0048869F, 
        0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004B859E, 0x00132127, 0x00000000, 0x003F6E82, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 
        0x00457284, 0x00020304, 0x0017262C, 0x005A94AC, 0x005B94AD, 0x005B95AD, 0x005C96AD, 0x005D96AE, 0x005E96AE, 0x005F97AE, 0x005F97AF, 0x006098B0, 0x006098AF, 0x006199B0, 0x006299B0, 0x00629AB1, 0x003E6170, 0x00000000, 0x00000000, 0x00517E90, 
        0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x00699EB5, 0x00679AB0, 0x006495A9, 0x006191A5, 0x005F8DA0, 0x005D899B, 0x00598496, 0x00577F90, 0x00537989, 0x004D717F, 0x0043616E, 0x00344B56, 
        0x00213137, 0x00080C0E, 0x00000000, 0x00000000, 0x000D1215, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x00618999, 0x000B1011, 0x00000000, 0x00334750, 0x007BACC0, 0x007CACC0, 0x007DACC0, 0x007DADC1, 
        0x007EADC1, 0x00557682, 0x000A0E0F, 0x00000000, 0x00000000, 0x00010101, 0x00445D68, 0x0081B0C3, 0x0082B0C3, 0x0083B1C4, 0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 
        0x0089B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 
        0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0094BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 
        0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x009AC2D2, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC3D3, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 
        0x009DC3D4, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009EC4D4, 
        0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D3, 0x009DC4D3, 0x009CC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009CC2D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 
        0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCF, 
        0x0094BDCE, 0x0094BDCE, 0x0094BCCE, 0x0093BCCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0091BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008CB8CA, 
        0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x0086B4C6, 0x0086B3C6, 0x0085B3C6, 0x0085B2C5, 0x00729AAA, 0x00141B1E, 0x00000000, 0x002E3F45, 0x007DABBD, 
        0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x005E818F, 0x000A0E0F, 0x00000000, 0x00161E22, 0x00668D9D, 0x00506E7B, 0x00010203, 0x00010202, 0x004C6A76, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 
        0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B7, 0x00568092, 0x0024363E, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x001A292F, 0x004D788A, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005E97AF, 0x005E96AE, 
        0x005D96AE, 0x005D96AE, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005389A1, 0x0005090B, 0x00243D47, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x00497E95, 0x00091114, 0x00010303, 
        0x00467A91, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x0048859F, 0x00030607, 0x00050A0C, 0x003C7086, 0x004887A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0043849F, 0x0043839E, 
        0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003D7F9A,
  0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004887A1, 0x004887A1, 0x00234250, 0x00000000, 0x00284B59, 0x004A89A3, 
        0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x00396678, 0x00000000, 0x0017282F, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x00558EA5, 
        0x001C2F36, 0x00000000, 0x000E181C, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x005A8CA1, 0x000D1518, 0x00000000, 0x0021333A, 
        0x00507A8C, 0x00476C7C, 0x00406270, 0x003A5864, 0x00334E59, 0x002C434D, 0x00273B43, 0x00213239, 0x001D2C32, 0x001B282D, 0x00172227, 0x00141D21, 0x0010181B, 0x000C1315, 0x00090E0F, 0x0006080A, 0x00010102, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00587D8D, 0x0075A8BC, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0075A4B8, 0x00141C20, 0x00000000, 0x00293940, 0x007AAABE, 0x007CACC0, 0x007DADC1, 0x007DACC1, 0x007DADC1, 
        0x007FAEC1, 0x007FAEC2, 0x004E6B77, 0x00000000, 0x00000000, 0x003B515A, 0x0081AFC3, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B4C7, 0x0089B5C7, 
        0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0090BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 
        0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C0D1, 0x0099C1D1, 
        0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 
        0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D4, 0x009EC4D4, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009FC5D5, 0x009FC5D4, 0x009FC5D5, 0x009FC4D4, 0x009FC4D5, 0x009FC5D5, 0x009EC5D4, 0x009EC5D4, 
        0x009EC4D4, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009DC4D3, 0x009DC4D3, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 
        0x009CC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0096BECF, 
        0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 
        0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B3C6, 0x0086B3C6, 0x0085B3C6, 0x0085B2C5, 0x007199A9, 0x0011171A, 0x00000000, 0x0032444B, 
        0x0083B1C4, 0x0082B0C4, 0x00516F7B, 0x00080A0C, 0x00000000, 0x00243238, 0x007099AB, 0x007EAEC1, 0x007EADC1, 0x003F5862, 0x00000000, 0x00080C0D, 0x00658E9E, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 
        0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BC, 0x00648FA2, 0x00527685, 0x0073A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006494A8, 0x00293E47, 0x0006090A, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00131D22, 0x00466C7C, 0x006399AF, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00629AB1, 0x006199B1, 0x006198B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 
        0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x00558BA2, 0x000C1518, 0x00000000, 0x00467488, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x0026434F, 0x00000000, 
        0x00223C46, 0x00508CA6, 0x004F8CA5, 0x004E8CA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00284A58, 0x00000000, 0x00244350, 0x004887A1, 0x004887A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849E, 
        0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B,
  0x003D7F9B, 0x003D809B, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004685A0, 0x004686A0, 0x004786A0, 0x004887A1, 0x0046849E, 0x00010303, 0x00040708, 0x0046829B, 0x004B89A3, 
        0x004B8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004F8CA5, 0x004E8BA5, 0x00172A32, 0x00000000, 0x00457A90, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x00416E80, 
        0x00000000, 0x00000000, 0x00010102, 0x0020353D, 0x00477487, 0x00518499, 0x004F8095, 0x00497688, 0x00406878, 0x003A5C6B, 0x0032505C, 0x002A424C, 0x0022363E, 0x001A282E, 0x00111B1F, 0x000A0F12, 0x00040708, 0x00000101, 0x00000000, 0x00000000, 
        0x00020303, 0x00010202, 0x00010102, 0x00000101, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00273840, 0x0071A2B6, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x001F2C31, 0x00000000, 0x00172023, 0x0075A2B5, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EADC1, 
        0x007FAEC2, 0x0079A5B8, 0x000E1315, 0x00000000, 0x0032454C, 0x0081B0C3, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 
        0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 
        0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 
        0x009AC2D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC4D3, 0x009DC4D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D4, 
        0x009EC5D4, 0x009FC5D5, 0x009FC4D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009CC3D3, 0x009BC3D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 
        0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BECE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0091BACC, 0x0090BACC, 0x008FBACB, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008EB8CB, 
        0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B4C6, 0x0085B2C6, 0x0085B3C5, 0x006D92A2, 0x000C1012, 0x00000000, 
        0x00394D55, 0x0053717E, 0x00050607, 0x00000000, 0x0029393F, 0x0077A4B5, 0x007FAEC2, 0x007FAEC2, 0x007EAEC1, 0x007EADC1, 0x002C3D44, 0x00000000, 0x000E1315, 0x007BAABE, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 
        0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x00547988, 0x00040607, 0x006A9AAD, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0070A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x003D5A67, 0x00030405, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003B5A67, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006299B0, 0x006199B0, 0x006198B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 
        0x005E97AF, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x004B7B8F, 0x00000000, 0x00000000, 0x000D1519, 0x005792AB, 0x005691AA, 0x005691AA, 0x005591A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00508BA4, 0x00000101, 
        0x000B1316, 0x0045798F, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x0047829B, 0x0005090B, 0x00020304, 0x0046849D, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 
        0x0042849F, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B,
  0x003D809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041839D, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x0046859F, 0x004686A0, 0x004786A0, 0x004787A1, 0x004887A1, 0x00264755, 0x00000000, 0x00000000, 0x000C171B, 0x002A4D5C, 
        0x0042788F, 0x004C89A2, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x0042768C, 0x00000000, 0x001A2E37, 0x00508CA5, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005892AA, 0x005691A8, 0x00101C20, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x0006090A, 0x005A8191, 0x0076A7BC, 0x0076A8BC, 0x0077A8BD, 0x0078A9BD, 0x0078A9BD, 0x0078A9BE, 0x003C555F, 0x00000000, 0x00090C0E, 0x005F8595, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 
        0x0079A6B9, 0x00182125, 0x00000000, 0x0026353A, 0x0082B0C3, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 
        0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 
        0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D2, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 
        0x009BC2D2, 0x009BC2D2, 0x009BC3D3, 0x009BC3D2, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x009EC5D4, 0x009FC4D4, 0x009FC4D5, 0x009FC5D5, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 
        0x00A0C5D5, 0x009FC5D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC5D4, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D3, 
        0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 
        0x0097BFCF, 0x0096BED0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 
        0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 0x0086B3C6, 0x0085B3C5, 0x0085B2C6, 0x00587784, 0x00060809, 
        0x00000000, 0x00000000, 0x00010202, 0x0031434A, 0x0081B0C3, 0x0080AFC2, 0x0080AFC2, 0x007FAEC2, 0x007EAEC2, 0x007EAEC1, 0x0075A2B4, 0x00171F23, 0x00000000, 0x00243238, 0x007BACC0, 0x007AABBF, 0x007AAABF, 0x007AAABE, 0x0079AABE, 0x0078A9BE, 
        0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BC, 0x00223137, 0x00233238, 0x0071A2B7, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x006B9CB1, 0x00557C8D, 0x00162125, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00050809, 0x0023353D, 0x006092A7, 0x00689DB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00639AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005B93AB, 0x00467384, 0x0006090B, 0x00000000, 0x00000000, 0x00000000, 0x00325361, 0x005792AA, 0x005691AA, 0x005591AA, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x002A4B58, 
        0x00000000, 0x00305564, 0x00508CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x0047829A, 0x0039687C, 0x00192E37, 0x00010202, 0x00000000, 0x00264856, 0x004887A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x0045859F, 0x0044849F, 0x0044849F, 
        0x0044849F, 0x0042839E, 0x0042839D, 0x0041829D, 0x0041819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003D7F9B,
  0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x0046849E, 0x0005090B, 0x00020405, 0x000A1317, 0x00000000, 0x00000000, 
        0x00080E11, 0x001F3842, 0x003A687B, 0x004E8BA5, 0x004F8CA5, 0x00142329, 0x00000000, 0x00396476, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005591A9, 0x005692AA, 0x005792AA, 0x005892AB, 0x002F4E5B, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x002B3D45, 0x0076A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x005A7F8F, 0x00060809, 0x00000000, 0x0047636E, 0x007CACC0, 0x007CACC0, 0x007DACC0, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x007BA8BB, 
        0x002A393F, 0x00000000, 0x00192226, 0x00749FB0, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 
        0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 
        0x0095BDCE, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 
        0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C6D5, 
        0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x009FC6D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D5, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 
        0x009DC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 
        0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECE, 0x0094BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 
        0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0085B3C6, 0x0085B2C5, 0x004E6974, 
        0x00000000, 0x00000000, 0x00374B53, 0x0082B1C4, 0x0081B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x007FAEC2, 0x007EADC1, 0x005F8493, 0x00050809, 0x00000000, 0x00425C67, 0x007BABC0, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 
        0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x006A97AB, 0x0006090A, 0x0027383F, 0x00557B8C, 0x005F899B, 0x00446370, 0x00213036, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00213239, 0x004E7686, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 
        0x005E97AF, 0x005E97AE, 0x005D96AE, 0x0054889E, 0x00263F49, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D161A, 0x004E8398, 0x005692AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538EA7, 0x004D859D, 
        0x0005080A, 0x00091114, 0x00508DA6, 0x004F8CA6, 0x004E8BA5, 0x00477F96, 0x002B4F5D, 0x00132228, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00050A0C, 0x0046849F, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 
        0x0043849F, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809C,
  0x003E809B, 0x003F809C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x002B5060, 0x00000000, 0x00122128, 0x0047839B, 0x00325B6C, 0x000B1519, 
        0x00000000, 0x00000000, 0x00030607, 0x00122228, 0x002B4C5B, 0x00000000, 0x00101C21, 0x004E879F, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x004D7F94, 0x00040608, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00010102, 0x006F9EB2, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0075A4B8, 0x0010171A, 0x00000000, 0x002F424A, 0x007BACBF, 0x007CACC0, 0x007DACC1, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x007EADC1, 0x00425B65, 
        0x00000000, 0x00050607, 0x006F98A9, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 
        0x008BB7C9, 0x008CB7CA, 0x008CB7CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BECE, 
        0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC3D3, 0x009CC2D3, 0x009CC3D3, 
        0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D5, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A0C6D6, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A1C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC5D5, 
        0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC3D3, 0x009CC2D2, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 
        0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 
        0x008FBACB, 0x008FB9CB, 0x008EB9CA, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C6, 0x0086B3C7, 0x0086B3C6, 0x0085B3C5, 0x0085B2C6, 
        0x00465E68, 0x00000000, 0x000A0D0F, 0x007AA4B7, 0x0082B0C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x007FAFC2, 0x007FAEC2, 0x007FAEC2, 0x007EADC1, 0x0047626D, 0x00000000, 0x0006090A, 0x00648A9B, 0x007BACC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 
        0x0079AABE, 0x0079A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x00415D69, 0x00000000, 0x00050708, 0x00070A0B, 0x00020303, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00090D0F, 0x004D7383, 0x00679AB0, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB3, 0x00669DB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098AF, 0x006098AF, 
        0x005F98AF, 0x005E97AF, 0x00355562, 0x0005090A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002E4D5A, 0x005691A9, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00518DA5, 
        0x00274551, 0x00000000, 0x00345B6C, 0x004E8AA3, 0x00233F4B, 0x00070D0F, 0x00010202, 0x00000000, 0x00000000, 0x001F3843, 0x0040758B, 0x00112026, 0x00000000, 0x002B5161, 0x004787A1, 0x004787A1, 0x004786A1, 0x004685A0, 0x0045859F, 0x0044849F, 
        0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F809C, 0x003E809C,
  0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004787A1, 0x0045849E, 0x00101E24, 0x00000000, 0x00305869, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 
        0x00345F70, 0x00101C22, 0x00030507, 0x00000000, 0x00000000, 0x00000000, 0x002D4E5C, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005692AA, 0x005792AA, 0x005792AA, 0x0020353D, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010303, 0x00030405, 0x00040607, 0x00020404, 
        0x00000000, 0x00000101, 0x00070B0D, 0x00080C0E, 0x00090E10, 0x000A1012, 0x000D1416, 0x00131D21, 0x001A272D, 0x0022333A, 0x002B4048, 0x00344C56, 0x003C5864, 0x00446471, 0x004E7180, 0x00547A8B, 0x004D707E, 0x001F2D33, 0x00000000, 0x00000000, 
        0x00000000, 0x00466471, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x002B3D44, 0x00000000, 0x00000000, 0x00476470, 0x0079A8BC, 0x007DACC0, 0x007DADC1, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x005E8290, 0x00000000, 
        0x00000000, 0x00648897, 0x0082B0C3, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0088B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008CB7C9, 
        0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 
        0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 
        0x009DC4D4, 0x009DC3D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 
        0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 
        0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009EC4D4, 0x009DC3D4, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D2, 0x0099C1D1, 0x0099C0D1, 
        0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 
        0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0086B4C6, 0x0086B3C6, 0x0085B3C5, 
        0x0082AEC1, 0x002D3C43, 0x00000000, 0x00161E21, 0x0080ADC0, 0x0082B0C3, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x0080AEC2, 0x007FAEC2, 0x007FAEC2, 0x007EADC1, 0x0027363D, 0x00000000, 0x00182226, 0x0077A7BA, 0x007BABBF, 0x007AABBF, 0x007AAABF, 
        0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x006995A8, 0x00141C20, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040607, 0x00304751, 
        0x006DA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006098B0, 0x005E95AB, 
        0x004C798C, 0x00111C20, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020405, 0x004F849A, 0x005791AA, 0x005590A9, 0x005591A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 
        0x00417185, 0x00050A0B, 0x0005090B, 0x00050A0C, 0x00000000, 0x00000101, 0x00070D0F, 0x00203B46, 0x00467F97, 0x004C8AA4, 0x004B89A3, 0x002F5868, 0x00000000, 0x00101E24, 0x0046849E, 0x004786A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 
        0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003E809C,
  0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044859F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x0037677B, 0x00030608, 0x00070D0F, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 
        0x004D8BA4, 0x004E8BA5, 0x00386678, 0x00192D35, 0x00000000, 0x0005080A, 0x004E89A1, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x00447184, 0x0005080A, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x00060A0B, 0x000B1114, 0x000F191C, 0x00142125, 0x0019282E, 0x001F3038, 0x00243840, 0x00294049, 0x002F4853, 0x0035525E, 0x003C5C69, 0x00426574, 0x00496F7F, 0x00334E5A, 
        0x00000000, 0x00030405, 0x005B889B, 0x006092A5, 0x006699AE, 0x006BA1B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B8, 0x0071A4B9, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x001C292E, 0x00000000, 
        0x00192429, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x00486672, 0x00000000, 0x00030405, 0x00010202, 0x00000000, 0x0026353B, 0x006991A3, 0x007DADC1, 0x007EAEC2, 0x007FAEC2, 0x00688F9F, 0x00060809, 0x00000000, 
        0x004C6873, 0x0081B0C3, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0088B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 
        0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x0090BACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 
        0x0096BECF, 0x0096BFD0, 0x0097C0D0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 
        0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 
        0x00A2C7D6, 0x00A2C7D7, 0x00A2C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C8D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A3C7D7, 0x00A3C8D7, 
        0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A2C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A1C6D5, 0x00A0C6D5, 0x00A0C6D5, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009FC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009CC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 
        0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0097BFCF, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 
        0x0090BACC, 0x0090BACB, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0086B4C6, 0x0085B3C6, 
        0x0085B2C6, 0x00769EAF, 0x00151C1F, 0x00000000, 0x0034464E, 0x0080AEC0, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x0080AEC2, 0x007FAEC2, 0x007EAEC1, 0x0076A4B7, 0x00182125, 0x00000000, 0x0032454D, 0x007BACC0, 0x007BABBF, 0x007AAABF, 
        0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0044616D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00293D45, 0x005B8799, 0x006DA2B7, 
        0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00649AB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x004E7B8E, 0x00263C45, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001B2D35, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 
        0x00518CA5, 0x0017282F, 0x00000000, 0x00020304, 0x0015252C, 0x002B4D5B, 0x00467D94, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B8AA3, 0x004A89A3, 0x00060C0F, 0x00030608, 0x0038677C, 0x004887A1, 0x004786A1, 0x004786A0, 0x004685A0, 0x004585A0, 
        0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003E809C,
  0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041839D, 0x0043839E, 0x0043839E, 0x0044849E, 0x0044859F, 0x004585A0, 0x004685A0, 0x004686A1, 0x004786A1, 0x0047859F, 0x0022404C, 0x00000000, 0x002A4E5D, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 
        0x004E8BA4, 0x004E8BA5, 0x004F8CA5, 0x002C4F5D, 0x00000000, 0x00294855, 0x00518EA7, 0x00538FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x001A2C33, 0x00000000, 0x00000000, 0x00000000, 
        0x00030506, 0x001A2B32, 0x002E4B56, 0x003E6575, 0x004A7789, 0x004E7E92, 0x00518196, 0x0054869A, 0x00578A9E, 0x00598DA2, 0x005C91A7, 0x005F94AA, 0x006197AF, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00669CB3, 0x00679DB3, 0x00679DB3, 0x00588699, 
        0x000B1114, 0x00000000, 0x00426472, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0074A6BB, 0x003F5B66, 0x00000000, 
        0x00557988, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x00638C9C, 0x000B1012, 0x00000000, 0x003B525C, 0x00597C8A, 0x00050809, 0x00000000, 0x000B1012, 0x00547480, 0x007FAEC2, 0x0075A1B3, 0x00161E22, 0x00000000, 0x002F4047, 
        0x007FADBF, 0x0082B1C4, 0x0083B1C4, 0x0083B1C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008CB7C9, 0x008CB7CA, 0x008CB7CA, 
        0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0094BECE, 0x0095BECF, 0x0095BECF, 0x0096BED0, 0x0096BECF, 
        0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 
        0x009FC4D4, 0x009EC4D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C8D7, 0x00A3C7D7, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C8D7, 0x00A4C8D8, 0x00A4C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A4C8D8, 
        0x00A4C8D7, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 
        0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC3D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 
        0x009AC1D2, 0x009AC1D2, 0x0099C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BED0, 0x0095BECF, 0x0095BECF, 0x0094BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCC, 0x0091BBCC, 
        0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB8CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 
        0x0086B3C6, 0x0085B3C5, 0x006E93A3, 0x00000000, 0x00000000, 0x0055737F, 0x0082B1C4, 0x0082B0C4, 0x0081AFC3, 0x0081AFC3, 0x0080AFC3, 0x007FAEC2, 0x007FAEC2, 0x0079A7BB, 0x00222F34, 0x00000000, 0x00000101, 0x004E6D79, 0x007BABBF, 0x007AABBF, 
        0x007AABBF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x00141D21, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00192429, 0x005A8495, 0x006C9FB5, 0x006EA3B8, 0x006EA2B8, 
        0x006EA2B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006A9FB6, 0x006A9FB6, 0x00699FB5, 0x00689FB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00639BB2, 0x006299B0, 0x002A424D, 0x00070C0D, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0005090A, 0x002F4D5A, 0x0049798C, 0x0048788C, 0x00213841, 0x00000000, 0x003B6474, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 
        0x00538EA8, 0x00376071, 0x00000000, 0x000F1B1F, 0x004A839B, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x002A4E5D, 0x00000000, 0x0022414D, 0x0047859F, 0x004787A1, 0x004686A1, 0x004686A0, 0x004585A0, 
        0x0045859F, 0x0044849F, 0x0043839F, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F809C,
  0x003F819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004887A1, 0x0044819B, 0x00070D0F, 0x00010203, 0x0048859F, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 
        0x004D8BA5, 0x004F8CA5, 0x004B859E, 0x000F1A1F, 0x00000000, 0x00508CA5, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005892AB, 0x003F6A7C, 0x00000000, 0x00000000, 0x00132025, 0x00436E81, 
        0x005B95AD, 0x005C96AD, 0x005D95AE, 0x005D97AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00679EB4, 0x00679DB3, 
        0x0022343B, 0x00000000, 0x00141F23, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x00233238, 0x001F2D32, 
        0x0074A6B9, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0075A4B8, 0x002A3A41, 0x00000000, 0x00141C1F, 0x007BABBF, 0x007CACC0, 0x0074A0B4, 0x001C282C, 0x00000000, 0x00000000, 0x00304249, 0x0032444C, 0x00000000, 0x0011171A, 0x007CA9BC, 
        0x0082B0C4, 0x0083B0C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 
        0x008DB8CB, 0x008DB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECE, 0x0095BECF, 0x0096BECF, 0x0096BED0, 0x0096BFD0, 0x0097BFD0, 
        0x0097BFD0, 0x0098C0D0, 0x0098C0D0, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D5, 0x009FC5D4, 
        0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 
        0x00A4C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 
        0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A4C8D7, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C7D6, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D2, 0x009BC2D2, 
        0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 
        0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 
        0x0086B4C6, 0x0086B3C6, 0x0085B2C5, 0x005B7B88, 0x00000000, 0x00030404, 0x00749DAE, 0x0082B1C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC3, 0x006A91A2, 0x000E1316, 0x00000000, 0x00010203, 0x00000000, 0x0012191C, 0x006D97AA, 0x007BABBF, 
        0x007BABBF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x00638D9F, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00324851, 0x006FA2B6, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 
        0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00456C7C, 0x00050809, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00263F49, 0x005991A8, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x0027414C, 0x000D1519, 0x00528BA2, 0x005691AA, 0x005691A9, 0x005490A9, 0x00548FA8, 0x00548FA8, 
        0x00538FA8, 0x00528EA7, 0x00091012, 0x0005090B, 0x003D6D80, 0x004F8CA6, 0x004F8CA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x0048859F, 0x00010203, 0x00070D10, 0x0044819B, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 
        0x004585A0, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C,
  0x003F819C, 0x0040819C, 0x0041829D, 0x0041829E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x00315D6F, 0x00000000, 0x00203C47, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 
        0x004E8BA5, 0x004F8CA5, 0x003C6B7E, 0x00000000, 0x0024404B, 0x00518DA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x00558DA4, 0x00070D0F, 0x00080D0F, 0x00395E6D, 0x005B94AC, 0x005B95AD, 
        0x005C95AD, 0x005D95AD, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659CB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB4, 
        0x00456877, 0x00010202, 0x0006090A, 0x00527A8B, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x006692A5, 0x00000000, 0x005E8596, 
        0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0050717E, 0x00000000, 0x00030505, 0x006A93A4, 0x007CACC0, 0x007CACC0, 0x007DADC0, 0x007CAABD, 0x003C535D, 0x00050809, 0x00000000, 0x00000000, 0x00050708, 0x006B93A2, 0x0082B0C4, 
        0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C8, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 
        0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BED0, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 
        0x0098C0D0, 0x0098C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009CC2D2, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 
        0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A4C9D8, 
        0x00A4C8D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C7D7, 
        0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D2, 
        0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BECE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 
        0x0092BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 
        0x0087B4C6, 0x0086B3C6, 0x0085B3C6, 0x0085B3C5, 0x00394D55, 0x00000000, 0x00161E21, 0x007DAABC, 0x0082B0C4, 0x0081AFC3, 0x007EACBF, 0x004A6571, 0x00040506, 0x00000000, 0x0011181B, 0x004F6C79, 0x0011171A, 0x00000000, 0x00364C55, 0x007BABC0, 
        0x007AABBF, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x00324851, 0x00000000, 0x00000000, 0x002A3E46, 0x0072A5BA, 0x0071A4B9, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 
        0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA1B7, 0x006BA1B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x004C7687, 0x001D2D34, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00010203, 0x001D2F37, 0x004D7C90, 0x005D96AD, 0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005893AB, 0x00142126, 0x00315360, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 
        0x00538FA8, 0x00528EA7, 0x00355C6D, 0x00000000, 0x00274552, 0x004E8AA4, 0x004F8CA5, 0x004E8CA5, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004B89A4, 0x004B89A3, 0x00203B47, 0x00000000, 0x00325D70, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 
        0x0045859F, 0x0045849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0041839E, 0x0041829D, 0x0040819D, 0x003F819C,
  0x0040819C, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004886A1, 0x004887A2, 0x000C171B, 0x00000101, 0x0038687B, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 
        0x004E8BA5, 0x004F8CA6, 0x0014232A, 0x00010202, 0x00417084, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AB, 0x00263F4A, 0x00030506, 0x0048778B, 0x005A94AC, 0x005B94AC, 0x005C95AD, 
        0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00689DB4, 0x00689EB5, 0x00699EB5, 
        0x00699EB4, 0x00090D0F, 0x00000000, 0x00334B56, 0x006BA0B6, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x006B99AD, 0x00507381, 0x0076A8BD, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x006F9CAE, 0x0006090A, 0x00000000, 0x004B6975, 0x007CACC0, 0x007CACC0, 0x007DADC0, 0x007EADC1, 0x007EADC1, 0x007FAEC2, 0x004C6773, 0x00000000, 0x00000000, 0x00557481, 0x0082B0C4, 0x0082B1C4, 
        0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 
        0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCE, 0x0096BECF, 0x0096BECF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0098BFD0, 0x0098C0D1, 
        0x0098C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009EC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 
        0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A3C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6C9D8, 0x00A5CAD8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 
        0x00A3C7D7, 0x00A3C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BED0, 0x0095BECF, 0x0095BECF, 0x0094BECE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 
        0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 
        0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0086B3C5, 0x007BA4B6, 0x00182125, 0x00000000, 0x0033454C, 0x0082B1C4, 0x0079A4B7, 0x002B3B41, 0x00010202, 0x00000000, 0x0029383E, 0x006D96A7, 0x007EADC1, 0x00658B9B, 0x00000000, 0x00000000, 0x005F8494, 
        0x007BACC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BE, 0x0077A8BD, 0x0076A8BC, 0x0076A8BC, 0x006692A4, 0x000D1316, 0x00000000, 0x00598091, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 
        0x006EA3B8, 0x006DA2B8, 0x006DA1B7, 0x006DA1B7, 0x006BA1B6, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x0059889C, 0x0022343C, 0x0006090A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x0017242A, 0x00477183, 0x005C94AB, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x004B7D92, 0x00437184, 0x005691A9, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 
        0x00538FA8, 0x00538EA7, 0x00518CA5, 0x00070C0F, 0x00091114, 0x004C869F, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x0039677C, 0x00000101, 0x000C171B, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 
        0x004685A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819C,
  0x0040819C, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x003A6D83, 0x00000000, 0x00101D23, 0x00457F97, 0x004B89A3, 0x004C8AA3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 
        0x004F8BA5, 0x0045798F, 0x00000000, 0x0015252C, 0x004D879F, 0x00528EA7, 0x00538EA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x00497B90, 0x0005090A, 0x0048778A, 0x005993AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 
        0x005C96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639BB1, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00669CB3, 0x00679DB3, 0x00679DB3, 0x00689EB4, 0x00699EB5, 0x00699FB5, 
        0x006A9FB5, 0x00344E59, 0x00000000, 0x00121B1E, 0x006495A9, 0x006DA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 
        0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABF, 0x00202C32, 0x00000000, 0x00212F35, 0x0074A3B6, 0x007CACC0, 0x007DADC0, 0x007EADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x00182024, 0x00000000, 0x0031424A, 0x007EABBE, 0x0082B1C4, 0x0083B1C4, 
        0x0084B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 
        0x008FBACB, 0x0090BACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 
        0x0099C1D1, 0x0099C1D2, 0x009AC1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D3, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 
        0x00A1C6D6, 0x00A1C7D6, 0x00A1C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A5CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CBD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CAD9, 
        0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC4D5, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 
        0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECE, 0x0094BDCF, 0x0094BDCE, 0x0093BCCE, 
        0x0093BCCE, 0x0092BCCD, 0x0091BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 
        0x0088B5C7, 0x0087B4C7, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x00688C9B, 0x00010101, 0x00060809, 0x003E535D, 0x000D1214, 0x00000000, 0x00040606, 0x004D6975, 0x007FAEC1, 0x007FAEC2, 0x007FAEC2, 0x007DACC0, 0x003E5660, 0x00000000, 0x000B0F11, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x003A535E, 0x00000000, 0x00577E8E, 0x0073A5BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 
        0x006FA3B9, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00385662, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00040708, 0x003C606F, 0x005E95AC, 0x006098AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A8, 
        0x005490A8, 0x00538FA8, 0x00528EA7, 0x002C4C59, 0x00000000, 0x00386475, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x00447E96, 0x000F1D22, 0x00000000, 0x003A6E84, 0x004887A1, 0x004786A1, 0x004686A0, 
        0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819C,
  0x0040819D, 0x0041829D, 0x0042829E, 0x0042839D, 0x0043839E, 0x0044849F, 0x0044859F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x001C333E, 0x00000000, 0x0022404C, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 
        0x004F8CA6, 0x001F3741, 0x00000000, 0x002C4D5B, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x0050859A, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 
        0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699FB5, 0x00699FB5, 
        0x006AA0B6, 0x006597AC, 0x00000000, 0x00000000, 0x004F7686, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0072A4BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 
        0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x004E6E7A, 0x00010202, 0x00050708, 0x005A7E8C, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC1, 0x00415963, 0x00000000, 0x00101619, 0x00729AAB, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 
        0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 
        0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCD, 0x0094BDCE, 0x0094BECE, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 
        0x009AC1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D5, 0x00A1C6D6, 0x00A1C6D6, 
        0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 
        0x00A7CBDA, 0x00A7CBD9, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6C9D9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 
        0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC3D3, 
        0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D2, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 
        0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 
        0x0088B5C7, 0x0088B4C7, 0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x0085B2C5, 0x00455E68, 0x00000000, 0x00000000, 0x00000000, 0x001A2327, 0x00658A99, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x007EAEC2, 0x00719CAE, 0x00151D20, 0x00000000, 
        0x00354A53, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 0x006E9DB0, 0x000B1113, 0x00374F59, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 
        0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006DA1B7, 0x006BA0B6, 0x006BA0B6, 0x00679BB1, 0x004D7384, 0x0010181C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060A0B, 0x0022363F, 
        0x005A8DA3, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005793AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 
        0x00548FA8, 0x00538FA8, 0x00528EA8, 0x0043758A, 0x00020405, 0x00101D23, 0x00508CA6, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x0022404C, 0x00000000, 0x001C343E, 0x004887A1, 0x004787A1, 0x004786A0, 
        0x004686A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D,
  0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x00427D95, 0x00081013, 0x00010303, 0x003D7186, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 
        0x00498198, 0x00080F12, 0x00040708, 0x00498097, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005590A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AB, 0x005893AB, 0x005993AC, 0x005A93AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 
        0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649CB2, 0x00659CB3, 0x00659DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 
        0x006BA0B6, 0x006BA0B6, 0x00263A42, 0x00000000, 0x001B282E, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A4B9, 0x0070A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 
        0x0078A9BD, 0x0078AABE, 0x00709EB0, 0x00162023, 0x00000000, 0x00030405, 0x00354A52, 0x00709BAD, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x00688F9F, 0x000A0E0F, 0x00000000, 0x005A7B88, 0x0082B0C4, 0x0082B0C4, 0x0083B1C4, 0x0084B1C5, 
        0x0084B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 
        0x0090BACC, 0x0091BBCD, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 
        0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D8, 0x00A4C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 
        0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A9CBDA, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 
        0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD8, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 
        0x009EC4D4, 0x009DC3D4, 0x009DC3D3, 0x009CC3D3, 0x009BC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0095BDCE, 
        0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 
        0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0086B3C6, 0x0086B3C6, 0x0085B2C5, 0x0028363C, 0x00000000, 0x000D1213, 0x007DA9BB, 0x0082B0C3, 0x0082B0C3, 0x0081AFC3, 0x0080AFC2, 0x0080AFC2, 0x007FAEC2, 0x007EAEC1, 0x004F6C79, 0x00000000, 
        0x00070A0B, 0x00608696, 0x007BABBF, 0x007BABBF, 0x0079ABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x004F717F, 0x00080B0D, 0x006A9AAD, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 
        0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006CA1B7, 0x006CA1B7, 0x0052798A, 0x001F2F36, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0022353D, 0x004C778A, 0x00639AB1, 
        0x00629AB1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005D97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A93AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005791AA, 0x005691AA, 0x005691AA, 0x005590A9, 
        0x005490A9, 0x00538FA8, 0x00538FA8, 0x004F88A1, 0x0017282F, 0x00000000, 0x0042758A, 0x00508CA6, 0x004F8BA5, 0x004E8BA5, 0x004D8BA5, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x003C7086, 0x00010303, 0x00081013, 0x00427D95, 0x004887A1, 0x004786A1, 
        0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D,
  0x0041829D, 0x0041829E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004786A1, 0x004787A1, 0x004787A1, 0x00315B6D, 0x00010303, 0x000D191E, 0x004A89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 
        0x0032596A, 0x00000101, 0x00192C34, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005994AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AE, 
        0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 
        0x006BA0B6, 0x006CA0B6, 0x00557E90, 0x00000000, 0x00000000, 0x005E8A9D, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 
        0x0078A9BE, 0x0079AABE, 0x0045616C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080B0C, 0x0046616C, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 0x00222E33, 0x00000000, 0x003A4F57, 0x0081B0C3, 0x0082B0C4, 0x0083B1C4, 0x0083B1C5, 0x0084B2C5, 
        0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 
        0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 
        0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A6C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CADA, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 
        0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A5C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C8D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 
        0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BED0, 0x0096BED0, 0x0095BECF, 0x0095BECF, 
        0x0095BECE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 
        0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x006F94A4, 0x000D1214, 0x00000000, 0x00567581, 0x0082B0C4, 0x0082B0C3, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x007FAEC2, 0x007FAEC2, 0x007EADC1, 0x001E2A2E, 
        0x00000000, 0x002A3A41, 0x0077A6B9, 0x007BABC0, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0079AABE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x00223137, 0x00344C55, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 
        0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006798AD, 0x0025373F, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1215, 0x004E798A, 0x006299AF, 0x00649BB2, 0x00639AB1, 
        0x00629AB1, 0x006199B0, 0x006199B0, 0x006099B0, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005590A9, 
        0x005590A9, 0x005490A8, 0x00538FA8, 0x00538EA8, 0x002E505E, 0x00000000, 0x001D333D, 0x00508CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA3, 0x004C8AA3, 0x004A89A3, 0x000D191D, 0x00010303, 0x00305B6C, 0x004887A1, 0x004786A1, 
        0x004786A1, 0x004685A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0043839E, 0x0043839E, 0x0041829D, 0x0041829D,
  0x0041829D, 0x0041829E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004786A0, 0x004786A1, 0x0047859F, 0x001D3742, 0x00000000, 0x002F5768, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8CA5, 0x004D89A2, 
        0x001C323B, 0x00000000, 0x00407184, 0x00518EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 
        0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006199B0, 0x006199B0, 0x006199B0, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 
        0x006CA0B6, 0x006CA1B7, 0x006496AA, 0x00172227, 0x00000000, 0x00283B43, 0x006FA3B8, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BA, 0x0073A5BB, 0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 
        0x0079AABE, 0x00709EB0, 0x00020303, 0x00000000, 0x005A7D8C, 0x00445F6A, 0x000D1214, 0x00000000, 0x00000000, 0x00192327, 0x00678D9E, 0x004D6975, 0x00000000, 0x00141B1E, 0x007CA9BB, 0x0082B0C3, 0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 0x0084B2C5, 
        0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0089B5C7, 0x008AB5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACB, 0x0090BBCC, 
        0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x009AC1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 
        0x009CC3D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C8D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CCDA, 
        0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00AACCDB, 0x00A9CDDB, 0x00AACCDB, 0x00AACCDB, 0x00AACDDB, 0x00A9CDDB, 0x00AACCDB, 0x00AACDDB, 0x00AACCDB, 0x00AACDDB, 0x00AACCDB, 0x00AACCDB, 0x00AACCDB, 0x00A9CCDB, 
        0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A6CAD8, 0x00A5C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 
        0x009FC5D4, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C0D1, 0x0099C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 
        0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0091BACC, 0x0090BACC, 0x008FBACB, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 
        0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B3C6, 0x0086B3C6, 0x0085B3C6, 0x00445C66, 0x00010101, 0x000E1315, 0x0077A1B3, 0x0082B0C4, 0x0082B0C3, 0x0081B0C3, 0x0080AFC2, 0x0080AFC2, 0x00749EB1, 0x003E555F, 0x00020404, 
        0x00000000, 0x00000000, 0x005E8292, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x006692A4, 0x000F1619, 0x00628EA0, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 
        0x0070A4B9, 0x006FA3B8, 0x00699AAE, 0x00496C7A, 0x00060A0B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080D0F, 0x00324D58, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB2, 
        0x00639AB1, 0x006299B1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005D97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005591A9, 
        0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00498096, 0x0005080A, 0x00070D0F, 0x004A839A, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x002F5767, 0x00000000, 0x001D3742, 0x0047859F, 0x004887A1, 
        0x004786A0, 0x004686A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D,
  0x0041829D, 0x0042829E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004787A1, 0x004787A1, 0x00427C95, 0x00091114, 0x00010203, 0x004987A1, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x00467D95, 
        0x0005080A, 0x000C1519, 0x00518EA7, 0x00538EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A93AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 
        0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB3, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 
        0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x0036505B, 0x00000000, 0x0006080A, 0x006594A8, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0078A8BD, 0x0078A9BE, 
        0x0079AABE, 0x0025343A, 0x00000000, 0x000B1011, 0x00628899, 0x007CACC0, 0x006F9AAA, 0x00354952, 0x00080B0C, 0x00000000, 0x00030405, 0x00020303, 0x00030405, 0x00577784, 0x0082B0C3, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 0x0090BBCC, 0x0091BBCD, 
        0x0091BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC2D3, 
        0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C6D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C9D7, 0x00A4C8D8, 
        0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACCDB, 
        0x00AACCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDB, 0x00AACDDC, 0x00AACDDB, 0x00ABCDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDC, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDB, 
        0x00ABCDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A8CCDA, 0x00A9CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A6CADA, 
        0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A4C8D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C7D6, 0x00A1C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 
        0x0095BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 
        0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0086B4C6, 0x0086B3C6, 0x0081ADC1, 0x00192226, 0x00000000, 0x003B4F58, 0x0081AFC2, 0x0082B0C3, 0x0082B0C3, 0x007CA9BC, 0x004A6671, 0x00141C1F, 0x00000000, 0x00000000, 
        0x0011181B, 0x00000000, 0x00131A1E, 0x007CACC0, 0x007BACBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0074A5BA, 0x0031464F, 0x0024343A, 0x0071A3B8, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 
        0x0070A2B7, 0x004A6C7B, 0x001A272C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040607, 0x002A414A, 0x00578497, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00639BB2, 
        0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005C95AE, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005690A9, 
        0x005590A9, 0x005490A9, 0x005390A8, 0x00538FA8, 0x00528EA8, 0x00192B33, 0x00000101, 0x00335A6A, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004987A1, 0x00010202, 0x00091215, 0x00427C95, 0x004887A1, 
        0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D,
  0x0041829D, 0x0042839E, 0x0043849E, 0x0043849E, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x00366679, 0x00000000, 0x001D353F, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x00325A6A, 
        0x00000000, 0x00305464, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005994AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 
        0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 
        0x006CA1B6, 0x006DA1B7, 0x006DA2B7, 0x00588293, 0x00060A0B, 0x00010102, 0x003E5B67, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0076A7BC, 0x0076A8BC, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 
        0x00577988, 0x00010202, 0x00000000, 0x00000000, 0x00090C0E, 0x0033474F, 0x0079A8BB, 0x007EADC1, 0x006A93A3, 0x002A3A41, 0x00010202, 0x00000000, 0x00253339, 0x0081AFC2, 0x0082B0C4, 0x0083B1C4, 0x0084B2C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 
        0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 
        0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECE, 0x0096BECF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 
        0x009DC3D4, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 
        0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 
        0x00AACDDB, 0x00AACDDC, 0x00AACDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 
        0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDB, 0x00ABCDDC, 0x00AACDDB, 0x00ABCDDB, 0x00AACDDB, 0x00AACCDB, 0x00AACCDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 
        0x00A7CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D5, 
        0x00A0C5D5, 0x00A0C6D5, 0x009FC5D5, 0x009EC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 
        0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B3C6, 0x0086B3C6, 0x0085B3C6, 0x007197A7, 0x00000000, 0x00040506, 0x006D93A3, 0x0083B1C4, 0x00668B9B, 0x001B252A, 0x00010202, 0x00000000, 0x00080C0D, 0x00547481, 
        0x006A93A3, 0x00182125, 0x00000000, 0x003F5761, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079ABBF, 0x0078AABE, 0x0078A9BE, 0x0077A9BE, 0x0077A8BD, 0x0076A8BC, 0x0076A7BC, 0x006591A3, 0x000A0E10, 0x00182327, 0x00567C8C, 0x006694A7, 0x00446370, 
        0x00151E22, 0x00030405, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001B282E, 0x00558193, 0x00679CB3, 0x00689EB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 
        0x00639BB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AB, 0x005791AA, 0x005691AA, 
        0x005691A9, 0x005490A9, 0x00548FA9, 0x00538FA8, 0x00528EA7, 0x00406F82, 0x00000000, 0x001D333D, 0x004E88A2, 0x004F8CA5, 0x004F8CA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x004B89A2, 0x001C353F, 0x00000000, 0x0037667B, 0x004887A1, 
        0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0041829D,
  0x0041829E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004887A1, 0x004887A1, 0x001A313B, 0x00000000, 0x0039697D, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8CA5, 0x004F8CA6, 0x00122025, 
        0x00010303, 0x00487E94, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005B94AC, 0x005B94AC, 0x005B95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 
        0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669DB3, 0x00679DB3, 0x00679EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006AA0B5, 0x006BA0B6, 0x006BA0B6, 
        0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006FA2B8, 0x00172126, 0x00000000, 0x001D2B30, 0x006B9CB0, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0072A4B8, 0x0075A7BC, 0x0076A7BD, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0075A5B8, 
        0x001E2A2F, 0x00000000, 0x001C272C, 0x00243339, 0x00020303, 0x00000000, 0x000C1012, 0x005A7C8B, 0x007BAABE, 0x005C7E8D, 0x00050607, 0x00020203, 0x007099A9, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B2C5, 0x0085B2C5, 0x0085B3C5, 0x0085B3C6, 
        0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 
        0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 
        0x009DC3D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5CAD8, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CDDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 
        0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDC, 
        0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDB, 0x00AACDDC, 0x00AACDDC, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDA, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 
        0x00A0C6D5, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 
        0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BDCF, 0x0095BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0085B3C6, 0x0085B3C5, 0x00445B65, 0x00000000, 0x00232F35, 0x003B5059, 0x00000000, 0x00000000, 0x00030405, 0x002C3C43, 0x0075A1B3, 0x007FAEC2, 
        0x00719CAE, 0x00223035, 0x00000000, 0x0006090A, 0x006F9AAC, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0074A7BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080B0D, 0x00476A79, 0x006BA0B6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00649CB2, 0x00649BB2, 
        0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AC, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 
        0x005691AA, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538EA8, 0x00528EA7, 0x00080F12, 0x00070D10, 0x00477E95, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C89A3, 0x004B89A3, 0x0039697D, 0x00000000, 0x001A313B, 0x004887A1, 
        0x004887A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0041829E,
  0x0041839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004887A1, 0x004785A0, 0x00000000, 0x000B151A, 0x00437D95, 0x004B89A3, 0x004C8AA3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00467D94, 0x00000000, 
        0x00192B33, 0x004D88A0, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 
        0x005F97AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x006299B1, 0x006299B1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 
        0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x004B6D7C, 0x00000000, 0x00030405, 0x00588091, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x006F9FB3, 0x00374F59, 0x006B99AD, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x00547685, 
        0x00020303, 0x00000000, 0x00608696, 0x007CACC0, 0x00506F7C, 0x001B252A, 0x00000000, 0x00000000, 0x00212E33, 0x001B2529, 0x00000000, 0x0047616B, 0x0082B0C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C5, 0x0084B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 
        0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACB, 0x0091BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 
        0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 
        0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD8, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 
        0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDD, 0x00ADCEDD, 0x00ACCFDD, 0x00ADCFDD, 0x00ACCFDD, 0x00ADCEDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCEDC, 
        0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDB, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 
        0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C7D6, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0097C0D0, 
        0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACB, 0x008FBACB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B3C6, 0x0085B3C6, 0x007CA6B8, 0x00161E21, 0x00000000, 0x00000000, 0x00020203, 0x001F2A2F, 0x005C7E8B, 0x0081AFC3, 0x00749FB1, 0x00445E68, 
        0x00080B0C, 0x00000000, 0x00000000, 0x00000000, 0x00384E58, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BB, 0x000F1619, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000A0F12, 0x00324B55, 0x006699AE, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659BB3, 0x00649BB2, 
        0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005791AA, 0x005791AA, 
        0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x002C4E5C, 0x00000000, 0x00386375, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x00447D94, 0x000B1418, 0x00000101, 0x004785A0, 
        0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839D,
  0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x002F586A, 0x00000000, 0x0015272F, 0x00468099, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x0024404C, 0x00000000, 
        0x002E505E, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 
        0x005F97AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 
        0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x00070A0C, 0x00000000, 0x001D2A2F, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0025353B, 0x00141C20, 0x0073A4B7, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0079AABE, 0x0078A9BE, 0x001E2A2F, 
        0x00000000, 0x00000000, 0x001C272B, 0x005A7E8C, 0x007DADC1, 0x0076A2B4, 0x004D6B76, 0x00080C0D, 0x00000000, 0x00000000, 0x001A2428, 0x007FACBF, 0x0082B0C4, 0x0083B1C4, 0x0083B1C5, 0x0084B2C5, 0x0084B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 
        0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB8CA, 0x008CB7CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 
        0x0094BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC4D4, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D8, 0x00A4C8D7, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 
        0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CBDA, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 
        0x00ADCFDD, 0x00ACCFDC, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00ADCFDD, 0x00AECFDE, 0x00AECFDD, 0x00AECFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDE, 0x00AECFDE, 0x00ADCFDE, 0x00AECFDD, 0x00ADCFDD, 
        0x00ADCFDD, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 
        0x00AACCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 
        0x00A2C7D6, 0x00A2C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 
        0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 
        0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x0089B6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x004F6A75, 0x00020303, 0x00030404, 0x0049636E, 0x007DAABD, 0x0082B0C4, 0x00557481, 0x00161E21, 0x00000000, 
        0x00000000, 0x00212E33, 0x00455E69, 0x00000000, 0x000D1214, 0x006C97A8, 0x007BABC0, 0x007BABBF, 0x007AAABF, 0x0079AABF, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0075A7BC, 0x0075A7BC, 0x005D8494, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002F454F, 0x005C899C, 0x006DA1B8, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB2, 
        0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AB, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 
        0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538EA7, 0x0046798F, 0x00000000, 0x00172930, 0x00508DA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B8AA3, 0x004986A0, 0x00172B33, 0x00000000, 0x0030596A, 
        0x004887A1, 0x004786A1, 0x004786A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0042839E, 0x0042839E,
  0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004686A0, 0x004686A1, 0x004786A1, 0x004887A1, 0x00112127, 0x00000000, 0x00000000, 0x00010303, 0x0014262D, 0x00345F71, 0x004A879F, 0x004D8BA5, 0x004E8BA5, 0x004F8CA6, 0x00070D10, 0x00060B0D, 
        0x00437489, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 
        0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 
        0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x0070A3B9, 0x0070A4B9, 0x00334B54, 0x00000000, 0x00000000, 0x0010171A, 0x003A535E, 0x00151E22, 0x00000000, 0x005B8292, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x00597E8C, 0x00000000, 
        0x00020404, 0x00000000, 0x00000000, 0x00000000, 0x00293940, 0x0077A4B7, 0x007FAEC1, 0x006D95A6, 0x00000000, 0x00000000, 0x005C7E8B, 0x0082B0C4, 0x0082B1C4, 0x0083B1C5, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 
        0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 
        0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC5D4, 
        0x009FC5D4, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A6C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 
        0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DD, 0x00AECFDD, 0x00AECFDD, 0x00AED0DD, 0x00AED0DE, 0x00AECFDE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DD, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DD, 
        0x00AED0DE, 0x00AECFDD, 0x00AECFDD, 0x00AECFDD, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCFDD, 0x00ADCEDD, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDB, 
        0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 
        0x00A2C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 
        0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BED0, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 
        0x008CB7CA, 0x008CB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C8, 0x0088B5C7, 0x0087B4C6, 0x0087B3C6, 0x0086B3C6, 0x0082AFC2, 0x00171F22, 0x00000000, 0x003D525B, 0x00749EAF, 0x00202B30, 0x00000000, 0x00000000, 0x00040606, 
        0x004E6B77, 0x007FAEC1, 0x007EADC1, 0x00172024, 0x00000000, 0x003F5761, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0079A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0073A5B9, 0x002C4047, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x000E1517, 0x00598294, 0x006FA2B8, 0x006EA2B8, 0x006EA2B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00659CB3, 0x00659CB2, 
        0x00649CB2, 0x00649AB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005792AB, 0x005792AA, 
        0x005692AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x004D869E, 0x0015252C, 0x00000000, 0x004D88A0, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004C89A3, 0x003D7085, 0x00203A45, 0x00050A0C, 0x00000000, 0x00000000, 0x00112127, 
        0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043839E, 0x0042839E,
  0x0042839E, 0x0043839F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004686A0, 0x004786A1, 0x004787A1, 0x00417A93, 0x00030608, 0x00010303, 0x000D181C, 0x00020405, 0x00000000, 0x00000000, 0x00030607, 0x001C323C, 0x00366172, 0x00345B6C, 0x00020304, 0x00101C21, 
        0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AA, 0x005993AB, 0x005993AC, 0x005993AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D97AE, 0x005E97AF, 0x005F97AE, 
        0x006098AF, 0x006098B0, 0x006198B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 
        0x006DA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B9, 0x0070A4B9, 0x005E899B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002C3E46, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0079A9BE, 0x0079AABE, 0x0012191C, 0x00000000, 
        0x0045616C, 0x005F8494, 0x001E2A2F, 0x00020404, 0x00000000, 0x0006090A, 0x004E6B78, 0x00304149, 0x00000000, 0x00253338, 0x007CA9BB, 0x0082B0C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 
        0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 
        0x0095BDCF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 
        0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A0C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCFDC, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDD, 
        0x00AECFDD, 0x00AECFDD, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 
        0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DD, 0x00AECFDD, 0x00AECFDD, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 
        0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A2C8D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C0D1, 
        0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 
        0x008CB8CA, 0x008CB8C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C6, 0x0086B3C6, 0x0086B3C6, 0x00618390, 0x00000000, 0x00040606, 0x00000000, 0x00000000, 0x000C1113, 0x003B515A, 0x007CAABD, 
        0x0080AFC2, 0x00688E9F, 0x0031444B, 0x00000000, 0x00000000, 0x00020404, 0x0074A1B4, 0x007BACC0, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x005F8899, 0x00080B0D, 0x00000000, 
        0x00000000, 0x00020303, 0x002E424B, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689FB5, 0x00689EB4, 0x00679EB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 
        0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006299B0, 0x006199B0, 0x006198B0, 0x006098B0, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005993AC, 0x005892AB, 0x005792AB, 
        0x005791AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA7, 0x00528EA7, 0x002A4855, 0x00000000, 0x002D505F, 0x004C859E, 0x003B6B7E, 0x0025424E, 0x000B1418, 0x00000000, 0x00000000, 0x00000000, 0x00081013, 0x00010202, 0x00030608, 
        0x00417B94, 0x004787A1, 0x004786A1, 0x004786A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0044849E, 0x0042839E,
  0x0043839E, 0x0043849F, 0x0044859F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x002D5666, 0x00010203, 0x00101E24, 0x0048839C, 0x00366275, 0x0024434F, 0x000E191E, 0x00000000, 0x00000000, 0x00000000, 0x00030607, 0x00000000, 0x002D4E5C, 
        0x00528EA7, 0x00538FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 
        0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x00699FB5, 0x006B9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 
        0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4BA, 0x006B9BB0, 0x000C1214, 0x00000000, 0x00000000, 0x00000000, 0x000A0F10, 0x006C9BAE, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x004B6A76, 0x00000000, 0x00101619, 
        0x006B96A7, 0x007CACC0, 0x007AA8BD, 0x00547482, 0x00172023, 0x00000000, 0x00000000, 0x00000000, 0x00010101, 0x00608392, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B3C5, 0x0085B3C5, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 
        0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x0090BACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCD, 0x0094BDCE, 0x0094BDCE, 
        0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 
        0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CBDA, 0x00A9CCDA, 
        0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCEDD, 0x00ADCEDD, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDD, 0x00AED0DD, 0x00AED0DD, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 
        0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D0DE, 0x00AFD1DE, 0x00AFD1DF, 0x00AFD1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 
        0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDC, 
        0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDB, 0x00A9CDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D7, 
        0x00A4C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 
        0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BCCD, 0x0091BCCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB8CB, 
        0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0085B3C6, 0x002B3A40, 0x00000000, 0x00010202, 0x00384C54, 0x006C92A2, 0x0081B0C3, 0x006F96A8, 
        0x0033464E, 0x000B0F11, 0x00000000, 0x00000000, 0x000A0E10, 0x00000000, 0x0033474F, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0076A9BD, 0x0076A8BC, 0x0075A8BD, 0x0075A7BC, 0x0030454D, 0x00000000, 
        0x00000000, 0x00324952, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 
        0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005893AB, 0x005892AB, 
        0x005792AA, 0x005691A9, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x003E6C7F, 0x00040709, 0x00080E11, 0x00121F25, 0x00000101, 0x00000000, 0x00000000, 0x00070D10, 0x001D3640, 0x00315969, 0x0041788F, 0x00101E23, 0x00010203, 
        0x002E5667, 0x004887A1, 0x004787A1, 0x004786A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043839E,
  0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x001C353F, 0x00000000, 0x002B505F, 0x004A89A3, 0x004C8AA3, 0x004B88A2, 0x004A869E, 0x0042768C, 0x0024414D, 0x00080F12, 0x00000000, 0x00000000, 0x004B859C, 
        0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005691A9, 0x005691A9, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AC, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 
        0x006098B0, 0x006199B0, 0x006199B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x006A9EB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 
        0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0071A3B9, 0x0071A4B9, 0x006D9FB3, 0x00202F35, 0x00000000, 0x00000000, 0x00000000, 0x00456370, 0x0075A6BB, 0x0076A8BC, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0075A4B8, 0x00161F23, 0x00000000, 0x00354A53, 
        0x007CACC0, 0x007DACC0, 0x007DADC1, 0x007EADC1, 0x007AA7BB, 0x00415A64, 0x00030404, 0x00000000, 0x00243237, 0x0082B0C3, 0x0082B1C4, 0x0083B1C4, 0x0083B1C5, 0x0085B2C5, 0x0085B2C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 
        0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 
        0x0095BECF, 0x0096BED0, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0099C1D1, 0x0099C1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009FC4D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 
        0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 
        0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 
        0x00B0D1DE, 0x00B0D1DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D1DF, 
        0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD1DE, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00AECFDE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 
        0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A4C9D8, 
        0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D1, 
        0x0099C1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 
        0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0085B3C6, 0x0076A0B0, 0x00010202, 0x00000000, 0x00769FB0, 0x0083B1C4, 0x00465F69, 0x00080B0D, 
        0x00000000, 0x00000000, 0x00101719, 0x00628796, 0x00557683, 0x00030506, 0x00030405, 0x006D98AA, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x006FA0B3, 0x00030505, 
        0x00030405, 0x004F7281, 0x0072A5BA, 0x0071A4BA, 0x0071A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00689EB5, 0x00689EB4, 0x00689DB4, 0x00669DB3, 0x00669CB3, 
        0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A93AC, 0x005993AB, 0x005892AB, 
        0x005792AB, 0x005691AA, 0x005691A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00518CA5, 0x000A1114, 0x00000000, 0x00000000, 0x00020405, 0x001A2E37, 0x0039677A, 0x0048829A, 0x004A87A0, 0x004C8AA3, 0x004A89A3, 0x002B4F5E, 0x00000000, 
        0x001C353F, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043849E,
  0x0043839E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x00417B93, 0x000E1B20, 0x00000000, 0x00457E98, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8CA5, 0x0043788D, 0x00040708, 0x00132127, 0x00518DA7, 
        0x00528EA8, 0x00538FA7, 0x00548FA8, 0x00548FA9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AB, 0x005892AA, 0x005893AB, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F98AF, 0x005F98AF, 
        0x006198B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639BB1, 0x00649BB1, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 
        0x006FA2B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x006FA1B6, 0x002C4048, 0x00000000, 0x00000000, 0x00162024, 0x006C99AC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x00527482, 0x00040606, 0x00040607, 0x006C96A8, 
        0x007CACC0, 0x007DACC1, 0x007DADC1, 0x007EAEC2, 0x007FAEC2, 0x00729CAE, 0x000A0E0F, 0x00000000, 0x00729BAC, 0x0082B0C3, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 
        0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8C9, 0x008DB8CA, 0x008EB8CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BECE, 0x0095BECE, 
        0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 
        0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 
        0x00AACDDB, 0x00ABCDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCEDD, 0x00ACCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00AFD1DE, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B0D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B1D2E0, 0x00B1D2DF, 
        0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 
        0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00AACDDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 
        0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 
        0x009AC1D2, 0x0099C1D2, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFCF, 0x0096BFCF, 0x0096BECF, 0x0095BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 
        0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x0086B3C6, 0x0084B0C3, 0x003A4E57, 0x00000000, 0x002B3B41, 0x0028363C, 0x00000000, 0x00000000, 
        0x000F1517, 0x0047606B, 0x007FAEC2, 0x007FAEC2, 0x0079A7B9, 0x00192226, 0x00000000, 0x00364C55, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0078AABE, 0x0078A9BE, 0x0078A9BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BB, 0x00486774, 
        0x00000000, 0x004D6F7E, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA2B8, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA0B6, 0x006BA0B6, 0x006AA0B6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00669DB3, 0x00669CB3, 
        0x00669CB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 
        0x005892AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA7, 0x00213B46, 0x00000000, 0x00223D48, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004D8BA4, 0x004C8BA4, 0x004C8AA4, 0x004C89A3, 0x00457F97, 0x00000000, 
        0x000E1B20, 0x00417B93, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849E,
  0x0043849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x003A6D82, 0x00000101, 0x000F1B21, 0x004A89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00335A6B, 0x00000000, 0x00345A6B, 0x00528EA7, 
        0x00528FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005892AA, 0x005892AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x006098B0, 
        0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669DB3, 0x00679DB3, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 
        0x006FA2B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0070A2B7, 0x00324751, 0x00000000, 0x00000000, 0x004A6A78, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0076A6B9, 0x00283940, 0x00000000, 0x0030434C, 0x007CACC0, 
        0x007CACC0, 0x007DADC0, 0x007EADC1, 0x007FAEC2, 0x0080AEC2, 0x00364A52, 0x00000000, 0x00394E57, 0x0082B0C4, 0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 
        0x0089B6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 
        0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 
        0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDC, 0x00ABCDDC, 
        0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DD, 0x00AECFDE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DE, 0x00AFD1DF, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 
        0x00B0D2DF, 0x00B1D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D2DF, 0x00B2D2E0, 0x00B1D2E0, 0x00B2D2E0, 0x00B1D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 
        0x00B2D2E0, 0x00B1D2E0, 0x00B1D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD1DF, 0x00B0D1DE, 0x00AFD0DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AECFDE, 
        0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDC, 0x00ABCDDB, 0x00A9CDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 
        0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 
        0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B4C7, 0x0087B4C7, 0x0086B4C6, 0x0086B3C6, 0x006B909F, 0x000A0D0F, 0x00000000, 0x00000000, 0x00060909, 0x003E545D, 
        0x00719BAC, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x007EAEC2, 0x004D6A76, 0x00000000, 0x0011191B, 0x006D98AA, 0x007BACC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 
        0x001A252A, 0x0037505A, 0x0071A4B9, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 
        0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005893AB, 
        0x005892AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528FA8, 0x00417185, 0x00000000, 0x001B3039, 0x004F8BA5, 0x004F8CA5, 0x004E8CA5, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x000F1B21, 
        0x00010202, 0x003A6E83, 0x004887A2, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0043849F,
  0x0043849E, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x002B5161, 0x00000000, 0x002A4E5E, 0x004A89A3, 0x004C89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004F8CA5, 0x004F8CA5, 0x001A2E36, 0x00000000, 0x004A8299, 0x00528EA7, 
        0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005893AB, 0x005893AB, 0x005993AB, 0x005994AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 
        0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 
        0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0070A2B8, 0x002F444D, 0x00000000, 0x001A262B, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0079AABE, 0x006993A4, 0x00000000, 0x00000000, 0x0072A0B3, 0x007CACC0, 
        0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007FAEC2, 0x00709AAB, 0x00000000, 0x00090D0E, 0x006F96A6, 0x0082B0C4, 0x0082B1C4, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B6C8, 
        0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BBCD, 0x0093BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 
        0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0099C0D1, 0x0099C1D1, 0x0099C1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009DC4D4, 0x009EC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 
        0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DD, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B2D2DF, 
        0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 
        0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 
        0x00AED0DE, 0x00AED0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 
        0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D2, 0x0099C0D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 
        0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x0086B3C6, 0x0086B3C6, 0x002B3A40, 0x00000000, 0x0012191B, 0x00668A98, 0x0081AFC2, 
        0x0082B0C3, 0x0081B0C3, 0x0080AFC3, 0x007FAEC2, 0x007FAEC2, 0x007EAEC1, 0x000B1012, 0x00000000, 0x004E6D79, 0x007BACC0, 0x007BABBF, 0x007AABBE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0074A7BC, 
        0x00598090, 0x0011191C, 0x006B9BAF, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA0B7, 0x006CA0B7, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 
        0x00669CB3, 0x00659CB2, 0x00649CB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005993AB, 0x005893AB, 
        0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00060B0D, 0x000C1518, 0x00467C93, 0x004F8CA6, 0x004F8CA5, 0x004D8BA5, 0x004D8AA4, 0x004D8AA4, 0x004B8AA3, 0x004B89A3, 0x002A4E5D, 
        0x00000000, 0x002C5261, 0x004887A1, 0x004887A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x0044849F, 0x0043849F,
  0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x0014262E, 0x00000000, 0x00417990, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004D89A3, 0x00000101, 0x0014232A, 0x004E89A1, 0x00528EA7, 
        0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005893AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005B95AC, 0x005B95AD, 0x005D95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098B0, 
        0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB5, 0x00699EB4, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA2B7, 0x006DA2B8, 0x006EA2B8, 
        0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x006FA0B4, 0x0027383F, 0x00000000, 0x006995A8, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0030444D, 0x00000000, 0x00161F23, 0x006D97A9, 0x0079A8BC, 
        0x007DADC1, 0x007DADC1, 0x007EADC2, 0x007FAEC2, 0x002C3C42, 0x00000000, 0x0033454D, 0x007FADBF, 0x0083B0C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0087B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 
        0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 
        0x0097C0D0, 0x0098C0D0, 0x0098C0D0, 0x0099C1D1, 0x0099C1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 
        0x00A3C8D7, 0x00A3C7D7, 0x00A3C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6C9D9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00AACCDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ACCEDC, 
        0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 
        0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D3E1, 0x00B3D3E1, 0x00B3D3E1, 
        0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D0DE, 0x00AFD0DE, 
        0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDC, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D3, 0x009DC3D3, 0x009CC3D3, 
        0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 
        0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB5C8, 0x0089B6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x006C92A0, 0x00000000, 0x000C1113, 0x006A909F, 0x0083B0C4, 
        0x0082B0C4, 0x0082B0C3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x007EAEC2, 0x004C6975, 0x00000000, 0x001C272C, 0x0079A8BC, 0x007BACC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0075A7BC, 0x0075A7BC, 
        0x0072A5B9, 0x0024353C, 0x00466573, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA0B7, 0x006BA0B6, 0x006B9FB6, 0x00699FB5, 0x00699FB5, 0x00689EB5, 0x00679EB4, 0x00679DB4, 
        0x00669DB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005993AB, 
        0x005892AB, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00243E49, 0x00000000, 0x003C6B7E, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x00417990, 
        0x00000000, 0x0015272F, 0x004887A2, 0x004887A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F,
  0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004786A0, 0x004887A1, 0x0046849E, 0x00000000, 0x000D181C, 0x0046829B, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x003A687B, 0x00000000, 0x00294855, 0x00518CA5, 0x00528EA7, 
        0x00538FA8, 0x00548FA8, 0x005490A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 
        0x006199B0, 0x00629AB1, 0x00629AB1, 0x00649AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 
        0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0072A5BA, 0x0072A5BA, 0x006E9EB2, 0x000E1417, 0x0038505A, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0079AABE, 0x00719FB2, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x002B3C43, 
        0x00577885, 0x0077A4B7, 0x007FAEC2, 0x006C95A5, 0x0007090A, 0x00060809, 0x00628695, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 
        0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCD, 0x0092BBCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 
        0x0098C0D0, 0x0098C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C7D7, 
        0x00A3C8D7, 0x00A3C9D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDD, 0x00ACCEDD, 
        0x00ADCEDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 
        0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D4E1, 0x00B4D3E1, 0x00B3D4E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 
        0x00B4D4E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 
        0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 
        0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009DC3D3, 
        0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 
        0x008FBACC, 0x008FB9CB, 0x008EB8CB, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0086B3C6, 0x0086B3C6, 0x002A393F, 0x00000000, 0x00415861, 0x0081AFC2, 
        0x0082B0C4, 0x0082B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x007CABBE, 0x0006090A, 0x00000000, 0x00628898, 0x007BACC0, 0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 
        0x0074A7BC, 0x006D9CB0, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 
        0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005994AC, 0x005993AB, 
        0x005993AB, 0x005792AB, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00548FA9, 0x00538FA8, 0x00538FA8, 0x00406F83, 0x00000000, 0x002A4A57, 0x00508CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x0046829B, 
        0x000C171B, 0x00000101, 0x0046849E, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0044859F, 0x0044849F,
  0x0044849F, 0x0044859F, 0x004685A0, 0x004686A0, 0x004786A0, 0x004887A1, 0x00356276, 0x00000000, 0x001F3944, 0x004986A0, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA6, 0x001D333C, 0x00000101, 0x00396577, 0x00528EA7, 0x00538FA8, 
        0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x006098B0, 0x006098B0, 0x006199B0, 
        0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 
        0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 0x005A8292, 0x000A0E10, 0x006794A6, 0x0075A7BC, 0x0076A8BC, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0039505A, 0x00000000, 0x001B262B, 0x00354A52, 0x00030405, 0x00000000, 
        0x00030506, 0x00182125, 0x00445D68, 0x0031434A, 0x00000000, 0x00202C31, 0x0081B0C3, 0x0082B1C4, 0x0083B1C4, 0x0084B1C4, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 
        0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 
        0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ACCEDD, 0x00ACCEDD, 0x00ADCEDD, 0x00ADCFDD, 
        0x00AECFDD, 0x00AED0DD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B1D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 
        0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D4E2, 0x00B5D4E2, 0x00B5D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B5D4E2, 
        0x00B5D4E1, 0x00B5D5E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D1DF, 
        0x00B0D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00AED0DD, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDC, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 
        0x009DC3D3, 0x009CC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 
        0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B3C6, 0x0086B3C6, 0x00749DAD, 0x00000000, 0x000B0F10, 0x007DA9BC, 
        0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x005B7D8B, 0x00233035, 0x00030506, 0x00000000, 0x00202C31, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0075A8BC, 
        0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B7, 0x006AA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 
        0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x005C96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 
        0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x004D869E, 0x00060A0C, 0x00101D22, 0x00508DA6, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A4, 0x004986A0, 
        0x001F3944, 0x00000000, 0x00346376, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044849F,
  0x0044849F, 0x0045859F, 0x004685A0, 0x004686A1, 0x004786A1, 0x004887A1, 0x001C343E, 0x00000000, 0x002E5666, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x00020405, 0x000A1216, 0x00477C92, 0x00528EA7, 0x00538FA8, 
        0x00548FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 
        0x006299B1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 
        0x0070A4B9, 0x0071A4B9, 0x0072A4BA, 0x0073A5BA, 0x0073A6BB, 0x0071A3B8, 0x00628D9F, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0075A4B9, 0x000C1113, 0x00010202, 0x0047626E, 0x007CACC0, 0x0075A2B5, 0x003C545D, 
        0x00080B0C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00628695, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 
        0x008CB7C9, 0x008CB8C9, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCD, 0x0094BDCE, 0x0095BDCE, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 
        0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 
        0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CDDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 
        0x00AED0DE, 0x00AED0DE, 0x00AFD1DE, 0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 
        0x00B5D4E1, 0x00B4D4E2, 0x00B5D5E1, 0x00B5D5E2, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 
        0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B5D5E2, 0x00B5D4E1, 0x00B4D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 
        0x00B1D1DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD1DE, 0x00AED0DE, 0x00AED0DD, 0x00AED0DD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A8CCDA, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 
        0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCD, 0x0090BBCC, 
        0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0086B3C6, 0x0085B2C5, 0x002E3E45, 0x00000000, 0x004F6A76, 
        0x0083B1C4, 0x0082B0C4, 0x0082B0C3, 0x00658A98, 0x001A2428, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x006B95A7, 0x007CABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 
        0x0075A7BC, 0x0074A7BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689DB4, 
        0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006198B0, 0x006098B0, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005A95AC, 0x005A94AC, 0x005993AC, 
        0x005993AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00508AA3, 0x001C3139, 0x00000000, 0x004D88A0, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004B8AA4, 0x004B89A3, 
        0x002E5666, 0x00000000, 0x001C343E, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0044849F,
  0x0044849F, 0x0045859F, 0x004686A0, 0x004786A0, 0x004787A1, 0x004887A1, 0x00060B0D, 0x00050A0C, 0x003A6C81, 0x004B89A3, 0x004B8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x003D6D81, 0x00000000, 0x0014242A, 0x00528EA7, 0x00528EA7, 0x00538FA8, 
        0x005390A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005792AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 
        0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 
        0x0071A4B9, 0x0071A4B9, 0x0071A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x0050707D, 0x00030405, 0x000A0E0F, 0x00709BAD, 0x007CACC0, 0x007DACC0, 0x007EADC1, 
        0x0077A4B7, 0x00425B65, 0x000C1113, 0x00000000, 0x00172023, 0x0082B0C3, 0x0082B0C4, 0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 
        0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BCCE, 0x0095BDCF, 0x0095BDCF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 
        0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC2D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009FC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 
        0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 
        0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B4D4E1, 0x00B5D4E2, 
        0x00B5D4E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B6D5E3, 0x00B6D5E3, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D6E3, 0x00B7D6E2, 0x00B6D6E2, 0x00B6D5E3, 0x00B6D5E2, 
        0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 
        0x00B1D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDC, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 
        0x00A9CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CADA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 
        0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BECE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCC, 
        0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B4C7, 0x0087B4C7, 0x0086B4C6, 0x0086B3C6, 0x00628391, 0x00000000, 0x000D1214, 
        0x0077A1B2, 0x00557380, 0x001F2A2E, 0x00000000, 0x00000000, 0x000B0F10, 0x0026343A, 0x00547482, 0x001F2C31, 0x00000000, 0x00354952, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0078AABE, 0x0078A9BE, 0x0078A9BD, 0x0076A8BD, 0x0076A8BD, 
        0x0076A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00689EB5, 0x00689EB4, 
        0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005994AC, 
        0x005993AB, 0x005892AB, 0x005892AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x002F5261, 0x00000000, 0x00325968, 0x00508CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 
        0x003B6C81, 0x00050A0C, 0x00060C0E, 0x004887A2, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0044859F,
  0x0045859F, 0x004585A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x003C7187, 0x00000101, 0x000C161B, 0x0047829A, 0x004C89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8CA5, 0x004F8CA5, 0x00274451, 0x00000000, 0x00274551, 0x00528EA7, 0x00528FA7, 0x00538FA8, 
        0x00538FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B0, 
        0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x006FA3B9, 
        0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0076A6BA, 0x002C3E46, 0x00000000, 0x002B3D44, 0x007CACC0, 0x007CADC0, 0x007DADC1, 0x007DADC1, 
        0x007FAEC1, 0x0080AEC2, 0x001D282D, 0x00000000, 0x005B7C8A, 0x0082B0C4, 0x0083B1C4, 0x0083B2C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 
        0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 
        0x0099C1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 
        0x00A5CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ADCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 
        0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E2, 0x00B5D4E2, 0x00B5D4E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 
        0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 
        0x00B2D3E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACCDB, 
        0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009EC5D4, 
        0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 
        0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0086B3C6, 0x007CA7B8, 0x001C262A, 0x00000000, 
        0x0013191C, 0x00000000, 0x00000000, 0x0011181A, 0x00455F69, 0x00668C9B, 0x0080AFC2, 0x007FAEC2, 0x004A6571, 0x00000101, 0x0012191C, 0x00729FB1, 0x007BABC0, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 
        0x0076A7BD, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A4BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 
        0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 
        0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x003D6A7D, 0x00020405, 0x0015262C, 0x00508CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 
        0x0046819A, 0x000C161A, 0x00000101, 0x003D7289, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F,
  0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x002A4E5E, 0x00000000, 0x00172A32, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x0014232A, 0x00000000, 0x003E6D81, 0x00528EA7, 0x00538FA8, 0x00538FA8, 
        0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x006299B1, 
        0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 
        0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0079AABE, 0x006A96A7, 0x000D1214, 0x00000000, 0x00668E9F, 0x007CACC0, 0x007DADC0, 0x007DADC1, 0x007EADC1, 
        0x007FAEC2, 0x006B92A2, 0x00000000, 0x00151C20, 0x007AA5B8, 0x0082B0C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB6C9, 0x008CB7C9, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008FB9CB, 0x008FBACC, 0x008FBACB, 0x0091BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 
        0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D6, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D7, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B0D1DF, 0x00B0D2DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D4E2, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D5E3, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D6E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D7E4, 
        0x00B8D7E3, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D5E3, 0x00B7D6E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E1, 
        0x00B3D3E0, 0x00B3D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 
        0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 
        0x009EC5D4, 0x009EC4D4, 0x009DC4D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BBCD, 
        0x0092BBCD, 0x0091BBCD, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C7, 0x0088B5C8, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x00425962, 0x00010101, 
        0x00000000, 0x0012181B, 0x00577684, 0x007EABBD, 0x0080AFC2, 0x0080AFC2, 0x007FAFC2, 0x007FAEC2, 0x0078A6B8, 0x00040607, 0x00030506, 0x00557684, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A8BD, 0x0077A8BD, 
        0x0076A8BD, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00689EB5, 
        0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005A94AC, 0x005A94AC, 
        0x005A93AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691A9, 0x005691A9, 0x005590A9, 0x00548FA9, 0x00548FA8, 0x00538FA8, 0x00497F95, 0x000C1519, 0x00010202, 0x00508DA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B8AA3, 
        0x004B89A3, 0x00162A32, 0x00000000, 0x002B505F, 0x004887A1, 0x004786A1, 0x004686A1, 0x004585A0, 0x0045859F,
  0x004585A0, 0x004685A0, 0x004686A1, 0x004786A1, 0x004887A1, 0x00193039, 0x00000000, 0x002A4E5D, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA5, 0x004E8BA5, 0x004E8CA5, 0x00467C92, 0x000B1518, 0x00020405, 0x00518EA7, 0x00528EA8, 0x00538FA7, 0x00538FA8, 
        0x005590A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006299B1, 
        0x00639AB1, 0x00649AB2, 0x00649BB2, 0x00659BB2, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB6, 0x006B9FB6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B7, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 
        0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x00517280, 0x00000000, 0x00161F23, 0x007CABC0, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 
        0x007FAEC2, 0x002C3D43, 0x00000000, 0x00405862, 0x0080AEC2, 0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008BB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 
        0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0094BDCE, 0x0094BDCE, 0x0094BECE, 0x0095BECF, 0x0096BFD0, 0x0096BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 
        0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D3, 0x009EC4D4, 0x009EC4D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D0DE, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B1D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D3E1, 0x00B3D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D5E2, 0x00B6D6E3, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D6E4, 0x00B8D7E3, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 
        0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D3E1, 
        0x00B3D3E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DD, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 
        0x00AACDDB, 0x00AACDDB, 0x00A9CCDA, 0x00A9CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 
        0x009FC5D4, 0x009EC4D4, 0x009DC4D3, 0x009DC3D3, 0x009CC3D3, 0x009CC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D2, 0x0099C0D1, 0x0098C0D1, 0x0097C0D1, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 
        0x0092BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CA, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x00739AAB, 0x00050708, 
        0x00090C0D, 0x006A8E9E, 0x0082B1C4, 0x0082B0C4, 0x0082B0C3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x007FAEC1, 0x002D3F46, 0x00000000, 0x00344850, 0x007AA9BC, 0x007BABC0, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0077A9BD, 0x0077A8BD, 
        0x0076A8BD, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 0x006DA2B7, 0x006DA2B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 
        0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B1, 0x006199B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 
        0x005A94AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x0015252C, 0x00000000, 0x003C6A7C, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 
        0x004B89A3, 0x002A4E5D, 0x00000000, 0x001A3039, 0x004887A1, 0x004786A1, 0x004786A1, 0x004585A0, 0x004585A0,
  0x004585A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x00447F98, 0x000F1C22, 0x00000000, 0x003E748A, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004F8CA5, 0x003B697D, 0x00020304, 0x00172830, 0x00528EA7, 0x00528EA7, 0x00538EA8, 0x005490A8, 
        0x005590A9, 0x005591A9, 0x005691A9, 0x005791AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 
        0x00639AB1, 0x00649BB1, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B8, 0x006EA2B7, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 
        0x0071A4BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078AABE, 0x0079AABE, 0x00202D32, 0x00000000, 0x004F6E7B, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC2, 
        0x00749FB1, 0x00050708, 0x00080B0D, 0x00648897, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 
        0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D2, 
        0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A4C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DF, 0x00B0D1DF, 0x00B1D1DF, 
        0x00B1D1DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D5E3, 0x00B6D6E3, 0x00B7D6E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 
        0x00B8D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D8E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD7E4, 0x00BAD8E5, 0x00BAD7E5, 0x00BAD8E4, 0x00BAD8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E4, 0x00BAD8E4, 0x00BAD8E4, 0x00B9D8E4, 
        0x00B9D8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D7E3, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E2, 0x00B7D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E2, 
        0x00B5D4E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 
        0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 
        0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 
        0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB8C9, 0x008BB7C9, 0x008BB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 0x0027353A, 
        0x00000000, 0x00435A64, 0x0082B0C3, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x007FAFC2, 0x007FAEC2, 0x006990A1, 0x00000000, 0x000E1416, 0x0074A1B3, 0x007BACC0, 0x007BABBF, 0x007AAABF, 0x0079AABF, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 
        0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA0B7, 0x006BA0B6, 0x006AA0B6, 0x00699FB5, 0x00699EB5, 
        0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005C95AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 
        0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x00294753, 0x00000000, 0x00274551, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 
        0x004B89A3, 0x003F7389, 0x00000000, 0x000F1C22, 0x00448098, 0x004787A1, 0x004786A1, 0x004686A0, 0x0045859F,
  0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x003B7085, 0x00070E11, 0x00040708, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004E8BA4, 0x004E8BA5, 0x004F8CA6, 0x00305564, 0x00000000, 0x00315666, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x005590A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x006299B0, 0x00629AB1, 
        0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x0070A3B9, 0x0070A3B9, 0x0071A4B9, 
        0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0075A7BB, 0x0075A7BC, 0x0076A7BC, 0x0077A8BD, 0x0077A8BD, 0x0078A9BD, 0x0079AABE, 0x00709CB0, 0x00000000, 0x00070A0B, 0x006F9BAD, 0x007CACC0, 0x007CADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 
        0x0047616C, 0x00000000, 0x001C262A, 0x0081AFC2, 0x0083B1C4, 0x0083B1C4, 0x0084B1C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0089B5C8, 0x008AB5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB8C9, 0x008DB8CA, 
        0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x0099C1D2, 0x009AC1D2, 
        0x009BC2D2, 0x009BC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC4D4, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD8, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2DF, 
        0x00B2D2E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D3E1, 0x00B3D4E1, 0x00B4D4E1, 0x00B4D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B9D7E4, 
        0x00B9D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00B9D8E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 
        0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00BAD8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 
        0x00B5D5E2, 0x00B4D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 
        0x00ABCEDC, 0x00ABCDDC, 0x00AACCDB, 0x00AACCDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 
        0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D1, 0x0099C1D1, 0x0098C1D1, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCD, 
        0x0093BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x0086B3C6, 0x006A8F9E, 
        0x00000000, 0x001C262B, 0x007BA6B8, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0080AFC3, 0x0080AFC3, 0x007FAEC2, 0x007EAEC1, 0x00172024, 0x00000000, 0x005B7F8E, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABE, 0x0079AABF, 0x0078A9BE, 0x0078A9BD, 
        0x0077A9BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BC, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 
        0x00689EB5, 0x00679EB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639BB2, 0x00629AB1, 0x00629AB1, 0x006199B1, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C96AD, 0x005B95AD, 0x005B94AC, 
        0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA7, 0x003F6D80, 0x00000000, 0x0016262D, 0x004F8DA6, 0x004F8CA5, 0x004F8CA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x004B89A3, 0x00030608, 0x00070E11, 0x003C7086, 0x004887A1, 0x004787A1, 0x004686A0, 0x004585A0,
  0x004585A0, 0x004685A0, 0x004786A1, 0x004887A1, 0x00336174, 0x00000000, 0x00182C34, 0x004A89A3, 0x004C89A4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8CA5, 0x004D89A2, 0x00203842, 0x00000000, 0x004A8198, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA9, 
        0x005490A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005892AB, 0x005892AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B94AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005F97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 
        0x00639BB2, 0x00649BB2, 0x00659CB2, 0x00669CB2, 0x00669DB3, 0x00679DB4, 0x00689DB4, 0x00699EB5, 0x00699EB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x0070A3B9, 0x0070A3B9, 0x0071A4BA, 
        0x0072A5BA, 0x0072A5BB, 0x0073A6BB, 0x0074A6BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x003F5863, 0x00000000, 0x00293940, 0x0078A6B9, 0x007CACC0, 0x007EADC1, 0x007EADC1, 0x007EAEC1, 0x007CAABE, 
        0x00212D33, 0x00000000, 0x0048626D, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C8, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 
        0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCD, 0x0094BDCE, 0x0095BDCE, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 
        0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 
        0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D6E2, 0x00B6D6E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D8E4, 
        0x00B9D8E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 
        0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D6E2, 0x00B6D5E2, 
        0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 
        0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00A9CBDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 
        0x00A0C6D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 
        0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0086B3C6, 0x0085B3C6, 
        0x00141B1E, 0x00000000, 0x006A90A0, 0x0083B1C4, 0x0082B1C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x007FAEC2, 0x007EAEC2, 0x0047626D, 0x00000000, 0x00293940, 0x007CACC0, 0x007CABC0, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 
        0x0077A9BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0073A5BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 
        0x00699EB5, 0x00679EB4, 0x00679DB4, 0x00679DB4, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x006299B1, 0x006299B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005B95AC, 
        0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00000101, 0x000D161A, 0x00487F96, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 
        0x004C8AA3, 0x004A89A3, 0x00172C34, 0x00000000, 0x00336274, 0x004887A1, 0x004787A1, 0x004686A0, 0x004685A0,
  0x004585A0, 0x004686A0, 0x004786A1, 0x004786A0, 0x00284B5A, 0x00000000, 0x0030586A, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004C87A0, 0x000E181D, 0x00070D10, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 
        0x005590A9, 0x005691A9, 0x005691AA, 0x005892AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B95AC, 0x005B95AD, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F98AF, 0x006098B0, 0x006099B0, 0x006199B1, 0x00629AB1, 0x00639AB1, 
        0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA3B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 
        0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0010171A, 0x00000000, 0x00496773, 0x007CACC0, 0x007CADC0, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x00688E9F, 
        0x000B0F11, 0x00030404, 0x0079A4B6, 0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x008AB5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB9CA, 
        0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0092BBCD, 0x0093BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D2, 0x009AC2D2, 0x009BC2D2, 
        0x009CC2D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC4D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 
        0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BBD9E6, 0x00BBD9E6, 0x00BCD9E6, 0x00BBD9E6, 0x00BCD9E5, 0x00BCD9E5, 0x00BBD9E6, 0x00BCD9E6, 0x00BBD9E5, 
        0x00BBD9E5, 0x00BCD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E3, 
        0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AED0DD, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 
        0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 
        0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 
        0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0091BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0086B3C6, 
        0x004D6772, 0x00000000, 0x003B4F57, 0x0083B1C4, 0x0083B1C4, 0x0082B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x006991A1, 0x00040606, 0x00000000, 0x0078A7BA, 0x007BACC0, 0x007BABBF, 0x007AAABF, 0x0079AABF, 0x0078AABE, 0x0077A9BE, 
        0x0077A9BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A4BA, 0x0070A4B9, 0x0070A4B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006AA0B6, 0x00699FB5, 
        0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659BB3, 0x00649CB2, 0x00649AB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098AF, 0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AC, 
        0x005A94AC, 0x005993AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00122026, 0x00040709, 0x003E6E82, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8AA5, 0x004C8AA4, 
        0x004C8AA3, 0x004B89A3, 0x002F5766, 0x00000000, 0x00294C5B, 0x004786A0, 0x004787A1, 0x004686A0, 0x004685A0,
  0x004686A0, 0x004686A0, 0x004786A1, 0x0046849E, 0x00192F38, 0x00000000, 0x00112026, 0x00233F4C, 0x00335E6F, 0x00467E95, 0x004D8BA4, 0x004E8BA4, 0x004F8CA5, 0x004A839B, 0x00000000, 0x001C323B, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 
        0x005590A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F98AF, 0x006098B0, 0x006199B0, 0x00629AB0, 0x00629AB1, 0x00639AB1, 
        0x00649BB2, 0x00649CB2, 0x00659CB3, 0x00659CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 
        0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079A9BE, 0x00618899, 0x00020404, 0x000B1011, 0x006A93A4, 0x007CACC0, 0x007DADC1, 0x007DADC1, 0x007FAEC2, 0x007EADC1, 0x004E6B77, 
        0x00000000, 0x0029383E, 0x0082B0C3, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB8CA, 
        0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 
        0x009CC3D3, 0x009DC3D3, 0x009DC4D3, 0x009EC5D4, 0x009EC5D4, 0x009FC5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A7CADA, 0x00A7CBDA, 0x00A8CBDA, 
        0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCEDD, 0x00ADCFDD, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E0, 
        0x00B3D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E4, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D8E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 
        0x00BBD9E5, 0x00BBD9E6, 0x00BBD9E5, 0x00BCD9E6, 0x00BCD9E6, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 
        0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B7D6E3, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B7D5E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AECFDD, 0x00ADCFDD, 
        0x00ADCFDD, 0x00ADCEDC, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A3C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C7D6, 
        0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D3, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D1, 0x0099C0D1, 0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BDCE, 0x0094BDCE, 
        0x0094BDCE, 0x0092BCCE, 0x0092BCCD, 0x0091BCCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C6, 0x0086B3C6, 
        0x007197A7, 0x00060809, 0x0007090A, 0x0084B1C4, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x0077A3B5, 0x001E2A2E, 0x00000000, 0x004F6D79, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 
        0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 
        0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E96AE, 0x005D97AE, 0x005D95AD, 0x005C95AD, 0x005B95AD, 
        0x005B94AC, 0x005A93AC, 0x005993AB, 0x005893AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005490A8, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x002C4C59, 0x00000000, 0x00345C6D, 0x00508CA6, 0x004F8CA6, 0x004E8BA5, 0x004D8BA4, 0x00477F97, 
        0x00356174, 0x00223F4B, 0x000F1D23, 0x00000000, 0x001A3039, 0x004785A0, 0x004787A1, 0x004786A1, 0x004686A0,
  0x004686A0, 0x004786A1, 0x004787A1, 0x0046839E, 0x000A1317, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070E10, 0x001C323C, 0x00325A6B, 0x00335B6C, 0x00000000, 0x002F5462, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005590A9, 
        0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005994AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 
        0x00649BB2, 0x00659CB2, 0x00659CB2, 0x00669CB3, 0x00679DB3, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006AA0B5, 0x006CA0B6, 0x006CA0B7, 0x006CA1B7, 0x006EA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A4B9, 0x0071A4B9, 0x0072A4BA, 
        0x0072A5BB, 0x0073A6BA, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x003C555F, 0x00000101, 0x00000000, 0x00141D20, 0x00455F6A, 0x00719DAE, 0x007DAABE, 0x007EADC1, 0x007DABBE, 0x00263439, 
        0x00000000, 0x00618492, 0x0082B0C3, 0x0083B1C4, 0x0083B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C9, 0x008AB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 
        0x008FB9CB, 0x0090BACB, 0x0090BACC, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 
        0x009CC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A6C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A9CCDA, 
        0x00A9CCDB, 0x00A9CDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 
        0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 
        0x00BBD9E5, 0x00BCDAE6, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BDDBE7, 0x00BDDAE7, 0x00BDDBE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 
        0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BCD9E6, 0x00BBD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D6E3, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 
        0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A1C7D6, 
        0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D3, 0x009DC3D3, 0x009BC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFCF, 0x0096BFCF, 0x0095BDCF, 0x0094BDCE, 
        0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B3C6, 
        0x007FA9BB, 0x00253136, 0x00000000, 0x005E7F8C, 0x0083B1C4, 0x0082B1C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x007FAFC2, 0x007FAEC2, 0x00394E57, 0x00000000, 0x001F2B30, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 
        0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4B9, 0x0071A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006A9FB5, 0x006A9FB5, 
        0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006099B0, 0x006098B0, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 
        0x005B95AD, 0x005994AC, 0x005993AB, 0x005993AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538EA7, 0x0044768A, 0x00000000, 0x0025424E, 0x00497F97, 0x00345C6D, 0x001D343E, 0x000A1215, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000A1317, 0x0046839D, 0x004887A1, 0x004786A1, 0x004686A0,
  0x004686A0, 0x004786A0, 0x004887A1, 0x00437E96, 0x00000000, 0x000E1A1F, 0x0023414D, 0x0014252C, 0x000C171B, 0x0005090B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003D6C7F, 0x00528EA7, 0x00528FA8, 0x00548FA8, 0x00548FA8, 0x005590A8, 
        0x005691A9, 0x005691AA, 0x005792AA, 0x005892AA, 0x005893AB, 0x005993AB, 0x005994AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639BB1, 
        0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 
        0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BE, 0x0078AABE, 0x0076A6BA, 0x00212E33, 0x00000000, 0x00090C0E, 0x00000000, 0x00000000, 0x00000000, 0x001F2B30, 0x0047616C, 0x00597B88, 0x00020303, 
        0x000C1113, 0x007FACBF, 0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0086B3C5, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 
        0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 
        0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A7CADA, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 
        0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D4E1, 
        0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 
        0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDAE7, 0x00BDDBE7, 0x00BEDBE6, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDAE7, 
        0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E3, 
        0x00B8D6E4, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B2D2E0, 0x00B2D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 
        0x00AECFDD, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 
        0x00A1C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BDCE, 
        0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x0089B6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 
        0x0086B3C6, 0x00445B65, 0x00000000, 0x0028363C, 0x0084B1C4, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x007BA9BC, 0x00668B9B, 0x004E6B77, 0x001D282C, 0x00000000, 0x00080C0D, 0x00709CAE, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078AABE, 
        0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B7, 0x006AA0B6, 0x006A9FB5, 
        0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 
        0x005B94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00000101, 0x00010303, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0005090A, 
        0x000C171B, 0x0014252C, 0x001F3A45, 0x000C171B, 0x00000000, 0x00437E97, 0x004887A1, 0x004786A1, 0x004686A0,
  0x004686A0, 0x004786A0, 0x004887A1, 0x00366579, 0x00000000, 0x00244351, 0x004B89A3, 0x004986A0, 0x00447B93, 0x003D6F83, 0x00345F71, 0x00274552, 0x00182A32, 0x00000101, 0x00080E11, 0x0044788D, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 
        0x005591AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB2, 
        0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 
        0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x006791A2, 0x000F1517, 0x00000000, 0x005B7F8E, 0x00567886, 0x0032464E, 0x000B0F11, 0x00000000, 0x00000000, 0x00030404, 0x00000000, 
        0x00354850, 0x0080AEC2, 0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B4C6, 0x0087B4C7, 0x0087B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB9CA, 0x008EB9CB, 0x008EB9CB, 
        0x0090BACB, 0x0090BBCC, 0x0090BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC2D2, 0x009BC2D3, 0x009CC2D3, 0x009CC3D3, 
        0x009DC4D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 
        0x00AACDDB, 0x00AACDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 
        0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 
        0x00BDDAE7, 0x00BDDBE7, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDBE8, 0x00BFDBE7, 0x00BFDBE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BFDCE7, 0x00BFDBE8, 0x00BFDCE8, 0x00BFDCE7, 0x00BFDCE7, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDBE7, 
        0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BCD9E6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 
        0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 
        0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 
        0x00A2C7D6, 0x00A1C7D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 
        0x0095BDCF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACB, 0x008FB9CB, 0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 
        0x0087B4C7, 0x00658896, 0x0007090A, 0x000A0D0F, 0x007EAABC, 0x0083B1C4, 0x006D94A5, 0x00435B65, 0x00212D33, 0x000A0E0F, 0x00000000, 0x00000000, 0x00000000, 0x00040606, 0x00537480, 0x007BACC0, 0x007BABC0, 0x007AABBF, 0x0079AABF, 0x0079AABE, 
        0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA0B7, 0x006BA0B6, 0x006A9FB5, 
        0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00679DB3, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B1, 0x006199B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005C95AE, 0x005B95AD, 
        0x005B94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005692AA, 0x005591AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00518DA6, 0x00132127, 0x00000000, 0x000A1316, 0x00192D35, 0x00264450, 0x00345E6F, 0x003C6E81, 
        0x00437B92, 0x004987A1, 0x004B89A3, 0x00244350, 0x00000000, 0x00366679, 0x004887A1, 0x004786A1, 0x004686A0,
  0x004686A0, 0x004786A1, 0x004887A1, 0x00244351, 0x00000000, 0x00305A6B, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x00000000, 0x00111E24, 0x004B839B, 0x00528FA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 
        0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006199B1, 0x00629AB1, 0x00639AB1, 0x00639BB2, 
        0x00659BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00689DB4, 0x00689EB4, 0x00689EB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 
        0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x00577A89, 0x00000000, 0x000D1315, 0x007CACC0, 0x007DADC0, 0x007CABBF, 0x007AA7BA, 0x005E8391, 0x00233136, 0x00000000, 0x00000000, 
        0x00597987, 0x0082B0C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 0x008EB8CA, 0x008EB9CB, 0x008FB9CB, 
        0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0094BDCE, 0x0094BECE, 0x0095BECF, 0x0095BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 
        0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 
        0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B4D3E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 
        0x00B6D5E2, 0x00B6D6E2, 0x00B6D6E2, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 
        0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDCE7, 0x00BFDBE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 
        0x00BFDCE8, 0x00BFDCE7, 0x00BFDCE7, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 
        0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 
        0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C7D7, 
        0x00A2C7D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC4D5, 0x009EC4D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 
        0x0095BDCF, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B4C7, 0x0087B4C7, 
        0x0086B4C6, 0x0083B0C2, 0x0012181B, 0x00030404, 0x002E3E45, 0x00171F22, 0x00020303, 0x00000000, 0x00000000, 0x00000000, 0x00131A1C, 0x004B6773, 0x00212D32, 0x00000000, 0x00374C55, 0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AAABE, 0x0079AABE, 
        0x0078AABE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0076A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006A9FB5, 
        0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB3, 0x00669DB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 
        0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x0025414C, 0x00000000, 0x0045798F, 0x004F8AA4, 0x004D8BA4, 0x004E8BA5, 0x004D8BA4, 
        0x004D8AA4, 0x004B89A4, 0x004B89A3, 0x0030596A, 0x00000000, 0x00244451, 0x004887A1, 0x004786A1, 0x004686A0,
  0x004686A1, 0x004786A1, 0x004887A1, 0x00112127, 0x00010202, 0x00396A7E, 0x004B89A3, 0x004B8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x0041748A, 0x00000000, 0x001A2E36, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 
        0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AC, 0x005994AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006099AF, 0x006199B0, 0x006299B0, 0x00639AB1, 0x00639AB2, 0x00649BB2, 
        0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB4, 0x006A9FB6, 0x006A9FB6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA2B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BA, 
        0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BD, 0x003A525B, 0x00000000, 0x00384E58, 0x007CACC0, 0x007DADC0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007DACBE, 0x00000000, 0x000F1416, 
        0x006E95A5, 0x0082B0C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 
        0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BECE, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC4D4, 
        0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A5C8D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBD9, 0x00A9CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 
        0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 
        0x00B6D6E2, 0x00B6D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 
        0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 
        0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE7, 0x00BFDCE8, 0x00BFDCE7, 0x00BEDCE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 
        0x00BAD8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD1DF, 
        0x00AFD0DE, 0x00AFD0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 
        0x00A2C7D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 
        0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCD, 0x0091BBCD, 0x0091BACC, 0x0090BACC, 0x0090BACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 
        0x0087B4C7, 0x0086B3C6, 0x0033444B, 0x00000000, 0x00000000, 0x00000000, 0x000D1213, 0x001F2A2E, 0x00455F69, 0x006B93A4, 0x0080AFC2, 0x007FAEC2, 0x0053727F, 0x00000000, 0x00202D32, 0x0075A2B5, 0x007BACC0, 0x007BABBF, 0x0079AABF, 0x0079AABE, 
        0x0078AABE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 
        0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x006299B0, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005C95AD, 0x005C95AD, 
        0x005B95AD, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005893AB, 0x005892AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x00365E6E, 0x00000000, 0x00365F70, 0x00508CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA4, 
        0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x0039697D, 0x00010202, 0x00122128, 0x004887A1, 0x004786A1, 0x004786A0,
  0x004686A0, 0x004787A1, 0x004887A2, 0x00030506, 0x00091114, 0x003F758B, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x00305564, 0x00000000, 0x0026424E, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 
        0x005691AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006099B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 
        0x00649CB2, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 
        0x0073A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A8BC, 0x00182226, 0x00000000, 0x00638B9B, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x004F6C78, 0x00000000, 0x00222F34, 
        0x007FACC0, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C6, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 
        0x0090BACC, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0095BECE, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 
        0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDB, 
        0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 
        0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE9, 0x00C0DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE9, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDBE7, 0x00BFDBE7, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 
        0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 
        0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDC, 0x00AACCDB, 0x00AACCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D9, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D4, 0x009EC5D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 
        0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B4C7, 
        0x0087B4C7, 0x0086B3C6, 0x00648695, 0x00000000, 0x000C1113, 0x004B6670, 0x006C92A2, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x0079A7B9, 0x00000000, 0x00090D0F, 0x006B95A7, 0x007BABC0, 0x007BABC0, 0x007AABBF, 0x0079AABF, 
        0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B8, 0x006FA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 
        0x006AA0B6, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00669DB4, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E96AE, 0x005D96AE, 0x005C95AD, 
        0x005C95AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538EA8, 0x003F6E82, 0x00000000, 0x00223C47, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 
        0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x0040758B, 0x00091114, 0x00030607, 0x004887A1, 0x004787A1, 0x004786A1,
  0x004786A0, 0x004786A1, 0x00407992, 0x00000000, 0x000F1C22, 0x00457F98, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x001E353F, 0x00000101, 0x00345B6C, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 
        0x005791AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006199B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 
        0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00689DB4, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BB, 0x0073A5BB, 
        0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0072A1B4, 0x00000000, 0x00090D0E, 0x0076A5B9, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x0028373D, 0x00000000, 0x003E555E, 
        0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B6C8, 0x008AB6C9, 0x008AB6C8, 0x008CB7CA, 0x008CB7CA, 0x008DB8CA, 0x008DB9CB, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 
        0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BED0, 0x0096BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC2D2, 0x009BC2D2, 0x009CC3D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 
        0x009EC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCEDC, 
        0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00BFDCE8, 
        0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DEE9, 0x00C2DDE9, 0x00C2DEE9, 
        0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDAE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E6, 
        0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00ADCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC4D4, 0x009DC4D4, 0x009DC3D3, 0x009DC3D3, 0x009BC3D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFCF, 
        0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB8CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x0088B5C7, 0x0088B5C7, 
        0x0087B4C7, 0x0086B3C6, 0x0086B3C6, 0x00040606, 0x00080B0D, 0x006F96A6, 0x0083B1C4, 0x0082B0C4, 0x0082B0C3, 0x0080AFC3, 0x0080AFC3, 0x007FAEC2, 0x007FAEC2, 0x001B252A, 0x00000000, 0x005B7E8D, 0x007CACC0, 0x007BACBF, 0x007AABBF, 0x0079AABE, 
        0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BA, 0x0072A5BA, 0x0072A5BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006BA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB3, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AD, 0x005C96AD, 
        0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005A93AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x0046798E, 0x00080E11, 0x000E191D, 0x00508DA6, 0x00508CA5, 0x004E8CA5, 0x004E8BA5, 
        0x004D8BA5, 0x004C8AA4, 0x004B89A3, 0x00457F97, 0x000F1C22, 0x00000000, 0x00427A92, 0x004787A1, 0x004786A1,
  0x004786A1, 0x004787A1, 0x00336072, 0x00000000, 0x00162931, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA6, 0x00101D23, 0x00020405, 0x00427489, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591AA, 
        0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 
        0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 
        0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 0x0079AABE, 0x00537482, 0x00000000, 0x0027363C, 0x007AA9BC, 0x007CACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x0078A4B7, 0x00131A1D, 0x00020303, 0x00628593, 
        0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 
        0x0091BACC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C0D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 
        0x009FC5D4, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 
        0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D6E2, 0x00B7D6E3, 0x00B7D6E3, 
        0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE8, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE9, 
        0x00C1DDE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C1DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DEE9, 0x00C3DEEA, 0x00C3DEE9, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DEEA, 
        0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE9, 0x00C0DCE8, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 
        0x00BCD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D1DF, 
        0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AECFDE, 0x00AECFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A4C9D8, 0x00A4C8D8, 
        0x00A3C8D8, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D3, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 
        0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 
        0x0088B4C7, 0x0086B4C6, 0x0086B3C6, 0x002F3F46, 0x00000000, 0x005B7C89, 0x0083B1C4, 0x0083B1C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x007FAEC2, 0x007FAEC2, 0x00425C66, 0x00000000, 0x003A505A, 0x007CACC0, 0x007BACBF, 0x007AABBF, 0x007AAABF, 
        0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0074A7BC, 0x0074A6BC, 0x0073A5BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B6, 0x006BA0B6, 
        0x006BA0B6, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006198B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 
        0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x004C839B, 0x00111E24, 0x00010202, 0x00508DA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 
        0x004D8BA4, 0x004C8AA4, 0x004C89A3, 0x004B89A3, 0x00162931, 0x00000000, 0x00336072, 0x004787A1, 0x004786A1,
  0x004786A1, 0x004787A1, 0x00264855, 0x00000000, 0x00203B46, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004A849C, 0x000A1114, 0x00030607, 0x004E8AA2, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005590A9, 0x005591A9, 0x005690A9, 
        0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005A94AC, 0x005A94AC, 0x005B94AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00649AB2, 0x00659BB2, 
        0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA2B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BB, 0x0073A6BB, 
        0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x002C3E45, 0x00000000, 0x00445F6A, 0x007BABBF, 0x007DADC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x00628796, 0x00090C0D, 0x00080B0C, 0x0080ADC0, 
        0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B4C7, 0x0089B5C8, 0x008AB6C8, 0x008AB7C8, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 
        0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BFCF, 0x0097BED0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 
        0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 
        0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D7E3, 
        0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DCE8, 0x00C0DDE9, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C2DDE9, 0x00C2DDE9, 0x00C2DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C4DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DEEA, 0x00C4DFEA, 0x00C3DEEA, 0x00C3DEEA, 
        0x00C3DEEA, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCD9E6, 
        0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E3, 0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 
        0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD8, 0x00A4C9D8, 
        0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009BC3D3, 0x009BC2D3, 0x009AC2D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFCF, 
        0x0096BECF, 0x0095BECF, 0x0094BECE, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 
        0x0088B4C7, 0x0087B4C6, 0x0086B4C6, 0x005B7B88, 0x00000000, 0x00384C54, 0x0083B2C4, 0x0083B1C4, 0x0082B0C3, 0x0082B0C3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x00668D9C, 0x00000000, 0x00172024, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 
        0x0079AABF, 0x0078A9BE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0073A6BB, 0x0073A6BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 
        0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006199B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AD, 
        0x005C95AD, 0x005B95AC, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005892AB, 0x005792AB, 0x005692AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00518CA6, 0x00182B33, 0x00000000, 0x00457B91, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 
        0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00203B46, 0x00000000, 0x00264755, 0x004887A1, 0x004786A1,
  0x004786A1, 0x004887A1, 0x00182C35, 0x00000101, 0x002C5160, 0x004B89A3, 0x004C89A3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8BA5, 0x00417388, 0x00060B0D, 0x000C1519, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005691A9, 
        0x005791AA, 0x005892AA, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B94AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639BB1, 0x00649BB2, 0x00659CB2, 
        0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006DA1B7, 0x006EA1B8, 0x006EA2B8, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BA, 0x0073A5BB, 
        0x0074A7BB, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 0x0077A9BD, 0x0078A9BE, 0x0079A9BE, 0x0079AABF, 0x000A0E0F, 0x00020303, 0x005A7D8C, 0x007CACC0, 0x007DACC1, 0x007EADC0, 0x007EAEC2, 0x007FAEC2, 0x004E6B77, 0x00000000, 0x00253338, 0x0082B0C4, 
        0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 0x0084B3C5, 0x0086B3C6, 0x0086B3C6, 0x0086B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008CB8C9, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 
        0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C0D1, 0x009AC1D1, 0x009AC2D2, 0x009BC2D2, 0x009CC2D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 
        0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ACCFDC, 
        0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 
        0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DDE9, 
        0x00C2DEE9, 0x00C2DEEA, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 
        0x00C4DFEA, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE8, 0x00C0DDE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE8, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE7, 
        0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E4, 0x00BAD8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 
        0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDC, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC2D3, 0x009BC2D3, 0x009BC2D2, 0x0099C1D2, 0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 
        0x0096BFD0, 0x0096BECF, 0x0095BECE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BACC, 0x008FBACC, 0x008FBACC, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x0089B5C8, 0x0089B5C7, 
        0x0088B5C7, 0x0087B4C7, 0x0086B3C6, 0x0078A1B2, 0x00000000, 0x0013191C, 0x0083B1C5, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x00749FB2, 0x000B0F11, 0x00000000, 0x0078A6B9, 0x007CACC0, 0x007AABBF, 0x007AAABF, 
        0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 
        0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AE, 
        0x005C96AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005692AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00223D48, 0x00000000, 0x00355D6E, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 
        0x004E8BA4, 0x004C8AA4, 0x004B8AA4, 0x004B89A3, 0x002B5060, 0x00000101, 0x00182D36, 0x004887A1, 0x004786A1,
  0x004787A1, 0x004987A1, 0x000F1C21, 0x00010203, 0x00376578, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x00396577, 0x00020405, 0x001C313A, 0x00518EA7, 0x00528FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005691A9, 
        0x005692AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AC, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F98AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639BB1, 0x00649BB2, 0x00659BB2, 
        0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 
        0x0074A6BC, 0x0075A7BC, 0x0075A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x006C96A9, 0x00000000, 0x000E1416, 0x006891A1, 0x007CACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x007DABBE, 0x00374B53, 0x00000000, 0x004D6A75, 0x0082B0C4, 
        0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0085B2C6, 0x0086B3C6, 0x0086B3C6, 0x0088B4C7, 0x0088B4C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BBCC, 
        0x0092BBCD, 0x0092BBCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 
        0x00A0C5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A9CBDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCEDD, 
        0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D8E4, 
        0x00B9D8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E6, 0x00BCD9E6, 0x00BCD9E6, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDBE7, 0x00BEDBE7, 0x00BFDBE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 
        0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4E0EB, 0x00C4E0EB, 0x00C4E0EB, 0x00C4E0EB, 0x00C5DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEB, 
        0x00C4E0EB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEA, 0x00C4DFEA, 0x00C4DFEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 
        0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 
        0x00B1D2E0, 0x00B1D2E0, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 
        0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 
        0x0096BFCF, 0x0096BFD0, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x0089B6C8, 0x0089B5C8, 
        0x0088B5C7, 0x0087B4C7, 0x0087B3C6, 0x007FAABC, 0x001C2529, 0x00000000, 0x007CA7B9, 0x0083B1C4, 0x0082B0C4, 0x0082B0C3, 0x0081B0C3, 0x0080AFC2, 0x007FAEC2, 0x0079A6B9, 0x00233035, 0x00000000, 0x005B7D8C, 0x007CACC0, 0x007BABC0, 0x007AABBF, 
        0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BB, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA0B6, 
        0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AE, 
        0x005C96AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005692AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x002F5261, 0x00000000, 0x00274552, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 
        0x004D8BA5, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00366478, 0x00010203, 0x000F1C21, 0x004887A1, 0x004787A1,
  0x004786A1, 0x00437E97, 0x000A1317, 0x00010303, 0x00417991, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x00305464, 0x00000000, 0x002B4B59, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 
        0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649CB3, 
        0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A2B7, 0x006290A2, 0x006F9FB4, 0x0073A6BB, 0x0073A6BB, 
        0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x004E6E7B, 0x00000000, 0x001B2529, 0x0076A4B7, 0x007DACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x0079A5B8, 0x001E292D, 0x00000000, 0x00739CAD, 0x0082B0C4, 
        0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 
        0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCF, 0x0095BDCF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C1D1, 0x009AC1D1, 0x009AC1D1, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 
        0x00A0C5D5, 0x00A0C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 
        0x00AECFDD, 0x00AECFDE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D5E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D8E4, 
        0x00BAD8E5, 0x00BAD8E4, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DEEA, 
        0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C4E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 
        0x00C5E0EB, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEA, 0x00C4DEEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE7, 0x00BEDBE7, 
        0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D7E4, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 
        0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5CAD9, 
        0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C5D6, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009BC3D3, 0x009BC2D2, 0x009AC2D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 
        0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 
        0x0088B5C8, 0x0087B4C7, 0x0087B4C6, 0x0083AFC2, 0x00364950, 0x00000000, 0x00567481, 0x0083B1C4, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC2, 0x007FAFC2, 0x007EACC0, 0x00394F57, 0x00000000, 0x00374C55, 0x007CACC0, 0x007BABC0, 0x007AABBF, 
        0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BB, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006EA3B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006BA0B6, 
        0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E96AE, 0x005D96AE, 
        0x005C96AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538EA8, 0x003B6678, 0x00010203, 0x00172930, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 
        0x004E8BA5, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00417991, 0x00010303, 0x000A1317, 0x00437E96, 0x004787A1,
  0x004787A1, 0x003C7187, 0x00070D10, 0x00030607, 0x004B89A3, 0x004B89A4, 0x004C8AA3, 0x004D8AA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x00274653, 0x00000000, 0x003C697B, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x00437184, 
        0x00528BA2, 0x005892AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005D95AE, 0x005D96AE, 0x005E96AE, 0x005F97AE, 0x005F98AF, 0x006098AF, 0x006198B0, 0x006299B1, 0x006299B1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 
        0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A4B9, 0x006D9EB3, 0x00202F35, 0x005F889A, 0x0073A6BB, 0x0074A6BB, 
        0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x00334750, 0x00000000, 0x0029393F, 0x007CACC0, 0x007DACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x0075A1B2, 0x00050607, 0x000B0F11, 0x0082B0C4, 0x0082B0C4, 
        0x0084B1C4, 0x0084B2C5, 0x0084B2C5, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0088B4C7, 0x0088B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 
        0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BED0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 
        0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6C9D9, 0x00A6CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCEDC, 0x00ADCFDD, 
        0x00AED0DD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D7E4, 0x00BAD8E5, 
        0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE7, 0x00BDDBE7, 0x00BEDBE7, 0x00BFDCE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C2DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 
        0x00C4DFEB, 0x00C4DFEB, 0x00C5DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 
        0x00C6E1EC, 0x00C6E0EB, 0x00C5E0EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DCE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 
        0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B3D3E1, 
        0x00B3D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 
        0x0097BFD0, 0x0096BED0, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 
        0x0089B5C8, 0x0088B4C7, 0x0087B4C6, 0x0086B4C6, 0x004F6975, 0x00000000, 0x00304047, 0x0083B1C4, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x004E6C78, 0x00000000, 0x00172024, 0x007CACC0, 0x007BABC0, 0x007BABBF, 
        0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B6, 
        0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00679EB4, 0x00679DB4, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AE, 0x005E97AE, 0x005D96AE, 
        0x005C96AE, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005591AA, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00477B91, 0x00020505, 0x000D181C, 0x00508CA6, 0x004F8CA6, 0x004E8CA5, 
        0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004A89A3, 0x00030607, 0x00070D10, 0x003C7288, 0x004887A1,
  0x004787A1, 0x00366579, 0x00040708, 0x000D191D, 0x004A89A3, 0x004C8AA3, 0x004C8AA3, 0x004D8AA4, 0x004E8BA5, 0x004E8CA5, 0x004D88A1, 0x001E353F, 0x00000000, 0x00498197, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005591A9, 0x005691A9, 0x00070B0E, 
        0x00426F82, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006198B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 
        0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x0070A4B9, 0x0071A4B9, 0x006A9AAF, 0x00050708, 0x005D8597, 0x0073A6BB, 0x0074A6BB, 
        0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x001B262A, 0x00000000, 0x00010202, 0x000E1416, 0x002C3D44, 0x004F6E7B, 0x006F99AB, 0x007FAEC2, 0x00668C9B, 0x00000000, 0x002B3B41, 0x0082B0C4, 0x0083B1C4, 
        0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 
        0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 
        0x00A0C6D5, 0x00A1C6D6, 0x00A2C6D6, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 
        0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 
        0x00BBD9E5, 0x00BBD9E6, 0x00BCD9E6, 0x00BDDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE8, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C4DFEB, 
        0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EC, 0x00C6E0EB, 0x00C6E1EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1ED, 0x00C7E1ED, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E0EB, 0x00C6E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEA, 0x00C4DFEA, 0x00C3DFEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE8, 0x00C0DCE8, 0x00BFDCE8, 
        0x00BFDCE8, 0x00BFDBE7, 0x00BDDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BCD9E5, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D4E1, 
        0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCEDC, 0x00ACCEDC, 0x00ABCDDB, 0x00AACDDC, 0x00AACDDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 
        0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D1, 0x0098C0D0, 0x0098C0D0, 
        0x0097C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BACC, 0x0090BACC, 0x0090BACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8C9, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 
        0x0089B5C8, 0x0088B4C7, 0x0087B4C7, 0x0087B3C6, 0x00628391, 0x0006090A, 0x000D1214, 0x0084B2C4, 0x0083B1C4, 0x0082B0C3, 0x0082B0C3, 0x0081AFC3, 0x0080AFC2, 0x007DABBE, 0x0052707D, 0x00050708, 0x00040607, 0x007AA7BB, 0x007BACBF, 0x007BABBF, 
        0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 
        0x006CA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006099B0, 0x006098B0, 0x006098AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 
        0x005D96AE, 0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AB, 0x005691AA, 0x005691A9, 0x005591A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00518CA5, 0x00040708, 0x00091114, 0x004A8299, 0x004F8CA5, 0x004E8CA5, 
        0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B8AA4, 0x004A89A3, 0x000D181D, 0x00040708, 0x00376679, 0x004787A1,
  0x004887A1, 0x00305A6B, 0x00000000, 0x00182D36, 0x004A89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004F8CA5, 0x004B859D, 0x0016262E, 0x00000101, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x00030607, 
        0x00385E6E, 0x005892AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005B94AD, 0x005B95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 
        0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00699EB4, 0x00699EB5, 0x006A9FB5, 0x006AA0B6, 0x006CA0B6, 0x006CA0B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0071A4B9, 0x00466673, 0x00000000, 0x005D8697, 0x0073A6BB, 0x0074A6BB, 
        0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x006F9CAE, 0x00121A1D, 0x00000000, 0x000A0E10, 0x00020404, 0x00000000, 0x00000000, 0x00000000, 0x00050708, 0x00101619, 0x00000000, 0x004A646F, 0x0082B1C4, 0x0083B1C4, 
        0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB9CA, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 
        0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0095BECE, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC2D2, 0x009AC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x00A0C5D5, 
        0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 
        0x00AED0DE, 0x00AFD0DE, 0x00B0D1DE, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D3E1, 0x00B4D4E2, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D6E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 
        0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDAE7, 0x00BEDBE7, 0x00BFDCE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C1DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C5E0EB, 
        0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E2EC, 0x00C7E2EC, 0x00C7E2ED, 0x00C7E1ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2EC, 0x00C7E2ED, 0x00C7E2ED, 0x00C7E1EC, 
        0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EB, 0x00C6E1EC, 0x00C5E0EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4E0EB, 0x00C4E0EA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 
        0x00BFDCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 
        0x00B3D3E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 
        0x00A5CAD9, 0x00A5C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 
        0x0097C0D0, 0x0097BFD0, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0093BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BBCC, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B6C8, 
        0x0089B5C8, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x007399AA, 0x00101517, 0x00020203, 0x00769FB0, 0x0079A3B5, 0x006D93A4, 0x005F818F, 0x0046606B, 0x00222E34, 0x00060809, 0x00000000, 0x00000000, 0x00020404, 0x00628797, 0x007BACC0, 0x007BABBF, 
        0x007AABBF, 0x0079AABF, 0x0079A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 
        0x006CA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098AF, 0x006098AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 
        0x005D96AE, 0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005892AB, 0x005892AB, 0x005692AA, 0x005691AA, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x000C1519, 0x00060C0E, 0x0043768B, 0x004F8CA5, 0x004F8CA5, 
        0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00182C35, 0x00000000, 0x00305A6B, 0x004887A1,
  0x004887A1, 0x002A4E5E, 0x00000000, 0x00254452, 0x004A89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8CA5, 0x0049829A, 0x000C161A, 0x000C1518, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005591A9, 0x005691AA, 0x00000000, 
        0x00233C46, 0x005691A8, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 
        0x00669DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006FA2B8, 0x006FA3B8, 0x0070A3B8, 0x006C9CB1, 0x000A0F11, 0x00050708, 0x005D8697, 0x0073A6BB, 0x0074A7BB, 
        0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079A9BE, 0x00628A9A, 0x000B1012, 0x00010202, 0x005F8695, 0x00587A88, 0x0046616C, 0x002F4149, 0x00161F22, 0x00000000, 0x00000000, 0x00000000, 0x00638695, 0x0082B1C4, 0x0083B1C4, 
        0x0084B2C5, 0x0085B2C5, 0x0085B2C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB5C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 
        0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C0D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D5, 
        0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 
        0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 
        0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DEE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EC, 
        0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C7E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E3ED, 0x00C9E2ED, 0x00C9E3ED, 0x00C9E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00C9E3ED, 0x00C9E2ED, 0x00C9E2ED, 0x00C8E2ED, 0x00C8E2ED, 
        0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2ED, 0x00C7E1EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 
        0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B5D4E1, 
        0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CAD9, 0x00A7CAD9, 
        0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 
        0x0098BFD0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BACC, 0x008FBACC, 0x008FBACB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008AB6C9, 0x008AB6C8, 
        0x0089B5C8, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x0083AFC2, 0x00182024, 0x00000000, 0x00212C31, 0x001B2529, 0x000A0D0F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00131A1D, 0x00050809, 0x00010202, 0x004C6976, 0x007CACC0, 0x007BABC0, 
        0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A6BC, 0x0073A4B9, 0x0071A4B8, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 
        0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679EB4, 0x00679DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005E97AE, 0x005D97AE, 
        0x005D96AE, 0x005C95AD, 0x005B94AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005791A9, 0x005690A8, 0x005791AA, 0x005691AA, 0x005591A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528EA8, 0x00182B33, 0x00030506, 0x003A677A, 0x004F8CA6, 0x004E8CA5, 
        0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00254451, 0x00000000, 0x002A4E5E, 0x004887A1,
  0x004786A0, 0x0023414E, 0x00000000, 0x00325D6F, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004F8CA5, 0x00477E95, 0x00040708, 0x00172830, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005691A9, 0x005691AA, 0x00010102, 
        0x00030607, 0x004E8298, 0x005993AB, 0x005A93AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659CB2, 0x00669CB3, 
        0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x001D2B30, 0x00000000, 0x0006090A, 0x005D8697, 0x0074A6BB, 0x0074A7BB, 
        0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x00567886, 0x00030505, 0x000B0F11, 0x007CACC0, 0x007DADC0, 0x007CACC0, 0x007BA9BD, 0x007AA7BA, 0x0076A2B4, 0x00050708, 0x00070A0B, 0x006F96A6, 0x0082B1C4, 0x0083B1C4, 
        0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB8C9, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACB, 0x0090BACC, 0x0091BBCD, 0x0091BBCD, 
        0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097C0D0, 0x0098BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 
        0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCEDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 
        0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 
        0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BEDBE8, 0x00BFDBE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE8, 0x00C2DEE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C3DEEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4E0EB, 0x00C5E0EB, 0x00C6E0EB, 0x00C6E1EB, 0x00C7E1EC, 
        0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E2ED, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3ED, 
        0x00C9E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C6E0EB, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEB, 0x00C4DFEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 
        0x00C0DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E1, 
        0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A7CBDA, 0x00A7CAD9, 
        0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 
        0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008AB6C9, 0x008AB6C8, 
        0x0089B6C8, 0x0089B5C7, 0x0087B5C7, 0x0087B4C7, 0x0087B4C6, 0x0028363B, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x001E282D, 0x00405861, 0x005B7C8B, 0x00709AAB, 0x007EADC1, 0x0027353B, 0x00000000, 0x00394F58, 0x007CACC0, 0x007BABBF, 
        0x007BABBF, 0x0079AABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0074A7BB, 0x003D5763, 0x002B3E46, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 
        0x006CA0B7, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005E97AE, 0x005E97AE, 
        0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x003C6474, 0x00223942, 0x005590A8, 0x005691AA, 0x005691A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x0025404B, 0x00000000, 0x00345B6C, 0x004F8CA6, 0x004F8CA5, 
        0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00325C6D, 0x00000000, 0x0023414E, 0x004786A0,
  0x0046849D, 0x001C343F, 0x00000000, 0x003C6F84, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00457B92, 0x00000000, 0x0025404C, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA9, 0x005490A9, 0x005691AA, 0x005691AA, 0x00010202, 
        0x00000000, 0x001A2B32, 0x005892AB, 0x005994AC, 0x005B95AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 
        0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006696AA, 0x0025363D, 0x00000000, 0x00000000, 0x0006090A, 0x005D8697, 0x0074A6BB, 0x0074A6BB, 
        0x0075A8BC, 0x0076A8BC, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x00496672, 0x00000000, 0x00243238, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EADC1, 0x007FAEC2, 0x0079A6B8, 0x00000000, 0x00182024, 0x0076A0B2, 0x0083B1C4, 0x0083B1C4, 
        0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B4C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BBCD, 
        0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 
        0x00A1C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDC, 0x00ADCFDD, 0x00AED0DD, 0x00AFD0DE, 
        0x00AFD0DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 
        0x00BCDAE6, 0x00BDDBE6, 0x00BEDAE7, 0x00BEDBE7, 0x00BFDCE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEB, 0x00C4DFEB, 0x00C4E0EB, 0x00C5E0EB, 0x00C5E0EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 
        0x00C7E2EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E2ED, 0x00C9E3EE, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00C9E3EE, 
        0x00C9E3EE, 0x00C9E3ED, 0x00C9E3ED, 0x00C9E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2ED, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C5E1EC, 0x00C5E0EB, 0x00C5DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDBE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD9E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 
        0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CADA, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A2C8D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009EC5D5, 0x009EC4D4, 0x009DC4D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D1, 0x0099C1D1, 
        0x0098C0D1, 0x0098BFD0, 0x0096BED0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008AB7C9, 0x008AB6C8, 
        0x0089B6C8, 0x0088B5C8, 0x0088B4C7, 0x0087B4C7, 0x0086B3C6, 0x00435A64, 0x00000000, 0x001D272C, 0x006B91A0, 0x0081AFC2, 0x0082B0C4, 0x0082AFC3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x003F5760, 0x00000000, 0x0028373D, 0x007CACC0, 0x007CABC0, 
        0x007BABBF, 0x007AAABF, 0x0079AABF, 0x0078AABE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0039525D, 0x0025363C, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 
        0x006CA1B7, 0x006B9FB6, 0x006AA0B6, 0x006A9FB5, 0x00689EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005E97AE, 0x005E97AE, 
        0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005993AB, 0x00395F6F, 0x001F333C, 0x005590A8, 0x005691AA, 0x005591A9, 0x005490A9, 0x005490A9, 0x00538FA8, 0x00528EA7, 0x00345A6A, 0x00000000, 0x002D4F5D, 0x004F8CA6, 0x004F8CA5, 
        0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x003C6F84, 0x00000000, 0x001C3540, 0x0046849D,
  0x0045819A, 0x0015272F, 0x00000000, 0x004A88A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8CA5, 0x004F8CA5, 0x00407186, 0x00000000, 0x002F5362, 0x00528EA7, 0x00528EA7, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005691A9, 0x005691AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00253D48, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00659BB2, 0x00659CB2, 0x00669CB3, 
        0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x00557D8E, 0x00192429, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005D8697, 0x0074A7BB, 0x0074A7BC, 
        0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BE, 0x0078A9BE, 0x0078A8BC, 0x003A515B, 0x00000000, 0x003D555F, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x00608492, 0x00000000, 0x0026353A, 0x007CA9BC, 0x0083B0C4, 0x0083B1C4, 
        0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACB, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 
        0x0093BCCE, 0x0093BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C1D1, 0x0099C1D1, 0x009AC2D2, 0x009BC2D3, 0x009BC2D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 
        0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AED0DD, 0x00AED0DE, 0x00AFD0DE, 
        0x00AFD1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E3, 0x00B7D6E2, 0x00B7D6E3, 0x00B8D6E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 
        0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE7, 0x00C0DCE8, 0x00C0DDE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C4DFEA, 0x00C4DFEA, 0x00C4E0EB, 0x00C5E0EB, 0x00C6E0EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 
        0x00C7E2ED, 0x00C9E2ED, 0x00C9E2ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CAE3EE, 0x00CBE4EE, 0x00CAE4EE, 0x00CAE4EE, 0x00CAE4EE, 0x00CBE4EE, 0x00CAE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CBE4EF, 0x00CAE4EE, 
        0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00CAE3EE, 0x00C9E3ED, 0x00C9E3EE, 0x00C9E2ED, 0x00C8E2ED, 0x00C7E2ED, 0x00C7E1ED, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C4E0EB, 0x00C4E0EB, 0x00C4DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 
        0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 
        0x00B4D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DE, 0x00AFD1DE, 0x00AED0DE, 0x00AECFDD, 0x00ACCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A7CBDA, 
        0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D2, 0x0099C1D1, 
        0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB6C9, 0x008AB6C9, 
        0x008AB6C8, 0x0088B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x005D7D8A, 0x00000000, 0x00233035, 0x0082B0C3, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x00587886, 0x00000000, 0x001D282D, 0x0075A3B6, 0x007BACC0, 
        0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0039525D, 0x001B282D, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 
        0x006CA0B7, 0x006BA0B6, 0x006B9FB6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005E97AF, 0x005E97AE, 
        0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005993AC, 0x002D4B57, 0x0020353E, 0x005590A8, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA8, 0x00406F82, 0x00000000, 0x0026434F, 0x00508CA6, 0x004F8CA5, 
        0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x0047859E, 0x00000000, 0x00152830, 0x0045819B,
  0x00447F98, 0x000F1D22, 0x00000000, 0x0014262E, 0x00192E37, 0x00233F4B, 0x002C5160, 0x00366375, 0x0041748A, 0x004B869F, 0x00335B6C, 0x00000000, 0x00386374, 0x00528EA7, 0x00528EA7, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x005691AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00223942, 0x005992A9, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00649AB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 
        0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA2B7, 0x003C5965, 0x00070B0C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005D8697, 0x0074A6BB, 0x0075A7BC, 
        0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0079AABE, 0x0075A5B8, 0x002A3A41, 0x00000000, 0x00567886, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC2, 0x007FAEC2, 0x0048636E, 0x00000000, 0x0035474F, 0x0082B0C4, 0x0083B1C4, 0x0084B1C4, 
        0x0085B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 
        0x0093BCCE, 0x0094BDCE, 0x0094BDCF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 
        0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00AECFDD, 0x00AFD0DE, 0x00AFD0DE, 
        0x00B0D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E6, 0x00BBD9E5, 0x00BCD9E6, 0x00BDDAE6, 
        0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C5E0EC, 0x00C5E1EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C8E2ED, 
        0x00C8E3ED, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE4EF, 0x00CBE5EF, 0x00CBE4EF, 
        0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2ED, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C5E0EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEA, 0x00C3DEEA, 0x00C2DEEA, 
        0x00C2DEE9, 0x00C1DEE9, 0x00C0DDE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 
        0x00B5D5E2, 0x00B4D4E2, 0x00B3D3E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AED0DE, 0x00AED0DE, 0x00AECFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 
        0x00A7CADA, 0x00A6CAD9, 0x00A6C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x0099C1D2, 0x0099C1D1, 
        0x0099C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 
        0x008AB6C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C6, 0x0077A0B1, 0x00000000, 0x00182024, 0x0077A1B1, 0x0083B1C4, 0x0082B1C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AEC2, 0x006D96A7, 0x00000000, 0x00141C1F, 0x006D98AA, 0x007CACC0, 
        0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x0039535D, 0x000D1316, 0x006895A8, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x006FA3B9, 0x006FA3B8, 0x006FA2B8, 0x006DA2B7, 0x006DA1B7, 
        0x006CA0B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00669CB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E96AE, 
        0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005994AC, 0x00101A1E, 0x00223942, 0x005590A8, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA7, 0x00497F95, 0x00000000, 0x001F3640, 0x004D88A0, 0x0044798F, 
        0x00396679, 0x002E5464, 0x0025434F, 0x001B323B, 0x0013232A, 0x000D181D, 0x00000000, 0x000F1D22, 0x00447F98,
  0x00427C95, 0x00070E11, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00427488, 0x00528EA7, 0x00528FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001E323A, 0x00588FA6, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 
        0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006798AD, 0x0025373F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8697, 0x0074A7BB, 0x0075A7BC, 
        0x0076A8BC, 0x0077A8BD, 0x0077A8BD, 0x0077A9BE, 0x0079AABE, 0x0073A2B6, 0x001B262B, 0x00000000, 0x006E99AA, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC2, 0x007FAEC2, 0x00304149, 0x00000000, 0x00445D67, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 
        0x0085B2C5, 0x0086B2C5, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BACC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 
        0x0094BDCE, 0x0094BDCE, 0x0095BDCF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC2D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A1C6D6, 
        0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCFDC, 0x00ADCFDD, 0x00AED0DE, 0x00AED0DE, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D4E2, 0x00B5D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE7, 
        0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DEE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C4DFEA, 0x00C4DFEA, 0x00C4E0EB, 0x00C5E0EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E2ED, 
        0x00C9E3EE, 0x00C9E3EE, 0x00CAE4EE, 0x00CAE4EE, 0x00CAE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CCE5EF, 0x00CCE5F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 
        0x00CCE5EF, 0x00CBE5EF, 0x00CBE4EF, 0x00CBE4EE, 0x00CAE4EE, 0x00CAE3EE, 0x00CAE3EE, 0x00C9E3ED, 0x00C9E3EE, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E1ED, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C3DEEA, 
        0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE8, 0x00BEDBE7, 0x00BDDAE7, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E5, 0x00BAD9E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 
        0x00B5D5E1, 0x00B5D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00AACDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 
        0x00A7CBD9, 0x00A6CAD9, 0x00A6C9D9, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 
        0x0099C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECE, 0x0094BDCE, 0x0094BDCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0091BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008AB6C9, 
        0x008AB6C8, 0x008AB5C8, 0x0088B5C8, 0x0088B4C7, 0x0087B4C7, 0x0086B3C6, 0x00020203, 0x000F1416, 0x006E94A3, 0x0083B1C4, 0x0082B1C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x007EAEC2, 0x00000000, 0x000A0E10, 0x00668D9E, 0x007CACC0, 
        0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0039525D, 0x00000000, 0x0039525D, 0x006D9EB2, 0x006FA3B7, 0x006FA3B8, 0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006DA2B7, 0x006DA1B7, 
        0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005E97AF, 0x005E97AE, 
        0x005E96AE, 0x005C96AD, 0x005C95AD, 0x005A93AB, 0x005A94AC, 0x00325361, 0x00000000, 0x00233B45, 0x005590A8, 0x005791AA, 0x005691AA, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00000000, 0x00010303, 0x00010203, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00000000, 0x00070E11, 0x00427C95,
  0x00427B94, 0x00030506, 0x000B151A, 0x00264755, 0x001C343E, 0x00182B34, 0x0013232A, 0x000F1B21, 0x000B1317, 0x00060C0E, 0x00010202, 0x00000000, 0x0045798E, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005691AA, 0x005691AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00111C21, 0x004A788B, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 
        0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B5, 0x006A9EB4, 0x00476A79, 0x000B1012, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8697, 0x0074A6BB, 0x0075A7BC, 
        0x0076A7BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0072A0B3, 0x000C1113, 0x00000000, 0x007BABBF, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x0080AEC2, 0x001D272C, 0x00030404, 0x0054737F, 0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 
        0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 0x0091BACC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCE, 
        0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A1C7D6, 
        0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6C9D9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDE, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 
        0x00BEDBE7, 0x00BFDBE7, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C5E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 
        0x00CAE3EE, 0x00CAE4EE, 0x00CBE4EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CCE5F0, 0x00CDE5F0, 0x00CDE5F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CCE6F0, 0x00CDE5F0, 0x00CCE6F0, 0x00CCE5F0, 
        0x00CCE5EF, 0x00CCE5EF, 0x00CBE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEB, 0x00C3DFEA, 
        0x00C2DEEA, 0x00C2DEE9, 0x00C2DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D6E2, 
        0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 
        0x00A7CBD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 
        0x0099C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB8C9, 0x008BB7C9, 0x008BB6C8, 
        0x008AB6C8, 0x008AB5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x0086B3C6, 0x00171F22, 0x00040606, 0x00658897, 0x0083B1C4, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x007FAEC2, 0x000F1517, 0x00010203, 0x00608493, 0x007CACC0, 
        0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0039535D, 0x00000000, 0x00000000, 0x001B272C, 0x00324953, 0x003E5A65, 0x0041606D, 0x0043626F, 0x0042616E, 0x0042616E, 0x0041606D, 
        0x0040606D, 0x0040606D, 0x0040606D, 0x003F5F6C, 0x003F5F6C, 0x003E5E6C, 0x003E5E6C, 0x003D5E6C, 0x003D5E6B, 0x003C5D6B, 0x003C5D6A, 0x003C5D6A, 0x003B5C6A, 0x003B5D6A, 0x003B5C6A, 0x003A5B69, 0x00395B69, 0x00395B69, 0x00385A69, 0x00385A68, 
        0x00385A68, 0x00365967, 0x00345462, 0x002C4955, 0x001B2C33, 0x00000000, 0x00000000, 0x00233A45, 0x005690A8, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00040708, 0x00000101, 0x00070D10, 0x000C1519, 
        0x000E1A1F, 0x0013232A, 0x00172B32, 0x001D353F, 0x00233F4C, 0x002A4D5C, 0x000C161A, 0x00030506, 0x00427B94,
  0x00407992, 0x00000000, 0x00182D36, 0x004B89A3, 0x004B89A3, 0x004B88A2, 0x0049849C, 0x00467F95, 0x00457A90, 0x0044788F, 0x00101D22, 0x0005090B, 0x00487D93, 0x00528EA7, 0x00538EA7, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005691AA, 0x005791AA, 0x00010102, 
        0x00040708, 0x00365A69, 0x00437082, 0x00263E48, 0x00000000, 0x00000000, 0x00070C0E, 0x003B606F, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006199B0, 0x006199B0, 0x006299B0, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 
        0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006496AB, 0x00213239, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8697, 0x0074A6BC, 0x0075A7BC, 
        0x0076A7BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x006F9CAF, 0x00000000, 0x000F1618, 0x007CACC0, 0x007CACC0, 0x007EADC1, 0x007EADC1, 0x007FAEC2, 0x0080AFC2, 0x0011171A, 0x00060809, 0x00638795, 0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 
        0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BACC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCE, 
        0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A2C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 
        0x00B1D2DF, 0x00B1D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D6E2, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BBD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BDDAE6, 0x00BDDAE6, 0x00BEDAE7, 
        0x00BFDCE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE8, 0x00C1DDE9, 0x00C1DEE9, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2EC, 0x00C8E2ED, 0x00C9E2ED, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE3EE, 
        0x00CAE4EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F1, 0x00CEE6F0, 0x00CEE6F1, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CDE6F0, 
        0x00CDE6F0, 0x00CDE6F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C9E3ED, 0x00C8E2ED, 0x00C7E2EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEA, 
        0x00C3DFEA, 0x00C2DFE9, 0x00C2DEEA, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B6D5E3, 
        0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D4E1, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 
        0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC1D2, 0x009AC1D1, 
        0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB8CB, 0x008DB8CA, 0x008CB8C9, 0x008BB7C9, 0x008BB7C9, 
        0x008AB6C8, 0x008AB5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0086B3C6, 0x002F3F46, 0x00000000, 0x005C7C89, 0x0084B1C4, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x007EAEC2, 0x00243238, 0x00000000, 0x00557685, 0x007CACC0, 
        0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0039535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233A45, 0x005590A8, 0x005792AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528EA8, 0x000E1A1E, 0x00070D10, 0x003E6E82, 0x00457B92, 
        0x00477E95, 0x004A839C, 0x004B88A0, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00182D35, 0x00000000, 0x00417992,
  0x003E738A, 0x00000000, 0x00213E4A, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8CA6, 0x004F8CA5, 0x000D171B, 0x000A1114, 0x00498096, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005791AA, 0x00010202, 
        0x002F4E5B, 0x005993AB, 0x005A94AB, 0x005A94AC, 0x00416A7C, 0x00020304, 0x00000000, 0x00000000, 0x002C4752, 0x005F97AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 
        0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x00496E7F, 0x00020404, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8697, 0x0074A6BC, 0x0075A7BC, 
        0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x006891A3, 0x00000000, 0x001F2C31, 0x007CACC0, 0x007CACC0, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x00749FB1, 0x000C1012, 0x00090C0D, 0x00729AAB, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 
        0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB8CA, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 
        0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC4D4, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D9, 0x00A6CAD8, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00AACCDA, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AFCFDE, 0x00AFD0DE, 0x00AFD1DF, 0x00B0D1DF, 
        0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D4E1, 0x00B4D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BFDBE7, 
        0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CBE4EE, 
        0x00CBE4EF, 0x00CBE5EF, 0x00CCE5EF, 0x00CDE5EF, 0x00CCE5EF, 0x00CDE6F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F1, 0x00CEE6F1, 0x00CEE6F1, 0x00CFE7F1, 0x00CEE6F1, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE7F1, 0x00CEE7F1, 0x00CEE6F1, 0x00CEE6F1, 
        0x00CEE6F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CCE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E1ED, 0x00C7E1EC, 0x00C6E0EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C4DFEB, 
        0x00C3DFEA, 0x00C3DFEA, 0x00C2DEE9, 0x00C1DEE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B6D6E3, 
        0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCDDC, 0x00ABCDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 
        0x0099C1D1, 0x0099C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB6C9, 
        0x008AB6C9, 0x0089B5C8, 0x0088B5C8, 0x0088B5C7, 0x0087B4C7, 0x0086B3C6, 0x00455D67, 0x00000000, 0x00506C77, 0x0083B0C3, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0080B0C3, 0x0080AEC2, 0x007FAEC2, 0x00374C54, 0x00000000, 0x00496672, 0x007CACC0, 
        0x007BACC0, 0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005590A8, 0x005792AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x0016262D, 0x00040809, 0x00487F96, 0x004F8CA6, 
        0x004F8CA6, 0x004E8BA4, 0x004D8AA4, 0x004D8AA4, 0x004B8AA4, 0x004B89A3, 0x00213E4A, 0x00000000, 0x003E748B,
  0x00356579, 0x00000000, 0x00284958, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004F8CA5, 0x004F8CA6, 0x00050A0C, 0x00101D22, 0x004B839B, 0x00528EA7, 0x00538EA7, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x00060A0C, 
        0x00406B7D, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x0051849A, 0x00131F23, 0x00000000, 0x00000000, 0x001A2A30, 0x0054869B, 0x006198B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00649AB1, 0x00649BB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 
        0x00679DB4, 0x00689EB4, 0x005B8B9F, 0x002B414A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121B1F, 0x0024343B, 0x001E2C31, 0x00010102, 0x0006090A, 0x005E8697, 0x0074A7BC, 0x0075A7BC, 
        0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0079AABE, 0x0079AABE, 0x00587C8B, 0x00000000, 0x002F4249, 0x007CACC0, 0x007CACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x006A91A1, 0x00090C0D, 0x000B0F11, 0x007EABBD, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 
        0x0085B2C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB8CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 
        0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A5C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00AACCDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B1D1DF, 
        0x00B1D2DF, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BBD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDCE7, 
        0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4E0EB, 0x00C5E0EC, 0x00C6E0EC, 0x00C6E1EC, 0x00C7E2EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CBE4EF, 
        0x00CBE4EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 
        0x00CEE6F1, 0x00CEE6F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CCE4EF, 0x00CBE4EF, 0x00CAE4EF, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E1ED, 0x00C6E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C5E0EB, 
        0x00C4DFEA, 0x00C3DFEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DEE9, 0x00C0DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BBDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 
        0x00B6D6E3, 0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDE, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 0x0099C1D2, 
        0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008BB7C9, 0x008BB7C9, 
        0x008AB6C9, 0x008AB6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0086B4C6, 0x005B7A87, 0x00000000, 0x00425962, 0x0081AFC2, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x004B6874, 0x00000000, 0x003C535D, 0x007BABBF, 
        0x007BACC0, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0077A9BE, 0x0077A8BD, 0x0077A8BD, 0x0075A7BC, 0x0039535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233A45, 0x005590A8, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x00213943, 0x00000000, 0x00477D93, 0x004F8CA5, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x00274957, 0x00000000, 0x00356579,
  0x0030596B, 0x00000000, 0x002E5465, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004F8CA5, 0x004F8CA5, 0x00000000, 0x0014232A, 0x004D859D, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x00030506, 
        0x00457284, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x00578DA4, 0x00273E49, 0x00000000, 0x00000000, 0x000D1518, 0x00487283, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 
        0x00679DB4, 0x003F606E, 0x0010181B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00050708, 0x003F5C68, 0x006695A9, 0x0070A4BA, 0x0072A5BA, 0x003E5A66, 0x00000101, 0x005E8798, 0x0075A7BC, 0x0075A7BC, 
        0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0079AABE, 0x0079AABE, 0x00486571, 0x00000000, 0x00405A64, 0x007CACC0, 0x007DACC0, 0x007EADC1, 0x007EAEC2, 0x007FAEC2, 0x005F8391, 0x00060809, 0x00131A1D, 0x0082B0C4, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 
        0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 
        0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D2DF, 
        0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E2, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BBD8E5, 0x00BCD9E6, 0x00BCD9E6, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDCE8, 
        0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C2DDE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4E0EB, 0x00C5E0EB, 0x00C5E0EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE4EF, 0x00CBE4EF, 0x00CBE4EF, 
        0x00CCE5F0, 0x00CDE5F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE7F0, 0x00CEE7F1, 0x00CEE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F2, 0x00D0E8F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E7F2, 0x00D0E8F2, 0x00CFE7F1, 
        0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE7F0, 0x00CEE6F1, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E2ED, 0x00C9E2ED, 0x00C7E2ED, 0x00C7E1EC, 0x00C7E1EC, 0x00C6E0EC, 0x00C5E0EB, 
        0x00C5E0EB, 0x00C4DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 
        0x00B6D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B0D2DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ACCFDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDA, 
        0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 
        0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0092BCCE, 0x0092BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008BB6C9, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0086B4C6, 0x006F94A4, 0x00000000, 0x0034464E, 0x0082AEC2, 0x0083B1C4, 0x0083B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x00608593, 0x00000000, 0x0031434B, 0x007BAABE, 
        0x007CACC0, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0075A7BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x0026424E, 0x00000000, 0x00457A91, 0x004F8CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004B8AA3, 0x004B89A3, 0x002D5464, 0x00000000, 0x00305A6C,
  0x002A5060, 0x00000000, 0x00356376, 0x004B89A3, 0x004B89A3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00000000, 0x001A2D36, 0x004F89A1, 0x00528EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x00426F81, 
        0x00538BA2, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D95AD, 0x005E96AE, 0x003C606F, 0x00000000, 0x00000000, 0x00000000, 0x0034525F, 0x006299B1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x006296AB, 
        0x0021333A, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00141D21, 0x005F8B9E, 0x006FA2B8, 0x0070A3B9, 0x0071A4BA, 0x0072A5BA, 0x006B9BB0, 0x000B1013, 0x005D8697, 0x0075A7BC, 0x0075A7BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x00374D56, 0x00000000, 0x00090D0F, 0x001B262A, 0x002B3C43, 0x003D545E, 0x004E6C78, 0x005C7E8C, 0x00445D67, 0x00030404, 0x001F2B30, 0x0082B0C4, 0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 
        0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0092BBCD, 0x0093BCCD, 0x0093BDCE, 
        0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00ABCDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D2DF, 
        0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDBE6, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 
        0x00C0DCE8, 0x00C0DDE9, 0x00C2DDE9, 0x00C2DEEA, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CBE5EF, 0x00CCE5EF, 
        0x00CDE5F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00D0E7F1, 0x00D0E8F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E8F2, 
        0x00D0E8F2, 0x00D0E8F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE6F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EF, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C8E2ED, 0x00C7E2EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EC, 
        0x00C5DFEB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEE9, 0x00C2DEEA, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E5, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B6D6E3, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D9, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC2D3, 0x009BC2D2, 0x009AC2D2, 
        0x009AC1D2, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCF, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008BB6C9, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0086B4C7, 0x007BA4B6, 0x00000000, 0x0028373D, 0x0084B1C5, 0x0083B1C4, 0x0082B0C4, 0x007EABBF, 0x00729BAC, 0x005D808F, 0x00496470, 0x0030424A, 0x00000000, 0x00212E33, 0x007BAABE, 
        0x007CACC0, 0x007AABBF, 0x007AAABF, 0x007AAABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA8, 0x00305462, 0x00000000, 0x00427489, 0x004F8CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004B89A4, 0x004B89A3, 0x00356376, 0x00000000, 0x002B5160,
  0x0023414E, 0x00000000, 0x0039697D, 0x004B89A3, 0x004C89A3, 0x004D8AA4, 0x004D8BA4, 0x004D8BA5, 0x004F8CA5, 0x00467D94, 0x00000000, 0x001C323B, 0x00508BA3, 0x00528EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AB, 
        0x005993AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005E97AE, 0x005E97AF, 0x004A7789, 0x000A1114, 0x00000000, 0x00000000, 0x00273D46, 0x005C90A5, 0x00639BB1, 0x00649BB2, 0x006399B0, 0x004D7688, 0x000A0F11, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00050809, 0x00334C57, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x006E9EB2, 0x001B272C, 0x005D8697, 0x0075A7BC, 0x0075A7BC, 
        0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0079A9BE, 0x0079AABE, 0x002C3E45, 0x00000000, 0x00020404, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002B3B41, 0x0082B0C4, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 
        0x0086B3C5, 0x0086B3C6, 0x0086B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 
        0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC2D2, 0x009AC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C6D6, 0x00A2C7D7, 
        0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 
        0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 
        0x00C0DCE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1ED, 0x00C8E2ED, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE3EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5F0, 
        0x00CDE6F0, 0x00CDE6F0, 0x00CEE6F1, 0x00CEE7F1, 0x00CFE7F1, 0x00D0E7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D1E9F2, 0x00D1E9F2, 0x00D1E9F3, 0x00D2E9F2, 0x00D2E9F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D0E8F2, 
        0x00D0E8F2, 0x00D0E8F2, 0x00CFE8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE3EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2EC, 0x00C6E1EC, 0x00C5E0EC, 
        0x00C5E0EB, 0x00C4E0EB, 0x00C3DFEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BCD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B9D7E4, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B6D5E3, 0x00B6D4E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCDDB, 0x00AACDDB, 0x00A9CCDB, 
        0x00A8CCDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D9, 0x00A4C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC1D2, 
        0x0099C1D2, 0x0099C1D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0094BECF, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C6, 0x0081ACBF, 0x00020203, 0x000B0F10, 0x0027353A, 0x001A2327, 0x000A0E10, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00182125, 0x007BA9BD, 
        0x007CACC0, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A7BC, 0x003A535D, 0x00000000, 0x000C1214, 0x00496A77, 0x006796A9, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006BA1B7, 0x006BA0B6, 0x006B9FB6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AE, 0x005C95AD, 0x00518398, 0x00385B69, 0x000A1114, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA7, 0x00355C6C, 0x00000000, 0x00396577, 0x004F8CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004C89A3, 0x004B89A3, 0x0038697D, 0x00000000, 0x0023424E,
  0x001F3A45, 0x00000000, 0x003B6D83, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00417388, 0x00000000, 0x00203842, 0x00518CA5, 0x00528EA7, 0x00538FA8, 0x005490A9, 0x005490A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005892AB, 
        0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x00528396, 0x001C2C33, 0x00000000, 0x00000000, 0x0018252B, 0x00507D90, 0x005C8EA4, 0x00283E47, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001E2D33, 0x00568091, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A5BA, 0x0072A5BA, 0x0071A3B8, 0x00547989, 0x006B9AAD, 0x0075A7BC, 0x0075A8BC, 
        0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x00212F35, 0x00000000, 0x00405964, 0x004B6975, 0x00435C67, 0x00394F58, 0x002F4249, 0x00212E33, 0x000C1113, 0x00000000, 0x003A4E57, 0x0082B0C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 
        0x0086B3C5, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 
        0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC3D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C8D7, 
        0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2E0, 
        0x00B2D2E0, 0x00B2D3E0, 0x00B4D3E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E6, 0x00BCD9E6, 0x00BDDAE6, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00C0DCE8, 
        0x00C0DCE8, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C4DFEA, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3EE, 0x00CAE4EE, 0x00CBE4EE, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CDE6F0, 
        0x00CDE6F0, 0x00CEE6F1, 0x00CFE7F1, 0x00D0E7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E9F3, 0x00D2E9F3, 0x00D2E9F3, 0x00D2E9F3, 0x00D2E9F3, 0x00D2E9F3, 0x00D3E9F3, 0x00D3EAF3, 0x00D2EAF3, 0x00D2EAF3, 0x00D1E9F3, 0x00D2E9F3, 0x00D2E9F2, 
        0x00D1E9F2, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00C9E3EE, 0x00C8E2EE, 0x00C8E2ED, 0x00C7E2ED, 0x00C7E1EC, 0x00C6E1EC, 
        0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E3, 
        0x00B7D6E3, 0x00B6D6E3, 0x00B5D5E2, 0x00B5D5E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACCDB, 0x00A9CCDB, 
        0x00A8CCDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A0C5D6, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC2D3, 0x009CC2D2, 0x009AC2D2, 
        0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0088B5C8, 0x0088B4C7, 0x0087B4C7, 0x0083AFC2, 0x000A0E10, 0x00000000, 0x00000000, 0x00000000, 0x00060809, 0x00101618, 0x001B252A, 0x00222F34, 0x002A3A40, 0x0031444B, 0x00010202, 0x000D1215, 0x007AA9BD, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0075A8BC, 0x003A535D, 0x00000101, 0x00527786, 0x0073A5BB, 0x0072A5BA, 0x0071A5BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 
        0x006DA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005E97AF, 
        0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AC, 0x004E8095, 0x00000000, 0x00233A44, 0x005690A8, 0x005792AA, 0x005791AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x003A6476, 0x00000000, 0x00335B6B, 0x004F8DA5, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004B8AA4, 0x004B89A3, 0x003C6D82, 0x00000000, 0x001F3B46,
  0x001C343E, 0x00000000, 0x003D7288, 0x004B89A3, 0x004B8AA3, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x003E6D81, 0x00000000, 0x0025414D, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005692AA, 0x005792AA, 0x005792AA, 
        0x005893AB, 0x005994AC, 0x005A94AC, 0x005A94AC, 0x005C95AD, 0x005C96AD, 0x005D96AD, 0x005E96AE, 0x005F97AE, 0x005F97AF, 0x006098AF, 0x005D94AA, 0x00314E5A, 0x00000000, 0x00000000, 0x00070A0C, 0x000A1113, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00436472, 0x00699CB1, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A7BC, 
        0x0077A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078AABE, 0x007AAABF, 0x00161E22, 0x00000000, 0x00648A9B, 0x007CACC0, 0x007DADC1, 0x007DADC0, 0x007CA9BD, 0x007AA7BA, 0x00384D56, 0x00000000, 0x0048626D, 0x0082B0C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 
        0x0085B2C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0092BBCC, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 
        0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D6, 
        0x00A3C8D7, 0x00A4C9D7, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 
        0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B6D5E2, 0x00B7D6E2, 0x00B7D6E3, 0x00B8D6E3, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD8E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00C0DCE8, 
        0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C6E0EB, 0x00C6E1EC, 0x00C7E2EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CDE5F0, 0x00CEE6F0, 
        0x00CEE6F1, 0x00CFE7F1, 0x00CFE7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D2E9F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D2EAF3, 0x00D3EAF3, 0x00D3EAF3, 0x00D3EAF3, 0x00D3EAF3, 0x00D3EAF3, 0x00D3EAF4, 0x00D3EAF3, 0x00D3EAF3, 0x00D2EAF3, 0x00D2E9F3, 
        0x00D2E9F3, 0x00D1E9F2, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2EC, 0x00C6E1EC, 
        0x00C6E0EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E3, 
        0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD1DF, 0x00AED0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00A9CCDB, 
        0x00A9CCDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 
        0x009AC1D2, 0x0099C1D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0094BECE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCC, 0x0091BBCC, 0x0090BBCC, 0x008FBACC, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B4C7, 0x0087B4C7, 0x0083B0C2, 0x00171E22, 0x00030405, 0x00628593, 0x006E95A6, 0x00739CAE, 0x0077A1B2, 0x0078A4B6, 0x007AA6B9, 0x007BA8BB, 0x0079A5B8, 0x000A0F10, 0x00040607, 0x007BA9BD, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x00131B1E, 0x006FA1B5, 0x0073A5BB, 0x0072A5BA, 0x0072A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 
        0x006DA2B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x00223942, 0x0020363F, 0x005690A8, 0x005792AA, 0x005691AA, 0x005591A9, 0x005490A9, 0x005490A9, 0x00538FA8, 0x00538EA8, 0x00417184, 0x00000000, 0x00305564, 0x00508DA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x003E7288, 0x00000000, 0x001C333E,
  0x00162830, 0x00020304, 0x003E748A, 0x004B89A3, 0x004B8AA3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA6, 0x00366072, 0x00000000, 0x00274551, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x005490A9, 0x005490A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AA, 
        0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AD, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00385966, 0x00010303, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000101, 0x00162126, 0x005F8EA2, 0x006BA0B6, 0x006CA0B7, 0x006DA1B7, 0x006EA1B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0079AABE, 0x0079AABE, 0x000C1113, 0x00030505, 0x00668D9E, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 0x00354951, 0x00000000, 0x00516E7A, 0x0082B0C4, 0x0083B1C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 
        0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 
        0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B2D2E0, 
        0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DDE8, 
        0x00C1DDE9, 0x00C2DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00CAE3EE, 0x00CAE4EE, 0x00CBE4EE, 0x00CBE4EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CDE6F0, 0x00CEE6F1, 
        0x00CEE7F1, 0x00CFE7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D2E9F3, 0x00D3EAF3, 0x00D3EAF4, 0x00D4EAF4, 0x00D4EAF4, 0x00D4EAF4, 0x00D4EAF4, 0x00D4EAF4, 0x00D3EAF4, 0x00D3EAF3, 0x00D3EAF4, 0x00D3EAF3, 
        0x00D2E9F3, 0x00D2E9F2, 0x00D1E9F3, 0x00D1E9F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EE, 0x00CAE3EE, 0x00CAE3EE, 0x00C9E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C6E1EC, 
        0x00C6E1EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEA, 0x00C3DFEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE9, 0x00BFDCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B8D7E4, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AED0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 
        0x00A9CCDB, 0x00A8CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x009FC5D5, 0x009FC5D5, 0x009EC5D5, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 
        0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 
        0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0087B5C7, 0x0087B4C7, 0x0084B1C3, 0x001E282D, 0x00000000, 0x007FABBE, 0x0084B2C4, 0x0082B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x007FAEC2, 0x007BA9BC, 0x0011171A, 0x00000000, 0x0079A8BC, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0075A7BC, 0x003A535D, 0x00213036, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 0x006DA2B7, 
        0x006DA2B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB3, 0x00669DB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x00375B69, 0x001F343D, 0x005690A8, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x0044768B, 0x00000000, 0x00294855, 0x00508CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA3, 0x004B89A3, 0x003F748A, 0x00010303, 0x00162931,
  0x00101E24, 0x00030506, 0x0040758B, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x00305564, 0x00000000, 0x00284753, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AB, 
        0x005993AB, 0x005994AB, 0x005A94AC, 0x005A94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x00456E7F, 0x00172429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x000A1012, 0x0037535F, 0x00689EB4, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x00060809, 0x000A0E0F, 0x006992A3, 0x007CACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x007DABBF, 0x0031434B, 0x00000000, 0x005D7E8B, 0x0082B0C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0092BBCC, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 
        0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C7D7, 
        0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDE, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B2D2E0, 
        0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D8E4, 0x00B9D8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DDE9, 
        0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EC, 0x00C7E1EC, 0x00C7E2EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE4EE, 0x00CBE4EE, 0x00CCE5EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CEE6F0, 0x00CEE7F1, 
        0x00CFE7F1, 0x00D0E7F1, 0x00D0E8F1, 0x00D1E8F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D3EAF3, 0x00D3EAF4, 0x00D4EAF4, 0x00D4EAF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D3EAF4, 0x00D3EAF4, 
        0x00D3EAF3, 0x00D2E9F3, 0x00D2E9F3, 0x00D1E9F2, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F0, 0x00CDE5F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE4EE, 0x00C9E3EE, 0x00C9E2ED, 0x00C8E2ED, 0x00C7E1EC, 
        0x00C6E1EC, 0x00C6E0EB, 0x00C5E0EB, 0x00C4DFEA, 0x00C3DFEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B8D7E4, 
        0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDC, 0x00A9CCDB, 
        0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C7D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C9, 0x0089B5C8, 0x0088B5C8, 0x0088B5C7, 0x0087B4C7, 0x0084B0C3, 0x0028363C, 0x00000000, 0x007AA5B7, 0x0083B1C5, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007CA9BD, 0x001A2428, 0x00000000, 0x0075A1B3, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A7BC, 0x003A535D, 0x0027383F, 0x0074A6BB, 0x0072A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006199B1, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AE, 0x005C96AE, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x003B6071, 0x001F333B, 0x005690A8, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x0045778C, 0x00000000, 0x00223C47, 0x00508CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA3, 0x004B89A3, 0x003F758B, 0x00030506, 0x00101E24,
  0x000E1B21, 0x00060B0D, 0x0040778E, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x002F5261, 0x00000000, 0x002D4F5C, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AB, 
        0x005993AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005C95AD, 0x005C96AD, 0x005D96AD, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005B91A8, 0x00243941, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x001F2F36, 0x0058879A, 0x00699EB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x00000000, 0x000D1214, 0x006A94A5, 0x007DACC0, 0x007DADC1, 0x007EADC2, 0x007FAEC2, 0x007CA9BD, 0x002C3C43, 0x00000000, 0x00638795, 0x0082B1C4, 0x0084B1C5, 0x0084B2C5, 0x0084B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB5C8, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACC, 0x0090BACC, 0x0091BACC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 
        0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D5, 0x009FC5D5, 0x009FC5D5, 0x00A1C6D5, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C7D7, 
        0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AED0DD, 0x00AFD0DE, 0x00B0D0DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 
        0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDBE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C4DFEA, 0x00C4DFEA, 0x00C5E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E2ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CBE4EE, 0x00CBE4EF, 0x00CCE5EF, 0x00CDE6F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CFE7F1, 
        0x00CFE7F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D3EAF4, 0x00D4EAF4, 0x00D4EAF4, 0x00D5EBF4, 0x00D5EBF4, 0x00D5EBF5, 0x00D5EBF5, 0x00D5EBF5, 0x00D5ECF5, 0x00D6ECF5, 0x00D5EBF5, 0x00D5EBF4, 0x00D5EBF5, 0x00D4EBF4, 
        0x00D4EAF4, 0x00D3EAF4, 0x00D2E9F3, 0x00D2E9F3, 0x00D2E9F2, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE8F1, 0x00CFE7F1, 0x00CEE6F0, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CBE5EF, 0x00CBE4EF, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C7E1EC, 
        0x00C6E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B8D7E3, 
        0x00B8D7E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDB, 0x00A9CCDB, 
        0x00A9CCDB, 0x00A8CCDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC1D2, 0x0099C1D2, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BCCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 
        0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0085B1C4, 0x002E3D44, 0x00000000, 0x00749DAE, 0x0083B2C5, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x007FAFC2, 0x007CAABE, 0x001E292E, 0x00000000, 0x00709CAD, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x0026363D, 0x0073A6BB, 0x0073A6BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A3B9, 0x0070A3B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AF, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x003A5F6F, 0x001E323A, 0x00568FA8, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00528FA8, 0x0046798F, 0x00000000, 0x00213B45, 0x00508DA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x0041778E, 0x00060B0D, 0x000F1C21,
  0x000C181C, 0x00091114, 0x00417991, 0x004B89A3, 0x004C8AA3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA6, 0x002C4E5D, 0x00000000, 0x00305462, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005791AA, 0x005792AA, 0x005590A8, 
        0x005892AA, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005D96AE, 0x004E7D90, 0x000D1518, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00000000, 
        0x00030405, 0x004C7484, 0x00699EB5, 0x0069A0B5, 0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A6BB, 0x0073A6BB, 0x0075A7BB, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x007AABBF, 0x00000000, 0x0011181A, 0x006C97A8, 0x007CACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x007BA8BB, 0x002A3940, 0x00000000, 0x006C92A2, 0x0082B1C4, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x0090BACB, 0x0090BACC, 0x0091BBCC, 0x0091BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 
        0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC5D4, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00AECFDD, 0x00AED0DD, 0x00AED0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BDDAE7, 0x00BDDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E2EE, 0x00C9E3EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CCE4EF, 0x00CCE5EF, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE6F1, 0x00CFE7F1, 
        0x00D0E7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D3E9F3, 0x00D4EAF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D5EBF5, 0x00D5ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D5ECF5, 0x00D6ECF5, 0x00D5EBF5, 0x00D4EBF4, 
        0x00D4EBF4, 0x00D4EAF4, 0x00D3EAF3, 0x00D2E9F3, 0x00D2E9F3, 0x00D1E9F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C7E2EC, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C5DFEB, 0x00C4DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C2DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BDDBE7, 0x00BDDAE7, 0x00BCDAE6, 0x00BCD9E5, 0x00BBD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 
        0x00B8D7E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E0, 0x00B1D3E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AECFDE, 0x00AECFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 
        0x00A9CCDA, 0x00A8CCDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008EB9CB, 0x008EB9CA, 0x008EB8CA, 0x008CB8C9, 0x008CB7C9, 
        0x008BB7C9, 0x008BB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0085B2C4, 0x0035464E, 0x00000000, 0x007199A9, 0x0084B1C4, 0x0082B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x007CAABE, 0x00253339, 0x00000000, 0x006D97A7, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BD, 0x0076A7BC, 0x003A535D, 0x0027373E, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 
        0x006DA2B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x003A6171, 0x001F333C, 0x005690A8, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00477B91, 0x00010303, 0x001F3640, 0x00508DA6, 
        0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x00417990, 0x00081013, 0x000D181D,
  0x000A1316, 0x000B1418, 0x00457E96, 0x004B89A3, 0x004B8AA3, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA6, 0x002A4A57, 0x00000000, 0x00325767, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x00101C20, 
        0x0047768A, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x00568BA0, 0x00304D59, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x0022343C, 0x00496F80, 0x0010191D, 
        0x00000000, 0x00000000, 0x00344F5A, 0x006597AD, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0078A8BC, 0x00000000, 0x00141C20, 0x00709CAE, 0x007DADC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x007DACBE, 0x0028373D, 0x00000000, 0x00729BAC, 0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0091BCCD, 0x0093BCCD, 0x0093BDCD, 0x0094BDCE, 
        0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 
        0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD9E5, 0x00BCD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C6E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CBE4EE, 0x00CBE4EF, 0x00CCE4EF, 0x00CCE5F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CFE7F1, 0x00CFE7F1, 
        0x00D0E8F1, 0x00D1E8F2, 0x00D1E9F3, 0x00D2E9F3, 0x00D2EAF3, 0x00D3EAF3, 0x00D4EBF4, 0x00D4EBF4, 0x00D5EBF5, 0x00D5ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D7ECF6, 0x00D7ECF5, 0x00D7EDF6, 0x00D7ECF6, 0x00D6ECF6, 0x00D6ECF5, 0x00D6ECF5, 0x00D5ECF5, 
        0x00D4EBF4, 0x00D4EAF4, 0x00D3EAF4, 0x00D3EAF3, 0x00D2E9F3, 0x00D2E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE8F1, 0x00CFE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C7E2ED, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEB, 0x00C3DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D7E4, 
        0x00B8D7E4, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDE, 0x00ACCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDB, 0x00A9CCDB, 
        0x00A9CCDB, 0x00A8CCDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D6, 0x00A2C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC1D2, 0x009AC1D2, 0x0098C0D1, 0x0098C0D1, 0x0097C0D0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008CB8CA, 0x008CB7CA, 
        0x008BB7C9, 0x008AB6C9, 0x008AB5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0084B2C4, 0x003B4F57, 0x00000000, 0x007098A8, 0x0084B2C5, 0x0082B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x002C3D44, 0x00000000, 0x00678FA0, 
        0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0076A8BC, 0x003A535D, 0x001D2A2F, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0070A4B9, 0x0070A4B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 
        0x006DA2B7, 0x006CA0B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00629AB1, 0x006199B1, 0x006199B0, 0x006099B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x0030505D, 0x0020353D, 0x005690A8, 0x005792AA, 0x005791AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00487C92, 0x00030607, 0x001C323B, 0x00508DA6, 
        0x004F8CA6, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA3, 0x004B89A3, 0x00457E96, 0x000B1418, 0x000A1316,
  0x00070D10, 0x00060C0E, 0x00274755, 0x002B4F5E, 0x002B4F5D, 0x002C4F5E, 0x002C505E, 0x002C505E, 0x002F5362, 0x0015262D, 0x00000101, 0x00325968, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005791AA, 0x005792AA, 0x00040708, 
        0x003E6778, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005D96AE, 0x00446E7F, 0x00121D21, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060A0B, 0x00416675, 0x006499B0, 0x00669DB3, 0x005D8EA3, 
        0x0023353C, 0x00000000, 0x00000000, 0x001C2B30, 0x006090A4, 0x006BA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0074A2B6, 0x00000000, 0x000D1214, 0x0046616D, 0x004E6D79, 0x004F6E7B, 0x004D6A76, 0x004B6773, 0x0048626E, 0x00161E22, 0x00000000, 0x00759EB0, 0x0083B1C4, 0x0083B1C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008EB8CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 
        0x0094BDCE, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC4D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2E0, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B3D4E1, 0x00B5D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BFDBE7, 0x00C0DCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C4E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CFE7F1, 0x00D0E8F1, 
        0x00D0E8F2, 0x00D0E8F2, 0x00D2E9F2, 0x00D3E9F3, 0x00D3EAF3, 0x00D4EAF3, 0x00D5EBF4, 0x00D5EBF5, 0x00D5ECF5, 0x00D6ECF5, 0x00D7EDF6, 0x00D7EDF6, 0x00D7EDF6, 0x00D8EDF6, 0x00D8EDF6, 0x00D7EDF6, 0x00D7EDF6, 0x00D7EDF6, 0x00D6ECF5, 0x00D6ECF5, 
        0x00D5ECF5, 0x00D4EBF4, 0x00D4EAF4, 0x00D3EAF4, 0x00D3EAF3, 0x00D1E9F3, 0x00D1E9F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CEE6F1, 0x00CDE6F1, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE5EF, 0x00CAE4EF, 0x00CAE3EE, 0x00C9E3EE, 0x00C8E2ED, 0x00C8E1ED, 
        0x00C7E2EC, 0x00C6E1EC, 0x00C5E0EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE8, 0x00BFDCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCD9E5, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00B8D7E4, 
        0x00B8D7E3, 0x00B7D6E3, 0x00B6D5E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 
        0x00A9CCDB, 0x00A8CCDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A0C7D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC2D2, 0x0099C1D2, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008CB8CA, 0x008CB7CA, 
        0x008BB7C9, 0x008BB7C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0084B2C4, 0x003C5059, 0x00000000, 0x002E3E45, 0x003A4E57, 0x00394D56, 0x00394D56, 0x00394D56, 0x0034464E, 0x0032454C, 0x0031444C, 0x0011181B, 0x00000000, 0x00628898, 
        0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078AABE, 0x0078A9BD, 0x0077A9BD, 0x0076A8BD, 0x003A535D, 0x00101619, 0x006C9AAE, 0x0073A6BB, 0x0073A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006099B0, 0x005F98AF, 0x005F98AF, 
        0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x00142127, 0x00223841, 0x005690A8, 0x005892AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00487C92, 0x00050A0B, 0x000A1215, 0x00192D35, 
        0x00172A32, 0x0016272F, 0x0016272F, 0x00162930, 0x00162830, 0x00162830, 0x0015272F, 0x00030607, 0x00070E11,
  0x00040709, 0x00000000, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000101, 0x00000000, 0x00010303, 0x00325768, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x005590A9, 0x005590A9, 0x005691A9, 0x005791AA, 0x005792AA, 0x00000101, 
        0x002D4A57, 0x005994AC, 0x005A94AC, 0x005A94AC, 0x005C95AD, 0x00263E48, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001D2D34, 0x005F93A9, 0x00649BB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 
        0x00689EB4, 0x00324C57, 0x00000000, 0x00000000, 0x0006090A, 0x00568193, 0x006CA1B6, 0x006DA2B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A7BD, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x0072A0B3, 0x00000000, 0x00000000, 0x00010202, 0x00010202, 0x00010202, 0x00010202, 0x00010202, 0x00010202, 0x00000000, 0x00000000, 0x00759FB1, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 
        0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B3D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BCDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C2DEE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C4DFEA, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C9E2ED, 0x00C9E3EE, 0x00C9E4EE, 0x00CAE4EE, 0x00CCE4EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CEE6F0, 0x00CEE7F1, 0x00CFE7F1, 0x00D0E7F2, 
        0x00D0E8F2, 0x00D1E8F2, 0x00D2E9F3, 0x00D3EAF3, 0x00D3EAF4, 0x00D4EAF4, 0x00D5EBF4, 0x00D5ECF5, 0x00D6ECF5, 0x00D7EDF6, 0x00D7EDF6, 0x00D8EDF6, 0x00D8EEF6, 0x00D9EEF7, 0x00D8EEF7, 0x00D8EEF7, 0x00D8EDF6, 0x00D7EDF6, 0x00D7EDF6, 0x00D6ECF5, 
        0x00D6ECF5, 0x00D5EBF5, 0x00D4EBF4, 0x00D3EAF4, 0x00D3E9F3, 0x00D2E9F3, 0x00D1E9F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CEE7F0, 0x00CEE6F0, 0x00CDE5F0, 0x00CCE5F0, 0x00CBE5EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E2ED, 0x00C8E2ED, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BDDBE6, 0x00BDDAE6, 0x00BCD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 
        0x00B8D7E4, 0x00B8D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00AACDDB, 0x00AACCDB, 
        0x00A9CCDB, 0x00A9CCDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC4D5, 0x009EC4D4, 0x009DC3D4, 0x009DC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC1D2, 0x009AC1D2, 0x0099C0D1, 0x0098C0D1, 0x0098BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0085B2C4, 0x003C5059, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x005D808F, 
        0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x00000000, 0x00425F6B, 0x0073A5BB, 0x0072A5BB, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B8, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AF, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x003A5F6F, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AB, 0x005792AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538EA8, 0x00487C92, 0x00060B0D, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0004080A,
  0x00010202, 0x00010303, 0x000A1317, 0x00111F25, 0x00111F25, 0x00112025, 0x00112026, 0x00122026, 0x00122127, 0x00060B0D, 0x00010203, 0x00325868, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591AA, 0x005791AA, 0x005792AA, 0x00000101, 
        0x00070C0E, 0x00426C7F, 0x004E8095, 0x003E6676, 0x000B1215, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080D0F, 0x00355461, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 
        0x00669DB3, 0x00699EB5, 0x00476C7B, 0x00070A0C, 0x00000000, 0x00000000, 0x00405F6C, 0x006B9FB4, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0072A4BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 
        0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x00709EB0, 0x00000000, 0x00020404, 0x00101618, 0x0011181B, 0x0012191C, 0x0012191C, 0x0012191C, 0x0011171A, 0x00050607, 0x00000000, 0x00759FB1, 0x0083B1C4, 0x0084B2C4, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BCCD, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 
        0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009DC3D3, 0x009DC4D3, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CDDB, 0x00ABCDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D6E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDCE7, 0x00C0DCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C2DEE9, 0x00C2DEEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE4EF, 0x00CBE5EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CEE6F0, 0x00CEE7F1, 0x00CFE7F1, 0x00D0E8F2, 
        0x00D1E8F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D3EAF4, 0x00D3EAF3, 0x00D4EBF4, 0x00D5EBF5, 0x00D5ECF5, 0x00D6ECF5, 0x00D7EDF6, 0x00D8EDF6, 0x00D8EEF6, 0x00D9EEF7, 0x00D9EEF7, 0x00D9EEF7, 0x00D9EEF7, 0x00D8EDF7, 0x00D8EDF6, 0x00D7EDF6, 0x00D6ECF5, 
        0x00D6ECF5, 0x00D5ECF5, 0x00D4EBF4, 0x00D4EAF4, 0x00D3EAF3, 0x00D2EAF3, 0x00D1E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 
        0x00C7E1ED, 0x00C6E1EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C2DDE9, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDAE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 
        0x00B8D7E3, 0x00B7D7E3, 0x00B7D5E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 
        0x00A9CCDB, 0x00A9CCDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC2D3, 0x009BC2D2, 
        0x009AC2D2, 0x009AC1D2, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008DB9CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008BB7C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0085B2C4, 0x003C515A, 0x00000000, 0x00151D20, 0x001E292D, 0x001E282D, 0x001E282D, 0x001E282D, 0x001D282D, 0x001D282C, 0x001C262B, 0x00090D0F, 0x00000000, 0x005B7E8C, 
        0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BC, 0x003A535D, 0x00000000, 0x00000000, 0x0024353C, 0x0043616E, 0x00507584, 0x00567D8E, 0x00577F90, 0x00577F90, 0x00557E8F, 0x00557E8F, 
        0x00557E8E, 0x00547E8F, 0x00547C8E, 0x00537C8E, 0x00527C8E, 0x00517C8D, 0x00517B8D, 0x00507B8C, 0x00507A8C, 0x004F7A8B, 0x004F798B, 0x004E788A, 0x004E788A, 0x004D788A, 0x004D788A, 0x004C778A, 0x004B7789, 0x004A7789, 0x004A7688, 0x004A7588, 
        0x00497587, 0x00477386, 0x00446E80, 0x003B5F6F, 0x00243C45, 0x00000000, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AB, 0x005791AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00487C92, 0x00060B0D, 0x00030506, 0x00101C21, 
        0x000F1B20, 0x000E191D, 0x000E1A1F, 0x000E1A1E, 0x000E191E, 0x000D191E, 0x000C171C, 0x00020405, 0x00010203,
  0x00000101, 0x000C161B, 0x00437A91, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8CA5, 0x004F8CA6, 0x00203842, 0x00000101, 0x0034596A, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x00010202, 
        0x00000000, 0x00010102, 0x00070C0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001E3037, 0x004E7B8E, 0x00629AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 
        0x00679EB4, 0x00699EB5, 0x00699FB5, 0x00568192, 0x00152024, 0x00000000, 0x00000000, 0x00283B44, 0x00699BB0, 0x006EA2B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A4BA, 0x0072A5BA, 0x0072A3B9, 0x00628EA0, 0x006FA0B4, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x00709DB0, 0x00000000, 0x00151D21, 0x006B95A7, 0x0079A6B9, 0x0079A7BA, 0x007AA8BA, 0x007BA8BB, 0x0074A0B2, 0x00212D33, 0x00000000, 0x00759FB0, 0x0082B0C4, 0x0084B1C4, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 
        0x0095BECE, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCEDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B3D3E1, 0x00B3D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BDDAE6, 0x00BEDAE6, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DDE8, 0x00C1DDE9, 
        0x00C2DEE9, 0x00C2DEEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE4EE, 0x00CBE4EE, 0x00CBE5EF, 0x00CCE5EF, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE7F1, 0x00CFE7F1, 0x00D0E8F2, 
        0x00D1E8F2, 0x00D1E9F3, 0x00D3E9F3, 0x00D3EAF3, 0x00D4EAF4, 0x00D4EBF4, 0x00D5ECF5, 0x00D6ECF5, 0x00D7ECF5, 0x00D8EDF6, 0x00D8EEF6, 0x00D9EEF7, 0x00D9EEF7, 0x00DAEFF8, 0x00DAEFF7, 0x00D9EEF7, 0x00D9EEF7, 0x00D8EEF7, 0x00D7EDF6, 0x00D7ECF6, 
        0x00D6ECF5, 0x00D5ECF5, 0x00D4EBF4, 0x00D4EBF4, 0x00D3EAF4, 0x00D3EAF3, 0x00D1E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F1, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE4EE, 0x00CAE3EE, 0x00CAE3EE, 0x00C9E3ED, 0x00C8E2ED, 
        0x00C7E1EC, 0x00C7E1EC, 0x00C6E0EB, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDBE6, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD8E5, 0x00BAD8E5, 0x00B9D7E4, 
        0x00B8D7E4, 0x00B8D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDC, 0x00AACDDB, 
        0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC1D2, 0x009AC1D1, 0x0099C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0086B3C5, 0x003F545D, 0x00000000, 0x006B91A0, 0x0084B1C4, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x0033464D, 0x00000000, 0x005D808F, 
        0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00487D93, 0x00050A0B, 0x00111E24, 0x00508DA6, 
        0x004F8CA5, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x0048859E, 0x000E1A1F, 0x00000101,
  0x00000000, 0x00060C0F, 0x00213E4A, 0x00213C48, 0x00213D48, 0x00223D49, 0x00223E49, 0x00223D49, 0x0024414D, 0x000C161A, 0x00010202, 0x00325868, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AB, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00395B68, 0x005D93A9, 0x006299B1, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00659BB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 
        0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x00679AAF, 0x00273A42, 0x00000000, 0x00000000, 0x000E1417, 0x005D899C, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0072A4BA, 0x0072A5BA, 0x006E9FB4, 0x001E2B31, 0x005F8899, 0x0075A7BC, 0x0076A8BD, 
        0x0077A8BC, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x00719FB2, 0x00000000, 0x000B0F11, 0x00384E58, 0x003F5761, 0x003F5862, 0x00405963, 0x003D535D, 0x00364A52, 0x00101518, 0x00000000, 0x0076A0B2, 0x0082B1C4, 0x0084B1C4, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008BB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x0090BACB, 0x0090BBCC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 
        0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC4D4, 0x009DC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCFDD, 0x00AECFDD, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B4D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E5, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 
        0x00C2DEE9, 0x00C3DEEA, 0x00C3DEEA, 0x00C4DFEB, 0x00C4E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E2EC, 0x00C7E2ED, 0x00C9E2ED, 0x00C9E3EE, 0x00CAE4EE, 0x00CAE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CEE6F0, 0x00CFE7F1, 0x00CFE7F1, 0x00D0E8F2, 
        0x00D1E8F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D3EAF4, 0x00D4EAF4, 0x00D4EBF4, 0x00D5EBF5, 0x00D6ECF5, 0x00D7EDF5, 0x00D8EDF6, 0x00D8EEF7, 0x00D9EEF7, 0x00DAEFF7, 0x00DAEFF8, 0x00DAEFF8, 0x00DAEFF8, 0x00D9EEF7, 0x00D8EEF7, 0x00D8EDF6, 0x00D7EDF6, 
        0x00D6ECF6, 0x00D6ECF5, 0x00D4EBF4, 0x00D4EAF4, 0x00D3EAF3, 0x00D3EAF3, 0x00D2E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E7F1, 0x00CFE7F1, 0x00CEE7F1, 0x00CDE6F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C8E2ED, 
        0x00C7E1EC, 0x00C7E1EC, 0x00C5E0EC, 0x00C5E0EB, 0x00C4E0EB, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D7E4, 
        0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00AACDDC, 0x00AACDDB, 
        0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009BC2D2, 0x009BC2D2, 
        0x009AC2D2, 0x009AC1D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0096BED0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0085B2C4, 0x003C515A, 0x00000000, 0x001B2529, 0x00243136, 0x00243137, 0x00233035, 0x00233035, 0x00222E34, 0x001B2529, 0x00192327, 0x00090C0E, 0x00000000, 0x005C808F, 
        0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AABBF, 0x0079A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005691A8, 0x005792AA, 0x005792AA, 0x005691A9, 0x005591A9, 0x005490A9, 0x00538FA8, 0x00538FA7, 0x00487C92, 0x00060B0D, 0x00010203, 0x000A1215, 
        0x000B1317, 0x000C161A, 0x000D171C, 0x000D171C, 0x000E191E, 0x000F1C21, 0x000E191E, 0x00020405, 0x00000000,
  0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010303, 0x00335768, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005791AA, 0x005792AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E1619, 0x004F7F92, 0x006198B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00679DB4, 
        0x00679EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x00395560, 0x00020405, 0x00000000, 0x00040607, 0x004F7383, 0x006FA2B7, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x006C9BB0, 0x000B1013, 0x005E8697, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0074A2B6, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00749EB0, 0x0082B1C4, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8C9, 0x008EB8CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCD, 0x0092BBCC, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 
        0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C0D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCEDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 
        0x00B3D3E0, 0x00B4D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E5, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C2DEE9, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CBE4EE, 0x00CCE5EF, 0x00CCE5F0, 0x00CDE5F0, 0x00CEE6F1, 0x00CEE7F1, 0x00CFE7F1, 0x00D0E8F2, 
        0x00D1E8F2, 0x00D1E9F3, 0x00D3EAF3, 0x00D3EAF4, 0x00D4EAF4, 0x00D4EBF4, 0x00D5ECF5, 0x00D6ECF5, 0x00D7ECF6, 0x00D8EDF6, 0x00D9EDF7, 0x00D9EEF7, 0x00DAEFF8, 0x00DAEFF8, 0x00DBEFF8, 0x00DAEFF8, 0x00D9EEF7, 0x00D9EEF7, 0x00D8EEF6, 0x00D7ECF6, 
        0x00D6ECF5, 0x00D5ECF5, 0x00D4EBF4, 0x00D4EBF4, 0x00D3EAF4, 0x00D3EAF3, 0x00D2E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE8F1, 0x00CFE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C8E2ED, 
        0x00C7E1EC, 0x00C7E1EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C5DFEB, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B8D7E4, 
        0x00B8D7E4, 0x00B8D7E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00AACDDB, 0x00AACDDB, 
        0x00AACCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC2D3, 0x009BC2D2, 
        0x009AC2D2, 0x009AC1D2, 0x0099C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0091BCCC, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008CB8CA, 0x008BB7C9, 
        0x008BB7C9, 0x008BB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C6, 0x0085B2C5, 0x003B4F57, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00618695, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AA, 0x005792AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00487C92, 0x00060B0D, 0x00000000, 0x00000101, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000,
  0x00000101, 0x00050A0C, 0x001A313A, 0x001B323C, 0x001C323C, 0x001C333D, 0x001C333D, 0x001D343D, 0x001E3640, 0x000B1418, 0x00010202, 0x00325868, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005791AA, 0x005792AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030506, 0x002D4854, 0x005D95AC, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00659BB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 
        0x00679EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x00496B7A, 0x000B1113, 0x00000000, 0x00000000, 0x00364F59, 0x006999AC, 0x0071A4BA, 0x0072A5BA, 0x00496976, 0x00000000, 0x005E8798, 0x0075A7BC, 0x0076A8BD, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABF, 0x0078A7BC, 0x00000000, 0x00080B0C, 0x002C3E45, 0x0032454D, 0x0032464E, 0x0033464E, 0x0031434B, 0x002D3E45, 0x000F1517, 0x00000000, 0x007098A9, 0x0082B1C4, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB5C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 
        0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B3D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C2DEE9, 0x00C3DEEA, 0x00C3DEEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE4EE, 0x00CAE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CDE6F0, 0x00CEE6F1, 0x00CFE7F1, 0x00CFE7F1, 0x00D0E8F2, 
        0x00D1E8F2, 0x00D1E9F3, 0x00D2EAF3, 0x00D3EAF3, 0x00D4EAF4, 0x00D4EBF4, 0x00D5EBF5, 0x00D6ECF5, 0x00D7ECF6, 0x00D7EDF6, 0x00D8EEF6, 0x00D9EEF7, 0x00D9EFF7, 0x00DAEFF8, 0x00DAEFF8, 0x00DAEEF7, 0x00D9EEF7, 0x00D9EEF7, 0x00D8EDF6, 0x00D7ECF6, 
        0x00D6ECF5, 0x00D5ECF5, 0x00D5EBF4, 0x00D4EBF4, 0x00D3EAF4, 0x00D2EAF3, 0x00D2E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3ED, 0x00C8E2ED, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C6E0EB, 0x00C5E0EB, 0x00C4E0EB, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDAE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E4, 0x00B9D7E4, 
        0x00B8D6E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 
        0x00A9CCDB, 0x00A8CCDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC2D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0092BCCE, 0x0092BCCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0085B2C4, 0x00394C54, 0x00000000, 0x003E545D, 0x0049646F, 0x0048626D, 0x0048626D, 0x0047626C, 0x0046606B, 0x00415963, 0x003F5761, 0x00151E21, 0x00000000, 0x00678E9E, 
        0x007CACC0, 0x007BACBF, 0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00487D93, 0x00060A0C, 0x00091114, 0x002D4F5D, 
        0x00294956, 0x00264450, 0x00254350, 0x0025424F, 0x0024424E, 0x00203C47, 0x001F3944, 0x00060B0D, 0x00000101,
  0x00020405, 0x000D191D, 0x0046829A, 0x004B89A3, 0x004C8AA3, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x00223C46, 0x00000000, 0x0033596A, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005792AA, 0x005792AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090F12, 0x004A788B, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006198B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00669CB3, 0x00669CB3, 0x00679DB4, 
        0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x00608DA0, 0x001B282D, 0x00000000, 0x00000000, 0x0011191D, 0x002F454E, 0x00293C44, 0x00050708, 0x00050809, 0x005E8798, 0x0075A7BC, 0x0075A8BD, 
        0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABF, 0x007AAABF, 0x00000000, 0x00121A1D, 0x00729FB1, 0x007DADC1, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x002C3C43, 0x00000000, 0x00688D9D, 0x0082B1C4, 0x0083B1C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB8C9, 0x008DB8CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCE, 0x0093BDCE, 0x0094BDCE, 
        0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00ABCDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B3D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E2, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 
        0x00C2DEE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE7F0, 0x00CFE7F1, 0x00D0E8F2, 
        0x00D1E8F2, 0x00D1E9F2, 0x00D3EAF3, 0x00D3EAF3, 0x00D3EAF4, 0x00D4EBF4, 0x00D5EBF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D7EDF6, 0x00D8EDF6, 0x00D8EEF6, 0x00D9EEF7, 0x00D9EEF7, 0x00D9EEF7, 0x00D9EEF7, 0x00D8EEF6, 0x00D8EDF6, 0x00D7EDF6, 0x00D6ECF5, 
        0x00D6ECF5, 0x00D5ECF5, 0x00D4EAF4, 0x00D4EAF4, 0x00D3EAF3, 0x00D2EAF3, 0x00D1E8F2, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F1, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00C9E3ED, 0x00C9E2ED, 0x00C8E2ED, 
        0x00C7E2EC, 0x00C6E1EC, 0x00C6E0EB, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BBD9E6, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E4, 0x00B9D7E4, 
        0x00B8D7E4, 0x00B7D7E3, 0x00B6D6E3, 0x00B6D5E3, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 
        0x00A9CCDB, 0x00A9CCDB, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009DC4D4, 0x009DC4D4, 0x009DC3D3, 0x009BC3D3, 0x009BC2D2, 
        0x009AC2D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C9, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0085B1C4, 0x0032434A, 0x00000000, 0x0078A1B3, 0x0084B2C5, 0x0082B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x0029383F, 0x00000000, 0x006C95A7, 
        0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AAABF, 0x0079AABF, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0076A8BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AA, 0x005792AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00487D93, 0x0005090B, 0x0015262D, 0x00508DA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA3, 0x004B8AA3, 0x0047859E, 0x000C181C, 0x00020405,
  0x00040809, 0x00020405, 0x00112127, 0x0023404C, 0x0023404C, 0x0023404C, 0x0023404D, 0x0024404D, 0x00264451, 0x00101D22, 0x00010202, 0x00325868, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005791AA, 0x005792AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0019282F, 0x005B95AC, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006099B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639BB1, 0x00649BB1, 0x00649BB2, 0x00669CB3, 0x00669DB3, 0x00679DB3, 
        0x00689EB4, 0x00689EB5, 0x00699EB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006A9CB1, 0x0025363D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8798, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x007AABBF, 0x00000000, 0x00030405, 0x00172124, 0x001B262B, 0x001B262B, 0x001C262B, 0x001C262B, 0x001B2529, 0x00090D0E, 0x00000000, 0x00618392, 0x0083B1C4, 0x0084B1C4, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008BB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB9CB, 0x008EB9CB, 0x008FB9CB, 0x0090BACB, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 
        0x0095BECE, 0x0096BECF, 0x0096BED0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC2D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC4D3, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A3C7D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CDDB, 0x00ABCEDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B3D3E1, 0x00B4D3E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C2DEE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C4DFEA, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E2ED, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE4EE, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CEE6F0, 0x00CEE7F1, 0x00CFE7F1, 0x00D0E8F2, 
        0x00D0E8F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D3E9F3, 0x00D3EAF4, 0x00D4EBF4, 0x00D5EBF5, 0x00D5ECF5, 0x00D6ECF5, 0x00D7EDF6, 0x00D7EDF6, 0x00D8EDF6, 0x00D8EEF7, 0x00D8EEF7, 0x00D9EEF7, 0x00D8EEF7, 0x00D8EDF6, 0x00D7EDF6, 0x00D7EDF6, 0x00D6ECF5, 
        0x00D6ECF5, 0x00D5EBF5, 0x00D4EBF4, 0x00D3EAF4, 0x00D3EAF4, 0x00D2E9F3, 0x00D1E9F2, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CBE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E2ED, 0x00C8E2ED, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E6, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 
        0x00B8D7E3, 0x00B7D6E3, 0x00B6D5E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00AACDDC, 0x00AACDDB, 
        0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC2D2, 0x009AC0D2, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0096BED0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0091BCCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008BB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C6, 0x0085B1C4, 0x002C3A41, 0x00000000, 0x00010101, 0x00030405, 0x00030404, 0x00030405, 0x00030404, 0x00030405, 0x00030405, 0x00020303, 0x00000000, 0x00000000, 0x006F9AAC, 
        0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x003A535D, 0x00000000, 0x00040708, 0x00405B68, 0x00618C9E, 0x006D9EB3, 0x0071A4B9, 0x0070A3B9, 0x0070A3B9, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00669CB4, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AD, 0x00588EA5, 0x004B7A8E, 0x002F4D59, 0x00040608, 0x00000000, 0x00233B45, 0x005691A8, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00487C92, 0x00060B0D, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0004080A,
  0x00070D10, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010303, 0x00315666, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005792AA, 0x005792AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00253C46, 0x005A93AA, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669DB3, 0x00669DB4, 
        0x00689EB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0030464F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8798, 0x0075A7BC, 0x0076A7BC, 
        0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x007AAABF, 0x00020303, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00587885, 0x0082B1C4, 0x0084B1C4, 0x0084B2C5, 0x0084B2C5, 
        0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCE, 0x0093BCCE, 0x0094BDCE, 
        0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097C0D0, 0x0098BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CCDA, 0x00A9CCDA, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDBE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C1DEE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C9E3ED, 0x00CAE3EE, 0x00CBE4EE, 0x00CBE5EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CDE6F0, 0x00CEE7F1, 0x00CFE7F1, 0x00CFE7F2, 
        0x00D0E8F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D3EAF3, 0x00D4EAF4, 0x00D5EBF4, 0x00D5EBF4, 0x00D6ECF5, 0x00D6ECF5, 0x00D7EDF6, 0x00D7EDF6, 0x00D8EDF6, 0x00D8EDF6, 0x00D8EDF6, 0x00D8EDF6, 0x00D7EDF6, 0x00D7EDF6, 0x00D6ECF5, 0x00D6ECF5, 
        0x00D5ECF5, 0x00D4EBF4, 0x00D4EAF4, 0x00D3EAF3, 0x00D3EAF3, 0x00D2E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E7F2, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CCE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E2ED, 0x00C8E2ED, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEA, 0x00C3DFEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 
        0x00B8D7E4, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDC, 0x00AACCDB, 
        0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC2D3, 0x009BC2D2, 
        0x009AC1D2, 0x0099C1D2, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0085B0C3, 0x00243035, 0x00000000, 0x00010101, 0x00020303, 0x00020303, 0x00020203, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0074A0B2, 
        0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x00000000, 0x004E6F7E, 0x0073A5BB, 0x0072A5BA, 0x0072A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00679EB4, 0x00679DB3, 0x00669DB4, 0x00669CB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AF, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B94AC, 0x00487689, 0x00000000, 0x00233B45, 0x005691A8, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00477C92, 0x0005090B, 0x00000000, 0x00000101, 
        0x00010202, 0x00000101, 0x00000101, 0x00010303, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070E11,
  0x000A1316, 0x00050A0C, 0x00264755, 0x002A4E5D, 0x002B4E5C, 0x002B4E5D, 0x002B4F5D, 0x002C4F5D, 0x002E5261, 0x00192C34, 0x00000000, 0x00305464, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x00010202, 
        0x00000000, 0x00000000, 0x0028424D, 0x005992AA, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00649BB1, 0x00649BB2, 0x00659BB2, 0x00669CB3, 0x00669CB3, 0x00679DB3, 
        0x00689EB4, 0x00689EB5, 0x00699EB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x0070A3B9, 0x0070A4B9, 0x00405D69, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8798, 0x0075A7BC, 0x0075A8BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x007AABBF, 0x000B0F11, 0x00010203, 0x003F5862, 0x004D6B77, 0x004E6D79, 0x004C6974, 0x004A6672, 0x004B6772, 0x00212D33, 0x00000000, 0x004F6B77, 0x0082B1C4, 0x0083B2C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x0090BACC, 0x0090BBCC, 0x0090BBCC, 0x0091BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 
        0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00AECFDE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDAE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C1DEE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C6E0EC, 0x00C7E1EC, 0x00C7E2EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE4EF, 0x00CBE4EF, 0x00CBE5EF, 0x00CCE5F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CFE7F1, 0x00CFE7F1, 
        0x00D0E8F2, 0x00D1E8F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D3EAF3, 0x00D3EAF4, 0x00D4EAF4, 0x00D4EBF5, 0x00D5EBF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF6, 0x00D7ECF5, 0x00D7EDF6, 0x00D7EDF6, 0x00D7EDF6, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF4, 
        0x00D5EBF5, 0x00D4EBF4, 0x00D3EAF4, 0x00D3EAF3, 0x00D2E9F3, 0x00D2E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E7F1, 0x00CFE7F1, 0x00CEE6F1, 0x00CEE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E2ED, 0x00C8E2ED, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEB, 0x00C3DEEA, 0x00C2DEEA, 0x00C1DEE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BBD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B8D7E4, 
        0x00B8D7E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACCDB, 
        0x00A9CCDB, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008BB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0085B1C3, 0x001C262A, 0x00020203, 0x005F808E, 0x00648695, 0x00638695, 0x00628593, 0x00618492, 0x005E808F, 0x005D7E8D, 0x005A7C8A, 0x000C1113, 0x00000000, 0x0079A7BB, 
        0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x003A535D, 0x0011181C, 0x006E9EB2, 0x0073A6BB, 0x0072A5BA, 0x0072A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA3B8, 0x006EA2B8, 
        0x006DA2B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x001D3037, 0x00213740, 0x005690A8, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00477B91, 0x00020505, 0x00172830, 0x003C6C7F, 
        0x003B697C, 0x003A687B, 0x003A677A, 0x003A697C, 0x00376476, 0x00335E6F, 0x002C5363, 0x00070D0F, 0x000A1317,
  0x000C171C, 0x00091114, 0x00417990, 0x004A88A2, 0x004A89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x004F8CA5, 0x002E5160, 0x00000000, 0x002E505E, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005692AA, 0x005792AA, 0x00010202, 
        0x00000000, 0x001A2B32, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AE, 0x005D96AE, 0x005E97AF, 0x005E97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00679DB4, 
        0x00689DB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x006FA2B6, 0x00324952, 0x00000000, 0x00000000, 0x0006090A, 0x005E8798, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABF, 0x007AAABF, 0x00121A1D, 0x00000000, 0x00648A9B, 0x007DACC0, 0x007DADC1, 0x007EAEC2, 0x007EADC1, 0x0080AEC2, 0x00405761, 0x00000000, 0x00425963, 0x0082B1C4, 0x0083B1C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0087B3C6, 0x0087B4C6, 0x0088B4C7, 0x0089B5C8, 0x0089B6C8, 0x008BB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x0090BACC, 0x0090BACC, 0x0091BACC, 0x0091BBCC, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 
        0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D7, 0x00A2C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00ABCDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D3E0, 
        0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDBE6, 0x00BEDBE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C2DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C5E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3ED, 0x00CAE4EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CDE6F0, 0x00CDE6F1, 0x00CEE6F0, 0x00CFE7F1, 
        0x00D0E7F2, 0x00D0E8F2, 0x00D1E9F3, 0x00D2E9F3, 0x00D2E9F3, 0x00D3EAF3, 0x00D4EBF4, 0x00D4EAF4, 0x00D4EBF4, 0x00D5EBF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D6ECF5, 0x00D5EBF5, 0x00D5EBF4, 
        0x00D4EBF4, 0x00D4EAF4, 0x00D3EAF3, 0x00D3E9F3, 0x00D2E9F3, 0x00D1E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE8F1, 0x00CEE7F1, 0x00CDE6F1, 0x00CDE6F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C7E1EC, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEB, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BDDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D7E4, 
        0x00B8D7E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 
        0x00A9CCDB, 0x00A8CCDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC4D4, 0x009EC4D4, 0x009DC3D4, 0x009DC3D3, 0x009BC2D2, 0x009BC2D2, 
        0x009AC1D2, 0x009AC1D2, 0x0099C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008EB9CB, 0x008EB9CB, 0x008DB9CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008BB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0083B0C2, 0x0012191B, 0x000A0E10, 0x0080ADC0, 0x0083B1C5, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007BA9BC, 0x000C1113, 0x00020303, 0x007BAABD, 
        0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x00202E34, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00649CB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x00365867, 0x001F343D, 0x005690A8, 0x005792AA, 0x005792AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00467A90, 0x00000000, 0x00213A45, 0x00508CA6, 
        0x004F8CA6, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x00417990, 0x00081013, 0x000D181D,
  0x000E1B21, 0x00060B0D, 0x0040778E, 0x004B89A3, 0x004B8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA6, 0x002F5462, 0x00000000, 0x00294856, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005791AA, 0x005792AA, 0x00010102, 
        0x00020404, 0x004E8196, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 
        0x00689EB4, 0x00689EB4, 0x00699EB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x006B9BB0, 0x00141D21, 0x00000000, 0x0006090A, 0x005E8798, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x00202C32, 0x00000000, 0x005F8494, 0x007DADC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x0046606B, 0x00000000, 0x00374B53, 0x0082B0C4, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BDCD, 0x0093BDCE, 
        0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 
        0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BDDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BFDCE7, 0x00C0DCE8, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E2ED, 0x00C9E3EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CBE5EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CFE7F1, 
        0x00CFE7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D2E9F2, 0x00D2E9F3, 0x00D3E9F3, 0x00D3EAF4, 0x00D4EAF4, 0x00D4EBF4, 0x00D4EBF5, 0x00D5EBF5, 0x00D5EBF5, 0x00D5ECF5, 0x00D6ECF5, 0x00D5ECF5, 0x00D5ECF5, 0x00D5EBF5, 0x00D5EBF4, 0x00D5EBF5, 0x00D4EBF4, 
        0x00D3EAF4, 0x00D3EAF4, 0x00D3E9F3, 0x00D2E9F3, 0x00D2E9F3, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F1, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CCE4EF, 0x00CBE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C7E1EC, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B8D7E4, 
        0x00B8D7E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDD, 0x00ABCEDC, 0x00AACDDB, 0x00AACCDB, 
        0x00A9CCDA, 0x00A8CCDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC5D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 
        0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097C0D0, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0091BCCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0082AEC1, 0x00090D0E, 0x0013191C, 0x0081AEC1, 0x0083B2C5, 0x0082B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007BA8BB, 0x00030405, 0x000C1113, 0x007BAABE, 
        0x007CACC0, 0x007BACBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BE, 0x0077A8BD, 0x0076A7BC, 0x003A535D, 0x0027383F, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00679EB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AF, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x003B6171, 0x001F333B, 0x005690A8, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x0045788D, 0x00000000, 0x00223C46, 0x00508CA6, 
        0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004B8AA3, 0x004B89A3, 0x0041778E, 0x00060B0D, 0x000F1C21,
  0x00101E24, 0x00030607, 0x003E748A, 0x004B89A3, 0x004C8AA3, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x00345D6E, 0x00000000, 0x00274551, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x00000000, 
        0x001F343D, 0x005790A8, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 
        0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x00577E8E, 0x00000000, 0x0006090A, 0x005E8698, 0x0075A7BC, 0x0076A8BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078AABE, 0x007AAABF, 0x002B3C43, 0x00000000, 0x00587B89, 0x007DACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AEC2, 0x004E6B78, 0x00010202, 0x002A393F, 0x0082B0C4, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 
        0x0094BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A3C8D7, 
        0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDE, 0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2DF, 
        0x00B2D3E0, 0x00B3D3E0, 0x00B3D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDCE7, 0x00C0DCE8, 0x00C0DDE8, 
        0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C3DFEA, 0x00C4DFEA, 0x00C4E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3ED, 0x00CAE3EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CFE7F1, 
        0x00CFE7F1, 0x00D0E8F1, 0x00D0E8F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D2EAF3, 0x00D3EAF3, 0x00D3EAF4, 0x00D4EAF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EAF4, 0x00D3EAF4, 
        0x00D3EAF4, 0x00D3EAF3, 0x00D2E9F3, 0x00D1E9F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CBE5EF, 0x00CAE4EE, 0x00C9E4EE, 0x00C9E3EE, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E1EC, 
        0x00C6E1EC, 0x00C6E0EB, 0x00C5E0EB, 0x00C4E0EA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BDDBE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E5, 0x00BAD9E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B8D7E4, 
        0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 
        0x00A9CCDA, 0x00A8CCDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D4, 0x009FC5D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C9, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x007FAABC, 0x00000000, 0x001F292E, 0x0081AFC1, 0x0084B1C4, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x0077A3B5, 0x00000000, 0x00151D21, 0x007BA9BD, 
        0x007CACC0, 0x007BACBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x0025363D, 0x0074A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00679EB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x00395F6F, 0x001E323A, 0x005690A8, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528FA7, 0x0044768B, 0x00000000, 0x00274551, 0x00508DA6, 
        0x004F8CA6, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x003F758B, 0x00030506, 0x00101F25,
  0x00152930, 0x00020304, 0x003E7389, 0x004B89A3, 0x004C89A3, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x003C6B7E, 0x00000000, 0x0026424E, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005792AA, 0x00020304, 
        0x00335563, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 
        0x00689DB4, 0x00689EB5, 0x00699EB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0072A5BA, 0x0024333A, 0x00030505, 0x005E8797, 0x0075A7BC, 0x0076A7BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x00364B54, 0x00000000, 0x004F6D7A, 0x007CACC0, 0x007DADC0, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 0x00587785, 0x00040606, 0x001C252A, 0x0082B0C4, 0x0084B1C4, 0x0084B1C5, 0x0084B2C5, 
        0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 
        0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 
        0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDE, 0x00AED0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B2D2E0, 
        0x00B2D3E0, 0x00B3D3E0, 0x00B4D3E1, 0x00B4D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DDE8, 
        0x00C1DDE9, 0x00C2DDE9, 0x00C2DEE9, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CBE4EE, 0x00CBE4EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CDE6F0, 0x00CEE6F0, 
        0x00CFE7F1, 0x00CFE7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D1E9F3, 0x00D2E9F3, 0x00D2EAF3, 0x00D3EAF3, 0x00D3EAF4, 0x00D3EAF4, 0x00D4EAF4, 0x00D4EAF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EBF4, 0x00D4EAF3, 0x00D3EAF4, 0x00D3EAF3, 
        0x00D2E9F3, 0x00D2E9F3, 0x00D1E9F2, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F1, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C8E3ED, 0x00C8E2ED, 0x00C7E2ED, 0x00C6E1EC, 
        0x00C6E1EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEB, 0x00C3DFEA, 0x00C2DEEA, 0x00C2DDE9, 0x00C1DDE9, 0x00C1DDE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B8D7E3, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD1DF, 0x00AFD0DE, 0x00AED0DD, 0x00AECFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDB, 0x00AACDDC, 0x00A9CCDB, 
        0x00A9CCDA, 0x00A8CCDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 
        0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB7C9, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0079A0B1, 0x00000000, 0x002B3A40, 0x0082AFC2, 0x0084B1C4, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0080AFC3, 0x007FAFC2, 0x006F98A9, 0x00000000, 0x001E2A2F, 0x007CABBE, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x0027373E, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006EA2B8, 0x006DA2B8, 
        0x006DA2B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AF, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x003B6271, 0x001F333C, 0x005690A8, 0x005792AA, 0x005791AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00528FA7, 0x00427387, 0x00000000, 0x002E5260, 0x00508CA6, 
        0x004F8CA6, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x003E748A, 0x00010303, 0x00162931,
  0x001C343E, 0x00000000, 0x003D7288, 0x004B89A3, 0x004B89A4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00417288, 0x00000000, 0x00213B46, 0x00518DA6, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x0005090A, 
        0x0040697C, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 
        0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x005C8596, 0x00000000, 0x005E8797, 0x0075A7BC, 0x0075A7BC, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0079AABE, 0x0079AABF, 0x0045616C, 0x00000000, 0x00405964, 0x007CACC0, 0x007DADC0, 0x007EAEC1, 0x007EAEC2, 0x0080AEC2, 0x00638897, 0x00070A0B, 0x000F1416, 0x0083B0C4, 0x0083B1C4, 0x0084B2C4, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB7C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0091BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 
        0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A1C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 
        0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 
        0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDBE8, 0x00BFDCE8, 0x00C0DCE8, 
        0x00C0DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C6E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CEE6F0, 
        0x00CEE6F1, 0x00CFE7F1, 0x00CFE7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D3EAF3, 0x00D3EAF3, 0x00D3EAF4, 0x00D3EAF3, 0x00D3EAF4, 0x00D3EAF4, 0x00D3EAF4, 0x00D3EAF4, 0x00D3EAF3, 0x00D3EAF3, 0x00D2E9F3, 
        0x00D2E9F3, 0x00D1E9F3, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F0, 0x00CEE6F0, 0x00CDE6F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EE, 0x00CAE3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E1ED, 0x00C6E1EC, 
        0x00C6E1EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEA, 0x00C3DFEA, 0x00C2DEE9, 0x00C1DEE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE8, 0x00BEDBE7, 0x00BDDAE7, 0x00BCDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E3, 
        0x00B7D6E3, 0x00B6D6E3, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AED0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 
        0x00A9CCDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC5D5, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 
        0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BBCC, 0x008FBACC, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C6, 0x00688B9A, 0x00000000, 0x00384C54, 0x0082AFC2, 0x0083B1C4, 0x0082B0C4, 0x0082B0C4, 0x0081AFC3, 0x0081AFC3, 0x007FAEC2, 0x005F8392, 0x00000000, 0x002E3F47, 0x007CABBE, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A7BC, 0x003A535D, 0x001F2D32, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A4BA, 0x0071A4BA, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 
        0x005E97AF, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x00325361, 0x0020353D, 0x005690A8, 0x005792AA, 0x005692AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538EA8, 0x003C687A, 0x00000000, 0x00335A6A, 0x00508CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA3, 0x004B89A3, 0x003D7288, 0x00000000, 0x001C333E,
  0x001F3A45, 0x00000000, 0x003B6E83, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x0044798F, 0x00000000, 0x001D333C, 0x00508BA3, 0x00528FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x00040809, 
        0x00467487, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005F97AF, 0x005F97AF, 0x006098B0, 0x006098B0, 0x006299B0, 0x006299B1, 0x00639AB1, 0x00649AB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 
        0x00679EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA0B6, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x006E9EB2, 0x000C1113, 0x005D8697, 0x0075A7BC, 0x0075A8BC, 
        0x0077A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABF, 0x00547684, 0x00000000, 0x00344850, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007FAEC1, 0x0079A6B9, 0x00608392, 0x00080B0D, 0x000A0D0F, 0x007BA6B9, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 
        0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BACC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 
        0x0094BDCE, 0x0095BECE, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 
        0x00A3C8D7, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A9CBDA, 0x00A9CCDB, 0x00A9CCDB, 0x00ABCDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2E0, 
        0x00B2D2E0, 0x00B2D3E0, 0x00B4D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B9D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00C0DCE8, 
        0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EC, 0x00C7E1EC, 0x00C7E1ED, 0x00C8E2ED, 0x00C9E2ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CBE4EE, 0x00CBE4EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CDE6F0, 
        0x00CDE6F0, 0x00CEE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D2EAF3, 0x00D2EAF3, 0x00D2EAF3, 0x00D3EAF3, 0x00D3EAF3, 0x00D2EAF3, 0x00D2E9F3, 0x00D3EAF3, 0x00D1E9F3, 0x00D2E9F3, 
        0x00D1E9F3, 0x00D1E8F2, 0x00D1E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CBE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C8E2ED, 0x00C7E2ED, 0x00C7E1EC, 0x00C6E1EC, 
        0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D6E3, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D4E2, 0x00B5D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 
        0x00A8CBDB, 0x00A8CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 
        0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0090BBCC, 0x0090BACB, 0x008FBACC, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 
        0x008BB7C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C6, 0x0054717D, 0x00000000, 0x001A2428, 0x003E535C, 0x0048626D, 0x00516D7A, 0x005A7A88, 0x00638796, 0x006A90A1, 0x00729CAE, 0x004B6773, 0x00000000, 0x00394F58, 0x007CACBF, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x003A535D, 0x0011191C, 0x006E9EB2, 0x0073A5BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005E97AF, 
        0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x0018282E, 0x00213741, 0x005690A8, 0x005792AA, 0x005691AA, 0x005690A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528FA8, 0x00355C6D, 0x00000000, 0x00376172, 0x00508DA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x003C6D82, 0x00000000, 0x001F3B46,
  0x0023424E, 0x00000000, 0x0039697D, 0x004B89A3, 0x004B89A3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004D89A2, 0x00000000, 0x001B3038, 0x004F8AA2, 0x00538EA7, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x00070C0E, 
        0x00477689, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 
        0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA0B6, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x006D9EB2, 0x001A252A, 0x005D8697, 0x0075A7BC, 0x0075A7BC, 
        0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0079A9BE, 0x0079AABE, 0x00648D9E, 0x00000000, 0x00182125, 0x00445F6A, 0x00354952, 0x0027363C, 0x001C272B, 0x0011181B, 0x000C1113, 0x00010101, 0x00080B0C, 0x006D94A5, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 
        0x0085B3C6, 0x0086B3C6, 0x0087B3C6, 0x0088B4C7, 0x0088B4C7, 0x0089B5C8, 0x0089B6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACB, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 
        0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C1D1, 0x0099C1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC2D3, 0x009DC3D3, 0x009DC3D3, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 
        0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDE, 0x00AFD1DE, 0x00AFD1DF, 0x00B0D1DF, 0x00B1D2E0, 
        0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BEDBE6, 0x00BEDBE7, 0x00BEDBE7, 0x00C0DCE8, 
        0x00C0DDE8, 0x00C1DDE9, 0x00C2DDE9, 0x00C3DEEA, 0x00C3DEEA, 0x00C4DFEA, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EB, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CDE6F0, 
        0x00CDE6F0, 0x00CEE6F0, 0x00CEE6F1, 0x00CFE7F1, 0x00CFE7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D1E9F2, 0x00D2E9F3, 0x00D2E9F3, 0x00D2E9F3, 0x00D1E9F3, 0x00D2E9F2, 0x00D1E9F2, 0x00D1E8F2, 0x00D0E8F2, 
        0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE5EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3ED, 0x00C9E2ED, 0x00C8E2ED, 0x00C7E1ED, 0x00C7E1EC, 0x00C6E0EC, 
        0x00C5E0EB, 0x00C4E0EB, 0x00C3DFEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C2DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BCDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B6D6E3, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACCDB, 0x00A9CCDB, 
        0x00A8CCDA, 0x00A8CBDA, 0x00A7CADA, 0x00A6CAD9, 0x00A6C9D9, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D3, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 
        0x009AC1D2, 0x0099C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACB, 0x008EB9CB, 0x008DB8CB, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008BB6C9, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C6, 0x003C5059, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010101, 0x00050607, 0x00080B0D, 0x000B0F10, 0x000D1315, 0x00090C0E, 0x00000000, 0x0047626D, 0x007BABBF, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0078A9BE, 0x0078A9BE, 0x0077A9BE, 0x0077A8BD, 0x0075A7BC, 0x003A535D, 0x00000000, 0x00496976, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 
        0x006DA1B7, 0x006BA0B7, 0x006BA0B6, 0x006BA0B6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x006399B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F97AF, 0x005E97AF, 
        0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005A94AC, 0x00416B7C, 0x00000000, 0x00233A45, 0x005690A8, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA8, 0x00325666, 0x00000000, 0x00407185, 0x00508CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004B8AA3, 0x004B89A3, 0x0038697C, 0x00000000, 0x0023424E,
  0x002A5060, 0x00000000, 0x00356376, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00508CA6, 0x00000000, 0x0015262C, 0x004D869D, 0x00528EA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x00060A0C, 
        0x00436E80, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00649AB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 
        0x00689DB4, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA0B6, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x006D9DB1, 0x00141D21, 0x005D8696, 0x0075A7BC, 0x0075A7BC, 
        0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0079AABE, 0x0079AABE, 0x006E9AAD, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00020303, 0x00030405, 0x00010101, 0x00050607, 0x005D7E8C, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 
        0x0085B2C6, 0x0086B3C6, 0x0086B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008BB7C8, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 
        0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009CC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 
        0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DF, 0x00B0D1DF, 0x00B1D1DF, 
        0x00B1D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E2, 0x00B5D4E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 
        0x00C0DCE8, 0x00C0DDE8, 0x00C2DDE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E2ED, 0x00C9E3ED, 0x00CAE3EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE5EF, 0x00CCE5EF, 
        0x00CDE6F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE7F1, 0x00CFE6F1, 0x00CFE7F1, 0x00CFE7F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D1E9F2, 0x00D1E9F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D1E8F2, 0x00D0E8F2, 
        0x00D0E8F2, 0x00D0E8F1, 0x00CFE7F1, 0x00CFE6F1, 0x00CEE7F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C7E2ED, 0x00C7E1EC, 0x00C6E1EC, 0x00C5E0EB, 
        0x00C5E0EB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E6, 0x00BAD8E4, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D6E3, 
        0x00B7D6E3, 0x00B6D6E2, 0x00B5D5E2, 0x00B4D4E2, 0x00B4D4E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x009FC5D5, 0x009FC4D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC1D2, 
        0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C6, 0x0027353B, 0x00000000, 0x00374B53, 0x003E535C, 0x002D3D43, 0x001A2327, 0x000D1214, 0x00060809, 0x00040606, 0x00030405, 0x00000000, 0x00000000, 0x00537380, 0x007CACC0, 
        0x007CACC0, 0x007BABBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x003A535D, 0x00000000, 0x00000000, 0x002E434B, 0x00507584, 0x005F8A9B, 0x006594A7, 0x006796AA, 0x006696AA, 0x006595A9, 0x006495A8, 
        0x006494A8, 0x006394A8, 0x006293A7, 0x006293A7, 0x006092A6, 0x006091A6, 0x006091A5, 0x005F90A5, 0x005E90A4, 0x005E8FA4, 0x005D8FA4, 0x005C8EA4, 0x005C8EA4, 0x005B8DA3, 0x005A8EA2, 0x00598DA2, 0x00598DA2, 0x00578CA2, 0x00578CA1, 0x00568BA1, 
        0x00568BA0, 0x0054889D, 0x00508196, 0x00467284, 0x002C4955, 0x00000101, 0x00000000, 0x00233B45, 0x005690A8, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00284652, 0x00000000, 0x00457A8F, 0x00508DA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA3, 0x004B89A3, 0x00356376, 0x00000000, 0x002B5161,
  0x002F596B, 0x00000000, 0x002E5565, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00020405, 0x00111E23, 0x004C839B, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x00020304, 
        0x00325360, 0x005993AB, 0x005A93AB, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 
        0x00679DB4, 0x00689EB4, 0x00689EB4, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A3B9, 0x0071A4B9, 0x0072A5BA, 0x005C8596, 0x00010102, 0x005E8697, 0x0075A7BC, 0x0075A7BC, 
        0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079A9BE, 0x0079AABE, 0x0072A0B3, 0x00080C0D, 0x00000000, 0x002A3A41, 0x00344850, 0x00405862, 0x004C6974, 0x00557482, 0x00648998, 0x001D272C, 0x00020203, 0x00506C78, 0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 
        0x0085B3C5, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 
        0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D1, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D1DF, 
        0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B4D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 
        0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C2DDE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 
        0x00CCE5EF, 0x00CDE5F0, 0x00CDE6F0, 0x00CEE6F1, 0x00CEE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00D0E8F1, 0x00D0E8F1, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D1E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00D0E8F2, 0x00CFE8F2, 
        0x00CFE7F1, 0x00CFE7F1, 0x00CEE7F1, 0x00CEE6F1, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2EC, 0x00C7E1EC, 0x00C6E0EC, 0x00C5E0EB, 
        0x00C4E0EB, 0x00C4DFEA, 0x00C3DFEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCDDB, 0x00A9CDDB, 0x00A8CCDA, 
        0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A6C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC4D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC2D3, 0x009AC2D2, 0x009AC1D2, 
        0x0099C1D2, 0x0099C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCE, 0x0092BBCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008AB6C9, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C6, 0x000F1416, 0x00080B0C, 0x006C91A0, 0x0084B1C4, 0x0083B1C4, 0x0082B0C4, 0x0082B0C3, 0x007EACBF, 0x006C94A4, 0x00628796, 0x000A0F10, 0x00000000, 0x005E8292, 0x007CACC0, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0075A7BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005590A8, 0x005792AA, 0x005691AA, 0x005591A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x00213A44, 0x00000000, 0x00467C93, 0x00508DA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004B89A3, 0x004B89A3, 0x002D5464, 0x00000000, 0x00305A6C,
  0x00356579, 0x00000000, 0x00284958, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x000B1518, 0x000B1418, 0x00498197, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x00000101, 
        0x000B1216, 0x0050849A, 0x005A93AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00659BB2, 0x00669CB3, 0x00669DB3, 
        0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4BA, 0x0072A5BA, 0x00151F23, 0x00040607, 0x005E8697, 0x0075A7BC, 0x0075A7BC, 
        0x0076A8BD, 0x0077A8BD, 0x0077A9BE, 0x0078A9BE, 0x0079AABE, 0x0073A2B6, 0x00182226, 0x00000000, 0x00729EB0, 0x007DADC0, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AFC2, 0x00384C55, 0x00000000, 0x003F555F, 0x0083B1C4, 0x0083B1C4, 0x0084B2C5, 
        0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 
        0x0094BDCE, 0x0095BDCE, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D7, 
        0x00A2C7D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DF, 0x00B1D1DF, 
        0x00B1D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDBE7, 0x00BFDCE7, 
        0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C5E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E2ED, 0x00CAE3EE, 0x00CAE4EE, 0x00CAE4EE, 0x00CBE4EF, 
        0x00CBE5EF, 0x00CCE5EF, 0x00CDE5F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 
        0x00CEE6F1, 0x00CEE6F0, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CCE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E1ED, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E0EB, 0x00C5DFEB, 
        0x00C4DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C2DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 
        0x00B6D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCFDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACCDB, 0x00A8CCDA, 
        0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A5CAD8, 0x00A5C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D4, 0x009EC5D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC3D3, 0x009AC1D2, 0x009AC1D2, 
        0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x0090BACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008AB6C8, 0x0089B6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0085B2C5, 0x00000000, 0x0012181B, 0x007198A9, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x00020404, 0x00080C0D, 0x00658C9C, 0x007CACC0, 
        0x007CACC0, 0x007BABBF, 0x007AAABE, 0x0079AABF, 0x0079AABE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005590A8, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A8, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x00192B33, 0x00030607, 0x00487F95, 0x004F8CA6, 
        0x004F8CA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00274957, 0x00000000, 0x00366579,
  0x003D748A, 0x00000000, 0x00213E4A, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004F8CA5, 0x004F8CA6, 0x00132229, 0x00060B0D, 0x00477D94, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x00010202, 
        0x00000000, 0x00020405, 0x00223942, 0x00365968, 0x0040697A, 0x00446F80, 0x00447081, 0x00457082, 0x00467182, 0x00467183, 0x00477183, 0x00487183, 0x00487283, 0x00497283, 0x004A7384, 0x004A7485, 0x004A7485, 0x004B7486, 0x004B7486, 0x004C7486, 
        0x004D7586, 0x004D7686, 0x004D7687, 0x004E7687, 0x004F7788, 0x00507788, 0x00507788, 0x00507889, 0x00517889, 0x00527989, 0x00537A89, 0x00507686, 0x00496B79, 0x0038525D, 0x000C1214, 0x00000000, 0x0006090A, 0x005E8697, 0x0074A6BC, 0x0075A7BC, 
        0x0076A8BD, 0x0076A8BD, 0x0077A9BD, 0x0078AABD, 0x0079AABF, 0x0076A4B8, 0x0026353B, 0x00000000, 0x005C808F, 0x007CADC0, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AFC2, 0x00506E7B, 0x00000000, 0x00304249, 0x0082B0C3, 0x0083B1C4, 0x0084B2C5, 
        0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB8CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 
        0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 
        0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B1D1DF, 
        0x00B1D2DF, 0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D5E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE8, 
        0x00BFDCE7, 0x00C0DCE8, 0x00C0DCE8, 0x00C1DDE9, 0x00C1DEE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C7E2EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE3EE, 0x00CBE4EF, 
        0x00CBE4EF, 0x00CCE4EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE7F1, 0x00CEE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CFE7F1, 0x00CEE7F1, 0x00CFE6F1, 0x00CEE6F1, 
        0x00CEE6F0, 0x00CEE6F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CDE5F0, 0x00CCE5EF, 0x00CBE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C6E1EC, 0x00C6E1EC, 0x00C5E0EC, 0x00C5E0EB, 0x00C4DFEB, 
        0x00C3DFEA, 0x00C3DFEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 
        0x00B6D5E2, 0x00B6D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D0DE, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CDDB, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A5CAD8, 0x00A5C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D4, 0x009EC5D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009CC2D3, 0x009AC2D2, 0x009AC1D1, 
        0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008BB7C9, 0x008BB6C9, 
        0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x006F94A4, 0x00000000, 0x001B2429, 0x007AA5B7, 0x0083B1C4, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x007FAFC2, 0x00739DAF, 0x00000000, 0x0012191C, 0x006C95A7, 0x007CACC0, 
        0x007CACC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078AABE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005590A8, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x00101C22, 0x00080F12, 0x00498198, 0x004F8CA6, 
        0x004F8CA5, 0x004D8BA5, 0x004D8AA4, 0x004D8AA4, 0x004B89A4, 0x004B89A3, 0x00213E4A, 0x00000000, 0x003E748B,
  0x00417991, 0x00000000, 0x00182C35, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x001F3641, 0x00000101, 0x00477B90, 0x00528EA7, 0x00528FA7, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005791AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8697, 0x0074A7BC, 0x0075A7BC, 
        0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0078A8BC, 0x00364C55, 0x00000000, 0x00435D68, 0x007CACC0, 0x007EADC1, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 0x006A90A0, 0x00000000, 0x00222E33, 0x007BA7B9, 0x0083B1C4, 0x0084B2C5, 
        0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 
        0x0094BDCE, 0x0094BECE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC4D4, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00AED0DD, 0x00AED0DE, 0x00AFD1DE, 0x00B0D1DF, 
        0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDBE7, 
        0x00BFDBE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4E0EB, 0x00C5E0EB, 0x00C6E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE3EE, 
        0x00CAE4EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CDE5F0, 0x00CDE5F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F1, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 0x00CEE6F0, 
        0x00CDE6F0, 0x00CDE6F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE4EF, 0x00CBE4EF, 0x00CBE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C8E2EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEA, 
        0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 0x00B6D6E3, 
        0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDA, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C8D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 
        0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 
        0x008AB6C8, 0x008AB5C8, 0x0089B5C7, 0x0088B4C7, 0x0087B4C6, 0x0055717D, 0x00000000, 0x00263339, 0x0084B2C5, 0x0083B1C5, 0x0083B1C4, 0x0082B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x005D7F8E, 0x00000000, 0x001C262B, 0x0075A2B3, 0x007CACC0, 
        0x007BACC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005590A8, 0x005792AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00528FA8, 0x00528EA7, 0x00080D10, 0x00101D22, 0x004C869E, 0x004F8CA6, 
        0x004F8CA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B8AA3, 0x004A89A3, 0x00182C35, 0x00000000, 0x00407A91,
  0x00427B94, 0x00020405, 0x00122128, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x0049839B, 0x0044798F, 0x003D6D81, 0x001A2E36, 0x00000000, 0x0043768A, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x005691AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8697, 0x0074A7BC, 0x0075A7BC, 
        0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x0046626E, 0x00000000, 0x00293A40, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x0080AEC2, 0x007FAEC2, 0x00000000, 0x00131A1D, 0x00739DAE, 0x0083B1C4, 0x0084B2C5, 
        0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 0x0091BACC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 
        0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x00A0C6D6, 0x00A0C6D6, 0x00A1C7D6, 
        0x00A2C7D7, 0x00A2C8D7, 0x00A3C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D0DF, 
        0x00B1D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 
        0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EB, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 
        0x00CAE3EE, 0x00CAE3EE, 0x00CAE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CCE5F0, 0x00CDE5F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CDE6F0, 0x00CDE5F0, 0x00CDE5F0, 0x00CDE5F0, 0x00CDE5F0, 0x00CDE5F0, 0x00CCE5F0, 
        0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EE, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEB, 0x00C3DFEA, 
        0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE8, 0x00C0DDE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E3, 
        0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D4E0, 0x00B3D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDA, 0x00A8CBDA, 
        0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009BC3D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 
        0x0099C0D1, 0x0098C0D1, 0x0097C0D0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BECE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BACC, 0x008FBACC, 0x008FBACC, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008AB6C9, 
        0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x003B4F57, 0x00000000, 0x00374951, 0x0084B2C5, 0x0083B1C4, 0x0082B1C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x00455F6A, 0x00000000, 0x00253339, 0x007BABBF, 0x007CACC0, 
        0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00233B45, 0x005590A8, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00000000, 0x000B1418, 0x00305463, 0x00376274, 
        0x003B6B7E, 0x0043778E, 0x0049859D, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x00122128, 0x00020506, 0x00427B94,
  0x00427C95, 0x00070E11, 0x0005090B, 0x00264654, 0x00162931, 0x000E1A1F, 0x00091013, 0x0005090A, 0x00030607, 0x00020405, 0x00010202, 0x00000000, 0x003A6678, 0x00528EA7, 0x00528FA8, 0x00548FA8, 0x005490A8, 0x005590A8, 0x005691AA, 0x005691AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005E8697, 0x0074A7BC, 0x0075A7BC, 
        0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0079AABE, 0x0079AABF, 0x00537482, 0x00010202, 0x000F1518, 0x007CACC0, 0x007DADC1, 0x007EADC1, 0x007EAEC2, 0x0080AFC2, 0x0080AFC2, 0x00131A1D, 0x00020203, 0x006D93A4, 0x0083B1C4, 0x0084B1C5, 
        0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 0x0091BACC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 
        0x0093BDCE, 0x0094BDCE, 0x0095BDCE, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC2D3, 0x009DC3D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A2C6D6, 
        0x00A2C7D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BCDAE6, 0x00BEDBE7, 
        0x00BEDBE7, 0x00BFDBE7, 0x00BFDBE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C4E0EB, 0x00C6E0EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E2EC, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3EE, 
        0x00C9E3EE, 0x00C9E3EE, 0x00CAE4EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5F0, 0x00CDE5F0, 0x00CDE5F0, 0x00CCE5F0, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 
        0x00CCE4EF, 0x00CBE4EF, 0x00CBE5EF, 0x00CBE4EF, 0x00CBE4EE, 0x00CAE4EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C5E0EC, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEA, 0x00C3DEEA, 
        0x00C2DEEA, 0x00C2DEEA, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BCD9E6, 0x00BAD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 
        0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00AACDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 
        0x00A7CBDA, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC2D3, 0x009BC2D2, 0x009AC2D2, 0x0099C0D1, 
        0x0099C0D1, 0x0097C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB7C8, 
        0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x00222D32, 0x00010202, 0x004E6974, 0x0084B1C5, 0x0083B1C4, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0080AFC2, 0x0080AFC2, 0x002D3E45, 0x00000000, 0x00344951, 0x007CACC0, 0x007CACC0, 
        0x007BACC0, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0077A9BE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0039535D, 0x00000000, 0x00000000, 0x00364E58, 0x00577E8E, 0x00618FA1, 0x006796AA, 0x006798AB, 0x006798AB, 0x006597AA, 0x006596AA, 
        0x006496AA, 0x006395A9, 0x006395A9, 0x006294A8, 0x006293A8, 0x006193A8, 0x006193A8, 0x006092A8, 0x005F91A7, 0x005F91A7, 0x005E91A6, 0x005D90A6, 0x005C8FA6, 0x005B8FA5, 0x005A8EA4, 0x005A8EA4, 0x00598DA4, 0x00598DA4, 0x00588CA3, 0x00578CA2, 
        0x00578CA2, 0x0054899F, 0x004F8095, 0x00426D7E, 0x0027404A, 0x00000000, 0x00000000, 0x00233B45, 0x005590A8, 0x005791AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x004B839A, 0x00000000, 0x00000000, 0x00010203, 0x00020304, 
        0x00020405, 0x00030507, 0x00040709, 0x00080E11, 0x000D181D, 0x00172A33, 0x00030607, 0x00080E11, 0x00427C95,
  0x00447F98, 0x000F1D22, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010203, 0x00030607, 0x0005090B, 0x00070D0F, 0x00070D10, 0x00000000, 0x00325868, 0x00528EA7, 0x00528EA7, 0x00548FA8, 0x00548FA8, 0x005590A9, 0x005691A9, 0x005691AA, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005D8697, 0x0074A6BB, 0x0075A7BC, 
        0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x00608696, 0x000A0E0F, 0x00020303, 0x0078A6B9, 0x007DADC1, 0x007EADC1, 0x007EAEC2, 0x007FAEC2, 0x0080AFC2, 0x0033454D, 0x00000000, 0x005C7E8B, 0x0083B1C4, 0x0083B1C5, 
        0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B4C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C9, 0x008BB6C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 
        0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BED0, 0x0097BFD0, 0x0098BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A1C6D6, 
        0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AED0DE, 0x00AED0DE, 0x00AFD1DF, 
        0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E4, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 
        0x00BDDBE7, 0x00BEDBE7, 0x00BFDBE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C3DEEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C8E2ED, 
        0x00C9E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CAE4EE, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE5EF, 0x00CBE4EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE5EF, 0x00CCE4EF, 0x00CBE4EF, 
        0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE4EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C5E0EC, 0x00C5DFEB, 0x00C4E0EA, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DEEA, 
        0x00C2DEE9, 0x00C1DEE9, 0x00C0DDE8, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 
        0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD1DF, 0x00AFD0DE, 0x00AED0DD, 0x00AECFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 
        0x00A7CBDA, 0x00A6CAD9, 0x00A5CAD8, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 
        0x0099C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0094BDCE, 0x0094BDCF, 0x0093BDCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 
        0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x007FAABB, 0x00161D20, 0x00010202, 0x00688B9A, 0x0084B2C5, 0x0083B1C4, 0x0083B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x007FAEC2, 0x00192226, 0x00010202, 0x00496570, 0x007CACC0, 0x007CACC0, 
        0x007BACBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0039525D, 0x00000000, 0x00476674, 0x0072A5BA, 0x0071A5BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA2B8, 0x006DA2B8, 0x006DA1B7, 
        0x006CA1B7, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098AF, 0x006098AF, 0x005E97AF, 0x005E96AE, 
        0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x003F697B, 0x00000000, 0x00233A45, 0x005590A8, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x0043758A, 0x00000000, 0x00091013, 0x000E191D, 0x00091013, 
        0x00070C0E, 0x0005090A, 0x00030507, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x000F1D22, 0x00447F98,
  0x0045819A, 0x0015272F, 0x00000000, 0x001F3A45, 0x0024434F, 0x002A4D5B, 0x00305868, 0x00366375, 0x003D6E82, 0x0044798F, 0x00407186, 0x00000000, 0x00274450, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x005490A9, 0x005490A9, 0x005691A9, 0x005691A9, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040608, 0x0005090A, 0x0005090A, 0x0005090A, 0x0005090A, 0x0005090A, 0x0005090A, 0x0006090A, 0x0006090B, 0x0006090B, 0x0006090B, 0x0006090B, 0x0006090B, 0x0006090B, 0x0006090B, 0x0006090B, 
        0x0006090B, 0x0006090B, 0x0006090B, 0x0006090B, 0x0006090B, 0x0006090B, 0x00060A0B, 0x00060A0B, 0x00060A0B, 0x00060A0B, 0x00060A0B, 0x00050708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x005D8697, 0x0074A6BB, 0x0074A7BC, 
        0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078AABE, 0x0079AABE, 0x006D98AA, 0x0011181A, 0x00010202, 0x00608695, 0x007DADC1, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AFC2, 0x00526F7C, 0x00000000, 0x00405760, 0x0083B1C4, 0x0083B1C4, 
        0x0084B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0093BCCD, 
        0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 
        0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AFD0DE, 0x00AFD0DE, 
        0x00B0D1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BCDAE6, 
        0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE8, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C7E2EC, 
        0x00C8E2ED, 0x00C8E2ED, 0x00C8E2EE, 0x00C9E3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CBE3EE, 0x00CAE4EF, 0x00CAE4EE, 0x00CAE4EE, 0x00CAE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CBE4EF, 0x00CAE4EE, 0x00CAE4EE, 0x00CBE4EF, 
        0x00CBE4EE, 0x00CAE3EE, 0x00CAE4EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C9E2ED, 0x00C8E2ED, 0x00C7E2ED, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E0EB, 0x00C5DFEB, 0x00C4DFEA, 0x00C4DFEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C2DEE9, 
        0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 
        0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 
        0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D1, 0x0099C0D1, 
        0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB6C9, 0x008AB6C9, 
        0x008AB6C8, 0x0089B5C8, 0x0088B4C7, 0x0087B4C7, 0x006E93A2, 0x000D1113, 0x00040506, 0x0080ADC0, 0x0083B2C4, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x00739FB0, 0x00101619, 0x00020404, 0x005F8392, 0x007CACC0, 0x007BACC0, 
        0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0039535D, 0x000E1518, 0x006A99AC, 0x0072A5BA, 0x0071A4BA, 0x0071A3B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 
        0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00669CB3, 0x00659BB3, 0x00659BB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 
        0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005993AC, 0x0017262C, 0x00213741, 0x005590A8, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00528FA8, 0x00365E6F, 0x00000000, 0x002D4F5D, 0x00508CA6, 0x004A849B, 
        0x0042768D, 0x003C6C80, 0x00366273, 0x00315A6B, 0x00294C5A, 0x00213D49, 0x00000000, 0x0015282F, 0x0045819A,
  0x0046849D, 0x001C353F, 0x00000000, 0x003B6D83, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8CA5, 0x004F8CA5, 0x00477E95, 0x00020304, 0x001A2E36, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005591AA, 0x005691AA, 0x00010202, 
        0x00000000, 0x001B2E36, 0x00467588, 0x004F8297, 0x00508398, 0x0051849A, 0x0051849A, 0x0052859A, 0x0052859A, 0x0053869A, 0x0054869B, 0x0055879B, 0x0056879C, 0x0056889C, 0x0057899D, 0x0058899D, 0x0058899D, 0x0059899E, 0x00598A9E, 0x00598A9F, 
        0x005B8B9F, 0x005B8BA0, 0x005C8CA0, 0x005C8CA1, 0x005E8DA1, 0x005E8DA1, 0x005F8EA2, 0x00608FA2, 0x00608FA2, 0x00618FA2, 0x006190A3, 0x006290A3, 0x00618EA1, 0x00598091, 0x00273941, 0x00000000, 0x0006090A, 0x005D8697, 0x0074A6BB, 0x0074A7BB, 
        0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x001A2428, 0x00000000, 0x00486470, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x0080AFC2, 0x006E96A8, 0x00000000, 0x00212D32, 0x0082B1C4, 0x0083B1C4, 
        0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BACC, 0x0091BBCC, 0x0091BBCD, 
        0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C1D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 
        0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AFD0DE, 
        0x00AFD0DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 
        0x00BDDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEEA, 0x00C2DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4E0EB, 0x00C4E0EB, 0x00C5E0EB, 0x00C5E0EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1ED, 
        0x00C7E1ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CAE3EE, 0x00CAE4EE, 0x00CAE4EE, 0x00CAE4EE, 0x00CAE3EE, 0x00CAE3EE, 0x00C9E3EE, 
        0x00C9E3EE, 0x00C9E3EE, 0x00C9E2EE, 0x00C9E3ED, 0x00C9E2ED, 0x00C8E2ED, 0x00C7E2ED, 0x00C7E2ED, 0x00C7E2EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C4E0EA, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B5D5E1, 
        0x00B4D4E2, 0x00B4D4E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AECFDE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A7CBD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC3D4, 0x009DC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D1, 0x0099C0D1, 
        0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 
        0x008AB6C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x005C7B87, 0x00020203, 0x001B2428, 0x0084B2C5, 0x0083B1C5, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x00638998, 0x00090C0E, 0x00030506, 0x0075A2B4, 0x007CACC0, 0x007BABC0, 
        0x007BABC0, 0x007AABBF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0039525D, 0x001E2C31, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 
        0x006CA0B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00689EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006098B0, 0x006098AF, 0x006097AF, 0x005E97AE, 0x005E96AE, 
        0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x00335563, 0x001F343D, 0x00558FA8, 0x005691AA, 0x005691A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00284653, 0x00000000, 0x00335968, 0x004F8DA6, 0x004F8CA5, 
        0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x003C6E83, 0x00000000, 0x001C3540, 0x0046849D,
  0x004786A0, 0x0023414E, 0x00000000, 0x00325C6F, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004F8CA6, 0x00488198, 0x000B1316, 0x000F1B20, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005591A9, 0x005691AA, 0x00000000, 
        0x00152329, 0x00548DA4, 0x005993AB, 0x005994AC, 0x005B94AC, 0x005B95AC, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E98AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 
        0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x006A9FB5, 0x006A9FB5, 0x006B9FB6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x002A3D45, 0x00030405, 0x005D8597, 0x0074A6BB, 0x0074A7BB, 
        0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A8BD, 0x0079A9BE, 0x0079AABE, 0x0079AABE, 0x002D3F47, 0x00000000, 0x002F4249, 0x007DACC1, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AFC2, 0x0077A3B5, 0x000D1214, 0x00020203, 0x0082B1C4, 0x0083B1C4, 
        0x0084B2C5, 0x0084B2C5, 0x0085B3C6, 0x0087B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0091BBCC, 0x0091BBCC, 0x0092BCCD, 
        0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009EC5D4, 0x009FC5D5, 0x009FC6D5, 0x00A0C6D5, 
        0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CADA, 0x00A8CBDA, 0x00A9CCDB, 0x00AACCDB, 0x00ABCDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AFCFDE, 
        0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D5E2, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BCD9E6, 
        0x00BCDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C2DDE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C4DFEA, 0x00C4DFEA, 0x00C4E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E1EC, 0x00C7E1EC, 
        0x00C6E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E2ED, 0x00C9E3ED, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00CAE3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3ED, 
        0x00C9E3ED, 0x00C9E3ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2EC, 0x00C7E1ED, 0x00C7E1EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C5DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C3DEEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 
        0x00C0DDE9, 0x00C0DDE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 0x00B7D5E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E1, 
        0x00B4D4E1, 0x00B4D4E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD1DF, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A7CBDA, 0x00A7CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D8, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 
        0x0098C0D1, 0x0097C0D0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008CB8CA, 0x008CB8CA, 0x008CB7C9, 0x008AB6C8, 0x008AB6C8, 
        0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0086B3C6, 0x00465D67, 0x00000000, 0x00090D0E, 0x0032434A, 0x00526F7B, 0x00729AAA, 0x007AA6B8, 0x007CA9BC, 0x007EACC0, 0x0080AFC2, 0x0052707D, 0x00010202, 0x0011171A, 0x007DADC1, 0x007CACC0, 0x007BABC0, 
        0x007BABBF, 0x0079AABF, 0x0079AABE, 0x0078AABE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A8BC, 0x0074A7BB, 0x0039525D, 0x0026373F, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 
        0x006CA1B7, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006099B0, 0x006098B0, 0x005F98AF, 0x005E97AE, 0x005D96AE, 
        0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005994AC, 0x005993AB, 0x00396070, 0x001E323B, 0x005590A8, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x001D323B, 0x00020304, 0x003A6577, 0x004F8CA6, 0x004F8CA5, 
        0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00325C6E, 0x00000000, 0x0023414E, 0x004786A0,
  0x004887A1, 0x002A4E5E, 0x00000000, 0x00254552, 0x004B89A3, 0x004C89A4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004A849D, 0x00132229, 0x00020304, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005691AA, 0x00020304, 
        0x00345765, 0x005892AB, 0x005993AB, 0x005993AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 
        0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A4B9, 0x0071A4BA, 0x006999AC, 0x00050708, 0x005D8697, 0x0074A6BB, 0x0074A7BC, 
        0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x00486571, 0x00000000, 0x001D292D, 0x007DACC0, 0x007DADC1, 0x007DACC0, 0x00709AAC, 0x005E818F, 0x004A6671, 0x00101518, 0x00000000, 0x00688C9C, 0x0083B1C4, 
        0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 
        0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0095BECE, 0x0096BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D5, 
        0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 
        0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 
        0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C3DEEA, 0x00C4DFEB, 0x00C4E0EB, 0x00C4E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EC, 
        0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E2ED, 0x00C7E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C9E3ED, 0x00C9E3ED, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C9E3EE, 0x00C9E3EE, 0x00C9E3ED, 0x00C8E2ED, 0x00C9E2ED, 
        0x00C8E2ED, 0x00C8E1ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2EC, 0x00C7E2EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C5DFEB, 0x00C4DFEA, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 
        0x00C0DDE8, 0x00BFDCE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E6, 0x00BAD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 
        0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 
        0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 
        0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCC, 0x0091BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008CB8CA, 0x008CB8CA, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 
        0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0083AFC1, 0x002D3C42, 0x00000000, 0x00010101, 0x00000000, 0x00000000, 0x00000000, 0x000E1315, 0x0026343A, 0x003B515B, 0x004D6975, 0x002E4048, 0x00000000, 0x0030424A, 0x007DADC0, 0x007CACC0, 0x007BACC0, 
        0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x0074A6BC, 0x004C6E7B, 0x003F5B67, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 
        0x006CA1B6, 0x006BA0B6, 0x006AA0B5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 
        0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x00437084, 0x00315260, 0x00568FA8, 0x005691AA, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x000E191D, 0x00060A0C, 0x00407286, 0x004F8CA5, 0x004F8CA5, 
        0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00254451, 0x00000000, 0x002A4E5E, 0x004887A1,
  0x004787A1, 0x00305A6C, 0x00000000, 0x00182D36, 0x004A89A3, 0x004C89A4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004C88A1, 0x001C313B, 0x00000000, 0x004C859D, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA9, 0x005590A9, 0x005691A9, 0x00060B0D, 
        0x00436F82, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B95AC, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006198B0, 0x00629AB0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 
        0x00669DB3, 0x00679DB3, 0x00679EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x006C9DB2, 0x00172125, 0x005C8595, 0x0073A6BB, 0x0074A6BB, 
        0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078AABE, 0x0079AABE, 0x00658E9E, 0x00000000, 0x000D1215, 0x00425C67, 0x00334750, 0x001E292E, 0x0011181B, 0x00060809, 0x00000000, 0x00000000, 0x00000000, 0x003F555E, 0x0083B1C4, 
        0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 
        0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0099C0D1, 0x0099C1D2, 0x009AC1D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D5, 0x009FC5D5, 0x009FC6D5, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D7, 0x00A5C9D9, 0x00A6C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00AED0DE, 
        0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D8E5, 0x00BAD8E5, 0x00BBD9E5, 
        0x00BBD9E5, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C1DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C5E0EB, 
        0x00C5E0EB, 0x00C6E0EB, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1ED, 0x00C7E2EC, 0x00C7E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C8E2ED, 0x00C7E2EC, 
        0x00C7E2EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEA, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 
        0x00BFDCE8, 0x00BFDBE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCD9E6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD8E4, 0x00BAD8E4, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 
        0x00B3D3E1, 0x00B3D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC4D5, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C0D1, 0x0098C0D1, 
        0x0097C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BCCD, 0x0093BCCD, 0x0091BBCD, 0x0090BBCD, 0x0090BACC, 0x0090BACC, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 
        0x0089B5C8, 0x0089B5C7, 0x0087B4C7, 0x007FAABB, 0x00111719, 0x00010202, 0x00688B9A, 0x0053707C, 0x0033464D, 0x00171F23, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00000000, 0x0051707D, 0x007DACC0, 0x007CACC0, 0x007BABBF, 
        0x007AABBF, 0x0079AABF, 0x0079A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A6BB, 0x0073A5BA, 0x0072A4B9, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B6, 
        0x006CA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 
        0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AB, 0x005993AB, 0x005791AA, 0x005790A9, 0x005791AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x0005090B, 0x00091012, 0x00487F95, 0x004F8CA6, 0x004F8CA5, 
        0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004A89A3, 0x00182C35, 0x00000000, 0x00305A6B, 0x004887A1,
  0x004787A1, 0x00376679, 0x00040708, 0x000D191D, 0x004A89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x00264350, 0x00000000, 0x003F6F83, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x00080D10, 
        0x00467589, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006099B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 
        0x00659DB3, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006AA0B5, 0x006CA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0071A4B9, 0x006D9EB2, 0x001D2A30, 0x005C8494, 0x0073A6BB, 0x0074A6BB, 
        0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x007AABBF, 0x00030405, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00030506, 0x00161E21, 0x00212D32, 0x00010202, 0x00182124, 0x0083B1C4, 
        0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8C9, 0x008EB9CB, 0x008EB9CB, 0x0090BACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCD, 
        0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D2, 0x009AC1D2, 0x009AC2D2, 0x009CC2D2, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 
        0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 
        0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD9E5, 
        0x00BBD9E5, 0x00BCD9E5, 0x00BCD9E6, 0x00BDDAE6, 0x00BDDAE6, 0x00BEDBE7, 0x00BEDBE8, 0x00BFDBE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4E0EB, 
        0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E2EC, 0x00C7E1EC, 0x00C7E2EC, 0x00C7E1ED, 0x00C7E2EC, 0x00C7E2ED, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 
        0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C6E0EC, 0x00C6E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEA, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 
        0x00BFDBE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B3D4E1, 
        0x00B3D3E1, 0x00B3D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CDDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 
        0x00A5C9D9, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A0C6D6, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009AC2D2, 0x009AC1D1, 0x009AC1D1, 0x0098C0D1, 0x0098C0D0, 
        0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0094BECE, 0x0093BCCE, 0x0093BCCD, 0x0093BCCD, 0x0091BBCD, 0x0090BBCC, 0x0090BBCC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 
        0x0089B5C8, 0x0087B4C7, 0x0087B4C7, 0x00749BAA, 0x00000000, 0x00202B2F, 0x0085B2C5, 0x0084B2C5, 0x0082B1C4, 0x0082B0C3, 0x007BA8BB, 0x00618594, 0x00354850, 0x00131B1E, 0x00000000, 0x00000000, 0x0074A1B4, 0x007DACC0, 0x007BACC0, 0x007BABBF, 
        0x007AAABF, 0x0079AABE, 0x0079A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0071A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 
        0x006BA1B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 
        0x005D96AD, 0x005C95AD, 0x005B94AD, 0x005B94AC, 0x005993AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00498096, 0x00030506, 0x000C1519, 0x00508CA6, 0x004F8CA6, 0x004E8BA5, 
        0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004A89A3, 0x000D181D, 0x00040708, 0x00366679, 0x004887A1,
  0x004787A1, 0x003C7187, 0x00070D10, 0x00030607, 0x004B89A3, 0x004C89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x002E505F, 0x00000000, 0x002F5462, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x00253E49, 
        0x004C7F95, 0x005892AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005B94AD, 0x005B95AD, 0x005C96AE, 0x005D96AE, 0x005E96AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006198B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 
        0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006CA0B6, 0x006CA1B6, 0x006CA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B8, 0x0070A4B9, 0x006EA0B4, 0x003D5863, 0x006490A2, 0x0073A6BB, 0x0074A6BB, 
        0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x007AABBF, 0x00212F35, 0x00000000, 0x00101619, 0x002F4148, 0x00496570, 0x00658C9B, 0x007BA8BB, 0x0080AFC2, 0x006E96A8, 0x000D1113, 0x00040506, 0x0078A4B6, 
        0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 
        0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 
        0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00AACCDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 
        0x00AED0DD, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B7D6E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 
        0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DEE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C2DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DFEA, 
        0x00C4DFEB, 0x00C4E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EC, 0x00C6E1EB, 0x00C6E0EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C6E1EC, 0x00C6E1EC, 0x00C7E1EC, 0x00C7E1EC, 0x00C6E1EC, 
        0x00C6E1EC, 0x00C6E1EC, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C4DFEB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DDE9, 0x00C2DDE9, 0x00C1DDE9, 0x00C0DDE9, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 
        0x00BFDBE8, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE7, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 
        0x00B3D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A5C9D8, 0x00A5C9D8, 0x00A3C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A1C7D6, 0x00A1C6D5, 0x00A0C6D6, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D1, 0x0098C0D1, 0x0097C0D0, 
        0x0097BFD0, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 
        0x0089B5C8, 0x0087B4C7, 0x0087B4C7, 0x004D6772, 0x00000000, 0x00455D67, 0x0084B2C5, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x00729CAE, 0x00000000, 0x000F1517, 0x007DADC1, 0x007CACC0, 0x007BABBF, 0x007BABBF, 
        0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 
        0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005D96AE, 0x005D96AE, 
        0x005D95AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x003E6C7F, 0x00010303, 0x0014232A, 0x004F8CA6, 0x004F8CA6, 0x004E8CA5, 
        0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C89A3, 0x004A89A3, 0x00030506, 0x00070D10, 0x003C7288, 0x004887A1,
  0x004787A1, 0x00437E96, 0x000A1317, 0x00010303, 0x00417990, 0x004B89A3, 0x004C8AA3, 0x004D8AA4, 0x004D8BA4, 0x004E8CA5, 0x004F8CA5, 0x00376173, 0x00010203, 0x001F3741, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005691AA, 
        0x005792AA, 0x005892AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 
        0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA3B8, 0x0070A3B8, 0x0070A4B9, 0x0071A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 
        0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x007AABBF, 0x00496773, 0x00000000, 0x002E4048, 0x007DACC0, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 0x007EACBF, 0x00182124, 0x00020203, 0x00567581, 
        0x0083B1C4, 0x0084B1C5, 0x0084B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB5C8, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB9CA, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 
        0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0095BECE, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009CC2D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 
        0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D7, 0x00A2C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 
        0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E2, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 
        0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE8, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DDE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C2DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C3DEEA, 0x00C3DFEA, 
        0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C5DFEB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C6E0EB, 0x00C6E0EC, 0x00C5E0EB, 0x00C6E0EB, 0x00C6E0EC, 0x00C6E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 
        0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C4E0EB, 0x00C4DFEB, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE7, 0x00BFDBE7, 
        0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE7, 0x00BCDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E1, 
        0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D0DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D9, 
        0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 
        0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 
        0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x001F292D, 0x00000000, 0x00658896, 0x0084B2C5, 0x0083B1C4, 0x0082B0C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x007FAFC2, 0x004C6975, 0x00000000, 0x0032454D, 0x007DADC0, 0x007CACC0, 0x007BACC0, 0x007AABBF, 
        0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 
        0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B1, 0x006099B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E96AE, 0x005D96AE, 
        0x005C95AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005A93AB, 0x005893AB, 0x005892AB, 0x005892AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00325766, 0x00000000, 0x00243F4A, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 
        0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x00417991, 0x00010303, 0x000A1317, 0x00437E96, 0x004887A1,
  0x004787A1, 0x004887A1, 0x000F1C21, 0x00010203, 0x00376579, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8BA5, 0x003F7084, 0x0005090B, 0x000F1B20, 0x00518EA7, 0x00538EA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005690A9, 0x005691AA, 
        0x005692AA, 0x005892AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639BB2, 0x00649BB2, 0x00659CB2, 
        0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x0070A3B8, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 
        0x0074A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x006E9AAD, 0x00000000, 0x00101619, 0x0079A7BB, 0x007DADC1, 0x007EAEC1, 0x007EAEC2, 0x007FAEC2, 0x0080AFC2, 0x00354951, 0x00000000, 0x0033454D, 
        0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 
        0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 
        0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCEDD, 
        0x00ADCFDD, 0x00AECFDE, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B8D6E4, 0x00B8D7E4, 0x00B9D7E4, 
        0x00BAD8E5, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C1DEE9, 0x00C2DDE9, 0x00C2DEE9, 0x00C2DEEA, 
        0x00C3DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C5DFEB, 0x00C5E0EB, 0x00C4E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C5E0EB, 0x00C4E0EB, 
        0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE8, 0x00C0DDE8, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDBE8, 0x00BFDBE7, 0x00BFDBE7, 0x00BDDBE7, 
        0x00BDDBE7, 0x00BDDAE7, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B2D3E1, 0x00B2D3E0, 
        0x00B2D2E0, 0x00B1D2E0, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A5CAD8, 0x00A5C9D8, 
        0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D0, 0x0097BFD0, 
        0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0094BECE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB8CB, 0x008DB8CA, 0x008DB8CA, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x0089B6C8, 0x0089B5C8, 
        0x0088B5C7, 0x0088B4C7, 0x0081ADBF, 0x00000000, 0x0011171A, 0x00739CAD, 0x0084B2C5, 0x0083B1C4, 0x0082B0C3, 0x0082B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x00243137, 0x00000000, 0x00557684, 0x007DACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 
        0x007AABBF, 0x0079A9BE, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA0B7, 
        0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 
        0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x0026424E, 0x00000000, 0x00315766, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 
        0x004E8BA5, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00366578, 0x00010203, 0x000F1C21, 0x004887A1, 0x004787A1,
  0x004786A1, 0x004887A1, 0x00182C35, 0x00000101, 0x002C5161, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x00488097, 0x00091013, 0x00040709, 0x00518EA7, 0x00528FA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005691A9, 0x005691AA, 
        0x005692AA, 0x005892AA, 0x005892AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005C96AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639BB1, 0x00649BB2, 0x00659BB2, 
        0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 
        0x0074A7BB, 0x0075A7BC, 0x0075A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078AABE, 0x0079AABF, 0x0079A8BD, 0x0011181A, 0x00000000, 0x006B95A7, 0x007DADC1, 0x007EADC1, 0x007EAEC2, 0x007FAEC2, 0x0080AFC2, 0x005D7E8D, 0x00000000, 0x001C262B, 
        0x007AA5B7, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB8CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 
        0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009BC2D2, 0x009BC2D2, 0x009CC2D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 
        0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 
        0x00ADCFDD, 0x00AECFDD, 0x00AED0DD, 0x00AFD0DE, 0x00AFD1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B8D7E4, 
        0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE8, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DDE9, 
        0x00C2DEE9, 0x00C3DEEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C4DFEA, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C4DFEB, 0x00C5DFEB, 0x00C4DFEB, 0x00C4E0EB, 0x00C4DFEA, 0x00C4E0EA, 0x00C4DFEA, 
        0x00C4DFEB, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDBE8, 0x00BFDCE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE7, 
        0x00BDDAE6, 0x00BDDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 
        0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00AACDDC, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 
        0x00A4C9D8, 0x00A3C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0097C0D0, 0x0097BFD0, 
        0x0096BFD0, 0x0095BECF, 0x0095BECE, 0x0094BDCE, 0x0094BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB8CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x0089B5C8, 0x0089B5C8, 
        0x0088B5C7, 0x0087B4C7, 0x0055737E, 0x00000000, 0x0028363C, 0x007FABBE, 0x0084B1C4, 0x0083B1C4, 0x0082B0C4, 0x0082B0C3, 0x0081AFC3, 0x0080AFC2, 0x007FAEC2, 0x00000101, 0x00040607, 0x006A93A4, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 
        0x0079AABF, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BC, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 
        0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005D96AE, 0x005D96AE, 
        0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x001A2E37, 0x00000000, 0x00417387, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 
        0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x002B5060, 0x00000101, 0x00182D36, 0x004887A1, 0x004787A1,
  0x004786A1, 0x004887A1, 0x00264755, 0x00000000, 0x00203B46, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x000E191E, 0x00020405, 0x0045798F, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 
        0x005791AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006299B0, 0x006299B1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 
        0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699FB4, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 
        0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078AABE, 0x0079AABE, 0x0078A9BE, 0x00334750, 0x00000000, 0x00435D68, 0x007DACC0, 0x007EADC1, 0x007EADC1, 0x007FAEC2, 0x0080AFC2, 0x0081AFC3, 0x00050708, 0x00080B0D, 
        0x00698E9D, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B3C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 
        0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BECE, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC2D2, 0x009AC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 
        0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ACCEDC, 
        0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B4D3E1, 0x00B4D4E1, 0x00B4D4E2, 0x00B5D4E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 
        0x00B9D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C1DDE9, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C3DFEA, 0x00C2DEEA, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DFEA, 0x00C4DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C3DFEA, 0x00C4DEEB, 0x00C3DFEA, 0x00C3DEEA, 
        0x00C3DEEA, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DCE9, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE6, 0x00BDDAE6, 
        0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 
        0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D9, 0x00A4C9D8, 
        0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 0x0099C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 
        0x0096BECF, 0x0096BECF, 0x0095BECE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008FB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8C9, 0x008CB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C8, 
        0x0088B4C7, 0x0087B4C7, 0x00263439, 0x00000000, 0x00435B64, 0x0084B2C5, 0x0083B1C4, 0x0082B1C4, 0x0082B0C4, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x005D808F, 0x00000000, 0x001B252A, 0x0073A0B2, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AAABF, 
        0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0074A7BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 
        0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AD, 
        0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005390A8, 0x00538FA8, 0x004D869D, 0x00132127, 0x00000000, 0x00508DA6, 0x00508CA6, 0x004E8BA5, 0x004E8BA5, 
        0x004D8BA4, 0x004C8AA4, 0x004B8AA4, 0x004B89A3, 0x00203B46, 0x00000000, 0x00264856, 0x004887A1, 0x004786A1,
  0x004786A1, 0x004786A1, 0x00325F72, 0x00000000, 0x00162931, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x001A2F37, 0x00010202, 0x00376072, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005590A9, 0x005590A9, 0x005691A9, 
        0x005791AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005994AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 
        0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006B9FB5, 0x006BA0B6, 0x006CA0B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 
        0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0079A9BE, 0x0079AABE, 0x007AAABF, 0x00527481, 0x00000000, 0x00151E21, 0x007CACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAFC2, 0x0080AFC3, 0x002D3D44, 0x00000000, 
        0x004F6B77, 0x0082B0C3, 0x0084B2C4, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008CB8C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 
        0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 
        0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBD9, 0x00A8CBDA, 0x00A9CCDA, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 
        0x00ACCEDC, 0x00ADCEDD, 0x00ADCFDD, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B4D4E0, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B6D6E2, 0x00B8D6E3, 
        0x00B8D7E3, 0x00B8D7E4, 0x00B9D7E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BCD9E5, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE8, 
        0x00C0DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C3DEE9, 0x00C2DEEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C3DEEA, 0x00C3DEEA, 0x00C2DEEA, 0x00C3DEE9, 0x00C3DEE9, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DEEA, 
        0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C0DDE9, 0x00C0DDE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDBE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCD9E6, 
        0x00BCD9E5, 0x00BBD9E5, 0x00BBD8E5, 0x00BAD8E4, 0x00BAD8E5, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 
        0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CCDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098BFD0, 0x0096BFD0, 
        0x0096BFCF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 
        0x0088B4C7, 0x007AA4B5, 0x000D1214, 0x00050708, 0x00658795, 0x0084B2C4, 0x0083B1C4, 0x0083B1C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AEC2, 0x00304249, 0x00000000, 0x0032454D, 0x007DACC0, 0x007CACC0, 0x007CABC0, 0x007AABBF, 0x007AAABF, 
        0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006EA3B8, 0x006EA2B8, 0x006EA1B7, 0x006DA1B7, 0x006CA1B6, 0x006BA0B6, 
        0x006AA0B6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AD, 
        0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005892AA, 0x005792AA, 0x005792AA, 0x005691A9, 0x005591A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00477B91, 0x000A1216, 0x000A1216, 0x00508DA6, 0x00508CA6, 0x004E8CA5, 0x004E8BA5, 
        0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00162931, 0x00000000, 0x00336072, 0x004787A1, 0x004786A1,
  0x004786A1, 0x004787A1, 0x00407992, 0x00000000, 0x000F1C22, 0x00457F97, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x002B4D5B, 0x00000000, 0x00294855, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005590A9, 
        0x005692AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005A93AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00649AB2, 0x00649BB2, 
        0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A4B9, 0x0070A4B9, 0x0072A5BA, 0x0072A5BA, 0x0072A6BB, 
        0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0079AABE, 0x0079AABF, 0x00648C9E, 0x000B1012, 0x00000000, 0x00719DB0, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AFC3, 0x00608392, 0x00000000, 
        0x0028373D, 0x0081AFC2, 0x0084B2C4, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8C9, 0x008DB8CA, 0x008DB8CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 
        0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 
        0x009FC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00AACCDB, 0x00ABCDDB, 0x00ABCEDC, 
        0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E2, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 
        0x00C0DCE8, 0x00C0DCE9, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DEE9, 0x00C2DDE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEE9, 0x00C2DEEA, 0x00C2DEEA, 0x00C2DEE9, 0x00C2DEE9, 0x00C1DEE9, 
        0x00C1DEE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE8, 0x00C0DDE8, 0x00C0DDE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E5, 
        0x00BBD9E6, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B7D7E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D1DF, 
        0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDB, 0x00AACDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD8, 0x00A4C9D8, 0x00A4C8D8, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x009FC5D5, 0x009FC5D5, 0x009FC4D4, 0x009EC4D4, 0x009DC4D3, 0x009CC3D3, 0x009BC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0096BFD0, 0x0096BFD0, 
        0x0096BECF, 0x0094BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C7, 0x0088B5C7, 
        0x0087B4C7, 0x005A7885, 0x00040606, 0x000F1416, 0x0085B2C5, 0x0084B1C5, 0x0083B1C4, 0x0082B1C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x007FAEC2, 0x000D1315, 0x00020404, 0x004D6B77, 0x007CACC0, 0x007CACC0, 0x007BACBF, 0x007AABBF, 0x007AAABF, 
        0x0079AABE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0075A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 
        0x006AA0B6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00669DB4, 0x00669CB3, 0x00669CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005C96AD, 
        0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005893AB, 0x005892AB, 0x005792AB, 0x005791AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00417185, 0x00010202, 0x001D343D, 0x00508DA6, 0x004F8CA5, 0x004E8CA5, 0x004D8BA5, 
        0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x00457F97, 0x000F1C22, 0x00000000, 0x00417A92, 0x004887A1, 0x004786A1,
  0x004786A1, 0x004786A1, 0x004887A1, 0x00030607, 0x00091114, 0x003F758B, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x003D6D81, 0x00000000, 0x001D323B, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 
        0x005691A9, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00649BB1, 0x00649BB2, 
        0x00659BB3, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006FA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A5BB, 
        0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0079A9BE, 0x0079AABE, 0x0074A2B6, 0x001D282D, 0x00000000, 0x0047636F, 0x007DADC0, 0x007EADC1, 0x007EAEC2, 0x007FAEC2, 0x0080AFC2, 0x007DAABD, 0x000A0E10, 
        0x00020203, 0x007AA5B6, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 
        0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 
        0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CDDB, 0x00AACDDB, 0x00AACDDC, 
        0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00AED0DD, 0x00AED0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 
        0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE8, 0x00BFDBE7, 0x00BFDBE7, 
        0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE9, 0x00C0DDE8, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C2DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 0x00C1DDE9, 
        0x00C1DDE9, 0x00C1DDE8, 0x00C0DDE8, 0x00C1DDE9, 0x00C0DDE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BBD9E6, 0x00BBD9E6, 0x00BBD9E5, 
        0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D8E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 
        0x00B0D1DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CADA, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D8, 
        0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC3D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 
        0x0095BECF, 0x0095BECE, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008CB8C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 
        0x0085B2C5, 0x00394B53, 0x00000000, 0x00233035, 0x007BA6B7, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x00618595, 0x00050809, 0x00080B0C, 0x006B94A4, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x0079AABF, 
        0x0079AABE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A6BC, 0x0074A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA3B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 
        0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C95AD, 
        0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AA, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00396374, 0x00000000, 0x00325766, 0x00508DA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 
        0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x0040758B, 0x00091114, 0x00030607, 0x004987A2, 0x004887A1, 0x004786A1,
  0x004686A0, 0x004886A1, 0x004887A2, 0x00112127, 0x00010202, 0x00396A7E, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004C88A1, 0x00000000, 0x00142229, 0x004D869E, 0x00528EA7, 0x00538FA7, 0x00548FA8, 0x005590A9, 0x005590A9, 
        0x005691AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00639AB1, 0x00639AB1, 0x00649BB2, 
        0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA2B7, 0x006FA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 
        0x0074A6BB, 0x0074A6BB, 0x0074A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078AABE, 0x0079AABE, 0x007AAABF, 0x00364B54, 0x00000000, 0x001F2B30, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x0080AFC2, 0x007EADC0, 0x00374A53, 
        0x00000000, 0x00506C78, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 
        0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D3, 0x009CC3D2, 0x009CC3D3, 0x009DC3D4, 
        0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00ABCDDB, 
        0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B4D3E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 
        0x00B6D5E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BEDAE7, 0x00BEDBE7, 0x00BEDBE7, 
        0x00BFDBE7, 0x00BFDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C0DDE8, 0x00C0DDE8, 0x00C0DDE8, 0x00C0DCE8, 0x00C0DDE8, 0x00C0DCE8, 0x00C0DDE8, 
        0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BEDCE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE7, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 
        0x00BAD8E4, 0x00BAD8E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B5D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 
        0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 
        0x0095BECF, 0x0095BECF, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 
        0x007BA5B5, 0x00182024, 0x00000000, 0x00030405, 0x0012181B, 0x002C3B42, 0x0054737F, 0x007DA9BD, 0x0081B0C3, 0x0080AFC2, 0x0080AFC2, 0x00415963, 0x00000000, 0x00182125, 0x007DADC0, 0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AAABF, 0x0079AABE, 
        0x0079A9BE, 0x0078A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A4BA, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 
        0x006A9FB6, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 
        0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005893AB, 0x005792AB, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x002A4855, 0x00000000, 0x0043768B, 0x00508CA6, 0x004F8CA6, 0x004E8BA5, 0x004D8BA5, 
        0x004D8AA4, 0x004B8AA3, 0x004B89A3, 0x0039697D, 0x00010202, 0x00122128, 0x004887A1, 0x004786A1, 0x004786A0,
  0x004686A0, 0x004786A1, 0x004887A2, 0x00244450, 0x00000000, 0x00305A6B, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x000A1316, 0x000A1114, 0x00477B90, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 
        0x005591A9, 0x005791AA, 0x005792AA, 0x005892AA, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639BB2, 
        0x00659BB2, 0x00659CB2, 0x00669CB3, 0x00669DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 
        0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x00597E8C, 0x00020303, 0x000D1215, 0x006C95A7, 0x007DADC1, 0x007EADC1, 0x007FADC1, 0x007EACC0, 0x0079A6B9, 0x00405761, 
        0x00000000, 0x00151D21, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B3C5, 0x0085B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB8C9, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 
        0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0095BECE, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 
        0x009DC4D4, 0x009EC4D4, 0x009FC4D4, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CDDB, 
        0x00AACDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 
        0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDAE6, 0x00BEDBE7, 
        0x00BEDBE7, 0x00BEDBE7, 0x00BFDBE7, 0x00BFDBE7, 0x00BFDCE7, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00C0DCE8, 0x00BFDCE8, 0x00BFDCE8, 
        0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDBE7, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDAE6, 0x00BDDAE7, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E4, 
        0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B2D3E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD1DE, 
        0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C7D7, 
        0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC2D3, 0x009AC2D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 
        0x0095BDCF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCC, 0x0091BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB9CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B4C7, 0x0087B4C7, 
        0x006B8F9D, 0x00000000, 0x000A0E10, 0x000D1214, 0x00010101, 0x00000000, 0x00000000, 0x00050607, 0x002C3C42, 0x005C7E8D, 0x00749EB0, 0x00253338, 0x00000000, 0x00445D68, 0x007DACC1, 0x007BACC0, 0x007BACBF, 0x007BABBF, 0x0079AABF, 0x0079AABE, 
        0x0078AABE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0076A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 
        0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB3, 0x00669CB3, 0x00669CB2, 0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006198B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AD, 0x005C95AD, 
        0x005B95AD, 0x005A94AC, 0x005A93AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00518DA7, 0x00172930, 0x00010303, 0x004C869E, 0x004F8CA6, 0x004F8BA5, 0x004E8BA5, 0x004D8BA4, 
        0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x0030596A, 0x00000000, 0x00244451, 0x004887A1, 0x004786A1, 0x004686A0,
  0x004686A0, 0x004786A1, 0x004887A1, 0x00366579, 0x00000000, 0x0024424F, 0x004A88A2, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004D88A2, 0x001A2F37, 0x00000000, 0x003F6F82, 0x00528EA8, 0x00528EA8, 0x005490A8, 0x005490A8, 0x005590A9, 
        0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB2, 
        0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A5BA, 0x0072A5BA, 
        0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x000A0E10, 0x00020303, 0x0051717E, 0x007CABBF, 0x006B93A4, 0x00547582, 0x002B3B42, 0x00050708, 0x00000000, 
        0x00000000, 0x00000000, 0x006C92A2, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B6C8, 0x0089B6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 
        0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BCCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0097BFCF, 0x0097BFD0, 0x0097C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 
        0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 
        0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ACCEDC, 0x00ADCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 
        0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D8E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 
        0x00BDDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDCE8, 0x00BFDBE7, 
        0x00BFDCE7, 0x00BFDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BEDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BBD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D8E4, 
        0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 
        0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D7, 0x00A3C8D7, 0x00A2C7D7, 
        0x00A2C7D7, 0x00A1C6D6, 0x00A1C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0097C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 
        0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CA, 0x008CB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 
        0x003B4F56, 0x00000000, 0x004F6A75, 0x0084B2C5, 0x00638594, 0x00364A52, 0x001B2428, 0x00070A0B, 0x00000000, 0x00000000, 0x00010203, 0x00030405, 0x00000000, 0x00729EB1, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 
        0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0074A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B6, 0x006BA0B6, 0x006AA0B6, 
        0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 
        0x005B95AD, 0x005A94AC, 0x005994AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x0005080A, 0x000B1316, 0x003C6A7D, 0x0044798F, 0x004A849C, 0x004E8BA5, 0x004D8BA4, 
        0x004C8AA4, 0x004C8AA3, 0x004A88A2, 0x0023424F, 0x00000000, 0x00366679, 0x004887A1, 0x004786A1, 0x004686A0,
  0x004686A0, 0x004786A1, 0x004887A1, 0x00437E97, 0x00000000, 0x0014252D, 0x004A89A3, 0x004B89A3, 0x00478199, 0x0039677B, 0x00294A57, 0x001B313A, 0x00111F25, 0x00060B0D, 0x00000000, 0x00335A6A, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005590A9, 
        0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A93AC, 0x005B94AD, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00649BB1, 
        0x00649BB2, 0x00659BB2, 0x00669CB2, 0x00669DB3, 0x00679DB3, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B5, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 
        0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x007AAABF, 0x00344850, 0x00000000, 0x00192327, 0x00233137, 0x000F1518, 0x00000000, 0x00000000, 0x00000000, 0x001D282C, 
        0x00171F23, 0x00000000, 0x00374A53, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0086B3C5, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 
        0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BECE, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 
        0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 
        0x00A9CCDB, 0x00AACCDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2DF, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 
        0x00B5D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D6E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 0x00BCD9E6, 0x00BCDAE6, 
        0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDBE7, 0x00BDDAE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 0x00BEDBE7, 
        0x00BDDAE7, 0x00BDDBE7, 0x00BDDAE7, 0x00BDDAE7, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE5, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 
        0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B5D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B0D2DF, 0x00B0D1DE, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 
        0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCDDB, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 
        0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0085B1C4, 
        0x00050708, 0x00050708, 0x00749BAC, 0x0084B2C5, 0x0083B1C4, 0x0082B0C4, 0x0079A4B7, 0x00658A98, 0x0046606B, 0x00192226, 0x00000000, 0x00000000, 0x001C272B, 0x007DADC1, 0x007CACC0, 0x007BACC0, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078AABE, 
        0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA3B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006B9FB6, 0x006A9FB5, 
        0x00699FB5, 0x00699EB4, 0x00679EB4, 0x00689DB4, 0x00669DB3, 0x00669CB3, 0x00659BB3, 0x00659CB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 
        0x005B94AD, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005591AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00528FA8, 0x00487E94, 0x00000000, 0x00000000, 0x00040708, 0x000B1317, 0x00111F24, 0x001B3139, 0x00294B59, 
        0x0039687C, 0x0048839C, 0x004B89A3, 0x0014252C, 0x00000000, 0x00447E97, 0x004887A1, 0x004786A1, 0x004686A0,
  0x004686A0, 0x004686A0, 0x004886A1, 0x0046839D, 0x000A1317, 0x00040708, 0x0023414D, 0x000C171B, 0x00020506, 0x00010202, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00213A45, 0x00528EA7, 0x00528EA7, 0x00548FA8, 0x00548FA8, 0x005590A9, 
        0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005994AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 
        0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00679CB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 
        0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x007AABBF, 0x006791A2, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00161F22, 0x0048636F, 0x007099AB, 0x0080AFC2, 
        0x00577684, 0x00010202, 0x00141C1F, 0x0079A4B6, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 
        0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 
        0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 
        0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B4D4E1, 
        0x00B4D4E1, 0x00B5D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E6, 
        0x00BCD9E6, 0x00BCD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE7, 0x00BDDAE7, 0x00BDDAE7, 0x00BDDBE7, 0x00BDDBE7, 0x00BEDBE7, 0x00BDDBE7, 0x00BDDAE7, 0x00BDDAE7, 0x00BDDBE7, 0x00BDDAE7, 0x00BDDAE6, 
        0x00BDDAE6, 0x00BDDAE7, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BCD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E5, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D6E3, 
        0x00B8D7E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B5D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B2D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 
        0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6C9D9, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 
        0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BECF, 
        0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0054707C, 
        0x00000000, 0x002A383E, 0x007FABBE, 0x0084B2C5, 0x0083B1C4, 0x0082B0C4, 0x0082B0C4, 0x0081AFC3, 0x007FAEC1, 0x007FAEC2, 0x001E2A2F, 0x00000000, 0x0051717E, 0x007DACC1, 0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 
        0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA0B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 
        0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 
        0x005B94AC, 0x005A94AC, 0x005994AB, 0x005993AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x00325666, 0x00000000, 0x000C161A, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 
        0x00010202, 0x00020405, 0x000C171C, 0x00020506, 0x000B1418, 0x0046839D, 0x004887A1, 0x004686A1, 0x004686A0,
  0x004685A0, 0x004686A0, 0x004787A1, 0x0046849F, 0x00192F39, 0x00000000, 0x00000000, 0x00000000, 0x00030607, 0x00080F12, 0x000E191E, 0x001A2F38, 0x002D505E, 0x003C6B7F, 0x00091114, 0x000D171B, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 
        0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005994AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 
        0x00639BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A5BA, 
        0x0073A5BA, 0x0072A4B9, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0078A9BD, 0x0078A9BE, 0x0078AABE, 0x0079AABF, 0x007AABBF, 0x00141C20, 0x00000000, 0x002B3C43, 0x006B95A6, 0x007DADC1, 0x007EAEC2, 0x007FAEC2, 0x0080AFC2, 
        0x0081AFC3, 0x000C1012, 0x00030405, 0x005A7A87, 0x0084B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 
        0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 
        0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 
        0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AED0DD, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 
        0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 
        0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BCDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BDDAE6, 0x00BCDAE6, 0x00BDDAE6, 
        0x00BDDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCDAE6, 0x00BCD9E6, 0x00BCD9E6, 0x00BBD9E6, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D6E3, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 
        0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CADA, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A1C7D6, 
        0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0097BFD1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECE, 0x0094BDCE, 
        0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB7C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C8, 0x0088B4C7, 0x0087B4C7, 0x00171E22, 
        0x00000000, 0x00506B76, 0x0084B2C5, 0x0084B2C5, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x0074A0B2, 0x00000000, 0x0006090A, 0x00739FB1, 0x007CACC0, 0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0078AABE, 0x0078A9BE, 
        0x0077A9BE, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BA, 0x0073A6BB, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA1B8, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B5, 0x006A9FB5, 
        0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 
        0x005B94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005792AB, 0x005792AA, 0x005691AA, 0x005591A9, 0x005490A9, 0x005490A9, 0x00538FA8, 0x00528EA7, 0x00192B33, 0x00020304, 0x003F6F82, 0x004F8CA6, 0x00407185, 0x002B4C5B, 0x00192D35, 0x000E191E, 
        0x00070E10, 0x00030507, 0x00000000, 0x00000000, 0x001A3039, 0x0047859F, 0x004887A1, 0x004786A0, 0x004686A0,
  0x004585A0, 0x004786A0, 0x004787A1, 0x004786A0, 0x00284B59, 0x00000000, 0x0013232A, 0x002D5363, 0x00366374, 0x0042768C, 0x004B87A0, 0x004E8BA5, 0x004E8CA5, 0x004E8BA4, 0x001B3039, 0x00000000, 0x004D879F, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 
        0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 
        0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00659CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 
        0x00618D9F, 0x002D424A, 0x0073A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x007AABBF, 0x00486470, 0x00000000, 0x0026353C, 0x007DADC1, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAFC2, 
        0x0080AFC3, 0x00425964, 0x00000000, 0x0032454C, 0x0080ADC0, 0x0084B2C5, 0x0084B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB9CA, 
        0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC2D2, 0x009BC2D2, 
        0x009CC3D3, 0x009CC3D3, 0x009DC3D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C8D7, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBDA, 0x00A8CBDA, 
        0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B2D3E0, 
        0x00B3D3E0, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B7D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D8E4, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD8E5, 
        0x00BBD8E5, 0x00BAD8E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E5, 0x00BBD9E5, 0x00BBD9E6, 0x00BBD9E6, 0x00BCD9E6, 0x00BCD9E6, 0x00BCD9E6, 0x00BCD9E6, 0x00BCD9E5, 0x00BCD9E6, 0x00BCD9E6, 0x00BBD9E6, 0x00BBD9E6, 0x00BBD9E6, 
        0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BCD9E5, 0x00BBD8E5, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00B9D8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D5E2, 
        0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E0, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DD, 0x00AECFDD, 0x00ADCFDD, 
        0x00ACCEDD, 0x00ACCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDC, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 
        0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 
        0x0093BCCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B4C7, 0x0087B4C6, 0x00658795, 0x00030404, 
        0x000D1214, 0x00749CAD, 0x0084B2C5, 0x0083B1C4, 0x0083B1C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x003C535C, 0x00000000, 0x002C3D44, 0x0079A8BB, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 
        0x0077A9BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 
        0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00669DB4, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 
        0x005A94AC, 0x005994AC, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x00030607, 0x000B1316, 0x00457B91, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004B88A2, 
        0x003F7287, 0x00366376, 0x00172C34, 0x00000000, 0x00284C5A, 0x004786A0, 0x004786A1, 0x004686A0, 0x004585A0,
  0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x00336174, 0x00000000, 0x00172B34, 0x004A89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8CA5, 0x004E8BA4, 0x002C4E5D, 0x00000000, 0x00386173, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 
        0x005490A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005892AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x006299B1, 0x00639AB1, 
        0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 
        0x0070A3B7, 0x000A0F11, 0x0044626F, 0x0073A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x007AAABE, 0x006791A2, 0x00070A0B, 0x00000000, 0x00709CAE, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 
        0x0080AFC2, 0x007AA6B9, 0x00000000, 0x00060809, 0x0077A1B3, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB6C8, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 
        0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 
        0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A3C7D7, 0x00A4C8D8, 0x00A4C9D7, 0x00A5C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 
        0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DF, 0x00B0D1DF, 0x00B0D2DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 
        0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D8E4, 
        0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 0x00BBD9E5, 
        0x00BBD8E5, 0x00BAD9E5, 0x00BBD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00BAD8E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D5E3, 0x00B6D5E2, 
        0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B1D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD1DE, 0x00AFD0DE, 0x00AED0DE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 
        0x00ACCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D5, 
        0x00A0C6D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009CC2D3, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 
        0x0093BCCE, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0034464D, 0x00000000, 
        0x002D3D44, 0x0084B2C5, 0x0084B1C5, 0x0083B1C4, 0x0082B1C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x007FAEC2, 0x00090D0F, 0x00010202, 0x004E6D79, 0x007DACC0, 0x007CACC0, 0x007BACC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 
        0x0077A9BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 
        0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006099B0, 0x006098AF, 0x005F98AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005B94AD, 
        0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x0043758A, 0x00000000, 0x00132127, 0x004F8BA5, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004C8BA4, 0x004C8AA4, 
        0x004C8AA4, 0x004B89A3, 0x00172B34, 0x00000000, 0x00336174, 0x004887A1, 0x004786A1, 0x004686A0, 0x004585A0,
  0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x003C7086, 0x00070E11, 0x00040708, 0x004A89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004E8AA4, 0x004E8CA5, 0x004F8CA5, 0x00396578, 0x00000000, 0x001E343E, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x005491A9, 0x005690A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x006299B1, 0x00629AB1, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA1B7, 0x006CA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA2B8, 0x006FA3B9, 0x0070A4B9, 0x0071A4BA, 
        0x0072A5BA, 0x003E5A66, 0x00080C0D, 0x006B9AAD, 0x0074A7BC, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A8BD, 0x0078A9BD, 0x0079AABE, 0x007AAABE, 0x0075A4B7, 0x0026343B, 0x00000000, 0x00395059, 0x007DACC0, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 
        0x0080AFC2, 0x0080AFC3, 0x0034474F, 0x00000000, 0x0048626D, 0x0083B1C4, 0x0084B1C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 
        0x008EB8CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCE, 0x0093BCCE, 0x0093BDCE, 0x0094BECE, 0x0095BECF, 0x0095BECF, 0x0097BFD0, 0x0097BFD0, 0x0098BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 
        0x009BC2D2, 0x009BC3D3, 0x009CC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2E0, 
        0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D6E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D7E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B8D7E4, 0x00B9D7E4, 
        0x00B9D7E4, 0x00B9D7E4, 0x00BAD8E5, 0x00B9D8E4, 0x00BAD8E5, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BAD9E5, 0x00BAD9E5, 0x00BBD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BBD9E5, 0x00BBD8E5, 0x00BAD8E5, 
        0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00BAD8E4, 0x00B9D7E4, 0x00B9D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B7D6E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 
        0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B0D2DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD1DE, 0x00AFD0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 
        0x00ABCEDC, 0x00ABCEDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A0C6D6, 0x00A0C6D5, 
        0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BCCE, 
        0x0093BCCD, 0x0091BCCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B4C7, 0x00759CAD, 0x0013191C, 0x00000000, 
        0x006B8F9F, 0x0084B1C5, 0x0083B1C4, 0x0083B1C4, 0x0082B1C4, 0x0081B0C3, 0x0080AFC3, 0x0080AFC3, 0x00557482, 0x00010202, 0x000F1517, 0x006D97A8, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 
        0x0077A8BD, 0x0075A7BC, 0x00618B9D, 0x003A535D, 0x0074A6BB, 0x0073A6BB, 0x0072A6BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699EB5, 
        0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB1, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 
        0x005A94AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005791AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x002E505E, 0x00000000, 0x00223C47, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 
        0x004B8AA4, 0x004A89A3, 0x00030608, 0x00070E11, 0x003C7086, 0x004787A1, 0x004787A1, 0x004685A0, 0x004585A0,
  0x004585A0, 0x004685A0, 0x004786A1, 0x004787A1, 0x00447F98, 0x000F1C22, 0x00000000, 0x003E748A, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x0043778D, 0x00091114, 0x00060B0D, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 
        0x005590A8, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AB, 0x005892AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006299B0, 0x00629AB1, 
        0x00639AB2, 0x00639BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA1B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A4B9, 0x0070A4BA, 
        0x0071A4BA, 0x00537887, 0x00000000, 0x003A545F, 0x0073A6BB, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x00486470, 0x00010203, 0x000E1315, 0x0077A5B9, 0x007DADC1, 0x007EADC2, 0x007FAEC2, 
        0x0080AEC2, 0x0080AFC2, 0x00658999, 0x00020203, 0x000A0D0F, 0x0081AEC1, 0x0083B1C4, 0x0084B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB6C8, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 
        0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACB, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 
        0x009AC2D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x009FC6D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D2DF, 
        0x00B1D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D7E4, 
        0x00B9D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B9D8E4, 0x00B9D8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E5, 0x00BAD8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00BAD8E4, 0x00BAD8E4, 0x00BAD8E5, 0x00B9D7E5, 0x00BAD8E4, 0x00BAD8E4, 
        0x00BAD8E4, 0x00B9D7E5, 0x00B9D8E4, 0x00B8D8E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B7D7E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D4E2, 0x00B5D4E2, 
        0x00B5D4E2, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 
        0x00ABCEDC, 0x00AACDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A8CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A5C9D9, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 
        0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 
        0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0054707C, 0x00000000, 0x00202B30, 
        0x0084B2C5, 0x0084B1C5, 0x0083B1C4, 0x0083B0C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x007FAFC2, 0x0029393F, 0x00000000, 0x002A3A41, 0x007DACC0, 0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0078AABE, 0x0078A9BD, 0x0077A9BD, 
        0x0076A8BD, 0x0076A7BC, 0x00151E21, 0x00334A52, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B6, 0x006BA0B6, 0x006AA0B6, 0x00699FB5, 0x00699EB4, 
        0x00689EB5, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 
        0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005791AA, 0x005691AA, 0x005591A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538EA8, 0x001A2D35, 0x00000000, 0x00376172, 0x004F8CA6, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 
        0x004B8AA3, 0x003E7389, 0x00000000, 0x000F1C22, 0x00448098, 0x004887A1, 0x004786A1, 0x004686A0, 0x004585A0,
  0x004585A0, 0x004685A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x00193039, 0x00000000, 0x002A4E5D, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004E8AA3, 0x00111F25, 0x00000000, 0x0044778C, 0x00528EA7, 0x00538FA8, 0x00538FA8, 
        0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D97AE, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006299B1, 
        0x00639AB1, 0x00649BB1, 0x00649BB1, 0x00659BB2, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 
        0x0071A4BA, 0x003B5661, 0x00000000, 0x00080B0D, 0x006997AA, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x006E9BAD, 0x00090C0E, 0x00030405, 0x00506F7C, 0x007DADC1, 0x007DADC1, 0x007EAEC1, 
        0x007FAEC2, 0x0080AFC2, 0x0079A6B9, 0x00222F34, 0x00000000, 0x004A6570, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB8CA, 
        0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECE, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0098BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 
        0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC3D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CDDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCFDD, 0x00AECFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 
        0x00B1D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B6D6E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B9D7E4, 0x00B8D7E4, 0x00B9D7E4, 
        0x00B9D7E4, 0x00B8D7E3, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D6E4, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 
        0x00B4D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00AACDDB, 
        0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 
        0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x0099C1D1, 0x0098C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 
        0x0092BBCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB5C8, 0x0089B5C8, 0x0089B5C7, 0x0087B4C7, 0x0087B4C6, 0x00182023, 0x00000000, 0x00648694, 
        0x0084B2C5, 0x0083B1C5, 0x0083B0C4, 0x0082B1C4, 0x0082B0C3, 0x0081AFC3, 0x0080AFC2, 0x006B93A4, 0x000D1315, 0x00000000, 0x00608595, 0x007DACC0, 0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0078AABE, 0x0078A9BD, 0x0077A8BD, 
        0x0076A8BD, 0x00466470, 0x00090D0F, 0x0073A5BA, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0072A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA2B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006AA0B6, 0x00699FB5, 0x00699EB5, 
        0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB0, 0x006299B0, 0x006199B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005C96AE, 0x005C95AD, 0x005B94AD, 0x005A94AC, 
        0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x004C859B, 0x000E191D, 0x00000000, 0x004D88A0, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 
        0x004B89A3, 0x002A4E5D, 0x00000000, 0x001A3039, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x0045859F,
  0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x002A4F5E, 0x00000000, 0x00172A32, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA5, 0x004E8CA5, 0x004F8CA5, 0x00223C46, 0x00000000, 0x002D4F5D, 0x00528EA7, 0x00538FA8, 0x00538FA8, 
        0x00548FA8, 0x005590A9, 0x005590A9, 0x005691A9, 0x005792AA, 0x005892AB, 0x005893AB, 0x005994AC, 0x005A94AC, 0x005A94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006199B1, 
        0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA0B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 
        0x00598192, 0x00040607, 0x00000000, 0x00000000, 0x002D414A, 0x0074A7BC, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A8BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x002C3E45, 0x00000000, 0x00293A40, 0x007AA8BC, 0x007DADC1, 0x007EADC1, 
        0x007FAEC2, 0x0080AFC2, 0x0080AFC2, 0x004C6873, 0x00020203, 0x0011171A, 0x0080AEC0, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 
        0x008DB8CA, 0x008DB8CA, 0x008EB8CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BFCF, 0x0096BFCF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C0D1, 
        0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC4D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B2D2DF, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D5E1, 0x00B5D4E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E3, 0x00B7D6E2, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D6E3, 0x00B8D7E4, 0x00B8D6E4, 0x00B8D7E3, 0x00B8D7E3, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E4, 0x00B8D7E3, 0x00B8D7E3, 
        0x00B8D6E4, 0x00B8D7E4, 0x00B7D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D5E2, 0x00B6D5E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D4E1, 
        0x00B3D3E0, 0x00B3D3E1, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 
        0x00A9CDDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A2C8D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 
        0x009EC4D4, 0x009EC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 
        0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0061828F, 0x00000000, 0x00000000, 0x00060809, 
        0x0040565F, 0x0079A3B5, 0x0080AEC1, 0x0082B0C4, 0x0081B0C3, 0x0080AFC3, 0x007FAEC1, 0x004B6773, 0x00000000, 0x00141C1F, 0x007DADC0, 0x007CACC0, 0x007BACC0, 0x007BACBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 
        0x006B99AC, 0x00131B1E, 0x00324851, 0x0074A6BB, 0x0072A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA0B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699EB5, 0x00699EB5, 
        0x00689EB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006299B0, 0x006199B0, 0x006099B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005A94AC, 0x005A94AC, 
        0x005993AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538EA8, 0x00406F82, 0x0005080A, 0x000F1B1F, 0x00508DA6, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 
        0x004B89A3, 0x00162A32, 0x00000000, 0x002B505F, 0x004887A1, 0x004787A1, 0x004786A0, 0x004585A0, 0x0045859F,
  0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x003C7188, 0x00000101, 0x000C161B, 0x0047829A, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00386475, 0x00000000, 0x00182A32, 0x00528EA7, 0x00538FA7, 0x00538FA8, 
        0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B0, 
        0x00629AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00699EB4, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA1B6, 0x006DA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006898AC, 0x003F5C68, 
        0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x005B8394, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0077A8BD, 0x0078A9BE, 0x0078AABE, 0x0079AABF, 0x0079AABF, 0x006992A3, 0x00000000, 0x00080C0D, 0x006991A2, 0x007DADC1, 0x007EADC1, 
        0x007EAEC2, 0x007FAEC2, 0x0080AFC2, 0x007CA9BC, 0x000F1517, 0x00020303, 0x00526F7B, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 
        0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACB, 0x0090BACC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 
        0x0099C1D1, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC6D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A5C9D8, 
        0x00A6C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 
        0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 
        0x00B6D5E2, 0x00B6D6E2, 0x00B6D5E2, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D6E3, 0x00B8D6E3, 0x00B8D7E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B8D6E3, 0x00B8D6E3, 0x00B7D6E3, 0x00B7D6E3, 
        0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B7D6E2, 0x00B6D6E3, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E0, 0x00B3D3E0, 
        0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2E0, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACCDB, 
        0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A1C6D6, 0x00A1C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009FC4D5, 
        0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 
        0x0091BBCD, 0x0090BBCC, 0x008FBACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B4C7, 0x0087B4C6, 0x00161D20, 0x00000000, 0x00141B1E, 0x00020303, 
        0x00000000, 0x0007090A, 0x00374A53, 0x00628594, 0x007CA9BC, 0x0080AFC3, 0x007EACC0, 0x00161F22, 0x00000000, 0x00567785, 0x007DADC1, 0x007CACC0, 0x007BACBF, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 
        0x0044616D, 0x00000000, 0x003E5965, 0x0074A6BB, 0x0073A6BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006BA0B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 
        0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006198B0, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005C96AE, 0x005C96AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 
        0x005993AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538EA8, 0x00335968, 0x00000000, 0x002C4C5A, 0x00508DA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 
        0x0046819A, 0x000C161A, 0x00000101, 0x003D7388, 0x004887A1, 0x004786A1, 0x004686A1, 0x004585A0, 0x0045859F,
  0x0044849F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00060B0D, 0x00050A0C, 0x003B6C81, 0x004B89A3, 0x004B8AA3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004E8CA5, 0x00000101, 0x000D161A, 0x004A8198, 0x00528EA7, 0x00538FA8, 
        0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006198B0, 0x006199B0, 
        0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B6, 0x006DA1B7, 0x006EA2B8, 0x00496C7A, 0x00162024, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121A1E, 0x0074A5BA, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x007AAABF, 0x007AABBF, 0x00243238, 0x00000000, 0x003F5862, 0x007DADC1, 0x007EADC1, 
        0x007EAEC1, 0x007FAEC2, 0x007AA7BA, 0x0047616C, 0x00090D0E, 0x00000000, 0x00233035, 0x007CA8BA, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 
        0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BECE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 
        0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009BC2D3, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 
        0x00A5C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CADA, 0x00A8CBD9, 0x00A8CBDA, 0x00A8CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDE, 0x00AED0DE, 
        0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B2D3E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B4D3E1, 0x00B3D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D5E2, 
        0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B6D5E2, 0x00B6D6E3, 0x00B7D6E3, 0x00B6D6E3, 0x00B6D6E3, 0x00B7D6E3, 0x00B7D6E3, 0x00B6D6E2, 0x00B7D5E3, 0x00B6D5E2, 
        0x00B6D6E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E1, 0x00B5D4E2, 0x00B4D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B3D4E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B1D2E0, 
        0x00B1D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCEDC, 0x00AACDDC, 0x00AACDDC, 0x00AACCDB, 0x00A9CCDB, 
        0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 
        0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 
        0x0091BBCC, 0x0090BACC, 0x0090BACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x00577580, 0x00000000, 0x00141B1E, 0x006F95A5, 0x00638595, 
        0x002F4047, 0x00000000, 0x00000000, 0x00060809, 0x00202C31, 0x004B6772, 0x00557482, 0x00000000, 0x0011181B, 0x0079A8BB, 0x007CACC0, 0x007BACC0, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x006E9DB0, 
        0x00030505, 0x00000000, 0x001C282D, 0x0073A6BB, 0x0073A5BB, 0x0072A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006BA1B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00689EB5, 0x00689EB4, 
        0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006099B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005994AC, 
        0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00518BA4, 0x00213943, 0x00000000, 0x00487F95, 0x00508CA6, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 
        0x003A6C81, 0x00050A0C, 0x00060C0E, 0x004887A1, 0x004787A1, 0x004786A0, 0x004686A0, 0x004685A0, 0x0044859F,
  0x0044849F, 0x0045859F, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x001C343E, 0x00000000, 0x002E5666, 0x004B89A3, 0x004B89A3, 0x004D8AA3, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA6, 0x0015262D, 0x00030506, 0x003D6A7D, 0x00528EA7, 0x00538FA8, 
        0x00548FA9, 0x005490A9, 0x005590A9, 0x005591A9, 0x005791AA, 0x005792AA, 0x005892AA, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005A95AD, 0x005C95AD, 0x005C95AD, 0x005D96AD, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x006098B0, 0x006098B0, 0x006199B0, 
        0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB1, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006495AA, 0x001E2D33, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x00405C68, 0x0075A7BC, 0x0076A7BD, 0x0076A8BC, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x007AAABE, 0x007AABBF, 0x00628999, 0x00000000, 0x00050708, 0x007CAABE, 0x007DADC1, 
        0x007BA9BC, 0x0046606C, 0x00060809, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00668A98, 0x0083B1C4, 0x0084B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 
        0x008CB7C9, 0x008CB8C9, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 
        0x0099C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D4, 0x00A0C5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 
        0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCEDD, 0x00ADCFDD, 0x00AECFDD, 
        0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2E0, 0x00B1D2DF, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B3D2E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 
        0x00B5D4E1, 0x00B5D4E2, 0x00B5D4E1, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 0x00B6D5E2, 
        0x00B6D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B5D5E2, 0x00B5D4E2, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D4E1, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 
        0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00AACDDC, 0x00AACDDB, 0x00A9CDDB, 0x00A9CCDB, 0x00A8CCDA, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 
        0x009DC3D4, 0x009CC3D3, 0x009CC2D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BECE, 0x0094BDCE, 0x0093BCCE, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 
        0x0090BBCC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B4C7, 0x0083AFC2, 0x001D282C, 0x00000000, 0x003F545D, 0x0084B2C5, 0x0084B1C5, 
        0x0082B0C3, 0x00759DAE, 0x0034474F, 0x00020203, 0x00000000, 0x00000000, 0x00010202, 0x00000000, 0x0045606B, 0x007CACBF, 0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079A9BE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x00233238, 
        0x00000000, 0x00000000, 0x00000000, 0x00314750, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B6, 0x006CA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 
        0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005993AC, 
        0x005993AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x004E879F, 0x000B1316, 0x000A1216, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C89A3, 0x004B89A3, 
        0x002E5566, 0x00000000, 0x001C343E, 0x004887A1, 0x004787A1, 0x004686A1, 0x004686A0, 0x0045859F, 0x0044849F,
  0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x00346276, 0x00000000, 0x001F3945, 0x004986A0, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA6, 0x00345B6C, 0x00000000, 0x002E515F, 0x00528EA7, 0x00528FA8, 
        0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AA, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 
        0x006199B1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB4, 0x00689DB4, 0x00689EB4, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006192A6, 0x00395561, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x000B1113, 0x001F2D33, 0x00233239, 0x000F1618, 0x0011181B, 0x006995A8, 0x0075A7BC, 0x0076A8BC, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x0075A4B7, 0x001E2A2F, 0x00000000, 0x003C535D, 0x0045606B, 
        0x00090C0E, 0x00000000, 0x00000000, 0x00101619, 0x00384C55, 0x00415963, 0x00000000, 0x00222E33, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C7, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 
        0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0095BECE, 0x0095BECF, 0x0095BECF, 0x0096BED0, 0x0097BFD0, 0x0097BFD0, 
        0x0098C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC3D3, 0x009DC3D3, 0x009DC3D3, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 
        0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCFDD, 0x00ADCFDD, 
        0x00AED0DD, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D3E1, 0x00B4D4E1, 
        0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B5D4E2, 0x00B5D4E2, 0x00B5D4E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B6D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D5E2, 0x00B5D4E2, 
        0x00B5D5E2, 0x00B5D4E1, 0x00B5D5E1, 0x00B5D4E1, 0x00B5D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D1DF, 
        0x00B0D1DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DD, 0x00AECFDE, 0x00ADCFDD, 0x00ADCEDD, 0x00ADCEDD, 0x00ACCFDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 
        0x009DC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0093BDCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0090BBCC, 
        0x0090BBCC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x005E7D8A, 0x00040506, 0x00080B0C, 0x007DA8BA, 0x0084B2C5, 0x0083B1C4, 
        0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0076A0B2, 0x00374B54, 0x00090C0E, 0x00000000, 0x000C1112, 0x006890A1, 0x007DACC0, 0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x00567A89, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0024343B, 0x005E8A9C, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 
        0x00679DB4, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x006199B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 
        0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA7, 0x0046798E, 0x00000000, 0x00243F4B, 0x00508DA6, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C89A3, 0x004986A0, 
        0x001F3944, 0x00000000, 0x00356376, 0x004887A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x0045859F, 0x0044849F,
  0x0044849F, 0x0045849F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004887A1, 0x0046849D, 0x00000101, 0x000D181C, 0x0046829B, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA6, 0x004B859E, 0x00000000, 0x001A2D35, 0x00508AA3, 0x00528EA8, 
        0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C96AE, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006099B0, 
        0x006199B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679EB4, 0x00699FB5, 0x00699FB5, 0x003C5B67, 0x0010191C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00090E0F, 0x003A5560, 0x005E899C, 0x0072A4BA, 0x0072A5BB, 0x006591A5, 0x001C292E, 0x003B555F, 0x0075A7BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x004A6774, 0x00010202, 0x00000000, 0x00000000, 
        0x00000000, 0x00253339, 0x00516F7C, 0x00719AAB, 0x0080AFC2, 0x0079A4B7, 0x00151D20, 0x00000000, 0x005C7D8B, 0x0084B1C4, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 
        0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 
        0x0098BFD0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009DC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C7D7, 
        0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCFDD, 
        0x00ADCFDD, 0x00ADCFDD, 0x00AED0DD, 0x00AECFDD, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00B0D0DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E1, 
        0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 
        0x00B4D4E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D4E1, 0x00B4D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D0DF, 
        0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDE, 0x00AED0DD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDD, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 
        0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC3D4, 0x009DC3D3, 
        0x009CC3D3, 0x009CC2D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 
        0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0084B1C2, 0x00263338, 0x00000000, 0x004B6570, 0x0084B2C5, 0x0084B2C5, 0x0083B1C4, 
        0x0082B1C4, 0x0082B0C3, 0x0081AFC3, 0x0080AFC2, 0x0080AFC2, 0x001E2A2F, 0x00000000, 0x002C3D44, 0x007DADC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BD, 0x0077A9BD, 0x0071A0B4, 0x001B272C, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000B1113, 0x00344D57, 0x006898AC, 0x006FA3B9, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 
        0x00679DB3, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 
        0x005893AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538EA8, 0x002B4B58, 0x00000000, 0x00396577, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x0047829B, 
        0x000C171C, 0x00000101, 0x0046849E, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F,
  0x0043849F, 0x0045849F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x0014262E, 0x00000000, 0x00417990, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00142329, 0x00020405, 0x004D869E, 0x00528EA7, 
        0x00528FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591AA, 0x005791AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AD, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 
        0x006199B0, 0x00629AB1, 0x00629AB1, 0x00649AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00517A8C, 0x000E1619, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00283B43, 
        0x006493A6, 0x006FA2B8, 0x0071A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A5BA, 0x005C8495, 0x00080C0D, 0x006B99AD, 0x0075A7BC, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x00709BAE, 0x000F1517, 0x00000000, 0x001A2428, 
        0x00678F9F, 0x0079A7BA, 0x007EAEC1, 0x007FAFC2, 0x0080AFC2, 0x0080AFC3, 0x0048626D, 0x00000000, 0x00101619, 0x0083B1C4, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0087B4C6, 0x0087B4C6, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 
        0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 
        0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CDDB, 0x00AACDDB, 0x00ABCDDB, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 
        0x00ACCFDC, 0x00ADCEDD, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDD, 0x00AECFDE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 
        0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D4E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B4D3E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B4D4E1, 0x00B4D3E1, 0x00B4D4E1, 0x00B4D4E1, 0x00B3D4E1, 0x00B4D4E1, 0x00B3D4E1, 
        0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD1DE, 
        0x00AFD0DE, 0x00AFD0DE, 0x00AED0DD, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A7CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C8D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 
        0x009BC2D3, 0x009BC2D3, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097C0D0, 0x0096BFD0, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 
        0x008FBACB, 0x008FB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x00648694, 0x00000000, 0x00131A1D, 0x0085B2C5, 0x0084B2C5, 0x0083B1C4, 0x0083B1C4, 
        0x0082B0C4, 0x0081B0C3, 0x0081AFC2, 0x0080AFC2, 0x00608392, 0x00070A0C, 0x00000000, 0x00638998, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A8BD, 0x004D6E7C, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1114, 0x004A6D7C, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 
        0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005D95AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005993AB, 0x005993AB, 
        0x005893AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x000B1418, 0x00080F11, 0x0044798E, 0x00508CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004B89A3, 0x004B89A3, 0x0042788F, 
        0x00000000, 0x0015282F, 0x004887A1, 0x004887A1, 0x004786A0, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F,
  0x0043849E, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A1, 0x004786A1, 0x004887A1, 0x002B5161, 0x00000000, 0x002A4F5E, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x002E505F, 0x00000000, 0x003B687A, 0x00528EA7, 
        0x00538EA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AB, 0x005994AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 
        0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00669DB3, 0x005C8DA1, 0x002A4049, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x00131D21, 0x00547B8B, 0x006EA2B8, 
        0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x002C3F47, 0x001E2B31, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x003C535D, 0x00000000, 0x00192327, 
        0x0074A0B3, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AFC2, 0x0080AFC3, 0x0076A0B2, 0x0012191C, 0x00010101, 0x004B6570, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 
        0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 
        0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 
        0x00A2C7D7, 0x00A2C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 
        0x00ACCEDC, 0x00ACCEDC, 0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AFD1DE, 0x00AFD1DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B1D2E0, 0x00B2D2E0, 
        0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E1, 0x00B3D3E0, 0x00B3D3E0, 0x00B3D3E0, 
        0x00B3D3E1, 0x00B2D3E1, 0x00B2D3E0, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD1DE, 0x00AFD1DE, 0x00AFD0DE, 
        0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC2D3, 
        0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BECF, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 
        0x008FB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008BB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0087B4C7, 0x0087B4C6, 0x00101618, 0x00000000, 0x00040506, 0x00465E69, 0x007BA5B6, 0x0083B1C4, 0x0082B1C4, 
        0x0082B0C3, 0x0081AFC3, 0x0080AFC3, 0x007DACBE, 0x0033464F, 0x00000000, 0x00222F34, 0x007DADC1, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0071A0B4, 0x0011191C, 0x00000000, 0x00010102, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001D2B31, 0x005B889A, 0x006A9FB4, 0x006CA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699EB5, 0x00699EB4, 0x00679DB4, 0x00679DB4, 
        0x00669DB3, 0x00659CB3, 0x00649CB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005B95AC, 0x005B94AD, 0x005994AC, 0x005993AC, 0x005893AB, 
        0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00487D93, 0x00000000, 0x00172830, 0x004D87A0, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B8AA4, 0x004B89A3, 0x002A4E5D, 
        0x00000000, 0x002C5161, 0x004887A1, 0x004787A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045849F, 0x0043849F,
  0x0043839E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x003A6D83, 0x00000101, 0x000F1C21, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x003F7084, 0x00000000, 0x001B2F37, 0x00528EA7, 
        0x00538EA7, 0x00538FA8, 0x005490A9, 0x005490A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 
        0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x005D90A4, 0x0034505B, 0x00080C0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121A1E, 0x00405F6D, 0x006A9DB3, 0x006DA2B7, 0x006EA2B8, 
        0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 0x006B99AD, 0x00000000, 0x004E6F7D, 0x0075A8BC, 0x0076A8BD, 0x0077A9BD, 0x0077A9BE, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x0077A5B9, 0x00080B0C, 0x00000000, 
        0x00506F7C, 0x007DACC1, 0x007EADC1, 0x007EAEC2, 0x007FAEC2, 0x0080AFC2, 0x0080AFC3, 0x004B6772, 0x00000000, 0x00161E21, 0x0077A1B2, 0x0084B2C5, 0x0084B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 
        0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 
        0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CDDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 
        0x00ABCDDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDE, 0x00AECFDE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B1D2DF, 
        0x00B1D1E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B2D3E0, 0x00B2D2E0, 0x00B3D3E0, 0x00B2D3E0, 0x00B2D3E0, 0x00B2D3E0, 
        0x00B2D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2E0, 0x00B1D2E0, 0x00B1D1DF, 0x00B0D2DF, 0x00B0D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 
        0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDC, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 
        0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 
        0x009BC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 
        0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x0048606A, 0x00000000, 0x00030405, 0x00000000, 0x00000000, 0x00151C1F, 0x004E6A75, 0x007FADC0, 
        0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x006D96A7, 0x00030405, 0x00000000, 0x006B94A5, 0x007DACC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AAABF, 0x0079AABF, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x003A535E, 0x00000000, 0x00293A42, 0x0043616D, 
        0x00374F59, 0x00131C20, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x002E444E, 0x005C889B, 0x006BA0B5, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 
        0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005994AC, 0x005993AB, 0x005893AB, 
        0x005892AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538EA7, 0x002A4855, 0x00000000, 0x00284653, 0x004F8CA6, 0x004F8CA6, 0x004E8CA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C89A3, 0x004B89A3, 0x000F1B21, 
        0x00010202, 0x003B6E83, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0045849F, 0x0043849F,
  0x0043839E, 0x0043849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004787A1, 0x00417B93, 0x000E1B20, 0x00000000, 0x00457F98, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00488098, 0x00101C21, 0x00000000, 0x00508DA6, 
        0x00528EA8, 0x00538FA8, 0x00548FA8, 0x00548FA9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 
        0x006198B0, 0x006199B0, 0x006299B0, 0x00639AB1, 0x00639AB2, 0x003E616F, 0x000B1214, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x003A5763, 0x006293A7, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 
        0x006FA2B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x000A0E10, 0x00172125, 0x006D9BAE, 0x0076A8BD, 0x0076A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x004A6774, 0x00000000, 
        0x00151D21, 0x007CACBF, 0x007DADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 0x0081B0C3, 0x001A2428, 0x00000000, 0x0048626D, 0x0083B1C5, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 
        0x0089B6C8, 0x008AB6C9, 0x008AB6C9, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0096BECF, 
        0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x0099C1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009BC3D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A1C6D6, 
        0x00A1C7D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 
        0x00AACDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCFDC, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DD, 0x00AECFDE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00AFD1DE, 0x00AFD1DE, 0x00B0D1DE, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B1D2DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B1D2E0, 0x00B2D2E0, 0x00B1D2E0, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2E0, 0x00B1D2E0, 
        0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B0D2DF, 0x00B1D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 
        0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ACCDDC, 0x00AACDDC, 0x00AACDDC, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 
        0x00A5C9D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 
        0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 
        0x008EB9CB, 0x008DB9CA, 0x008CB8C9, 0x008CB7CA, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x00759CAB, 0x000E1315, 0x00020303, 0x004F6A75, 0x0053707C, 0x000C1012, 0x00000000, 0x00020203, 0x00171F23, 
        0x005F818F, 0x0081AFC3, 0x007FAFC2, 0x002A3A40, 0x00000000, 0x0032454D, 0x007DADC1, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x00648EA0, 0x00000000, 0x0045626F, 0x0072A5B8, 0x0074A6BB, 
        0x0074A6BB, 0x006B9AAD, 0x00476875, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080D0E, 0x00324C57, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB3, 0x00669CB3, 
        0x00669CB3, 0x00649BB2, 0x00649BB2, 0x00649AB2, 0x00639AB1, 0x006299B1, 0x006299B0, 0x006099B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005892AB, 
        0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x000E191E, 0x00020405, 0x00417388, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004D8AA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x00457F98, 0x00000000, 
        0x000E1B20, 0x00417B93, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849E,
  0x0043839E, 0x0043849F, 0x0045849F, 0x0045859F, 0x004685A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x001C353F, 0x00000000, 0x002B505F, 0x004A89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004D8AA3, 0x004C879F, 0x001C313A, 0x00000000, 0x00345C6C, 
        0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B94AD, 0x005C95AD, 0x005C96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 
        0x006098B0, 0x006199B0, 0x006197AF, 0x00538295, 0x00142025, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x0019272C, 0x005C8C9F, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 
        0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x00040506, 0x00000000, 0x00486673, 0x0076A8BD, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x0078A7BB, 0x0011181B, 
        0x00000000, 0x004E6D79, 0x007DADC1, 0x007DAEC1, 0x007FAEC2, 0x007FAEC2, 0x007AA8BA, 0x00435B65, 0x00010202, 0x00000000, 0x00040506, 0x007AA5B6, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 
        0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BACC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 
        0x0096BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D2, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D9, 0x00A6CAD8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 
        0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDE, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DE, 0x00AFD0DE, 
        0x00AFD1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B1D1DF, 0x00B1D1DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D2DF, 0x00B1D1DF, 0x00B1D2DF, 0x00B1D1DF, 0x00B0D2DF, 0x00B1D2DF, 0x00B1D1DF, 0x00B1D2DF, 
        0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DE, 0x00AFD1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AECFDE, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCFDD, 
        0x00ACCEDD, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 
        0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CA, 
        0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0088B5C7, 0x0088B5C7, 0x0085B2C4, 0x003D515A, 0x00000000, 0x00080B0D, 0x0078A1B2, 0x0084B2C5, 0x0080ADC0, 0x00364A52, 0x00050708, 0x00000000, 
        0x00000000, 0x002F4148, 0x005D7F8E, 0x00000000, 0x00050809, 0x00678FA0, 0x007DACC0, 0x007CACC0, 0x007BACBF, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A8BD, 0x001B262B, 0x002F434C, 0x0075A8BC, 0x0074A6BC, 0x0074A6BB, 
        0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x006D9FB3, 0x00283B43, 0x00030505, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E1518, 0x00527C8E, 0x00669BB1, 0x00679DB4, 0x00679CB4, 0x00669CB3, 
        0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005893AB, 0x005892AB, 
        0x005792AB, 0x005691AA, 0x005691A9, 0x005591A9, 0x00548FA9, 0x00548FA8, 0x00538FA8, 0x00427388, 0x00060B0D, 0x00010303, 0x002B4C59, 0x00457A90, 0x004C879F, 0x004D8AA3, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x002A4F5E, 0x00000000, 
        0x001C353F, 0x004887A1, 0x004787A1, 0x004787A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849E, 0x0043849E,
  0x0042839E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A1, 0x004786A1, 0x004887A1, 0x002D5666, 0x00010203, 0x00111F25, 0x004A89A3, 0x004C8AA3, 0x004C8AA4, 0x00437B92, 0x00376274, 0x0025414E, 0x000D181C, 0x00000000, 0x00000000, 0x0016262D, 
        0x00518EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005791A9, 0x005892AB, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AD, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 
        0x006098B0, 0x00528195, 0x002D4752, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00172328, 0x00456978, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 
        0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x0070A4B9, 0x0070A4BA, 0x0071A4BA, 0x0072A5BA, 0x003C5762, 0x00000000, 0x00000000, 0x000C1214, 0x006F9EB0, 0x0076A8BC, 0x0077A8BD, 0x0077A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x0079A9BE, 0x004C6976, 
        0x00000000, 0x00080B0C, 0x0077A5B7, 0x007EADC1, 0x007CABBD, 0x0052717E, 0x00151E21, 0x00000000, 0x00000000, 0x000A0E10, 0x00000000, 0x002C3B42, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 
        0x0088B5C7, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BDCE, 
        0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096C0D0, 0x0097C0D0, 0x0098C0D0, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 
        0x00A0C5D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A6CAD8, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDA, 
        0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AED0DD, 0x00AECFDE, 0x00AECFDE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 
        0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD1DF, 0x00B0D1DE, 0x00B0D1DE, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 0x00B0D1DF, 
        0x00B0D1DF, 0x00B0D1DE, 0x00B0D1DE, 0x00B0D0DF, 0x00B0D1DF, 0x00AFD1DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AECFDD, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDC, 0x00ACCEDC, 
        0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDB, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 
        0x00A4C8D8, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 
        0x0099C1D1, 0x0099C0D1, 0x0098C0D0, 0x0098BFD0, 0x0097BFD0, 0x0096BED0, 0x0096BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB8CA, 
        0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x007096A6, 0x00080B0C, 0x00000000, 0x00000000, 0x000A0D0F, 0x0049636F, 0x0077A1B2, 0x0082B0C4, 0x00618492, 0x0026343A, 
        0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x002E4047, 0x007BAABD, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x006B97AA, 0x002B3D44, 0x0073A4B8, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 
        0x0073A5BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x00537A8A, 0x001F2E34, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00253840, 0x00517C8E, 0x00669DB3, 0x00669CB3, 
        0x00659CB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005893AB, 0x005893AB, 0x005792AB, 
        0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538EA7, 0x002E515F, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x000F1B20, 0x0025414E, 0x00366375, 0x00457E95, 0x004C89A3, 0x004B89A3, 0x00111F25, 0x00010203, 
        0x002E5667, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E,
  0x0042839E, 0x0043849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x00427A93, 0x00030608, 0x00060B0D, 0x003D7187, 0x00315A6B, 0x00182C34, 0x000B1418, 0x00020304, 0x00000000, 0x00000000, 0x00070C0E, 0x00000101, 0x00070D0F, 
        0x00487D94, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005791AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F97AF, 
        0x002F4A55, 0x000B1114, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070C0E, 0x00406371, 0x006194A9, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 
        0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x006A9AAE, 0x00273940, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x0030454E, 0x0076A7BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078AABE, 0x0079AABE, 0x007AAABF, 0x00709EB0, 
        0x00161F23, 0x00000000, 0x00354A53, 0x00668D9E, 0x00212E33, 0x00010202, 0x00000000, 0x000A0E0F, 0x0048626E, 0x00628594, 0x000F1517, 0x00000000, 0x00567581, 0x0084B1C5, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 
        0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACB, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 
        0x0094BDCF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0099C0D1, 0x0099C0D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 
        0x009FC6D5, 0x00A0C6D5, 0x00A1C6D5, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 
        0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00ABCDDB, 0x00AACDDB, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ADCEDD, 0x00ACCEDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00ADCFDE, 
        0x00AECFDD, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 
        0x00AFD0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AECFDE, 0x00AECFDD, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCEDD, 0x00ACCFDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCDDC, 
        0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C8D8, 0x00A4C8D8, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 
        0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0096BFD0, 0x0097BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 
        0x008DB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B4C7, 0x0087B4C7, 0x00243035, 0x00000000, 0x003D525B, 0x00304148, 0x00000000, 0x00000000, 0x00151D20, 0x004F6A77, 0x0081B0C3, 0x007DAABC, 
        0x005B7D8B, 0x00182125, 0x00000000, 0x00030405, 0x00648B9B, 0x007CACC0, 0x007CACC0, 0x007CABC0, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0074A5B9, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 
        0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x006FA3B9, 0x006FA2B8, 0x006A9DB2, 0x004D7281, 0x0010181B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090B, 0x00273C45, 0x005F94A9, 
        0x00659BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006099B0, 0x006098B0, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005892AB, 0x005792AA, 
        0x005791AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x004F89A1, 0x001A2E36, 0x00000000, 0x00366071, 0x00213B46, 0x00040809, 0x00000000, 0x00000000, 0x00020405, 0x000D171C, 0x00192F37, 0x002A4D5C, 0x0004090A, 0x00030608, 
        0x00417B94, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0044849E, 0x0042839E,
  0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x00122128, 0x00000000, 0x00010303, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x00182B33, 0x00366273, 0x004F8CA6, 0x001C323B, 0x00000000, 
        0x00325968, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x00528BA2, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x00487485, 0x00090F11, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x002B424C, 0x006298AD, 0x00659CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006CA0B6, 0x006CA0B7, 0x006CA1B7, 
        0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x0070A3B9, 0x00446471, 0x00030505, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x005F8899, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x007AABBF, 
        0x00496672, 0x00000101, 0x00000101, 0x00010203, 0x00000000, 0x00000101, 0x002A3A40, 0x0075A0B2, 0x0080AFC3, 0x0076A1B4, 0x001C262A, 0x00000000, 0x00151D20, 0x0078A2B4, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 
        0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 
        0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC2D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 
        0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D9, 0x00A5CAD9, 0x00A6C9D9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CBDA, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 
        0x00ADCFDD, 0x00AECFDD, 0x00AECFDE, 0x00AECFDD, 0x00AED0DE, 0x00AECFDD, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 0x00AFD0DE, 0x00AFD0DE, 0x00AED0DE, 
        0x00AED0DE, 0x00AED0DD, 0x00AECFDE, 0x00AECFDD, 0x00AED0DE, 0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDB, 
        0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 
        0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009CC3D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 
        0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 
        0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B4C7, 0x0087B4C7, 0x00506C76, 0x00000000, 0x00131A1D, 0x0077A1B2, 0x0083B1C4, 0x00618392, 0x000E1416, 0x00000000, 0x00000000, 0x001D272C, 0x006D95A6, 
        0x0079A6B8, 0x00202C31, 0x00000000, 0x002D3F46, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0073A6BB, 0x0073A6BB, 
        0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x003A5662, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 
        0x003D5E6C, 0x00629AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005892AB, 0x005792AA, 
        0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00487E94, 0x00030607, 0x000F1B20, 0x00508DA6, 0x00508CA6, 0x004B879F, 0x00366173, 0x0015272E, 0x00010303, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00122228, 
        0x004888A1, 0x004787A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043839E, 0x0043839E,
  0x0042839E, 0x0042839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x002F586A, 0x00000000, 0x00010303, 0x000B1519, 0x00172A33, 0x002F5666, 0x0048829A, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x00407084, 0x00000000, 
        0x001E343D, 0x00508BA3, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005691AA, 0x0047788C, 0x00070D0F, 0x0050869C, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005B94AD, 0x005B95AD, 0x004A788C, 0x001F333B, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020404, 0x0019282E, 0x004D788A, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 
        0x006DA1B7, 0x006C9FB5, 0x0052798A, 0x001A262C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001A252A, 0x0075A7BB, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078AABE, 0x0079AABE, 0x007AABBF, 
        0x007AABBF, 0x00141C20, 0x00000000, 0x00000000, 0x001A2428, 0x00557683, 0x007EAEC1, 0x0076A2B5, 0x004D6A76, 0x00090D0E, 0x00000000, 0x00000000, 0x00000000, 0x00435B65, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 
        0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 
        0x0093BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 
        0x009EC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CAD9, 
        0x00A7CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDD, 
        0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00AECFDD, 0x00AECFDD, 0x00AECFDD, 0x00AECFDD, 0x00AECFDE, 0x00AECFDE, 0x00AED0DD, 0x00AECFDD, 0x00AECFDE, 0x00AECFDE, 0x00AECFDE, 0x00AECFDD, 0x00ADCFDD, 0x00AECFDD, 
        0x00AECFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCEDD, 0x00ADCFDD, 0x00ADCEDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDB, 0x00AACDDB, 
        0x00AACCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 
        0x00A2C7D7, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D3, 0x009CC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 0x009AC1D1, 0x0098C0D1, 0x0098C0D1, 
        0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 
        0x008CB8C9, 0x008BB7C9, 0x008BB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x00769EAE, 0x00060809, 0x00000000, 0x00000000, 0x0029373D, 0x00678A99, 0x0083B1C4, 0x0081B0C3, 0x003F555E, 0x000E1315, 0x00000000, 0x00000000, 
        0x00222F34, 0x00000000, 0x00060809, 0x0077A5B8, 0x007DACC0, 0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AABBE, 0x0079AABF, 0x0079AABE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 
        0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA1B6, 0x005F8FA2, 0x0023353C, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x0018252B, 0x004A7485, 0x006096AD, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A93AC, 0x005993AB, 0x005893AB, 0x005792AB, 0x005792AA, 
        0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA7, 0x00355C6D, 0x00000000, 0x00305665, 0x00508DA6, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x0048829B, 0x002E5464, 0x00162830, 0x00030607, 0x00000000, 0x0030596A, 
        0x004887A1, 0x004786A1, 0x004686A1, 0x004685A0, 0x0045859F, 0x0045859F, 0x0044849F, 0x0043839E, 0x0042839E,
  0x0041839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A1, 0x004887A1, 0x0046849F, 0x00000000, 0x00070D0F, 0x003D7186, 0x004B89A3, 0x004C89A4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x000A1114, 
        0x00060C0E, 0x004A8198, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005691A9, 0x005691AA, 0x001D3038, 0x001C2E36, 0x005690A8, 0x005993AC, 0x005A94AC, 0x00477486, 0x00223841, 0x00060B0C, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00141F24, 0x00436979, 0x006098AE, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 
        0x00588395, 0x0024363D, 0x00030505, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x00212F35, 0x0010181B, 0x00000000, 0x004D6E7B, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 
        0x007AABBF, 0x00648B9B, 0x00000000, 0x00000000, 0x00628797, 0x007DADC1, 0x00567885, 0x001C262B, 0x00000000, 0x00000000, 0x001E292E, 0x00506D79, 0x00020203, 0x00050607, 0x006D93A3, 0x0084B2C4, 0x0085B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B4C6, 
        0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB5C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x008FBBCC, 0x0091BBCD, 0x0091BBCC, 0x0091BCCD, 0x0092BCCD, 
        0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009DC4D4, 
        0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D6, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 
        0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDD, 0x00ADCEDD, 0x00ACCFDD, 0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCFDD, 0x00ADCFDD, 0x00ADCFDD, 0x00ACCFDD, 
        0x00ADCEDD, 0x00ACCEDD, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDC, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00A9CDDB, 0x00A9CCDB, 0x00A9CCDB, 
        0x00A9CCDA, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBD9, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C8D7, 0x00A2C7D7, 0x00A2C6D6, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098BFD0, 
        0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCC, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 
        0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0084B0C3, 0x00304148, 0x00000000, 0x00131A1D, 0x000B0F10, 0x00000000, 0x00060809, 0x00314249, 0x006F96A7, 0x0081B0C3, 0x006E96A7, 0x0034474F, 0x00020303, 
        0x00000000, 0x00000000, 0x004E6D79, 0x007DADC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 
        0x0072A4BA, 0x0071A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 0x00699FB6, 0x004F7788, 0x001F2F36, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00010303, 0x0020333B, 0x004F7E90, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x00568EA5, 0x004E8196, 0x005993AB, 0x005893AB, 0x005792AA, 0x005791AA, 
        0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00111D22, 0x00020405, 0x00457B91, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004C8BA4, 0x004C8AA4, 0x004B89A3, 0x00457F97, 0x000A1216, 0x00000101, 0x0046849E, 
        0x004887A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E,
  0x0042829D, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004887A1, 0x004887A1, 0x001A313B, 0x00000000, 0x0039697D, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004F8CA5, 0x004F8CA6, 0x002B4C5A, 
        0x00000000, 0x00376273, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x005691AA, 0x0049798E, 0x0005090A, 0x00080D0F, 0x001C2F36, 0x000F191E, 0x00020405, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00385866, 0x005E95AC, 0x006199B1, 0x00629AB1, 0x00629AB1, 0x00639BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669DB3, 0x00679DB3, 0x00679EB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x00314A54, 
        0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x00425F6B, 0x006D9DB1, 0x0070A2B6, 0x0070A0B5, 0x003B555F, 0x00141C20, 0x006F9EB2, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 
        0x007AAABF, 0x007BABBF, 0x00374D56, 0x00000000, 0x00192226, 0x0028373D, 0x00000101, 0x00000000, 0x00030405, 0x004B6773, 0x007BA9BC, 0x0081AFC3, 0x00374B53, 0x00000000, 0x00141B1E, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B2C6, 0x0086B3C6, 
        0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008FB9CB, 0x008FBACB, 0x008FBACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 
        0x0093BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C0D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 
        0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CADA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDB, 0x00AACDDB, 0x00A9CDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 
        0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDD, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 
        0x00ACCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A8CBDA, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A2C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 
        0x00A0C6D5, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009CC3D3, 0x009CC3D3, 0x009BC3D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 
        0x0097BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 
        0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B4C7, 0x0087B4C6, 0x0061818E, 0x00000000, 0x00010101, 0x00779FB0, 0x0077A0B1, 0x0027353B, 0x00000000, 0x00000000, 0x00060809, 0x003E545E, 0x0080AFC3, 0x007FAEC2, 0x00253339, 
        0x00000000, 0x001D292E, 0x0075A2B5, 0x007CADC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 
        0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00659AAF, 0x00486E7D, 0x0006090A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x002B444F, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x00355866, 0x00101B20, 0x005893AB, 0x005892AB, 0x005791AA, 0x005691AA, 
        0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00528FA8, 0x00477C92, 0x00000000, 0x00182B33, 0x004C869F, 0x004F8CA6, 0x004F8CA6, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x0039697D, 0x00000000, 0x001A323B, 0x004887A1, 
        0x004887A1, 0x004786A0, 0x004686A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E,
  0x0041829D, 0x0042839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x0036667A, 0x00000000, 0x001D353F, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA6, 0x00457A90, 
        0x00000000, 0x0014242B, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x00558FA8, 0x0026404B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040708, 
        0x0020333B, 0x00598EA4, 0x005F98AF, 0x006198B0, 0x006199B0, 0x006199B1, 0x00629AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x006599AE, 0x00496E7D, 0x000A0F11, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080C0E, 0x002F454E, 0x006D9FB3, 0x0071A4BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0070A1B5, 0x001C282D, 0x00476673, 0x0076A8BC, 0x0076A8BD, 0x0077A9BE, 0x0078A9BE, 0x0078AABE, 
        0x007AAABF, 0x007AABBF, 0x006B96A7, 0x000D1315, 0x00000000, 0x00000000, 0x00080B0C, 0x0033474F, 0x007CABBD, 0x007FAEC2, 0x006E96A7, 0x0031434B, 0x00000000, 0x00000000, 0x00000000, 0x003C5159, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 
        0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCD, 0x0091BBCD, 
        0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 
        0x009DC3D4, 0x009DC3D4, 0x009EC4D4, 0x009EC5D4, 0x009EC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A1C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A5C9D8, 0x00A6C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A8CBD9, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDC, 
        0x00ABCDDC, 0x00AACDDC, 0x00ABCDDB, 0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ACCEDC, 0x00ACCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCEDC, 
        0x00ABCDDC, 0x00ABCEDC, 0x00ABCEDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00ABCDDC, 0x00AACDDC, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00A9CDDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDA, 0x00A8CBDA, 0x00A8CBDA, 
        0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD8, 0x00A5C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 
        0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 
        0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0094BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x008FBACC, 0x008FBACB, 0x008FBACB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008BB7C9, 0x008BB7C9, 
        0x008BB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x007EA8BA, 0x000E1315, 0x00000000, 0x00536F7C, 0x0085B2C5, 0x0083B2C4, 0x0083B1C4, 0x0060818F, 0x00141B1E, 0x00000000, 0x00000000, 0x001A2327, 0x0048626E, 0x00010202, 
        0x00030506, 0x00557683, 0x007DACC1, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 
        0x0071A4BA, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA1B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00669DB4, 0x002B424B, 0x00050809, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070B0D, 0x00406878, 0x00598EA5, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005B95AC, 0x004D7F94, 0x000D1519, 0x00416C7E, 0x005893AB, 0x005892AB, 0x005791AA, 0x005691AA, 
        0x005691A9, 0x005490A9, 0x005490A9, 0x00538FA8, 0x00528EA7, 0x00233C47, 0x00000000, 0x002E515F, 0x004F8DA6, 0x004F8CA6, 0x004F8CA5, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x001C353F, 0x00000000, 0x0036667B, 0x004887A1, 
        0x004887A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839F, 0x0042839E, 0x0041829D,
  0x0041829D, 0x0042839D, 0x0042839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x00427C95, 0x00091215, 0x00010203, 0x004987A0, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8CA5, 0x004F8CA5, 0x004B859E, 
        0x00172830, 0x00000000, 0x00487E95, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591AA, 0x005691AA, 0x004C8095, 0x00070C0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001C2E35, 0x00446E80, 
        0x005E96AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006198B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00689EB4, 0x004A7181, 0x001E2D33, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x002A3E46, 0x00588293, 0x006FA3B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x00577C8C, 0x00070B0C, 0x006C9AAD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 
        0x0079AABE, 0x0079AABF, 0x007AABBF, 0x00415A65, 0x00000000, 0x00030506, 0x004F6E7B, 0x007EADC1, 0x00719CAD, 0x003A5059, 0x000B0F11, 0x00000000, 0x00000000, 0x00222E34, 0x00010101, 0x00050607, 0x0060818F, 0x0084B2C5, 0x0084B2C5, 0x0085B2C5, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 
        0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D3, 0x009CC2D3, 
        0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A1C6D5, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A4C9D8, 
        0x00A4C9D8, 0x00A5C9D8, 0x00A5CAD8, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CADA, 0x00A7CBD9, 0x00A8CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CDDB, 
        0x00A9CCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDB, 0x00AACDDB, 0x00AACDDC, 0x00AACDDC, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDC, 0x00AACDDC, 0x00AACDDC, 0x00AACDDB, 0x00AACDDC, 0x00AACDDB, 
        0x00ABCDDB, 0x00AACDDB, 0x00AACDDB, 0x00ABCDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 
        0x00A6CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D9, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 
        0x0095BECF, 0x0095BECF, 0x0094BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BBCD, 0x0092BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FB9CB, 0x008EB9CB, 0x008DB9CB, 0x008DB8CA, 0x008DB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008AB6C8, 0x008AB5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0028363C, 0x00000000, 0x002C3B41, 0x0083AFC2, 0x0084B2C5, 0x0083B1C5, 0x0083B1C4, 0x0082B0C4, 0x0076A2B3, 0x003F5660, 0x00060809, 0x00000000, 0x00000000, 0x00000000, 
        0x0026343B, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4B9, 
        0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00527F92, 0x00263A43, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0018282E, 0x003A5E6C, 0x00558AA0, 0x005B95AD, 0x00426C7E, 0x00121D22, 0x001B2D34, 0x005790A8, 0x005892AB, 0x005792AA, 0x005692AA, 0x005690AA, 
        0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x004F89A1, 0x00070C0E, 0x00060A0C, 0x0045798F, 0x004F8DA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004A87A1, 0x00010202, 0x00091215, 0x00427C95, 0x004787A1, 
        0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D,
  0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004786A1, 0x0047859F, 0x001E3742, 0x00000000, 0x002F5868, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 
        0x002D505F, 0x00000000, 0x00223C46, 0x00518EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005792AA, 0x0030515F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090B, 0x003E6576, 0x005890A6, 0x005D96AE, 
        0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006099B0, 0x006199B0, 0x006199B0, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x005C8DA2, 0x001F2F36, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00131D21, 0x00578091, 0x006C9FB5, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x00233339, 0x00212F35, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 
        0x0079AABE, 0x0079AABE, 0x007AABBF, 0x0079A8BC, 0x00131A1E, 0x00000000, 0x002D3E46, 0x00405963, 0x000B1012, 0x00000000, 0x00000000, 0x000E1316, 0x005C7E8B, 0x0080AEC2, 0x00394D56, 0x00000000, 0x001A2327, 0x007BA6B9, 0x0084B2C5, 0x0084B2C5, 
        0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0091BBCC, 
        0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x009AC1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 
        0x009BC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D4, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C8D7, 0x00A3C8D7, 0x00A3C8D7, 
        0x00A4C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CBD9, 0x00A7CBD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A9CCDA, 
        0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00A9CDDB, 0x00AACCDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00AACDDB, 0x00AACDDB, 0x00AACCDB, 0x00AACDDB, 0x00AACCDB, 
        0x00A9CCDB, 0x00A9CDDB, 0x00A9CCDB, 0x00A9CCDB, 0x00AACCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 
        0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D3, 0x009DC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0095BECF, 
        0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACB, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB7C9, 0x008AB6C8, 
        0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x00465E68, 0x00000000, 0x000F1416, 0x007096A6, 0x0084B2C5, 0x0084B1C5, 0x0083B1C4, 0x0082B0C4, 0x0081B0C4, 0x0081B0C3, 0x007EADC1, 0x006F98A8, 0x00202C31, 0x00000000, 0x00000101, 
        0x00729EB1, 0x007DADC0, 0x007CACC0, 0x007BACBF, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 
        0x0070A4B9, 0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B6, 0x006CA1B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x006197AD, 0x00507D90, 
        0x00142025, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x00090F11, 0x000B1114, 0x00040708, 0x00040809, 0x00447082, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005591A9, 
        0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00355B6C, 0x00010202, 0x0016272E, 0x00508DA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x002F5668, 0x00000000, 0x001E3742, 0x0047859F, 0x004787A1, 
        0x004786A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043839F, 0x0043839E, 0x0041829E, 0x0041829D,
  0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x00305B6D, 0x00010303, 0x000D191E, 0x004A89A3, 0x004B8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 
        0x0044778D, 0x00060C0E, 0x00060A0C, 0x004F8AA3, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x000D161A, 0x00000000, 0x00000000, 0x000B1215, 0x00518499, 0x005B95AD, 0x005C95AD, 0x005D96AE, 
        0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x006196AB, 0x003C5C6A, 0x00030405, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00060A0B, 0x003F5E6B, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BA, 0x0074A6BB, 0x004E717F, 0x00000000, 0x00557887, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 
        0x0078AABE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x00638B9B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090D0F, 0x00455F6A, 0x007FAFC2, 0x0080AFC2, 0x0081AFC3, 0x0081B0C3, 0x00192226, 0x00000000, 0x003A4F57, 0x0084B1C5, 0x0084B2C5, 
        0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB9CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 
        0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0093BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0095BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 
        0x009BC2D2, 0x009BC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D3, 0x009DC3D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A5C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5CAD9, 0x00A6C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 
        0x00A8CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 
        0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CADA, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A6C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D4, 0x009FC5D5, 
        0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009BC3D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 
        0x0094BECE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 
        0x0089B6C8, 0x0089B5C7, 0x0088B5C7, 0x0087B4C7, 0x006A8E9D, 0x000B0E10, 0x00000000, 0x00374B52, 0x0084B2C5, 0x0084B2C5, 0x0083B1C4, 0x0082B0C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x0076A1B4, 0x0006090A, 0x00000000, 0x004F6D79, 
        0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078AABE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 
        0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006EA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB1, 
        0x00639AB1, 0x00375764, 0x00060A0C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001F333C, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 
        0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528DA6, 0x001C3139, 0x00000000, 0x00396577, 0x00508CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x000D181D, 0x00010303, 0x00305B6D, 0x004887A1, 0x004786A1, 
        0x004686A1, 0x004685A0, 0x004585A0, 0x0044859F, 0x0043849F, 0x0043849E, 0x0042839E, 0x0041829D, 0x0041829D,
  0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x00427D95, 0x00081013, 0x00010303, 0x003D7186, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 
        0x004F8CA6, 0x00172930, 0x00000101, 0x00335969, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005692AA, 0x00457286, 0x00000000, 0x00000000, 0x00467486, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 
        0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x006197AF, 0x00426776, 0x00131E22, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070A0C, 0x002E454E, 
        0x006090A4, 0x006CA0B6, 0x006CA1B6, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x004F7180, 0x00000000, 0x00202E34, 0x0071A2B5, 0x0077A8BD, 0x0077A9BD, 
        0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x003C545E, 0x00000000, 0x00000000, 0x002B3B42, 0x006E97A9, 0x007EAEC1, 0x007FAEC2, 0x0080AFC2, 0x0080AFC3, 0x0081AFC3, 0x006E97A7, 0x000C1012, 0x00000000, 0x00516D79, 0x0084B2C5, 
        0x0084B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACC, 
        0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BED0, 0x0096BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 
        0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A1C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D7, 0x00A2C7D7, 
        0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A6C9D9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CBD9, 0x00A7CBD9, 
        0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CCDA, 0x00A8CCDA, 0x00A8CBDA, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A9CCDB, 0x00A9CCDA, 0x00A8CCDA, 0x00A9CCDB, 0x00A9CCDA, 0x00A9CCDA, 0x00A8CCDA, 
        0x00A8CCDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD8, 0x00A5C9D8, 
        0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 
        0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009AC2D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D2, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 
        0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 
        0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0082ADBF, 0x00202B30, 0x00000000, 0x00000000, 0x00020303, 0x003A4E57, 0x0078A3B5, 0x0083B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x00222F34, 0x00000000, 0x0026343B, 0x007CACC0, 
        0x007CACC0, 0x007BACC0, 0x007BABC0, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0072A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 
        0x0070A3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 0x00649CB3, 0x00649BB2, 0x00639BB2, 0x00639AB1, 
        0x00629AB1, 0x006199B0, 0x00578A9E, 0x0029404A, 0x00060A0B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040809, 0x0051869C, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 
        0x005490A9, 0x00538FA8, 0x00538FA8, 0x00467A90, 0x00080D10, 0x00080F12, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x003C7086, 0x00010303, 0x00081013, 0x00427D95, 0x004887A1, 0x004786A1, 
        0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0040829D,
  0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x001C343E, 0x00000000, 0x0022404C, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 
        0x004F8CA6, 0x003D6B7E, 0x00000000, 0x001A2E37, 0x00508BA3, 0x00528FA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x00558FA7, 0x00213841, 0x00000000, 0x005790A9, 0x005A94AC, 0x005B95AC, 0x005B95AC, 0x005C95AD, 
        0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x004C788A, 0x0018252B, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00253940, 0x00578497, 0x00699FB5, 
        0x006B9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x00202F35, 0x00000000, 0x00000000, 0x00527583, 0x0076A8BC, 0x0077A8BD, 
        0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x007AAABE, 0x007AABBF, 0x0072A0B3, 0x001B262A, 0x00000000, 0x0027363C, 0x007DADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AFC2, 0x0081AFC3, 0x0081AFC3, 0x004F6A76, 0x00030404, 0x0007090A, 0x00638594, 
        0x0084B2C5, 0x0084B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B4C7, 0x0088B5C7, 0x0088B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008CB7C9, 0x008CB8C9, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 
        0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 0x0095BECE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C0D1, 0x0099C1D2, 
        0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D4, 0x009DC4D3, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 
        0x00A2C6D6, 0x00A2C7D6, 0x00A3C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A5C9D8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A7CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A8CBDA, 0x00A7CBDA, 
        0x00A7CBDA, 0x00A8CBDA, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CBD9, 0x00A7CBD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C8D8, 0x00A4C9D8, 
        0x00A4C8D7, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 
        0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BED0, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 
        0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CA, 0x008EB9CB, 0x008DB8CA, 0x008CB8C9, 0x008CB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 
        0x0088B5C7, 0x0088B4C7, 0x0087B4C6, 0x00314248, 0x00000000, 0x00222E32, 0x004D6873, 0x00000000, 0x00000000, 0x00161D21, 0x00658A98, 0x0082B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x00435C66, 0x00000000, 0x000A0E10, 0x00658C9C, 0x007DACC0, 
        0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0074A6BC, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 
        0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA0B7, 0x006BA0B6, 0x006AA0B6, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00669CB4, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 
        0x00629AB1, 0x006199B0, 0x006098B0, 0x006098AF, 0x004F7E92, 0x001E3138, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00375C6B, 0x005993AB, 0x005892AA, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005590A9, 
        0x005490A9, 0x00538FA8, 0x00528EA7, 0x00335868, 0x00000000, 0x00305463, 0x00508DA6, 0x004F8CA6, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00223F4B, 0x00000000, 0x001C343E, 0x004887A2, 0x004787A1, 0x004786A0, 
        0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839D, 0x0041829D, 0x0040819D,
  0x0040819C, 0x0040829D, 0x0041839D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x003B6E83, 0x00000000, 0x000F1D22, 0x00447E96, 0x004B89A3, 0x004C8AA3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 
        0x004F8BA5, 0x004F8CA6, 0x000B1418, 0x0005090B, 0x0043778C, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x00457488, 0x00020404, 0x0047768A, 0x005A93AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 
        0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x005A8FA5, 0x00263C45, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090E10, 0x004B7384, 0x00689EB4, 0x00699EB5, 0x00699FB5, 
        0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x006D9EB2, 0x002F444C, 0x00000101, 0x00000000, 0x00000000, 0x000C1113, 0x0076A8BC, 0x0076A8BC, 
        0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABF, 0x007AAABF, 0x007AABBF, 0x00587B89, 0x00060809, 0x00010203, 0x004C6A76, 0x007DADC1, 0x007EADC1, 0x007EAEC2, 0x0080AEC2, 0x0080AEC2, 0x0080AFC3, 0x007FAEC1, 0x00182124, 0x00000000, 0x00192225, 
        0x0077A1B2, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B4C6, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008EB8CB, 0x008EB9CB, 0x008EB9CB, 
        0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCD, 0x0093BDCE, 0x0093BDCE, 0x0095BDCE, 0x0095BDCE, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C1D1, 
        0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A1C6D6, 
        0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C9D8, 0x00A4C8D7, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A5CAD8, 0x00A5CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CBDA, 0x00A7CBD9, 0x00A7CAD9, 0x00A7CBD9, 0x00A7CAD9, 
        0x00A7CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A5CAD9, 0x00A6CAD9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D7, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 
        0x009CC3D3, 0x009CC3D3, 0x009BC3D2, 0x009BC2D2, 0x009BC2D2, 0x009AC1D1, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCE, 0x0093BCCE, 
        0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 
        0x0088B5C7, 0x0087B4C7, 0x004A636D, 0x00000000, 0x000B0F11, 0x006D91A1, 0x0084B2C5, 0x00698E9D, 0x000F1517, 0x00000000, 0x00040506, 0x004D6A75, 0x007EACC0, 0x0080AFC2, 0x00678C9C, 0x000B1012, 0x00000000, 0x003E555F, 0x007DADC0, 0x007CACC0, 
        0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0072A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 
        0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x006299B1, 
        0x006299B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005E97AF, 0x005E97AE, 0x003C6170, 0x00010102, 0x00000000, 0x00000000, 0x00000000, 0x00142127, 0x005791A8, 0x005993AB, 0x005892AB, 0x005792AA, 0x005692AA, 0x005691AA, 0x005590A9, 0x005590A9, 
        0x00548FA8, 0x00538FA8, 0x00528FA7, 0x000F1A1E, 0x00030607, 0x004A839A, 0x00508CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x00457E96, 0x000F1D23, 0x00000000, 0x003B6E84, 0x004787A1, 0x004786A1, 0x004686A0, 
        0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0040829D, 0x0040829C,
  0x0040819C, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0044849E, 0x0044849F, 0x0044849F, 0x004685A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004887A2, 0x000C171B, 0x00000101, 0x0039687C, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 
        0x004E8CA5, 0x004F8CA6, 0x00335B6B, 0x00000000, 0x002D505E, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x00233943, 0x0016252B, 0x005993AC, 0x005A94AC, 0x005B94AD, 0x005B95AD, 
        0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x00578BA1, 0x003B5E6D, 0x000A1012, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000B1114, 0x00334E5A, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 
        0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA1B6, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B8, 0x006C9FB3, 0x00517686, 0x00162024, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00384F59, 0x0076A8BD, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x00344850, 0x00000000, 0x00101618, 0x006C95A7, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AFC2, 0x006B92A2, 0x0026343A, 0x00000000, 0x00000000, 0x00000000, 
        0x0032444B, 0x0083B1C4, 0x0084B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 
        0x008FB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0093BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0098BFD0, 0x0098C0D0, 0x0098C0D1, 
        0x0099C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A5CAD9, 0x00A5C9D9, 0x00A6CAD8, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A7CAD9, 0x00A6CAD9, 0x00A6CAD9, 
        0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6CAD9, 0x00A6C9D9, 0x00A6CAD9, 0x00A5CAD8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC4D5, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D3, 0x009CC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BED0, 0x0096BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0093BCCE, 0x0093BDCE, 
        0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 
        0x0088B4C7, 0x00658694, 0x00060809, 0x00010202, 0x004F6A75, 0x0084B2C5, 0x0084B2C5, 0x0083B1C4, 0x0077A1B2, 0x002A393F, 0x00000000, 0x00000000, 0x00304249, 0x0069909F, 0x0027353C, 0x00000000, 0x001D282C, 0x007DADC1, 0x007CACC0, 0x007CACC0, 
        0x007BABC0, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A8BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 
        0x006FA3B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 
        0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x00406878, 0x00040708, 0x00000000, 0x00020404, 0x00416B7D, 0x005993AC, 0x005893AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005490A9, 0x005490A8, 
        0x00538FA8, 0x00538FA8, 0x00406F83, 0x00000000, 0x00203943, 0x004E8AA3, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x0038677B, 0x00000101, 0x000C181C, 0x004887A2, 0x004787A1, 0x004786A1, 0x004686A0, 
        0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819C,
  0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x00325D6F, 0x00000000, 0x00203C47, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA5, 
        0x004E8BA5, 0x004F8CA5, 0x004A839C, 0x00080E10, 0x00070C0E, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x00538BA2, 0x00040608, 0x00395F6F, 0x005A94AC, 0x005A94AC, 0x005B95AD, 
        0x005C95AD, 0x005C96AE, 0x005D96AE, 0x003D6272, 0x00142025, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002E4853, 0x0057879A, 0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 
        0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006FA2B8, 0x00598394, 0x00223138, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030505, 0x00608B9B, 
        0x0076A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078AABE, 0x0079AABE, 0x0079AABF, 0x007AABBF, 0x0079A8BC, 0x001A2529, 0x00000000, 0x0027363C, 0x007DADC1, 0x007EADC1, 0x007EAEC2, 0x004E6B77, 0x000F1518, 0x00000000, 0x00060809, 0x0048626D, 0x00141C1F, 
        0x00000000, 0x003E535D, 0x0084B2C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 
        0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BACC, 0x0091BBCC, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 
        0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D5, 0x009FC5D5, 
        0x009FC5D5, 0x00A0C5D5, 0x00A1C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D8, 
        0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D9, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 
        0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A3C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 
        0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A1C6D5, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 
        0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 
        0x0092BBCD, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 
        0x007AA3B5, 0x0013191C, 0x00000000, 0x003E535C, 0x0084B2C5, 0x0084B2C5, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x007FADC0, 0x00516F7B, 0x00090D0E, 0x00000000, 0x000B1012, 0x00000000, 0x000A0E10, 0x00709CAE, 0x007DACC0, 0x007CACC0, 0x007BACBF, 
        0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A6BC, 0x0074A7BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA2B8, 
        0x006EA2B8, 0x006DA1B8, 0x006DA1B7, 0x006CA0B7, 0x006CA0B6, 0x006B9FB5, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB0, 0x006199B0, 
        0x006199B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D95AD, 0x005C95AD, 0x00132025, 0x00000000, 0x001B2D34, 0x005790A8, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005490A9, 0x005490A8, 
        0x00538FA8, 0x00528EA8, 0x00121F24, 0x00010303, 0x00396577, 0x00508CA6, 0x004F8CA5, 0x004E8CA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00203B46, 0x00000000, 0x00325E70, 0x004887A1, 0x004787A1, 0x004686A0, 0x004686A0, 
        0x004585A0, 0x0044859F, 0x0044849F, 0x0043839F, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C,
  0x003F819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x0044819B, 0x00070D10, 0x00010203, 0x0048859F, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 
        0x004E8BA5, 0x004F8BA5, 0x004E8AA3, 0x00264450, 0x00000000, 0x00345C6C, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005892AB, 0x003C6476, 0x000A1013, 0x0050849A, 0x005A94AC, 0x005A94AC, 
        0x005C95AD, 0x004F8195, 0x0016242A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0017252B, 0x0057879C, 0x006299B0, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00679EB4, 0x00689EB4, 
        0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B7, 0x006DA1B7, 0x006B9EB4, 0x002D434C, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0025353B, 
        0x0075A7BB, 0x0077A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x006E99AB, 0x00050809, 0x00000000, 0x00435D68, 0x007DADC1, 0x00384E57, 0x00020404, 0x00000000, 0x00171F23, 0x006D95A6, 0x0081AFC3, 0x005E7F8D, 
        0x00060909, 0x00010202, 0x004D6874, 0x0084B2C5, 0x0084B2C5, 0x0085B2C6, 0x0086B3C5, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C7, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 
        0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0091BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 
        0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 
        0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D8, 
        0x00A4C8D7, 0x00A4C8D8, 0x00A4C9D7, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A5C9D8, 0x00A4C9D8, 0x00A4C9D8, 
        0x00A4C9D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 
        0x009AC2D2, 0x009AC2D2, 0x0099C1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 
        0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 
        0x001A2427, 0x00000000, 0x002A393F, 0x0085B2C5, 0x0084B2C5, 0x0084B1C4, 0x0083B1C4, 0x0082B1C4, 0x0081B0C3, 0x0081B0C3, 0x0081AFC3, 0x00678D9C, 0x000F1518, 0x00000000, 0x00000000, 0x00577987, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007BABBF, 
        0x007AABBF, 0x007AABBE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 
        0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB0, 0x006299B1, 0x006199B0, 
        0x006099B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C94AD, 0x0017262C, 0x00010202, 0x0049788C, 0x005893AB, 0x005893AB, 0x005892AB, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 
        0x00538FA8, 0x00407084, 0x00000101, 0x000F1B20, 0x004D87A0, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x0048859F, 0x00010202, 0x00070E11, 0x0044819B, 0x004887A1, 0x004786A0, 0x004686A0, 0x004685A0, 
        0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042829D, 0x0041829D, 0x0041829D, 0x0040819C, 0x003F819C,
  0x003F809C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004787A1, 0x0047859F, 0x0022404C, 0x00000000, 0x002A4E5D, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8BA4, 
        0x004D8BA4, 0x004E8CA5, 0x004F8CA5, 0x003D6C80, 0x00040809, 0x000A1114, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x0015242A, 0x000B1316, 0x00375A69, 0x003E6576, 
        0x001D3138, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1417, 0x003C5E6D, 0x006299B1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 
        0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006697AC, 0x00476A78, 0x00090D0F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090E10, 0x0025363D, 0x00537888, 0x005E8798, 0x00324851, 0x00070B0C, 
        0x00567B8A, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x007AABBF, 0x007BABBF, 0x004E6C79, 0x00010202, 0x00000000, 0x001E2A2F, 0x00000000, 0x00050708, 0x0031434B, 0x0079A5B8, 0x0080AFC3, 0x0080AFC3, 0x0081B0C3, 
        0x00435B66, 0x00000000, 0x00080B0D, 0x00638594, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 
        0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCE, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0096BFD0, 
        0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0099C1D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 
        0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D8, 0x00A4C8D7, 0x00A4C8D7, 0x00A4C8D8, 0x00A4C8D7, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C9D8, 0x00A4C8D8, 0x00A4C8D8, 0x00A4C9D8, 0x00A4C8D7, 0x00A4C9D7, 
        0x00A4C8D8, 0x00A4C8D7, 0x00A4C8D8, 0x00A4C8D7, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D8, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A2C6D6, 0x00A1C7D6, 0x00A1C6D6, 
        0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D2, 0x009AC1D2, 
        0x009AC1D2, 0x0099C1D1, 0x0099C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 
        0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0085B1C3, 0x002B3A40, 
        0x00000000, 0x00192226, 0x007BA4B6, 0x0084B2C5, 0x0083B2C5, 0x0083B1C4, 0x0083B1C4, 0x0081B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x00719BAD, 0x00101719, 0x00000000, 0x0031434B, 0x007BAABE, 0x007CADC0, 0x007CACC0, 0x007BABC0, 0x007BABBF, 
        0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0076A7BB, 0x005B8190, 0x00557887, 0x0060899A, 0x00648FA1, 0x006794A6, 0x006B99AB, 0x006E9DB1, 0x0070A2B7, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x0070A3B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659BB2, 0x00659BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006199B1, 0x006199B0, 
        0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x00578FA6, 0x000B1316, 0x00253E48, 0x005A94AB, 0x005893AB, 0x005892AB, 0x005892AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 
        0x00538FA8, 0x001D333C, 0x00000000, 0x002B4C59, 0x00508CA6, 0x004F8CA6, 0x004F8CA5, 0x004E8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x002A4D5D, 0x00000000, 0x0022404D, 0x0047859F, 0x004787A1, 0x004686A1, 0x004686A0, 0x004585A0, 
        0x004484A0, 0x0044849F, 0x0043849F, 0x0043849E, 0x0042829E, 0x0041829D, 0x0041829D, 0x003F819C, 0x003F819C,
  0x003F809C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x0037677B, 0x00030608, 0x00060C0F, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 
        0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00111F25, 0x00000000, 0x00365E6F, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AB, 0x00426E81, 0x00030506, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070C0E, 0x0033515D, 0x00588CA2, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00669DB4, 0x00679EB4, 
        0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x00496D7C, 0x001B292F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x00314750, 0x005C8698, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A6BB, 0x003E5965, 
        0x001A252A, 0x0072A3B8, 0x0076A8BD, 0x0077A8BD, 0x0077A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x007AABBF, 0x0079A8BC, 0x002B3D44, 0x00000000, 0x00000000, 0x00172024, 0x00577886, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 0x0081AFC3, 
        0x0081B0C3, 0x003D525B, 0x00000000, 0x0011171A, 0x007199AA, 0x0084B2C4, 0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C9, 0x008BB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 
        0x008CB8CA, 0x008DB8CA, 0x008DB8CB, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCD, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 
        0x0096BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x009AC1D1, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 
        0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A1C6D5, 0x00A0C6D6, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 
        0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C7D7, 0x00A3C7D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A4C8D7, 0x00A4C8D7, 0x00A4C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 0x00A3C8D7, 
        0x00A3C7D7, 0x00A3C8D7, 0x00A2C8D7, 0x00A2C8D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A3C7D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D6, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D5, 0x009FC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC1D2, 0x009AC1D2, 
        0x0099C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0090BBCC, 
        0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0086B3C5, 0x003E525B, 0x00000000, 
        0x000B0F10, 0x006C91A0, 0x0084B2C5, 0x0083B1C5, 0x0083B1C4, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x007CA9BD, 0x0027353C, 0x00000000, 0x00151D20, 0x0074A1B4, 0x007DACC0, 0x007CACC0, 0x007BACBF, 0x007BABBF, 0x007AABBF, 
        0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0073A3B6, 0x001E2B30, 0x00000000, 0x00000000, 0x00050708, 0x000E1417, 0x00162024, 0x001F2D33, 0x00283941, 0x0030454E, 0x0039535E, 0x0043626F, 0x004D7180, 0x00577F90, 0x00618FA1, 0x006A9CB2, 0x006DA2B8, 
        0x006CA1B7, 0x006CA1B7, 0x006BA1B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00689EB5, 0x00679EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098AF, 
        0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x003C6373, 0x000D161A, 0x00568EA5, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 
        0x0045788E, 0x00080F12, 0x00000000, 0x00223D48, 0x0042768B, 0x004F8CA5, 0x004E8BA5, 0x004E8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004A89A3, 0x00060C0E, 0x00030608, 0x0037677B, 0x004887A1, 0x004786A1, 0x004786A0, 0x004685A0, 0x004585A0, 
        0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x0040819C, 0x003E819C,
  0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x0046849E, 0x00101E24, 0x00000000, 0x00305969, 0x004B89A3, 0x004B89A4, 0x004C8AA4, 
        0x004D8BA4, 0x004E8BA4, 0x003C6C80, 0x0014242B, 0x00020304, 0x00000000, 0x0015252B, 0x00518CA5, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x001E323A, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00253B44, 0x0055899F, 0x005F97AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00649AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB3, 
        0x00689EB4, 0x00699EB5, 0x005F90A3, 0x001E2E34, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001E2C31, 0x005F8A9D, 0x006EA2B6, 0x0071A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x006C9AAE, 
        0x00405C67, 0x0071A2B6, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0079A9BE, 0x0079AABE, 0x0079AABF, 0x007AABBF, 0x0077A6B9, 0x000D1315, 0x00000000, 0x00233036, 0x007BAABE, 0x007EADC1, 0x007FAEC2, 0x007FAEC1, 0x0080AFC2, 0x0080AFC2, 
        0x0081AFC3, 0x007EACBF, 0x0034474F, 0x00000000, 0x000E1416, 0x007BA6B6, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 
        0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 
        0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D1, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 
        0x009DC3D3, 0x009DC3D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC4D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 
        0x00A2C7D6, 0x00A2C6D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A3C7D7, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D7, 
        0x00A2C7D6, 0x00A2C7D7, 0x00A2C7D7, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D4, 
        0x009FC5D5, 0x009FC5D5, 0x009EC5D5, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D2, 0x0099C1D2, 0x0099C1D1, 
        0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 
        0x0090BACB, 0x008FBACB, 0x008EB9CB, 0x008EB9CA, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x004F6A75, 0x00000000, 0x00000000, 
        0x006A8F9E, 0x0084B2C5, 0x0083B2C5, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x0080AEC2, 0x00405862, 0x00000000, 0x00010203, 0x006E99AB, 0x007DADC0, 0x007CACC0, 0x007BACC0, 0x007BABC0, 0x007AAABF, 0x007AAABE, 
        0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BE, 0x00577B8B, 0x0006090A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x00040607, 0x0006080A, 0x00080C0D, 0x00090E10, 0x000E1518, 
        0x001A262B, 0x00293D45, 0x0037525E, 0x00466A79, 0x00547F90, 0x006395AB, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006198B0, 0x006098AF, 
        0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005C96AE, 0x005C95AD, 0x00578DA4, 0x000A1114, 0x00395E6D, 0x005994AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00518EA6, 
        0x002F5160, 0x00000000, 0x00000000, 0x00000000, 0x00040809, 0x0016282F, 0x003C6B7F, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x002F5768, 0x00000000, 0x00101E24, 0x0046849E, 0x004887A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 
        0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003E809C,
  0x003E809B, 0x003F809C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x002B5160, 0x00000000, 0x00122128, 0x004B89A3, 0x004B8AA3, 0x0047829A, 
        0x00376578, 0x00101D22, 0x00000000, 0x00000000, 0x00030506, 0x00030607, 0x0005080A, 0x003F6D80, 0x00528EA7, 0x00538EA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AA, 0x004A7C90, 0x00030607, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x000D1619, 0x00487588, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB3, 
        0x006395AB, 0x00385561, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D1316, 0x00486B79, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 
        0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007BABBF, 0x006D98AA, 0x00050708, 0x00000000, 0x00415A64, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 
        0x0080AFC3, 0x0081B0C3, 0x0078A4B6, 0x00212D31, 0x00000000, 0x00192225, 0x007BA6B7, 0x0085B2C5, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008BB6C8, 0x008BB6C9, 
        0x008CB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BECE, 
        0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D2, 0x009AC1D1, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009CC2D2, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009DC3D3, 0x009DC3D4, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC5D4, 0x009EC4D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 0x00A2C7D6, 
        0x00A1C7D6, 0x00A2C7D6, 0x00A1C7D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009EC5D4, 
        0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 
        0x0098C0D1, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACB, 
        0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B4C7, 0x0087B4C6, 0x005E7D8A, 0x00000000, 0x00000000, 0x00000000, 
        0x003B5058, 0x0082AFC2, 0x0083B1C4, 0x0083B1C4, 0x0082B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x00597A88, 0x00000000, 0x00000000, 0x00597B89, 0x007DADC1, 0x007DACC0, 0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AABBF, 0x0079AABE, 
        0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0077A8BD, 0x003A535D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1215, 0x001A282E, 0x00293F48, 0x00365360, 0x00456B7A, 0x00517E91, 0x005A8BA0, 0x005B8DA3, 0x005C90A6, 0x005D93A9, 0x005E94AB, 0x005E96AD, 0x006098AF, 
        0x005F98AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x00578DA4, 0x00142127, 0x00131F24, 0x005489A1, 0x005993AB, 0x005993AB, 0x005892AA, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA9, 0x00538FA8, 0x004F88A1, 
        0x000D161A, 0x00020405, 0x00365F70, 0x00101C21, 0x00020304, 0x00000000, 0x00000000, 0x00122127, 0x003B6C81, 0x0047839B, 0x004A88A2, 0x00122128, 0x00000000, 0x002B5161, 0x004887A1, 0x004787A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x0044859F, 
        0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F809C, 0x003E809B,
  0x003E809B, 0x003E809B, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x004485A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x0046849F, 0x00050A0C, 0x0004080A, 0x00315A6C, 0x002A4D5C, 0x00101D22, 
        0x00000000, 0x00000000, 0x0005090B, 0x001B313A, 0x00396577, 0x00366071, 0x00000000, 0x00233E49, 0x00518CA5, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005893AB, 0x002C4955, 0x00000000, 
        0x00000000, 0x00000000, 0x00223841, 0x005589A0, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006099B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x006498AF, 0x00406270, 
        0x00111B1F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1214, 0x00344E59, 0x006495A9, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BB, 0x0073A6BB, 
        0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0076A7BD, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x007AABBF, 0x007BABBF, 0x00547683, 0x00030506, 0x00000000, 0x004D6B77, 0x007DADC1, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 
        0x0080AFC2, 0x0081AFC3, 0x0081B0C3, 0x00739BAC, 0x00182124, 0x00000000, 0x0027353B, 0x007EA9BC, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 
        0x008BB6C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008CB7CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 
        0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D3, 
        0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC3D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 0x00A0C5D5, 
        0x00A0C6D5, 0x00A0C6D5, 0x00A1C6D5, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C7D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 
        0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A1C6D6, 0x00A0C6D6, 0x00A0C6D6, 0x00A0C6D5, 0x009FC6D5, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D5, 0x009EC5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC4D4, 0x009EC4D4, 
        0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC2D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 
        0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 
        0x008FB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0087B5C7, 0x0087B4C7, 0x005B7985, 0x00000000, 0x00030404, 0x002C3C42, 0x00040606, 
        0x00000000, 0x00314249, 0x007CA8BA, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x00638797, 0x00050708, 0x00000000, 0x003B525C, 0x007CACC0, 0x007CACC1, 0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 
        0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x00293B43, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060A0C, 0x0010191D, 0x0019272D, 0x0022363E, 0x002A434E, 0x0033515E, 
        0x003A5C6B, 0x00406777, 0x00436D7E, 0x00426B7C, 0x00304E5B, 0x000B1215, 0x00000000, 0x003F6879, 0x005993AC, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00375F70, 
        0x00000000, 0x00274552, 0x00508DA6, 0x004F8CA6, 0x00356071, 0x001A2F38, 0x0004080A, 0x00000000, 0x00000000, 0x00111F25, 0x00203C48, 0x0004080A, 0x00050A0C, 0x0047849E, 0x004887A1, 0x004786A1, 0x004686A0, 0x004586A0, 0x0045859F, 0x0044849F, 
        0x0044849F, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809B,
  0x003D7F9B, 0x003F809B, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x004887A2, 0x00274957, 0x00000000, 0x0004090A, 0x00000000, 0x00000000, 
        0x0005090A, 0x00264552, 0x0041768C, 0x004C87A1, 0x004F8CA5, 0x004E8AA4, 0x000F1B1F, 0x00000000, 0x004B839A, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005892AB, 0x005690A8, 0x000E171B, 
        0x00000000, 0x00121E23, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006099B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x004B7484, 0x00141F24, 0x00020303, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002B414A, 0x005C8A9D, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 
        0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x007AAABE, 0x007AABBF, 0x007AABBF, 0x003B525C, 0x00000000, 0x00070A0C, 0x005B7E8C, 0x007EADC1, 0x007EADC1, 0x007FAEC2, 
        0x007FAEC2, 0x0080AFC2, 0x0080AFC3, 0x0081B0C3, 0x0075A0B1, 0x00172024, 0x00000000, 0x00263338, 0x0084B1C5, 0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 
        0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACB, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BDCE, 
        0x0094BDCE, 0x0094BDCE, 0x0095BDCE, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 
        0x009BC2D2, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC5D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C6D5, 0x00A0C5D5, 0x00A0C5D5, 0x00A0C6D5, 
        0x00A0C6D5, 0x00A0C5D5, 0x00A0C5D5, 0x009FC6D5, 0x00A0C5D5, 0x00A0C5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009FC5D5, 0x009FC5D4, 0x009FC4D5, 0x009EC5D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D3, 
        0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D2, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D2, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0098BFD0, 0x0097BFD0, 
        0x0096BFD0, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0091BACC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008EB9CB, 
        0x008EB9CB, 0x008EB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB8C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x00638491, 0x00080B0D, 0x00000000, 0x00435A64, 0x0085B2C5, 0x0060818F, 
        0x00030404, 0x00000000, 0x00212D32, 0x007EABBE, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x00729CAE, 0x00151D20, 0x00000000, 0x00212D32, 0x007AA9BD, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 
        0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x006E9EB2, 0x001B272C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00020405, 0x00040708, 0x00040708, 0x00000000, 0x00000000, 0x001A2C33, 0x005A94AC, 0x005893AB, 0x005893AB, 0x005892AB, 0x005791AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00080D10, 
        0x00060A0C, 0x00417388, 0x00508DA6, 0x004F8CA6, 0x004E8BA5, 0x004A879F, 0x00407388, 0x00223F4B, 0x00020405, 0x00000000, 0x00000000, 0x00000000, 0x00274857, 0x004887A1, 0x004787A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0044849F, 0x0044849F, 
        0x0043849E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B,
  0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0041839D, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045849F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x0046849E, 0x00020304, 0x00000000, 0x00070D10, 0x00284956, 
        0x0047839B, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004F8CA5, 0x004F8CA5, 0x00345C6C, 0x00000000, 0x00223D48, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x003F6A7C, 
        0x00000000, 0x0029444F, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x006098B0, 0x006099B0, 0x006199B0, 0x006299B1, 0x006299B0, 0x005C90A5, 0x00263C45, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00111A1D, 0x00568192, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A4BA, 0x0072A5BA, 
        0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABF, 0x007AAABF, 0x007AABBF, 0x007BABC0, 0x00212E33, 0x00000000, 0x00101618, 0x006E98AA, 0x007EADC1, 0x007EADC1, 
        0x007FAEC2, 0x0080AEC2, 0x0080AFC2, 0x0081AFC3, 0x00739DAE, 0x000F1417, 0x00000000, 0x00000000, 0x00233035, 0x0083B1C4, 0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 
        0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 
        0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BED0, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 
        0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC3D4, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 
        0x009FC5D5, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC6D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 
        0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 0x009FC5D5, 0x009FC5D4, 0x009EC5D5, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D4, 0x009DC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 
        0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 
        0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x006E93A2, 0x00030404, 0x00000000, 0x003C5059, 0x0085B2C5, 0x0084B2C5, 0x0083B1C4, 
        0x006C93A2, 0x000A0E10, 0x00000000, 0x00131A1D, 0x00759FB1, 0x0080AFC3, 0x007EACBF, 0x00233036, 0x00000000, 0x000E1315, 0x007BAABE, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 
        0x0077A9BE, 0x0076A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x005D8798, 0x000A0F11, 0x00000000, 0x00030405, 0x00151F23, 0x000E1417, 0x00040607, 0x00020304, 0x00020303, 0x00010202, 0x00000101, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0052889E, 0x005994AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691A9, 0x005591AA, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00528FA8, 0x00315564, 0x00000000, 
        0x001B2F37, 0x00508DA6, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA3, 0x0048849D, 0x00254451, 0x00000000, 0x00020405, 0x0046849E, 0x004887A1, 0x004786A1, 0x004686A0, 0x004586A0, 0x0045859F, 0x0044849F, 0x0044849F, 
        0x0043839F, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B,
  0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004686A1, 0x004787A1, 0x004887A1, 0x0023414E, 0x00000000, 0x002A4E5D, 0x004B89A3, 
        0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x00477F97, 0x000E181D, 0x00000000, 0x00498097, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x00548DA4, 
        0x0018272E, 0x001E313A, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x00598DA2, 0x00385966, 0x00060A0C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x0010191C, 0x003B5A67, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006EA1B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A3B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 
        0x0072A5BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x0079A9BC, 0x001C272C, 0x00000000, 0x001B262B, 0x0074A0B3, 0x007EADC1, 
        0x007FAEC2, 0x007FAEC2, 0x007FAFC2, 0x00608392, 0x000A0E10, 0x00000000, 0x00141B1E, 0x000C1113, 0x00000000, 0x002D3D43, 0x007EAABC, 0x0085B2C5, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 
        0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 
        0x0093BCCE, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 
        0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009CC2D3, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 
        0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009FC5D4, 0x009EC5D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009EC5D4, 0x009FC5D5, 0x009FC5D4, 0x009FC5D4, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D5, 0x009FC5D4, 
        0x009FC5D5, 0x009FC4D5, 0x009EC4D4, 0x009EC4D4, 0x009EC4D5, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D3, 0x009DC3D4, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BED0, 0x0096BECF, 
        0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0094BECE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCE, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB9CA, 
        0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x00648694, 0x00030404, 0x00000000, 0x003B5058, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0083B1C4, 
        0x0082B1C4, 0x00688C9C, 0x00151C20, 0x00000000, 0x00141C1F, 0x00628795, 0x002F4149, 0x00000000, 0x000D1215, 0x006E99AB, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 
        0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 0x00446370, 0x00000000, 0x00000000, 0x002F454F, 0x006FA3B9, 0x006FA3B8, 0x006595A9, 0x00588193, 0x004B707F, 0x003E5C69, 0x00324B55, 0x00263941, 
        0x001E2D34, 0x00182429, 0x00121C1F, 0x000C1215, 0x00060A0C, 0x00010102, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0031515F, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x004F89A1, 0x000D161A, 0x00010203, 
        0x003D6B7E, 0x00508DA6, 0x004F8CA5, 0x004E8CA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x002A4E5D, 0x00000000, 0x0024434F, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849F, 
        0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B,
  0x003C7F9A, 0x003D7F9B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041839D, 0x0042839E, 0x0043849E, 0x0043849E, 0x0045849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x003B6F86, 0x00050A0C, 0x00030608, 0x0048859F, 
        0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x00294855, 0x00000000, 0x001D333C, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 
        0x00426D7F, 0x00040708, 0x0052879D, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x003C5F6F, 0x00111B1F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00040708, 0x00375460, 0x005A8B9F, 0x00679EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA3B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4BA, 0x0072A5B9, 
        0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x007AAABE, 0x007AAABF, 0x007AABBF, 0x006D98AA, 0x00161F23, 0x00000000, 0x001E2A2F, 0x0077A5B8, 
        0x007EADC1, 0x007EAEC1, 0x00597A88, 0x000A0E0F, 0x00000000, 0x00182024, 0x006E96A6, 0x006B90A0, 0x000D1213, 0x00000000, 0x0029383E, 0x0084B1C4, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B5C7, 
        0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 
        0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 
        0x0099C0D1, 0x0099C1D1, 0x0099C1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 
        0x009DC3D4, 0x009DC3D3, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC4D4, 0x009EC4D4, 0x009DC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009EC4D4, 0x009DC4D4, 
        0x009EC4D4, 0x009DC4D4, 0x009EC4D4, 0x009DC4D4, 0x009DC3D4, 0x009DC4D4, 0x009DC3D4, 0x009DC3D3, 0x009CC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 
        0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC1D2, 0x0099C1D2, 0x009AC1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 
        0x0094BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008CB7CA, 
        0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x005E7E8A, 0x00090D0E, 0x00000000, 0x003B5058, 0x0082AEC1, 0x0084B2C5, 0x0083B1C5, 0x0083B1C4, 0x0082B1C4, 
        0x0082B0C3, 0x0081B0C3, 0x007099AA, 0x00192226, 0x00000000, 0x00090D0F, 0x00000000, 0x00070A0B, 0x005C808F, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0077A9BE, 0x0077A8BD, 
        0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BA, 0x0072A5BA, 0x0072A5BA, 0x00334B54, 0x00000000, 0x00000000, 0x003D5A67, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 
        0x006A9FB5, 0x006396AB, 0x005E8FA3, 0x00588598, 0x00517D8F, 0x004C7485, 0x00456B7A, 0x003A5967, 0x002E4751, 0x0022363E, 0x00172329, 0x000B1214, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00111D21, 0x00548BA1, 0x005994AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00345B6B, 0x00000000, 0x0016272E, 
        0x00508DA6, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B8AA3, 0x0048859F, 0x00030607, 0x00050A0C, 0x003B7085, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0043849E, 0x0043849E, 
        0x0042839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E7F9B, 0x003D7F9B,
  0x003C7F9B, 0x003E7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004786A1, 0x004786A0, 0x00192F38, 0x00000000, 0x00254553, 
        0x004A89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004C879F, 0x00040809, 0x00060C0E, 0x00427388, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 
        0x005993AB, 0x001B2D34, 0x0018282E, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x00507F94, 0x00131E23, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001D2C33, 
        0x005A8BA0, 0x00659BB2, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 
        0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0074A6BB, 0x0074A6BC, 0x0074A7BC, 0x0076A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007BABBF, 0x00628999, 0x00090C0E, 0x00000000, 0x002B3B42, 
        0x007DADC1, 0x00597B89, 0x00010203, 0x00000000, 0x001B2529, 0x007AA7B9, 0x0081B0C3, 0x0081B0C3, 0x00719BAC, 0x000F1417, 0x00000000, 0x001B2428, 0x0080ADC0, 0x0085B2C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 
        0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 
        0x0091BBCD, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 
        0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009BC2D2, 0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009DC3D3, 0x009DC3D4, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D4, 0x009DC3D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D4, 0x009DC3D4, 0x009DC4D4, 0x009DC3D4, 0x009DC4D4, 0x009DC4D4, 0x009DC4D4, 0x009DC3D4, 
        0x009DC3D3, 0x009DC4D4, 0x009CC3D3, 0x009DC3D3, 0x009CC3D4, 0x009DC3D3, 0x009CC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009CC2D3, 0x009BC2D2, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 
        0x009AC1D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCF, 
        0x0094BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 
        0x008CB7C9, 0x008BB7C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x0061828F, 0x00020203, 0x00000000, 0x003A4E56, 0x0085B2C5, 0x0084B2C5, 0x0083B1C5, 0x0083B1C4, 0x0082B1C4, 0x0082B0C4, 
        0x0081B0C3, 0x0081AFC3, 0x0080AFC2, 0x0077A4B5, 0x00192226, 0x00000000, 0x00000000, 0x004F6C79, 0x007DADC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 
        0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A5BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A3B9, 0x001E2C32, 0x00000000, 0x00000000, 0x00527989, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006AA0B6, 
        0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00669DB3, 0x00669CB3, 0x00649BB2, 0x006399B0, 0x006399B0, 0x006199AF, 0x006197AE, 0x006096AD, 0x00598CA2, 0x004A7689, 0x003C5F6D, 0x002A434E, 0x00131F24, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00010203, 0x00385D6C, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x004E879F, 0x0015252B, 0x00000000, 0x00457A90, 
        0x00508DA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B8AA4, 0x004B89A3, 0x00254552, 0x00000000, 0x00192F38, 0x004786A0, 0x004787A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0043849E, 0x0043839E, 
        0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E7F9B, 0x003C7F9B,
  0x003C7E9A, 0x003C7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0045849F, 0x004585A0, 0x004585A0, 0x004686A1, 0x004786A1, 0x004887A1, 0x00356376, 0x00020304, 0x00080E11, 
        0x00457F98, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x002B4D5B, 0x00000000, 0x0024404B, 0x00518CA5, 0x00528FA8, 0x00538FA8, 0x005490A9, 0x005490A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005792AA, 
        0x005892AB, 0x0053899F, 0x00060B0D, 0x003E6676, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C96AE, 0x00518398, 0x002E4955, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00111B1F, 0x00446A7A, 0x00649BB2, 
        0x00659BB2, 0x00669CB3, 0x00669CB3, 0x00669DB4, 0x00679DB4, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4BA, 
        0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007BABBF, 0x00587A89, 0x00040607, 0x00000000, 
        0x0026343B, 0x00000000, 0x00000000, 0x002C3D44, 0x007DABBF, 0x0080AEC2, 0x0080AFC2, 0x0081AFC3, 0x0081B0C3, 0x006B90A0, 0x00141B1D, 0x00000000, 0x001E292E, 0x00769FB0, 0x0085B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 
        0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 
        0x0091BACC, 0x0091BBCD, 0x0091BBCC, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 
        0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009CC2D3, 0x009BC2D2, 
        0x009CC2D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009CC3D3, 0x009CC3D3, 0x009DC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 0x009DC3D3, 0x009DC3D3, 0x009DC3D3, 0x009CC3D3, 
        0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009CC3D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009BC1D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 
        0x009AC1D1, 0x0099C1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0094BDCE, 
        0x0094BDCE, 0x0093BCCD, 0x0093BCCE, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008CB7C9, 
        0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0088B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0056737E, 0x00000000, 0x00020303, 0x003F555E, 0x0085B2C5, 0x0084B2C5, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0082B0C3, 0x0082B0C3, 
        0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x00557582, 0x00000000, 0x00000000, 0x00415A65, 0x007DADC1, 0x007DACC0, 0x007CACC0, 0x007BACC0, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x007AAABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BD, 
        0x0076A8BD, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x006491A5, 0x000E1417, 0x00000000, 0x00080C0D, 0x005F8DA0, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 
        0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005E97AF, 0x005B92A8, 0x0031505C, 
        0x00040708, 0x00000000, 0x00000000, 0x00142126, 0x005790A7, 0x005993AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00528FA8, 0x003C687B, 0x00000000, 0x001E353E, 0x00508DA6, 
        0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x00457F98, 0x00070E11, 0x00020304, 0x00346376, 0x004887A1, 0x004786A1, 0x004786A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0043849F, 0x0043839E, 0x0042839E, 
        0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9A,
  0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045849F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00112026, 0x00000000, 
        0x002A4E5E, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004E8AA4, 0x00091012, 0x00030607, 0x00487D94, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 
        0x005892AA, 0x005892AB, 0x00365A69, 0x00060B0D, 0x00365968, 0x004C7C90, 0x00446E80, 0x0028414B, 0x000B1215, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1316, 0x003A5A68, 0x005E92A8, 0x00639AB1, 0x00649BB2, 
        0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006FA3B8, 0x0070A3B8, 0x0070A4B9, 
        0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABF, 0x007AABBF, 0x007BABBF, 0x00557785, 0x00040606, 
        0x00000000, 0x00000000, 0x003C545D, 0x007BA9BD, 0x007EAEC2, 0x007FAEC2, 0x0080AFC2, 0x0080AFC3, 0x0081AFC3, 0x0081B0C3, 0x006F96A6, 0x001B2428, 0x00000000, 0x001A2327, 0x006F96A6, 0x0084B2C5, 0x0085B2C5, 0x0085B3C6, 0x0085B3C6, 0x0086B4C6, 
        0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C8, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACB, 
        0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFD0, 0x0096BFD0, 
        0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 
        0x009AC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D3, 0x009BC2D2, 0x009BC3D3, 0x009BC3D3, 0x009BC2D2, 0x009CC2D3, 0x009CC2D3, 0x009BC2D3, 0x009BC3D3, 0x009BC2D2, 0x009BC2D3, 0x009BC2D3, 0x009BC2D3, 0x009BC2D3, 
        0x009BC2D3, 0x009BC3D3, 0x009BC3D3, 0x009BC2D3, 0x009BC2D2, 0x009BC2D2, 0x009AC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D1, 0x009AC1D1, 0x009AC1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0099C1D1, 
        0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BED0, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BECE, 0x0094BECE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 
        0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCC, 0x0091BBCD, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x0090B9CB, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C6, 0x00455C66, 0x00000000, 0x00000000, 0x001D272B, 0x007FACBE, 0x0084B1C4, 0x0083B1C4, 0x0083B1C4, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 
        0x0080AFC2, 0x0080AFC2, 0x004E6B78, 0x00000101, 0x00000000, 0x00415963, 0x007DADC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 
        0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x004E7282, 0x00010102, 0x00000000, 0x001D2C32, 0x00689BB0, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 
        0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 
        0x00345462, 0x00000000, 0x00000000, 0x00457285, 0x005A94AC, 0x005993AB, 0x005892AB, 0x005892AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00538EA7, 0x000B1316, 0x00020405, 0x0042758A, 0x00508CA6, 
        0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x002A4F5E, 0x00000000, 0x00112026, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 
        0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809B, 0x003E7F9B, 0x003C7F9B, 0x003C7E9A,
  0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042839D, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044859F, 0x0045859F, 0x004686A0, 0x004686A1, 0x004786A0, 0x004887A1, 0x003A6E84, 0x00000000, 
        0x000F1D23, 0x00458098, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00365E70, 0x00000000, 0x00203943, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 
        0x005792AA, 0x005892AB, 0x00538AA1, 0x00142228, 0x00010102, 0x00040809, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002F4A56, 0x005B90A5, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639BB1, 
        0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689DB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 
        0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0075A7BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079A9BE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x004E6C79, 
        0x00020303, 0x00000000, 0x00354952, 0x007EADC1, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC3, 0x0081B0C3, 0x0079A4B6, 0x00243136, 0x00000000, 0x00090D0E, 0x00648695, 0x0084B2C5, 0x0085B2C6, 0x0085B3C6, 0x0086B3C6, 
        0x0086B4C6, 0x0087B3C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 
        0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BECE, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 
        0x0096BFCF, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x0099C1D2, 0x009AC1D1, 0x009AC1D2, 
        0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 0x009BC2D2, 
        0x009BC2D2, 0x009AC2D2, 0x009BC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D1, 0x0099C1D2, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 
        0x0098C0D0, 0x0098BFD1, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCF, 0x0094BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 
        0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB7C9, 0x008AB6C8, 
        0x008AB6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0036484F, 0x00000000, 0x00000000, 0x00020203, 0x00000000, 0x003E545D, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 
        0x0080AFC3, 0x00547481, 0x00050809, 0x00000000, 0x00344850, 0x007CABBE, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A8BC, 0x0075A7BC, 
        0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x0038545F, 0x00000000, 0x00000000, 0x00344D58, 0x006BA0B6, 0x006BA0B6, 0x00699FB5, 0x00699FB5, 
        0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D95AD, 
        0x00426A7C, 0x00000000, 0x00243C46, 0x005A94AC, 0x005993AC, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x002F5160, 0x00000000, 0x001E353E, 0x004F8BA4, 0x004F8CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA3, 0x004B89A3, 0x00468098, 0x000F1D23, 0x00000000, 0x003B6E84, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0044849E, 0x0042839E, 0x0042839E, 
        0x0041829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A,
  0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x004887A2, 0x00162931, 
        0x00000000, 0x00346173, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8CA5, 0x004F8CA5, 0x0049829A, 0x00111E24, 0x00000000, 0x0045798F, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 
        0x005791AA, 0x005792AA, 0x005892AB, 0x003B6272, 0x00020404, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020404, 0x00152126, 0x004E7C90, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 
        0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x006A9FB6, 0x006B9FB6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 
        0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007BABBF, 
        0x00415B65, 0x00020303, 0x00000000, 0x00445E69, 0x007CAABE, 0x007EAEC1, 0x007EAEC2, 0x007FAEC2, 0x0080AEC2, 0x0080AFC3, 0x0081AFC3, 0x0081B0C3, 0x007AA7BA, 0x0027363B, 0x00010202, 0x00040506, 0x00587784, 0x0083B1C4, 0x0085B2C5, 0x0085B3C6, 
        0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 
        0x008FB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCE, 0x0094BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCF, 0x0094BECE, 0x0095BECF, 0x0095BECF, 
        0x0096BECF, 0x0096BECF, 0x0096BFCF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 
        0x0099C1D1, 0x009AC1D1, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009AC1D2, 0x009AC1D2, 0x009AC2D2, 0x009AC1D2, 0x009AC2D2, 
        0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 0x009AC1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097C0D0, 0x0098BFD1, 
        0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFCF, 0x0096BFD0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0095BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 
        0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 
        0x0089B6C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0080AABB, 0x00253237, 0x00000000, 0x00070A0B, 0x00628391, 0x005E7F8C, 0x00020303, 0x00000000, 0x00465F6A, 0x0083B1C4, 0x0082B0C3, 0x0082B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 
        0x005F8291, 0x00030506, 0x00000000, 0x002A3A41, 0x007DADC1, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 
        0x0074A7BC, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x00213137, 0x00000000, 0x00000000, 0x00496F7F, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 
        0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00659CB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D95AE, 0x005B94AC, 
        0x00304F5C, 0x00030506, 0x00558DA3, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005692AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x004D859D, 0x00060B0D, 0x0005080A, 0x003E6E82, 0x004F8DA6, 0x004F8CA5, 
        0x004F8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x00356173, 0x00000000, 0x00162A32, 0x004887A2, 0x004887A1, 0x004786A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0041829E, 
        0x0041829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A,
  0x003B7E99, 0x003B7E9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x003A6D82, 
        0x00000000, 0x00091215, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x00315766, 0x00000101, 0x00132228, 0x00518EA7, 0x00528EA7, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691AA, 
        0x005691AA, 0x005791AA, 0x005892AB, 0x005791A9, 0x0017262C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00111C21, 0x003B5F6F, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006198B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 
        0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA1B6, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 
        0x006FA3B9, 0x0070A4B9, 0x0070A4BA, 0x0071A4B9, 0x0072A5BA, 0x0073A5BA, 0x006FA1B5, 0x00608B9D, 0x00517483, 0x00567B8B, 0x0075A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 
        0x007BABBF, 0x0046616D, 0x00000000, 0x00000000, 0x00415A64, 0x007DADC1, 0x007EAEC1, 0x007EAEC1, 0x007FAFC2, 0x007FAFC2, 0x0080AFC3, 0x0081AFC3, 0x0081B0C3, 0x007FADC0, 0x0012181B, 0x00000000, 0x00020203, 0x00445C66, 0x0084B2C5, 0x0085B2C5, 
        0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008CB7CA, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CA, 
        0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 0x0093BCCD, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCF, 
        0x0094BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BED0, 0x0096BFCF, 0x0096BFCF, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C0D1, 
        0x0099C0D1, 0x0098C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D2, 0x0099C1D1, 0x0099C1D2, 0x009AC1D2, 0x0099C1D1, 0x009AC1D1, 0x009AC1D1, 0x0099C1D1, 0x0099C1D1, 0x009AC1D2, 0x0099C1D2, 0x009AC1D1, 0x009AC1D1, 0x009AC1D2, 0x0099C1D1, 0x0099C1D1, 
        0x0099C1D1, 0x0099C1D2, 0x0099C0D1, 0x0099C1D1, 0x0099C1D1, 0x0099C1D1, 0x0099C0D1, 0x0099C1D1, 0x0099C0D1, 0x0099C0D1, 0x0098C1D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0097BFD0, 0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 
        0x0097BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0091BCCD, 0x0092BBCD, 0x0091BBCC, 
        0x0090BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008BB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 
        0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x006F94A3, 0x001B2529, 0x00000000, 0x0012191B, 0x00658896, 0x0084B2C5, 0x0083B2C5, 0x004C6773, 0x00020203, 0x00000000, 0x00516D7A, 0x0082B0C3, 0x0081B0C3, 0x0080AFC2, 0x0080AFC2, 0x00557582, 
        0x00030506, 0x00000000, 0x00344750, 0x007DADC1, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 
        0x0074A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006597AB, 0x00141F23, 0x00000000, 0x00030405, 0x00527D8E, 0x00699FB5, 0x00689EB4, 
        0x00689DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005A92AA, 
        0x000C1518, 0x00325361, 0x005A94AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x00284653, 0x00000000, 0x001B3038, 0x00508DA6, 0x004F8CA5, 0x004F8CA6, 
        0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00091215, 0x00000000, 0x003B6E83, 0x004887A1, 0x004787A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0041829D, 
        0x0041829D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A,
  0x003B7D99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0044849E, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A0, 0x004787A1, 0x0046839D, 
        0x00182E37, 0x00000000, 0x002A4E5D, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x00508DA6, 0x000D171B, 0x00010303, 0x00365F6F, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA9, 0x005590A9, 0x005590A9, 
        0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x004B7B90, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0027404A, 0x00558BA1, 0x005D96AE, 0x005E96AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 
        0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659CB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B8, 0x006EA2B8, 
        0x006FA3B8, 0x0070A3B9, 0x006FA1B7, 0x00557C8D, 0x003A5460, 0x00213036, 0x0010181B, 0x000A0F11, 0x00040607, 0x0031464F, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079ABBE, 
        0x007AABBF, 0x007BABBF, 0x004C6976, 0x00000000, 0x00000000, 0x00344850, 0x007EADC1, 0x007EADC2, 0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 0x0080AFC3, 0x0080AFC3, 0x004B6671, 0x00040606, 0x00000000, 0x00000000, 0x00000000, 0x00263338, 0x007CA8BA, 
        0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B6C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 
        0x008DB9CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 
        0x0094BDCE, 0x0094BDCF, 0x0095BDCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BFCF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D1, 
        0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 0x0099C0D1, 0x0099C0D1, 0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C1D1, 0x0098C0D1, 0x0098C0D1, 
        0x0098C0D1, 0x0098C0D1, 0x0099C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D1, 0x0097BFD0, 0x0098BFD0, 0x0098BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BECF, 
        0x0096BECF, 0x0095BECF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCD, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BACC, 
        0x0090BACC, 0x0090BACB, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 
        0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x005D7C89, 0x000B0E10, 0x00000000, 0x001D272B, 0x00769FB0, 0x0084B2C5, 0x0084B1C4, 0x0083B1C4, 0x0083B1C4, 0x003F555F, 0x00000000, 0x00070A0B, 0x005C7E8D, 0x0080AFC2, 0x0080AFC3, 0x004E6B78, 0x00060809, 
        0x00000000, 0x00344750, 0x0079A8BB, 0x007DACC0, 0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x0079ABBF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0077A9BE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 
        0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B6, 0x006BA0B6, 0x00537C8D, 0x0006090A, 0x00000000, 0x00141F23, 0x005E8FA3, 0x00689DB4, 
        0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x00578FA6, 
        0x00263E48, 0x0052869D, 0x005993AC, 0x005993AB, 0x005893AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00487E94, 0x00091114, 0x00000000, 0x00091012, 0x00335B6B, 0x004F8CA5, 0x004E8BA5, 
        0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C89A3, 0x004B89A3, 0x002A4D5C, 0x00000000, 0x00182E37, 0x0046839D, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 
        0x0040829D, 0x003F819C, 0x003E809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E99,
  0x003A7D99, 0x003B7E99, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0041819D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0045849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 
        0x00336073, 0x00030607, 0x0004080A, 0x0047839C, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004C8AA4, 0x00488199, 0x00203A45, 0x00000101, 0x00000000, 0x0014242A, 0x004C869D, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 
        0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005893AB, 0x0028424D, 0x00000000, 0x00000000, 0x00253D47, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006299B0, 
        0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689DB4, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB6, 0x006BA0B6, 0x006A9EB4, 0x00699CB1, 0x00699BB1, 0x00618FA4, 0x004A6D7C, 
        0x002F454D, 0x000F1719, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00141D21, 0x0072A3B8, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 
        0x007AABBF, 0x007AABBF, 0x007BABC0, 0x00435D68, 0x00020404, 0x00000000, 0x00384E57, 0x007AA8BB, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x005D7F8E, 0x00060809, 0x00000000, 0x002B3A41, 0x00597987, 0x00090C0D, 0x00000000, 0x00171F22, 
        0x007199A9, 0x0084B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB8CA, 
        0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCD, 0x0093BDCE, 
        0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0094BDCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BFCF, 0x0096BFD0, 0x0096BFD0, 0x0097BFD0, 0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 
        0x0097C0D0, 0x0097C0D0, 0x0098BFD0, 0x0097C0D0, 0x0097C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 
        0x0098C0D1, 0x0098C0D0, 0x0098C0D0, 0x0098C0D0, 0x0098C0D0, 0x0097BFD0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BED0, 0x0096BFCF, 0x0096BECF, 0x0095BECF, 0x0096BECF, 0x0095BECF, 
        0x0095BECF, 0x0095BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 
        0x008FBACC, 0x008FBACB, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CB, 0x008DB9CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 
        0x0088B4C7, 0x0086B3C6, 0x00445B64, 0x00000000, 0x00000000, 0x002E3E45, 0x0082B0C3, 0x0084B2C5, 0x0084B1C5, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0082B0C3, 0x0031434A, 0x00000000, 0x00060809, 0x00678E9D, 0x00567683, 0x00000101, 0x00000000, 
        0x002A3A41, 0x007DADC1, 0x007CADC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0079A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 
        0x0073A6BB, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x003B5864, 0x00000000, 0x00000000, 0x002B414A, 0x00659BB1, 
        0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005B95AD, 0x005B95AD, 
        0x005A94AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x002A4855, 0x00000000, 0x00020304, 0x00000000, 0x00000000, 0x00122026, 0x0041748A, 
        0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x0047839B, 0x0004080A, 0x00030607, 0x00336274, 0x004887A1, 0x004787A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0041829E, 0x0041829D, 0x0041829D, 
        0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7F9A, 0x003B7E9A, 0x003A7D99,
  0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003E809C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 
        0x004887A1, 0x00122229, 0x00000000, 0x00264654, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x00477F97, 0x002E5363, 0x00080E11, 0x00000000, 0x00000000, 0x000A1216, 0x00000000, 0x00376071, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA9, 0x005490A9, 
        0x005590A9, 0x005691AA, 0x005692AA, 0x005792AA, 0x005893AB, 0x00558DA4, 0x000A1114, 0x00000000, 0x00548BA1, 0x005B94AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006199B0, 0x006199B0, 
        0x006299B1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00679BB2, 0x005C8C9F, 0x00517A8B, 0x00466A78, 0x0035505B, 0x00202F36, 0x000B1113, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121B1E, 0x006D9CB1, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 
        0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007BABBF, 0x0046616C, 0x00040606, 0x00000000, 0x00354952, 0x0078A5B8, 0x007EADC1, 0x007EAEC2, 0x00658B9B, 0x000A0F10, 0x00000000, 0x0026343A, 0x007EADBF, 0x0081B0C3, 0x006B91A2, 0x001D272B, 0x00000000, 
        0x00080B0D, 0x00577582, 0x0083B1C4, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CA, 0x008EB9CB, 0x008FBACB, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 
        0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BECE, 0x0095BDCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BFD0, 0x0096BECF, 0x0096BECF, 
        0x0096BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0098C0D0, 0x0097BFD0, 0x0097C0D0, 0x0097BFD0, 0x0097C0D0, 0x0097C0D0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097C0D0, 
        0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0097BFD0, 0x0096BFD0, 0x0097BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BFCF, 0x0096BFCF, 0x0096BECF, 0x0096BECF, 0x0096BFCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0095BECF, 
        0x0094BDCF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACC, 
        0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C9, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0088B4C7, 0x0088B4C6, 
        0x00769EAE, 0x002E3E45, 0x00000000, 0x00040606, 0x00435A64, 0x0085B2C5, 0x0084B2C5, 0x0083B1C5, 0x0083B1C4, 0x0083B1C4, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081B0C3, 0x002A3A41, 0x00000000, 0x0006090A, 0x00000101, 0x00000000, 0x00344850, 
        0x007DADC1, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007BACBF, 0x007BABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 
        0x0073A5BB, 0x0072A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 0x00293E47, 0x00000000, 0x00000000, 0x003C5C69, 
        0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 0x005F98AF, 0x005F97AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AC, 0x005A94AC, 
        0x005A94AC, 0x005993AC, 0x005993AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00528FA8, 0x00487E93, 0x00000000, 0x00101D22, 0x003E6D80, 0x001B3038, 0x0005090B, 0x00000000, 0x00000000, 
        0x00203944, 0x003F7288, 0x004C8AA4, 0x004B89A3, 0x00264653, 0x00000000, 0x00122229, 0x004887A1, 0x004787A1, 0x004787A1, 0x004686A0, 0x004585A0, 0x004485A0, 0x0045849F, 0x0043849F, 0x0043849E, 0x0042839E, 0x0041839D, 0x0041829D, 0x0040829D, 
        0x003F819C, 0x003F819C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99,
  0x00397D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004686A0, 0x004686A0, 0x004786A1, 
        0x004787A1, 0x003C7087, 0x00000000, 0x000B1418, 0x00447C94, 0x004B89A3, 0x00315B6C, 0x000E1A1F, 0x00000000, 0x00000000, 0x000B1519, 0x00335B6C, 0x00407287, 0x00060A0C, 0x00070D10, 0x00508CA5, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x00548FA8, 
        0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x00375B6A, 0x00000000, 0x00548BA1, 0x005A94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006198B0, 
        0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00507C8D, 0x003C5C69, 0x00273C45, 0x00182429, 0x000F171A, 0x0006090A, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x0018252A, 0x00304852, 
        0x00456674, 0x00070A0C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E1417, 0x005F899B, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078AABE, 
        0x0079AABE, 0x0079AABE, 0x0079ABBF, 0x007AABBF, 0x007BABBF, 0x00557786, 0x0006090A, 0x00000000, 0x00212E34, 0x0076A2B4, 0x006F98AA, 0x000F1517, 0x00000000, 0x00233136, 0x0077A4B5, 0x0080AFC3, 0x0081AFC3, 0x0081B0C3, 0x0079A4B6, 0x00384C54, 
        0x00000000, 0x00010202, 0x0032434A, 0x007DA9BB, 0x0085B2C5, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C8, 0x008BB7C9, 
        0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 
        0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BCCD, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCF, 0x0094BECE, 0x0094BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 
        0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BFCF, 0x0096BECF, 0x0096BECF, 0x0096BFD0, 0x0096BFCF, 0x0096BFCF, 0x0096BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BFD0, 0x0096BED0, 0x0096BFD0, 0x0096BFD0, 0x0096BECF, 
        0x0096BECF, 0x0096BED0, 0x0096BED0, 0x0096BFCF, 0x0096BFCF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0094BDCE, 0x0094BDCF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 
        0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x008FBACC, 0x0090BACC, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 
        0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x005B7A87, 
        0x0012181B, 0x00000000, 0x00131A1D, 0x00638593, 0x0084B2C5, 0x0084B2C5, 0x0083B1C5, 0x0083B1C4, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x0080AFC3, 0x007098AA, 0x00101719, 0x00000000, 0x00000000, 0x00415963, 0x007CABBF, 
        0x007CACC1, 0x007CACC0, 0x007BACC0, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A8BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 
        0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699EB5, 0x006498AD, 0x001C2B32, 0x00000000, 0x00020303, 
        0x00466C7C, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 
        0x005993AC, 0x005993AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x00122025, 0x00000000, 0x001C323B, 0x00508CA6, 0x004F8CA6, 0x003D6C80, 0x0016282F, 0x00000000, 
        0x00000000, 0x00070D10, 0x00223E4A, 0x003E7187, 0x000B1418, 0x00000000, 0x003C7187, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819C, 
        0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99,
  0x00397C99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004685A0, 0x004686A0, 0x004786A0, 
        0x004887A1, 0x004887A1, 0x001D3640, 0x00000000, 0x0023414C, 0x00112026, 0x00000000, 0x00000000, 0x00000000, 0x00223D48, 0x004A849D, 0x004F8CA5, 0x00467D95, 0x000F1B20, 0x00000000, 0x00233D48, 0x00518EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x00538AA1, 0x000F181C, 0x00365867, 0x005A94AC, 0x005B94AD, 0x005C95AD, 0x005C95AD, 0x005C96AE, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 
        0x006199B0, 0x006299B0, 0x00629AB1, 0x005C91A7, 0x00497283, 0x002F4853, 0x00131D21, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070A0C, 0x001E2E34, 0x003A5764, 0x00588598, 0x00689CB2, 0x006B9FB6, 0x006B9FB5, 
        0x00273A42, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040707, 0x004F7383, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 
        0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x00597D8C, 0x00060809, 0x00000000, 0x00172024, 0x000F1518, 0x00000000, 0x00182225, 0x00729CAE, 0x007FAFC2, 0x0080AFC2, 0x0080AFC3, 0x0081B0C3, 0x0081B0C3, 0x0082B0C3, 
        0x004F6A77, 0x00000000, 0x00000000, 0x0012191B, 0x007198A9, 0x0085B2C5, 0x0085B2C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 
        0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 
        0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCE, 0x0093BCCD, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 0x0095BDCF, 0x0095BECF, 0x0095BECF, 
        0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0095BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 0x0096BECF, 
        0x0095BECF, 0x0095BECF, 0x0096BECF, 0x0095BECF, 0x0096BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0094BDCF, 0x0095BDCF, 0x0094BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 
        0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0093BCCD, 0x0092BCCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 
        0x008DB8CB, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0084B0C3, 0x0040555E, 0x00020303, 
        0x00000000, 0x00000000, 0x002E3E44, 0x0084B2C5, 0x0084B2C5, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0081AFC3, 0x0080AFC2, 0x007DABBF, 0x002F4149, 0x00000000, 0x00000000, 0x00425A65, 0x007DADC1, 0x007DACC0, 
        0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 
        0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00568396, 0x000B1114, 0x00000000, 
        0x000C1316, 0x00578599, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005D97AE, 0x005C96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A93AC, 
        0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00335969, 0x00000101, 0x00000000, 0x00000000, 0x00091114, 0x00376274, 0x004E8CA5, 0x004D8BA4, 0x00366173, 
        0x00070D10, 0x00000000, 0x00000000, 0x00010203, 0x00000000, 0x001D3641, 0x004887A2, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819C, 
        0x003F819C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99,
  0x00397C98, 0x00397D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 
        0x004786A1, 0x004887A1, 0x00437C94, 0x00030607, 0x00000000, 0x00000000, 0x00020405, 0x00162830, 0x00407288, 0x004D8AA4, 0x00467D94, 0x00284754, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00427388, 0x00528EA7, 0x00538FA8, 0x00538FA8, 
        0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x003B6272, 0x00020405, 0x00487688, 0x005A95AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005D95AC, 0x00578BA1, 0x00508093, 0x00497385, 
        0x00385866, 0x0022363E, 0x000E161A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080C0E, 0x0010191C, 0x0019262C, 0x002C434D, 0x00436776, 0x005A889C, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x003B5964, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003D5A66, 0x0070A3B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0073A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 
        0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007BABC0, 0x005F8494, 0x000F1518, 0x00000000, 0x00000000, 0x00070A0B, 0x006E97A8, 0x007EAEC1, 0x007FAEC2, 0x007FAFC2, 0x0080AFC2, 0x0081AFC3, 0x0081B0C3, 0x0081B0C3, 
        0x0082B0C4, 0x006B91A2, 0x00192226, 0x00000000, 0x00000000, 0x004A646F, 0x007DA9BB, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C6, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 
        0x008AB6C9, 0x008BB6C8, 0x008BB6C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FBACB, 0x008FBACC, 0x0090BACB, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 
        0x0090BBCC, 0x0091BBCC, 0x0091BBCC, 0x0092BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCF, 
        0x0094BDCE, 0x0094BECE, 0x0094BDCE, 0x0095BDCE, 0x0095BDCF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECF, 0x0095BECE, 
        0x0095BECF, 0x0095BECF, 0x0095BDCF, 0x0095BDCF, 0x0095BDCF, 0x0094BDCE, 0x0094BECF, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCD, 0x0093BCCE, 0x0093BCCD, 0x0093BCCD, 
        0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 
        0x008DB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x0089B6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x006F94A4, 0x00243035, 0x00000000, 0x0006090A, 
        0x0033444B, 0x00111719, 0x00000000, 0x004B6570, 0x0084B1C4, 0x0083B1C4, 0x0082B1C4, 0x0082B0C4, 0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x00729CAE, 0x00233036, 0x00000000, 0x00070A0B, 0x004F6C79, 0x007DADC1, 0x007CACC0, 0x007CACC0, 
        0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0071A5BA, 
        0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00416372, 0x00010102, 
        0x00000000, 0x001F3138, 0x006096AC, 0x00639BB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AB, 
        0x005993AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x004B839A, 0x000D171C, 0x00000101, 0x00233E49, 0x000C161A, 0x00000000, 0x00000000, 0x00182B33, 0x003D6D82, 0x004C8AA4, 
        0x0049859E, 0x00213C48, 0x00060B0E, 0x00000000, 0x00030506, 0x00427C95, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004685A0, 0x0044859F, 0x0044849F, 0x0043839F, 0x0042839E, 0x0042839E, 0x0041829E, 0x0040819D, 0x0040819D, 0x003F819C, 
        0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397C99,
  0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0045859F, 0x004585A0, 0x004686A0, 
        0x004686A0, 0x004786A1, 0x004786A0, 0x00244350, 0x00000000, 0x00010303, 0x00356274, 0x004B89A3, 0x004C8AA4, 0x002A4C5B, 0x000B1418, 0x00000000, 0x00000000, 0x00192D35, 0x0025424E, 0x00000000, 0x0016272E, 0x004F88A1, 0x00528EA7, 0x00538FA8, 
        0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AA, 0x005892AB, 0x00192A30, 0x00030506, 0x00263F4A, 0x003B6271, 0x00436D7F, 0x0040697A, 0x00385B6A, 0x002B4550, 0x001E3037, 0x00131F25, 0x00080D0F, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x0010191D, 0x0021333B, 0x0034515D, 0x00446979, 0x00507A8D, 0x005C8EA3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x006A9FB5, 0x006AA0B6, 0x00446674, 0x00010202, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003A5561, 0x006FA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0077A8BD, 
        0x0077A8BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007BABBF, 0x006992A4, 0x001D292D, 0x00000000, 0x00070A0C, 0x004F6E7B, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 0x0080AFC2, 0x0081AFC3, 
        0x0081AFC3, 0x0081B0C3, 0x0079A4B6, 0x00405660, 0x00030404, 0x00000000, 0x00212D32, 0x00688C9B, 0x0084B2C5, 0x0085B3C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 
        0x0089B6C8, 0x0089B6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CA, 0x008EB9CA, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACC, 
        0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BDCE, 
        0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0094BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0095BDCE, 0x0094BDCE, 
        0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0094BDCE, 0x0094BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCD, 0x0093BCCD, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0092BBCD, 0x0091BBCD, 
        0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8C9, 
        0x008CB7CA, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0084B0C2, 0x00445B65, 0x00090D0E, 0x00000000, 0x001A2327, 0x00618391, 
        0x0084B2C5, 0x00536F7C, 0x00020303, 0x00020203, 0x005D7F8D, 0x0082B0C4, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0080AFC2, 0x0080AFC2, 0x00638797, 0x00151D20, 0x00000000, 0x000D1215, 0x005C808F, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007BABC0, 
        0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 
        0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x0033505B, 
        0x00000000, 0x00000000, 0x002D4751, 0x00639AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 
        0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x002C4C5A, 0x00000000, 0x0016272E, 0x00508DA6, 0x00467D95, 0x0025424E, 0x00020304, 0x00000000, 0x00040809, 0x001E3741, 
        0x0041778D, 0x004B89A3, 0x00122228, 0x00000000, 0x00244451, 0x004786A0, 0x004887A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 
        0x003E809C, 0x003E809B, 0x003D7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397C98,
  0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0043839E, 0x0044849E, 0x0044859F, 0x004585A0, 0x004685A0, 
        0x004686A0, 0x004786A1, 0x004887A1, 0x003E758C, 0x00091114, 0x00000101, 0x0037677A, 0x0039697D, 0x000A1216, 0x00000101, 0x00000000, 0x00060B0E, 0x00376275, 0x004D8AA3, 0x004F8CA6, 0x000C161A, 0x00000000, 0x00375F70, 0x00528EA7, 0x00528FA8, 
        0x00538FA8, 0x00548FA8, 0x005490A9, 0x005690A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x0051889E, 0x00010102, 0x00000000, 0x00020304, 0x00020405, 0x00020404, 0x00010203, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121D22, 
        0x002E4955, 0x00467081, 0x00588BA0, 0x005E93AA, 0x005F96AC, 0x006299B0, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x004E7686, 0x00010102, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x002C424A, 0x006B9EB3, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 
        0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x0074A1B5, 0x00233036, 0x00000000, 0x00010203, 0x003F5862, 0x007EADC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 0x0080AFC2, 
        0x0080AFC3, 0x0081B0C3, 0x0082B0C3, 0x007199AA, 0x00050607, 0x00000000, 0x00000000, 0x00040506, 0x003D525B, 0x0085B2C5, 0x0085B2C5, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 
        0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 
        0x008FBACB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0091BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 
        0x0093BCCE, 0x0093BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCD, 0x0093BDCE, 0x0093BCCE, 0x0093BDCE, 0x0093BCCE, 0x0093BDCE, 0x0094BDCE, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BDCE, 0x0093BDCE, 0x0093BDCE, 
        0x0093BDCE, 0x0093BDCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCE, 0x0093BCCD, 0x0092BCCE, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 
        0x0091BBCC, 0x0091BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACC, 0x008FB9CB, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008BB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x007298A7, 0x00161E21, 0x00000000, 0x00000000, 0x0035484F, 0x007EA9BB, 0x0084B2C5, 
        0x0084B2C5, 0x0083B1C5, 0x002B3B41, 0x00000000, 0x00192226, 0x0075A0B1, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC2, 0x00597A88, 0x00050708, 0x00000000, 0x000E1315, 0x006F99AB, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007BABC0, 0x007BABBF, 
        0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0079A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 
        0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00649AB0, 
        0x0022363E, 0x00000000, 0x00000000, 0x003D606E, 0x00629AB1, 0x006199B0, 0x006198B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005893AB, 
        0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538EA8, 0x004B839A, 0x00000101, 0x00000000, 0x00020304, 0x00274552, 0x004E8CA5, 0x004D8AA4, 0x00447990, 0x0015262D, 0x00000000, 0x00000000, 
        0x00050A0C, 0x001B323C, 0x00000101, 0x00091114, 0x003E768C, 0x004887A1, 0x004787A1, 0x004786A1, 0x004685A0, 0x0045859F, 0x0045859F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0041839D, 0x0041829D, 0x0041829D, 0x0040819C, 0x003F819C, 0x003E809C, 
        0x003E809C, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397C98, 0x00387C98,
  0x00387B98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003C7E9A, 0x003C7E9A, 0x003C7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 
        0x004685A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x00254552, 0x00000000, 0x00030608, 0x00010202, 0x00000000, 0x00050A0C, 0x00223D49, 0x004C8AA4, 0x004E8BA5, 0x00407387, 0x00162830, 0x00000000, 0x00000000, 0x000B1316, 0x004E879F, 0x00528EA7, 
        0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AB, 0x005893AB, 0x0030505D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0005090A, 0x00101B1F, 0x002C4752, 0x00497789, 0x005E97AE, 0x005F97AF, 
        0x005F98AF, 0x006098B0, 0x006198B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00578397, 0x00090E10, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00182429, 0x006698AD, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 
        0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079A9BE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007BABBF, 0x007CACC0, 0x0032464E, 0x00010202, 0x00000000, 0x002C3D44, 0x0076A2B4, 0x007EAEC1, 0x007EAEC2, 0x007FAEC2, 0x007FAFC2, 
        0x0080AFC2, 0x0081AFC3, 0x007DABBD, 0x00243136, 0x00000000, 0x0011171A, 0x0027353B, 0x00050708, 0x00000000, 0x00192226, 0x00698D9C, 0x0082AFC1, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 
        0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x0089B6C8, 0x008AB6C8, 0x008BB6C8, 0x008AB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB8CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 
        0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACB, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0091BACC, 0x0091BBCC, 0x0091BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCD, 0x0091BBCD, 0x0092BBCD, 0x0092BCCD, 0x0092BBCD, 
        0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0093BCCD, 0x0092BCCD, 0x0093BCCD, 0x0093BCCD, 0x0092BCCE, 0x0093BCCD, 0x0093BCCE, 0x0093BCCE, 0x0092BCCD, 0x0093BCCD, 0x0093BCCD, 0x0093BCCE, 0x0093BCCD, 0x0093BCCD, 0x0093BCCD, 0x0093BCCE, 
        0x0093BCCE, 0x0093BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BBCD, 0x0092BCCD, 0x0092BBCD, 0x0092BBCD, 0x0092BCCD, 0x0091BBCD, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BACC, 0x0090BACC, 
        0x0090BACC, 0x0090BACC, 0x008FBACB, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008BB6C9, 0x008BB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0088B4C7, 0x007EA7B8, 0x00435B64, 0x00000000, 0x00000000, 0x00050708, 0x005E7F8C, 0x0084B2C5, 0x0084B2C5, 0x0083B1C5, 
        0x0083B1C4, 0x0083B1C4, 0x007CA9BC, 0x00101619, 0x00000000, 0x003A4E57, 0x007EACC0, 0x0080AFC2, 0x007CA9BD, 0x00405862, 0x00000000, 0x00000000, 0x00212D32, 0x007BAABE, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007AABBF, 
        0x007AABBF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A5BA, 0x0070A4B9, 0x0070A3B9, 
        0x006FA3B9, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 
        0x005A8BA0, 0x0010191D, 0x00000000, 0x00040709, 0x004E7B8E, 0x006199B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005C95AE, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005993AB, 0x005892AB, 
        0x005792AB, 0x005791AA, 0x005691AA, 0x005591AA, 0x005590A9, 0x00548FA9, 0x00548FA8, 0x00538FA8, 0x00528EA7, 0x0016272E, 0x00000000, 0x00080E11, 0x00010202, 0x00000000, 0x000E191D, 0x003A687B, 0x004A869F, 0x004D8AA4, 0x00335D6E, 0x00091115, 
        0x00000101, 0x00000000, 0x00000000, 0x00254552, 0x004887A1, 0x004787A1, 0x004786A1, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0043839F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F809C, 0x003E809C, 
        0x003D809B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00387C98, 0x00387C98,
  0x00377B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7F9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0042839D, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x004585A0, 
        0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x004887A1, 0x00091114, 0x00000000, 0x0004090A, 0x001D353F, 0x003D7084, 0x004C8AA4, 0x00407388, 0x00223E49, 0x00030708, 0x00000000, 0x00000000, 0x00111E23, 0x00000000, 0x00223B46, 0x00528EA7, 
        0x00528EA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x0050859C, 0x000F181C, 0x00000000, 0x00000000, 0x00121D22, 0x00457183, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AF, 
        0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x006194A8, 0x00162226, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x0011191D, 0x005F8EA2, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 
        0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BACBF, 0x004C6A76, 0x00080C0D, 0x00000000, 0x00171F23, 0x005F8493, 0x007EADC1, 0x007FAEC2, 0x007FAEC2, 
        0x007FAEC2, 0x007FAFC2, 0x0048626E, 0x00000000, 0x00000000, 0x005F818F, 0x0082B0C4, 0x005A7A88, 0x001D282C, 0x00000000, 0x00020203, 0x00364951, 0x006F96A6, 0x0084B2C5, 0x0086B2C6, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C7, 0x0087B4C7, 
        0x0088B4C7, 0x0087B5C7, 0x0088B5C7, 0x0088B5C8, 0x0089B6C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008BB6C9, 0x008AB6C8, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB8C9, 0x008CB8CA, 0x008DB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 
        0x008EB9CB, 0x008EB8CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x0090BACB, 0x008FBACC, 0x008FBACC, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0091BACC, 0x0090BACC, 0x0090BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 
        0x0091BBCD, 0x0092BBCD, 0x0092BBCD, 0x0092BBCD, 0x0091BBCD, 0x0091BBCD, 0x0091BCCD, 0x0092BCCD, 0x0092BBCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0091BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 0x0092BCCD, 
        0x0092BCCD, 0x0092BBCD, 0x0092BBCD, 0x0091BBCD, 0x0092BBCD, 0x0091BBCC, 0x0092BBCC, 0x0092BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0090BACC, 0x0091BACC, 0x0091BACC, 0x0090BBCC, 0x008FBACC, 0x0090BACC, 0x008FBACB, 0x008FBACC, 
        0x008FB9CC, 0x008FBACB, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008DB8CA, 0x008DB9CB, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB7C9, 0x008BB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008BB6C9, 
        0x008AB6C8, 0x0089B5C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C8, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0054707C, 0x00192226, 0x00000000, 0x00030405, 0x00000000, 0x00040606, 0x006C91A1, 0x0083B1C5, 0x0083B1C5, 0x0083B1C4, 
        0x0082B0C4, 0x0082B1C4, 0x0082B0C3, 0x00688E9D, 0x00060809, 0x00000000, 0x004E6B78, 0x00729CAE, 0x0027353C, 0x00000000, 0x00000000, 0x003B525C, 0x007AA9BD, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 
        0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0076A8BD, 0x0075A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 
        0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 
        0x00639AB1, 0x00487182, 0x00020404, 0x00000000, 0x00142125, 0x005A8FA5, 0x005F97B0, 0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AA, 
        0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00315665, 0x00000000, 0x0015252B, 0x00487F96, 0x002F5261, 0x000C161A, 0x00000000, 0x00000000, 0x00192E36, 0x003D7085, 0x004C8AA3, 0x0047829B, 
        0x00192F38, 0x00000000, 0x00091215, 0x004786A0, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003D809B, 
        0x003D7F9B, 0x003D7F9B, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00397C98, 0x00387B97,
  0x00377B97, 0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0042829D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0045849F, 
        0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x00396C81, 0x00000000, 0x00080E11, 0x0046829B, 0x004B89A3, 0x00284956, 0x00070D10, 0x00000000, 0x00000000, 0x00122026, 0x003F7084, 0x00467C93, 0x000E191D, 0x00000000, 0x003A6577, 
        0x00528EA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005591AA, 0x005791AA, 0x005792AA, 0x005892AA, 0x00335664, 0x00010202, 0x00020405, 0x003A5F6F, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E96AE, 
        0x005F97AF, 0x005F97AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x006199B0, 0x00619AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00659BB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x0018252B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00070A0C, 0x005D8B9F, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA3B8, 0x006FA3B9, 0x0070A3B8, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 
        0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x00658E9E, 0x000E1315, 0x00000000, 0x00050809, 0x0047626D, 0x007EADC1, 0x007EAEC2, 
        0x007FAEC2, 0x00698FA0, 0x00020404, 0x00000000, 0x00496470, 0x0080B0C3, 0x0081B0C3, 0x0082B0C3, 0x0079A4B6, 0x0048626D, 0x00010101, 0x00000000, 0x000A0E10, 0x00405760, 0x0084B2C5, 0x0085B2C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 
        0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008AB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 0x008FBACC, 0x008FBACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 
        0x0090BACC, 0x0091BACC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCD, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 
        0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACC, 0x008FBACC, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 
        0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008EB9CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 
        0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B5C6, 0x0087B4C7, 0x0087B4C6, 0x006C8F9F, 0x001D282C, 0x00030404, 0x00000000, 0x00222E32, 0x006B8F9F, 0x0028373D, 0x00000000, 0x00141B1E, 0x0083B1C4, 0x0083B1C4, 0x0082B1C4, 
        0x0082B0C3, 0x0082B0C3, 0x0081AFC3, 0x0081AFC3, 0x0049646F, 0x00000000, 0x00050708, 0x000F1517, 0x00000000, 0x00010203, 0x00597B89, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AAABE, 0x0079AABE, 
        0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0072A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 
        0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639BB1, 
        0x00639AB1, 0x00639AB1, 0x00395B68, 0x00000000, 0x00000000, 0x0023373F, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005893AB, 0x005892AA, 0x005792AA, 
        0x005791AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00477B91, 0x000A1215, 0x00000000, 0x00407185, 0x00508CA6, 0x004F8CA5, 0x00467F96, 0x00284856, 0x00000000, 0x00000000, 0x00050A0C, 0x001F3944, 0x00447F97, 
        0x000B161A, 0x00000000, 0x003A6C82, 0x004887A1, 0x004787A1, 0x004786A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003D809B, 
        0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7C99, 0x00397C98, 0x00387C98, 0x00377B98,
  0x00377B97, 0x00377B98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003F819B, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839F, 0x0043849F, 0x0044849F, 
        0x0044859F, 0x004685A0, 0x004686A0, 0x004686A0, 0x004887A1, 0x004887A1, 0x001C353F, 0x00000000, 0x001B333C, 0x000C161A, 0x00000000, 0x00000000, 0x00060A0C, 0x002C515F, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x00345C6D, 0x00010202, 0x000D171B, 
        0x004C869E, 0x00538EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x000E181C, 0x00040809, 0x00457084, 0x005B94AC, 0x005B95AC, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 
        0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x0023363E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040708, 
        0x004E7686, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007BABC0, 0x007AAABE, 0x00243238, 0x00000000, 0x00000000, 0x0027363D, 0x0077A4B7, 
        0x007DADC0, 0x0012191C, 0x00000000, 0x0027363C, 0x0080AFC2, 0x0080AFC3, 0x0081B0C3, 0x0081B0C3, 0x0082B0C3, 0x0082B0C3, 0x00749EAF, 0x00090D0E, 0x00000000, 0x00000000, 0x000C1113, 0x005F808E, 0x0082AEC1, 0x0085B2C6, 0x0086B3C6, 0x0086B3C6, 
        0x0086B4C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7CA, 
        0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008EB8CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x008FB9CB, 0x008FBACC, 0x0090BACB, 0x0090BACB, 0x008FBACC, 
        0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BBCC, 0x0090BACC, 0x0090BBCC, 0x0090BBCC, 0x0091BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BBCC, 0x0090BBCC, 0x0090BBCC, 0x0090BACC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 
        0x0090BACC, 0x0090BBCC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x008FBACC, 0x008FBACB, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008FBACB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 
        0x008EB9CB, 0x008EB9CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 
        0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0088B4C7, 0x0086B3C5, 0x007EA8B9, 0x00384B53, 0x00000000, 0x00000000, 0x00050707, 0x00000000, 0x002F4047, 0x0082B0C3, 0x00698D9C, 0x0007090A, 0x00000000, 0x0048616C, 0x0082B0C3, 0x0082B0C4, 
        0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC2, 0x00739EAF, 0x00182125, 0x00000000, 0x00000000, 0x00151D20, 0x006E99AB, 0x007DADC0, 0x007CADC0, 0x007CACC0, 0x007BACC0, 0x007BACBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x0079AABE, 0x0079A9BE, 
        0x0078A9BE, 0x0077A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 
        0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 
        0x00639AB1, 0x006199B1, 0x006199B0, 0x00253B44, 0x00000000, 0x00000000, 0x0033515E, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005A93AB, 0x0052869B, 0x005993AB, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005791AA, 
        0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00518CA6, 0x00243E49, 0x00000000, 0x0025404C, 0x00508DA6, 0x004F8CA6, 0x004F8BA5, 0x004E8CA5, 0x004D8BA4, 0x00437990, 0x0014242B, 0x00000101, 0x00000000, 0x00000000, 
        0x00000000, 0x001C3540, 0x004887A2, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0040819C, 0x0040819D, 0x003F819C, 0x003F809C, 0x003D809B, 0x003D7F9B, 
        0x003C7F9B, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D98, 0x00397C98, 0x00387B98, 0x00377B97,
  0x00377B97, 0x00387B97, 0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003B7E99, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 
        0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x003C7289, 0x00060C0E, 0x00000000, 0x00000000, 0x00070D0F, 0x00203A45, 0x00447C93, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x001A2F37, 0x00000000, 
        0x00294855, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005892AA, 0x00457386, 0x00010102, 0x00385D6D, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005C95AD, 0x005C96AD, 0x005D96AE, 
        0x005D96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006198B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649AB1, 0x0034505C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003B5A67, 
        0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A5BA, 0x0073A5BA, 0x0073A6BB, 0x0073A6BB, 
        0x0075A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0077A8BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABC0, 0x00425C67, 0x0006090A, 0x00000000, 0x00182125, 
        0x0028373E, 0x00000000, 0x00131B1E, 0x006F98A9, 0x007FAFC2, 0x0080AFC2, 0x0080AFC2, 0x0081AFC3, 0x0081B0C3, 0x0082B0C3, 0x00608392, 0x00000000, 0x00040506, 0x00151C1F, 0x00000000, 0x00000000, 0x00253237, 0x005D7D8B, 0x0082AEC1, 0x0085B3C5, 
        0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 
        0x008CB8C9, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CB, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x008FBACB, 
        0x008FBACB, 0x008FBACB, 0x008FBACB, 0x008FBACC, 0x008FBACC, 0x008FBACB, 0x008FBACB, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 0x0090BACC, 
        0x0090BACC, 0x008FBACC, 0x008FBACC, 0x0090BACB, 0x008FBACC, 0x008FBACB, 0x008FBACC, 0x008FBACB, 0x008FBACB, 0x008FBACB, 0x008FB9CB, 0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008EB8CA, 0x008DB9CA, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB7CA, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C9, 0x008AB6C9, 0x0089B6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0088B5C7, 
        0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x00759CAC, 0x00465E68, 0x00070A0B, 0x00000000, 0x00000000, 0x0035484F, 0x00678A99, 0x00090C0D, 0x00000000, 0x00587885, 0x0083B1C4, 0x0035484F, 0x00000000, 0x000C1113, 0x00719BAC, 0x0081B0C3, 
        0x0081AFC3, 0x0080AFC2, 0x0080AFC2, 0x00678D9C, 0x0026353B, 0x00000000, 0x00000000, 0x0031434B, 0x0074A1B4, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007CABC0, 0x007BABC0, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 
        0x0078A9BE, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 
        0x006299B1, 0x006199B0, 0x006199B0, 0x005B91A7, 0x00152126, 0x00000000, 0x00000000, 0x003A5E6C, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x002E4C58, 0x00080E10, 0x00548DA3, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005791AA, 
        0x005691AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x003E6C7F, 0x00000000, 0x000E191D, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x00335E6F, 0x00091215, 0x00000000, 
        0x00060B0D, 0x003C7289, 0x004887A1, 0x004787A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809B, 0x003D809B, 0x003D7F9B, 
        0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97,
  0x00367A96, 0x00377B97, 0x00387B97, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040829D, 0x0040829D, 0x0042829D, 0x0042839E, 0x0043839E, 0x0043849F, 
        0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x0022414E, 0x00000000, 0x00070D10, 0x003C6D82, 0x004B89A3, 0x004C89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x004C859E, 0x00080F12, 
        0x00000101, 0x0044778C, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005892AB, 0x002B4854, 0x003C6373, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 
        0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F98AF, 0x005F97AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x006299B1, 0x00639AB1, 0x00649AB1, 0x00456A7A, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0035515D, 0x00689EB4, 
        0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 
        0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0073A5B9, 0x006C9AAD, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007BABC0, 0x00638A9B, 0x00182226, 0x00000000, 
        0x00000000, 0x00010203, 0x00557582, 0x007EAEC1, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 0x0080AFC2, 0x007BA7BA, 0x00182124, 0x00000000, 0x0026353B, 0x00759FB1, 0x00435C66, 0x00000000, 0x00000000, 0x00040606, 0x00202B30, 0x005C7C8A, 
        0x0085B2C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 
        0x008BB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CB, 0x008DB9CA, 0x008EB8CA, 0x008EB9CA, 0x008EB9CB, 
        0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008FB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FB9CB, 0x008FBACB, 0x008FB9CB, 0x008EB9CB, 0x008FB9CB, 0x008FB9CB, 
        0x008FB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CA, 0x008EB8CA, 0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB7CA, 
        0x008CB8CA, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0089B5C8, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0088B4C7, 
        0x0087B4C7, 0x0087B4C7, 0x007CA6B8, 0x003B5058, 0x000F1517, 0x00000000, 0x00000000, 0x00010202, 0x00000000, 0x00516E7A, 0x0084B1C5, 0x00425963, 0x00000000, 0x000B0F10, 0x007CA9BC, 0x00739BAD, 0x00080B0D, 0x00000000, 0x003C525B, 0x007EADC0, 
        0x0080AFC2, 0x007FAFC2, 0x00435C66, 0x000B1012, 0x00000000, 0x000A0E10, 0x00577987, 0x007BAABE, 0x007DADC0, 0x007CACC0, 0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AAABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 
        0x0077A9BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A3BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 
        0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 
        0x006299B0, 0x006199B0, 0x006098AF, 0x006098AF, 0x004D7B8E, 0x0005090A, 0x00000000, 0x00030506, 0x0031505D, 0x005A92A9, 0x004F8297, 0x0021363F, 0x00000000, 0x00345765, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691A9, 
        0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00508AA3, 0x00070C0F, 0x00020304, 0x003E6E81, 0x00508CA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA3, 0x004B89A3, 0x004A87A1, 0x000E1A1F, 0x00000000, 
        0x0023424E, 0x004887A1, 0x004887A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E7F9B, 0x003D7F9B, 0x003C7F9A, 
        0x003C7F9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97,
  0x00367A97, 0x00367B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043839E, 
        0x0044849F, 0x0044859F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x0047859F, 0x00080E11, 0x00000101, 0x002C5363, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x003A6679, 
        0x00000000, 0x000B1316, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A93AB, 0x005A94AC, 0x005B95AC, 0x005B95AD, 0x005C95AD, 
        0x005D96AD, 0x005D96AE, 0x005E96AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00507D90, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00273B44, 0x00679DB4, 0x00679EB4, 
        0x00689EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006B9FB6, 0x006BA0B6, 0x006BA1B6, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 
        0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0075A7BC, 0x00496976, 0x00030505, 0x004D6E7C, 0x0075A6BA, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABC0, 0x0078A7BB, 0x0032454D, 
        0x00000101, 0x00000000, 0x0011171A, 0x00658B9B, 0x007DACC1, 0x007EAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x004A6671, 0x00010202, 0x00040506, 0x005E808E, 0x0082B0C4, 0x00171F23, 0x00000000, 0x00141B1D, 0x00050708, 0x00000000, 0x00000000, 
        0x00192226, 0x00698D9C, 0x0085B2C5, 0x0085B2C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C6, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C8, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 
        0x008AB6C8, 0x008AB6C9, 0x008AB7C9, 0x008BB6C9, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB7CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB9CA, 
        0x008EB9CA, 0x008DB9CB, 0x008EB8CB, 0x008EB9CA, 0x008EB9CA, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 
        0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB9CB, 0x008EB8CA, 0x008EB8CA, 0x008DB9CA, 0x008DB9CB, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8C9, 0x008CB8C9, 0x008CB7C9, 0x008CB7C9, 
        0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C7, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0088B4C6, 0x0087B4C7, 
        0x0082AEBF, 0x00435A64, 0x00050708, 0x00000000, 0x00000000, 0x001E292D, 0x007299A9, 0x0047606A, 0x00000000, 0x00090D0E, 0x0081AFC2, 0x00739BAC, 0x0012181B, 0x00000000, 0x00374A52, 0x0081B0C3, 0x0046606B, 0x00000000, 0x00060809, 0x006E97A8, 
        0x0076A1B4, 0x00222F34, 0x00000000, 0x00000000, 0x001D282C, 0x00709CAE, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007BABC0, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 
        0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 
        0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00689EB5, 0x00689DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB0, 0x006199B0, 
        0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x003A5D6B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00101B1F, 0x005993AC, 0x005893AB, 0x005892AB, 0x005792AB, 0x005791AA, 0x005691AA, 0x005591A9, 
        0x005590A9, 0x005490A8, 0x005390A8, 0x00538FA8, 0x00528EA8, 0x00192B33, 0x00000000, 0x00223D48, 0x00508DA6, 0x004F8CA6, 0x004F8CA6, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x002D5262, 0x00000101, 0x00080E11, 
        0x004886A1, 0x004787A1, 0x004786A1, 0x004786A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040829D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 
        0x003C7E9A, 0x003B7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00377B98, 0x00367B97, 0x00367A97,
  0x00367A96, 0x00367A97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 0x0040819D, 0x0040829C, 0x0041829D, 0x0041829E, 0x0042839E, 0x0043839E, 
        0x0043849E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x0037687B, 0x00000000, 0x000A1216, 0x00437B93, 0x004B89A3, 0x004B89A4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 0x004D89A2, 
        0x001E353F, 0x00000000, 0x00223C48, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AB, 0x005892AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005B94AC, 0x005B95AD, 0x005B95AD, 
        0x005D95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006099B0, 0x006199B0, 0x006199B0, 0x00538397, 0x0006090B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001A292F, 0x006195AB, 0x00679DB3, 0x00679DB4, 
        0x00689EB4, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA0B7, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 
        0x0072A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BC, 0x0074A7BB, 0x004D6E7C, 0x0006090A, 0x00202E34, 0x005B8192, 0x0075A5BA, 0x0077A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BACC0, 
        0x004E6D79, 0x00121A1D, 0x00000000, 0x00000000, 0x003E5660, 0x00719CAE, 0x007EAEC1, 0x007FAEC2, 0x0075A0B2, 0x00141C1F, 0x00000000, 0x002C3D43, 0x0081AFC3, 0x004D6975, 0x00000000, 0x00090C0D, 0x006B90A1, 0x0077A1B3, 0x000A0D0F, 0x00000000, 
        0x00000000, 0x00000000, 0x00233035, 0x005C7C89, 0x0079A3B4, 0x0085B3C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B4C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C7, 0x0089B5C8, 
        0x008AB5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB6C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008DB8CA, 
        0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008EB9CA, 0x008DB8CA, 0x008EB8CA, 0x008DB8CB, 0x008DB9CA, 0x008EB9CA, 0x008EB8CB, 0x008EB9CA, 0x008EB8CA, 0x008EB8CA, 0x008EB9CA, 0x008DB8CA, 0x008DB9CB, 0x008DB8CA, 
        0x008EB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB7CA, 0x008CB8C9, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x008BB6C9, 0x008BB6C9, 0x008BB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0087B4C7, 0x0087B4C7, 0x0085B2C4, 0x007094A4, 0x00435963, 
        0x0006090A, 0x00000000, 0x00050708, 0x00202B30, 0x005B7A87, 0x0084B2C5, 0x0084B2C5, 0x007AA4B6, 0x0011171A, 0x00000000, 0x00354850, 0x0082B0C4, 0x00465F69, 0x00000000, 0x000B0F11, 0x00698F9F, 0x0081AFC3, 0x00192326, 0x00000000, 0x00202C31, 
        0x0006090A, 0x00000000, 0x000A0E10, 0x003E555F, 0x007DADC1, 0x007DADC0, 0x007CACC0, 0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BD, 0x0078A9BD, 0x0077A8BD, 0x0076A8BD, 
        0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0073A6BB, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 
        0x006CA1B7, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x006299B1, 0x006299B0, 0x006199B0, 
        0x006198B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x0020343D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0048788C, 0x005993AB, 0x005892AB, 0x005892AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 
        0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00355C6C, 0x00000101, 0x000C1518, 0x004A839A, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004D8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C89A4, 0x004B89A3, 0x00427B93, 0x00091215, 0x00000000, 0x0038687C, 
        0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 
        0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B98, 0x00367A97, 0x00367A97,
  0x00357A96, 0x00357A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 
        0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x00213F4B, 0x00000000, 0x001B333D, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004F8CA5, 
        0x00487F96, 0x00070C0E, 0x00010303, 0x00396374, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691A9, 0x005791AA, 0x005892AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 
        0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x00588BA0, 0x00131E22, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1215, 0x0058889B, 0x00659CB3, 0x00669CB3, 0x00679DB3, 
        0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA1B8, 0x006EA2B8, 0x006EA3B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 
        0x0072A5BA, 0x0072A5BA, 0x0073A6BA, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x00507381, 0x00010202, 0x00040506, 0x00293B42, 0x00648FA1, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 0x007AABBF, 0x007BABBF, 
        0x007BABBF, 0x006D99AA, 0x00364C55, 0x00000000, 0x00000000, 0x00151D20, 0x004F6C79, 0x007EAEC1, 0x0046616C, 0x00000000, 0x00080B0C, 0x0076A2B4, 0x00749FB0, 0x00141B1E, 0x00000000, 0x0034474E, 0x0081B0C3, 0x004C6772, 0x00000000, 0x00080B0D, 
        0x00405660, 0x00141B1E, 0x00000000, 0x00000000, 0x001A2428, 0x0040565F, 0x00739AAB, 0x0085B3C6, 0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B3C6, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 
        0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B6C8, 0x0089B6C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008AB6C9, 0x008AB6C9, 0x008AB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 
        0x008CB8C9, 0x008CB7C9, 0x008CB8CA, 0x008CB7CA, 0x008CB7CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8C9, 0x008DB8CA, 0x008DB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 
        0x008CB8C9, 0x008CB8CA, 0x008CB8CA, 0x008CB8CA, 0x008CB8C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008BB6C8, 0x008AB6C9, 0x008AB6C9, 
        0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 0x0086B4C6, 0x005A7986, 0x002C3A41, 0x000B0E10, 0x00000000, 
        0x00000000, 0x00060809, 0x0053707C, 0x0081AEC1, 0x0084B1C5, 0x0084B1C5, 0x0083B1C4, 0x0083B1C4, 0x0047616B, 0x00010101, 0x00050708, 0x00658A99, 0x0081B0C3, 0x00161E21, 0x00000000, 0x0032444C, 0x007FAEC2, 0x0048626E, 0x00000000, 0x00000000, 
        0x00000000, 0x0026343B, 0x00658C9C, 0x007DACC0, 0x007CADC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 
        0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006299B1, 0x006299B1, 0x006199B0, 0x006098B0, 
        0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x0054889E, 0x00060B0C, 0x00000000, 0x00000000, 0x00000000, 0x00253E48, 0x005892AA, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005490A9, 
        0x00548FA8, 0x00538FA8, 0x00538FA7, 0x004A8197, 0x000B1316, 0x00000000, 0x003F7084, 0x00508DA6, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004A89A3, 0x001B333C, 0x00000000, 0x00223F4B, 0x004887A2, 
        0x004887A1, 0x004786A1, 0x004685A0, 0x004685A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839F, 0x0042839E, 0x0041839D, 0x0041829D, 0x0040829C, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9A, 0x003C7E9A, 0x003B7E9A, 
        0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96,
  0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0042839D, 
        0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x00407991, 0x000C161B, 0x00000000, 0x00335E70, 0x004A89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 
        0x004F8CA6, 0x003C6B7E, 0x00000000, 0x000E191E, 0x004B8299, 0x00528EA8, 0x00528FA7, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005791AA, 0x005791AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005994AB, 0x005A94AC, 0x005A94AC, 
        0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x006098AF, 0x006098AF, 0x001D2F36, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x0058899E, 0x00649BB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 
        0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0071A4B9, 
        0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x00131C1F, 0x00000000, 0x00000000, 0x00020304, 0x00374F59, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 0x007AABBE, 
        0x007AABBF, 0x007BABBF, 0x007BABBF, 0x005F8494, 0x000B0F11, 0x00000000, 0x00000000, 0x001F2C31, 0x00050809, 0x00000000, 0x0048636E, 0x007FAEC2, 0x00445E68, 0x00000000, 0x00050607, 0x007AA7BA, 0x0075A0B1, 0x00090D0E, 0x00000000, 0x00394D56, 
        0x007FAEC0, 0x007DAABC, 0x00577682, 0x0011171A, 0x00000000, 0x00000000, 0x00040506, 0x0027353A, 0x00698D9C, 0x0085B3C5, 0x0085B3C6, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 
        0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x008AB5C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008AB6C9, 0x008AB6C9, 0x008BB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008CB7C9, 0x008CB7C9, 0x008BB7C9, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7CA, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 0x008CB7C9, 
        0x008CB7C9, 0x008CB7C9, 0x008CB7CA, 0x008BB7C9, 0x008CB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008AB7C9, 0x008BB6C9, 0x008BB7C9, 0x008AB6C9, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 
        0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0083B0C2, 0x004C6570, 0x0011171A, 0x00030404, 0x00000000, 0x00010101, 0x00384C54, 
        0x001A2327, 0x00000000, 0x004F6B76, 0x0084B1C4, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0082B0C4, 0x007CA8BA, 0x0012191C, 0x00000000, 0x0026343A, 0x007CAABE, 0x00688F9F, 0x00000000, 0x00020303, 0x00253339, 0x00010202, 0x00000000, 0x00000101, 
        0x004F6D7A, 0x007CACBF, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007BACBF, 0x007BABBF, 0x007BABBF, 0x007AAABF, 0x007AAABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 
        0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689DB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098B0, 
        0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D95AE, 0x005B93AB, 0x002B4652, 0x00000000, 0x00000000, 0x00090F12, 0x0049798D, 0x005893AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 
        0x00548FA8, 0x00538FA8, 0x00528EA7, 0x001C323A, 0x00000000, 0x002F5261, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00335E70, 0x00000000, 0x000C171B, 0x00407991, 0x004887A1, 
        0x004787A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849E, 0x0043849E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003E819C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 
        0x003A7E9A, 0x00397C99, 0x00397D98, 0x00397C98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00357A96, 0x00357996,
  0x00347996, 0x00357996, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E7F9B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829E, 
        0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x002D5566, 0x00010203, 0x00050A0C, 0x00447E96, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 
        0x004F8CA5, 0x004F8DA6, 0x0025424E, 0x00000000, 0x00243E4A, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 
        0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F98AF, 0x00273F49, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020404, 0x004B7586, 0x00639AB2, 0x00649BB2, 0x00659BB2, 0x00659BB3, 0x00669CB3, 
        0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x00699FB5, 0x006A9FB6, 0x006A9FB6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 
        0x0071A4BA, 0x0071A4B9, 0x0071A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x00182327, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000F1518, 0x00557987, 0x0072A2B5, 0x0077A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABF, 0x0079AABF, 
        0x007AABBE, 0x007AABBF, 0x007AABBF, 0x007BACC0, 0x007CACC0, 0x00354A53, 0x00070A0B, 0x00000000, 0x00000000, 0x000F1517, 0x006A92A2, 0x0075A0B2, 0x000A0F10, 0x00000000, 0x004E6B77, 0x0080AFC2, 0x00374C54, 0x00000000, 0x000C1113, 0x006C94A4, 
        0x0082B0C3, 0x0082B0C3, 0x0082B0C4, 0x0083B1C4, 0x00597986, 0x001B2529, 0x00000000, 0x00000000, 0x00000000, 0x00192226, 0x0054717D, 0x00749CAD, 0x0080ADBF, 0x0086B3C5, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B3C7, 0x0087B4C6, 0x0087B4C7, 
        0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C9, 0x008AB6C8, 0x008BB6C9, 0x008AB6C9, 
        0x008BB6C9, 0x008BB6C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 0x008BB7C9, 
        0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008BB7C9, 0x008BB7C9, 0x008BB6C9, 0x008BB6C9, 0x008BB6C9, 0x008AB6C9, 0x008BB6C8, 0x008AB6C8, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x0089B5C8, 0x0089B6C8, 0x0089B5C8, 
        0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x007CA6B7, 0x00698D9C, 0x00384B53, 0x00020203, 0x00000000, 0x00020203, 0x00101517, 0x00394C54, 0x00769FB0, 0x0084B2C5, 
        0x00608290, 0x00000000, 0x00131A1D, 0x0080ADC0, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0082B0C3, 0x0081B0C3, 0x00567682, 0x00000000, 0x00040506, 0x005D808E, 0x0079A5B8, 0x00222F34, 0x00000000, 0x00000000, 0x00030506, 0x0026343B, 0x00729EB1, 
        0x007DADC1, 0x007CACC1, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x0079AABF, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0074A7BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 
        0x006A9FB6, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00659CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098AF, 0x005F98AF, 
        0x005F98AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x0040697A, 0x00010203, 0x00000000, 0x0027424C, 0x005893AB, 0x005892AB, 0x005792AB, 0x005791AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A8, 0x00548FA8, 
        0x00538FA8, 0x00528FA7, 0x00335968, 0x00000000, 0x0016272E, 0x004D89A1, 0x00508CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00447E96, 0x00050A0C, 0x00010203, 0x002E5666, 0x004887A1, 0x004887A1, 
        0x004786A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0041839E, 0x0041829D, 0x0041829D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 
        0x003A7D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377A97, 0x00367A97, 0x00357A96, 0x00357996,
  0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 
        0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A2, 0x00162932, 0x00000000, 0x001D3540, 0x004A87A1, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 
        0x004E8BA5, 0x004F8CA5, 0x004D87A0, 0x0015252B, 0x00000000, 0x00325766, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005791AA, 0x005893AB, 0x005993AB, 0x005A93AB, 0x005A94AC, 
        0x005A94AC, 0x005B94AD, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x00304D59, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x003A5B6A, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649CB2, 0x00659CB3, 
        0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA3B8, 0x006FA3B9, 0x006FA3B9, 
        0x0070A4B9, 0x0070A4BA, 0x0071A4BA, 0x0072A4BA, 0x0072A5BA, 0x0073A5BA, 0x00638EA1, 0x00090D0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00202E34, 0x00577B8A, 0x0077A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 
        0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BACC0, 0x00618696, 0x002A3A41, 0x00000000, 0x00000000, 0x00182125, 0x0027363D, 0x00000000, 0x0026353B, 0x007EAEC1, 0x00688F9F, 0x000A0F10, 0x00000000, 0x00415963, 0x0080AFC3, 
        0x0080B0C3, 0x0082B0C3, 0x0081B0C3, 0x0082B0C4, 0x0082B0C4, 0x0053717D, 0x00000000, 0x000C1012, 0x001C262A, 0x00000000, 0x00000000, 0x000A0E10, 0x002C3C42, 0x004E6873, 0x007096A6, 0x0086B3C6, 0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B3C6, 
        0x0087B3C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C6, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x008AB6C8, 0x0089B5C8, 0x0089B6C8, 0x0089B6C8, 
        0x008AB5C8, 0x0089B6C8, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008BB6C8, 0x008AB6C9, 0x008AB6C8, 0x008AB7C8, 0x008BB6C9, 0x008AB7C9, 0x008BB6C8, 0x008BB6C8, 0x008AB6C8, 
        0x008BB6C8, 0x008AB6C8, 0x008AB6C9, 0x008BB6C8, 0x008AB6C9, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB6C8, 0x008AB5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C7, 0x0088B5C7, 
        0x0089B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0081ADBF, 0x0060808D, 0x003C5059, 0x001C2529, 0x00000000, 0x00000000, 0x00060809, 0x002D3C43, 0x0053717D, 0x007AA4B5, 0x0084B2C5, 0x0084B2C5, 0x0083B1C4, 
        0x0080AEC0, 0x001C262A, 0x00000000, 0x005B7A88, 0x0082B0C3, 0x0082B0C3, 0x0082B0C3, 0x0081AFC3, 0x0081AFC3, 0x0080AFC2, 0x0029383E, 0x00000000, 0x00182125, 0x00212D32, 0x00000000, 0x00000000, 0x001D292E, 0x00557683, 0x007DADC0, 0x007DADC1, 
        0x007CACC0, 0x007CACC0, 0x007CACBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x0079AABE, 0x0079AABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BD, 0x0076A7BC, 0x0076A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 
        0x0073A6BB, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 
        0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00689DB4, 0x00689DB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006198B0, 0x006098B0, 0x006098AF, 0x005F97AF, 
        0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B94AD, 0x00447082, 0x00040708, 0x00090E11, 0x00558DA4, 0x005892AB, 0x005892AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 
        0x00538FA8, 0x003F6E81, 0x00020405, 0x00030506, 0x00396577, 0x00508DA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004987A1, 0x001D353F, 0x00000000, 0x00162A32, 0x004887A1, 0x004887A1, 0x004786A1, 
        0x004686A0, 0x004685A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9A, 0x003C7E9B, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 
        0x00397D99, 0x00397C98, 0x00387C98, 0x00387B97, 0x00377B97, 0x00367A97, 0x00367A96, 0x00357996, 0x00347996,
  0x00347895, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F809C, 0x0040819C, 0x0040819D, 0x0041829D, 
        0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x0045819A, 0x00030608, 0x00000000, 0x00376779, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 
        0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x002E5160, 0x00000101, 0x00040708, 0x003F6F83, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005591AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005893AB, 0x005993AB, 
        0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x003C6171, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002A424C, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 
        0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x006A9FB5, 0x006A9FB5, 0x006B9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA2B8, 
        0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A4BA, 0x0039525D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00131B1E, 0x0038515B, 0x00293B42, 0x0006090A, 0x0026373D, 0x0071A1B4, 0x0077A9BE, 0x0078A9BE, 
        0x0079AABE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007BABBF, 0x007BACBF, 0x0077A6B9, 0x005E8292, 0x00131A1E, 0x00000000, 0x00000000, 0x00000000, 0x0048636E, 0x007EADC1, 0x002B3C42, 0x00000000, 0x0011171A, 0x007FAFC2, 0x0080AFC2, 
        0x0080AFC3, 0x0080AFC3, 0x0081AFC3, 0x0081B0C3, 0x007FADC0, 0x00161E21, 0x00000000, 0x004C6873, 0x007DAABC, 0x00648896, 0x002F4047, 0x00010101, 0x00000000, 0x00020203, 0x000A0D0F, 0x001C272B, 0x004B646F, 0x007BA4B7, 0x0085B2C5, 0x0086B3C6, 
        0x0085B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0089B5C7, 0x0089B5C8, 
        0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B6C8, 0x008AB5C8, 0x008AB6C8, 0x008AB6C8, 0x0089B6C8, 0x008AB6C8, 0x008AB5C8, 0x008AB5C8, 0x0089B6C8, 0x008AB6C8, 0x0089B6C8, 0x008AB6C8, 0x0089B6C8, 
        0x0089B5C8, 0x0089B6C8, 0x0089B6C8, 0x0089B5C8, 0x0089B6C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 
        0x0087B4C7, 0x0087B4C6, 0x0087B4C7, 0x0087B4C6, 0x0086B4C6, 0x00658896, 0x0032444B, 0x00101618, 0x00050708, 0x00000000, 0x00000000, 0x00141B1E, 0x004E6873, 0x00749DAD, 0x007FACBE, 0x0084B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 
        0x0082AFC3, 0x004F6B77, 0x00000000, 0x00151C20, 0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC3, 0x0080AFC2, 0x007FAFC2, 0x005C7E8C, 0x00000000, 0x00000000, 0x00000000, 0x00060809, 0x004E6D79, 0x0075A2B5, 0x007DADC1, 0x007CACC0, 0x007CACC0, 
        0x007CACC0, 0x007BABC0, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 
        0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B8, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x00699FB5, 
        0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005E97AF, 
        0x005E97AE, 0x005E96AE, 0x005D96AD, 0x005C96AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x003F6778, 0x00000000, 0x00406A7C, 0x005893AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 
        0x004B8299, 0x00111E24, 0x00000000, 0x00000000, 0x000B1518, 0x003E6E82, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x0037667A, 0x00000000, 0x00040708, 0x0045819B, 0x004887A1, 0x004786A1, 0x004786A0, 
        0x004686A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 
        0x00397D99, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347996,
  0x00337895, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040829D, 
        0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A1, 0x004886A1, 0x004887A1, 0x00356477, 0x00000000, 0x00060C0F, 0x0047859E, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 
        0x004D8BA5, 0x004B88A0, 0x00274754, 0x00000000, 0x00000000, 0x00000000, 0x00101D22, 0x004C859C, 0x00528FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005692AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 
        0x005A94AB, 0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005C95AD, 0x004B7A8D, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001D2E35, 0x006098B0, 0x006199B0, 0x006299B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 
        0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689DB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x006EA1B8, 0x006EA2B7, 0x006EA2B8, 
        0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x006491A4, 0x000F1618, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00223137, 0x0074A7BB, 0x0075A7BC, 0x0076A7BC, 0x006C9AAD, 0x00233238, 0x0006090A, 0x00476571, 0x0073A4B8, 
        0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABF, 0x007AAABF, 0x007AAABF, 0x007BABBF, 0x007BABC0, 0x007BACC0, 0x007BACC0, 0x003F5862, 0x0006090A, 0x00000000, 0x00000000, 0x00171F23, 0x00000000, 0x00000000, 0x00628796, 0x007FAEC2, 0x007FAEC2, 
        0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x0081AFC3, 0x005D7E8D, 0x00000000, 0x000C1012, 0x007BA7B9, 0x0082B0C4, 0x0082B0C4, 0x0083B1C4, 0x007FACBE, 0x004E6A75, 0x00192226, 0x0007090A, 0x00010202, 0x00000000, 0x00000000, 0x00192225, 0x004B6570, 
        0x00739BAC, 0x007EA9BB, 0x0083AEC2, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C8, 
        0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C7, 0x0089B5C8, 0x0089B5C7, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 0x0089B5C8, 
        0x0089B5C8, 0x0089B5C7, 0x0089B5C7, 0x0089B5C7, 0x0088B5C8, 0x0089B5C7, 0x0088B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0088B4C7, 0x0087B4C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0085B2C4, 
        0x0081ADBF, 0x007CA6B7, 0x00648694, 0x0035464E, 0x00080B0C, 0x00000000, 0x00000000, 0x00040506, 0x000B0F11, 0x00020303, 0x00020303, 0x00739CAD, 0x0084B2C5, 0x0084B2C4, 0x0084B1C5, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0082B0C4, 
        0x0082B0C3, 0x007098A9, 0x0012181B, 0x00000000, 0x005B7C8A, 0x0080AFC3, 0x0080AFC2, 0x007DACBE, 0x006D96A7, 0x002A3A40, 0x00000000, 0x00000000, 0x00030405, 0x002D3F46, 0x0077A5B8, 0x007CADC1, 0x007DADC0, 0x007CACC0, 0x007CACC0, 0x007BACBF, 
        0x007BABBF, 0x007BABBF, 0x007AAABF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0073A5BB, 
        0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4B9, 0x0071A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B6, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B5, 0x00699FB5, 0x00699EB5, 
        0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB4, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x006097AF, 0x005F97AF, 0x005E97AE, 
        0x005D96AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005B94AD, 0x005A94AC, 0x005993AB, 0x002F4D5A, 0x00192A31, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00518DA7, 
        0x0026434F, 0x00000000, 0x00172A31, 0x000D171B, 0x00000000, 0x00000000, 0x00284855, 0x004B87A1, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x0047859E, 0x00060C0E, 0x00000000, 0x00356579, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 
        0x004686A0, 0x004485A0, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 
        0x00397C99, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337895,
  0x00337895, 0x00337895, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 
        0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x0047859F, 0x001E3742, 0x00000000, 0x00172B33, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 
        0x003D6F83, 0x0014252C, 0x00000000, 0x00000101, 0x001F3843, 0x001C323B, 0x00000000, 0x00243F4A, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x00426E81, 0x00538CA2, 
        0x005993AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x00487689, 0x00070B0D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0018272D, 0x005C94AA, 0x006098AF, 0x006098B0, 0x006099B0, 0x006299B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00649AB2, 
        0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 0x006CA1B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 
        0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0071A4B9, 0x00354D57, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00162024, 0x0072A4B8, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x00537685, 0x000E1316, 0x00172025, 
        0x0050717F, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABC0, 0x006F9BAD, 0x00384E58, 0x000D1214, 0x00000000, 0x00000000, 0x000C1012, 0x00557683, 0x007AA7B9, 0x007FAEC2, 
        0x007EAEC2, 0x007FAEC2, 0x0080AEC2, 0x007FAFC2, 0x00182024, 0x00000000, 0x003F5660, 0x007FAEC1, 0x0081B0C3, 0x0082B0C3, 0x0082B0C3, 0x0082B1C4, 0x0083B0C4, 0x0082B1C4, 0x006E95A5, 0x0049636E, 0x002D3C43, 0x0007090A, 0x00000000, 0x00000000, 
        0x00000000, 0x00161E21, 0x0034464E, 0x004F6A76, 0x00638693, 0x0077A0B1, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0088B4C7, 
        0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0089B5C8, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 
        0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B5C7, 0x0088B4C7, 0x0088B4C7, 0x0088B5C7, 0x0088B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0081ACBE, 0x006D92A2, 0x00597884, 0x00435963, 
        0x00263339, 0x00070A0B, 0x00000000, 0x00000000, 0x00060809, 0x001E292D, 0x00394D55, 0x005C7C8A, 0x007CA8BA, 0x001E292D, 0x00000000, 0x00435A65, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0082B1C4, 0x0082B1C4, 0x0082B1C4, 0x0082B0C3, 0x0081B0C3, 
        0x0081B0C3, 0x0081AFC3, 0x0032444C, 0x00000000, 0x00212D32, 0x007BA9BB, 0x00608492, 0x0033464F, 0x00030405, 0x00000000, 0x00050809, 0x002E4047, 0x00648B9B, 0x007DADC1, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BABC0, 0x007BABBF, 
        0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 
        0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00699FB5, 0x00699EB5, 
        0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006198B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 
        0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x004C7E93, 0x004F849A, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00355C6D, 
        0x00000000, 0x000F1B20, 0x004E8AA2, 0x0049829A, 0x001C333C, 0x00000000, 0x00000000, 0x0015272E, 0x003F7288, 0x004C8AA4, 0x004B8AA3, 0x004A89A3, 0x00172B33, 0x00000000, 0x001E3843, 0x004785A0, 0x004787A1, 0x004786A1, 0x004786A0, 0x004686A0, 
        0x0045859F, 0x0045849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E99, 0x003A7D99, 0x00397D99, 0x00397D99, 
        0x00397C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337895,
  0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397D98, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003F819C, 0x003F819C, 
        0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004786A0, 0x004787A1, 0x004887A1, 0x00417A92, 0x00091114, 0x00000000, 0x00294C5B, 0x004B89A3, 0x004B89A3, 0x002D5262, 
        0x00060C0E, 0x00000000, 0x00030507, 0x00315868, 0x004D89A1, 0x004A849C, 0x00111E23, 0x00000000, 0x00335A6A, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005590A9, 0x005590A9, 0x005690A9, 0x005691AA, 0x005791AA, 0x00111D22, 0x00213741, 
        0x005893AB, 0x005993AB, 0x005994AC, 0x00426D7F, 0x00090F12, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D1519, 0x00528498, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 
        0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x005D889B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040708, 0x00588091, 0x0073A5BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0060899A, 0x00040607, 
        0x00030405, 0x001D292E, 0x005F8797, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABF, 0x007AAABF, 0x007AABBF, 0x007BABC0, 0x007BABBF, 0x007CACC0, 0x006C97A8, 0x003F5761, 0x00020404, 0x00000000, 0x00030506, 0x00192226, 0x004D6976, 
        0x007EAEC1, 0x007EAEC2, 0x007FAEC2, 0x005A7C8A, 0x00000000, 0x000A0E0F, 0x00668C9B, 0x0080AFC3, 0x0080AFC3, 0x0081AFC3, 0x0081B0C3, 0x0081B0C3, 0x0082B0C3, 0x0082B0C4, 0x0082B0C4, 0x0082B0C4, 0x0082B0C3, 0x000B0F11, 0x00000000, 0x00243137, 
        0x001A2327, 0x00000000, 0x00000000, 0x00000000, 0x00070A0B, 0x0012181B, 0x001E282C, 0x00364951, 0x0055717E, 0x007199A8, 0x0085B3C5, 0x0086B2C5, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0086B4C6, 
        0x0087B4C6, 0x0086B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 
        0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C7, 0x0087B4C6, 0x0087B4C6, 0x0087B4C6, 0x0087B4C6, 0x0086B3C6, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x007FA9BB, 0x00648695, 0x00465E68, 0x0029373D, 0x00172023, 0x000C1012, 0x00030404, 0x00000000, 
        0x00000000, 0x00070A0B, 0x002E3E44, 0x0055737F, 0x006E95A5, 0x007BA6B7, 0x0084B2C5, 0x0084B2C5, 0x0084B1C4, 0x00425A63, 0x00000000, 0x00222F34, 0x0080ADC0, 0x0082B0C4, 0x0082B0C4, 0x0082B0C3, 0x0081B0C3, 0x0081AFC3, 0x0081B0C3, 0x0081AFC3, 
        0x0080AFC3, 0x0080AFC2, 0x00678E9D, 0x00010202, 0x00040606, 0x00182125, 0x00070A0C, 0x00000000, 0x00000000, 0x0032454D, 0x00678FA0, 0x007BAABC, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 
        0x007AABBE, 0x0079AABF, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A7BC, 0x0074A6BB, 0x0073A5BB, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0071A5BA, 
        0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00689EB5, 0x00689EB4, 
        0x00679DB4, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006099B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 
        0x005C96AD, 0x005C95AD, 0x005B94AD, 0x005B94AD, 0x005B94AC, 0x005994AC, 0x005993AB, 0x005993AB, 0x005892AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00406F82, 0x00030506, 
        0x0005090B, 0x003F6F82, 0x004F8CA6, 0x004F8CA6, 0x004B88A0, 0x00315869, 0x00000101, 0x00000000, 0x00070E10, 0x002D5261, 0x004B89A3, 0x00294C5C, 0x00000000, 0x00091114, 0x00417A92, 0x004887A1, 0x004786A1, 0x004786A1, 0x004685A0, 0x004585A0, 
        0x0045859F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0041829D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E99, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 
        0x00387C98, 0x00377B98, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337895, 0x00337895,
  0x00327895, 0x00337895, 0x00347995, 0x00347995, 0x00357996, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D98, 0x003A7D99, 0x003A7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9A, 0x003D809B, 0x003E809B, 0x003F809C, 0x003F819C, 
        0x0040819C, 0x0041829D, 0x0041829D, 0x0041829D, 0x0043839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045849F, 0x004585A0, 0x004686A1, 0x004786A1, 0x004786A1, 0x004887A1, 0x00346073, 0x00000000, 0x00070E11, 0x003B6E83, 0x001A3039, 0x00000000, 
        0x00000000, 0x000C161A, 0x00447B92, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x003F6F84, 0x00060B0D, 0x00000000, 0x00427488, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x00437083, 0x00000000, 
        0x001C2F36, 0x003F6A7C, 0x00294450, 0x00010203, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030506, 0x004B798C, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 
        0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B5, 0x006B9FB6, 0x006BA0B6, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 
        0x006DA2B7, 0x006DA2B8, 0x006EA2B8, 0x006FA3B8, 0x00141E22, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002B3F47, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0072A3B7, 0x002C3E46, 
        0x00000000, 0x00000000, 0x00000101, 0x00364C55, 0x0074A4B7, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABC0, 0x007CACC0, 0x0074A1B4, 0x0033474F, 0x00030405, 0x00000000, 0x00000000, 
        0x000B1012, 0x004C6975, 0x007EAEC1, 0x0027363C, 0x00000000, 0x0026353B, 0x007EAEC1, 0x0080AEC2, 0x0080AFC2, 0x0080AFC3, 0x0080AFC3, 0x0081B0C3, 0x0081AFC3, 0x0081B0C3, 0x0081B0C3, 0x0082B0C3, 0x00668A9A, 0x00020203, 0x000A0E10, 0x00688C9C, 
        0x0083B1C4, 0x007CA7BA, 0x00577684, 0x002D3D43, 0x000A0D0F, 0x00010202, 0x00010101, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x001A2226, 0x00394C55, 0x0054717D, 0x006F95A5, 0x007FABBD, 0x0083B0C2, 0x0084B0C3, 0x0084B1C4, 0x0084B1C4, 
        0x0085B2C5, 0x0086B3C6, 0x0086B3C6, 0x0087B4C6, 0x0086B4C6, 0x0086B3C6, 0x0086B3C6, 0x0086B4C6, 0x0087B4C6, 0x0086B4C6, 0x0087B4C6, 0x0087B4C6, 0x0086B3C6, 0x0087B4C6, 0x0086B3C6, 0x0087B4C6, 0x0087B4C6, 0x0086B4C6, 0x0087B3C6, 0x0087B3C6, 
        0x0086B3C6, 0x0086B2C5, 0x0085B3C5, 0x0084B1C4, 0x0084B0C3, 0x0083B0C2, 0x0082AEC1, 0x007AA3B4, 0x00638492, 0x0047606A, 0x002A383E, 0x000E1214, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00010101, 0x00000000, 0x002C3B41, 
        0x006C92A2, 0x0084B2C5, 0x0084B2C5, 0x0084B2C5, 0x0084B1C4, 0x0084B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x00729AAB, 0x00000000, 0x000F1416, 0x006D94A5, 0x0082B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC3, 
        0x007FAEC1, 0x007DABBF, 0x005C7E8D, 0x00050708, 0x00000000, 0x00000000, 0x00000101, 0x00222F34, 0x006B94A5, 0x007DADC0, 0x007DACC1, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BACC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABF, 
        0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BD, 0x0078A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 
        0x0070A4B9, 0x0071A4B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 
        0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B1, 0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005C96AD, 
        0x005C96AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x004B8299, 0x000D171B, 0x00000101, 
        0x002D4F5D, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x0042778D, 0x000E191E, 0x00000000, 0x00000000, 0x00132229, 0x00070D10, 0x00000000, 0x00346274, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 
        0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0041829E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 
        0x00387C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347996, 0x00337895, 0x00327895,
  0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F819C, 
        0x003F819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00213E4A, 0x00000000, 0x00020304, 0x00000000, 0x00020405, 
        0x00203B46, 0x004B86A0, 0x004D8BA4, 0x004D8BA5, 0x004E8CA5, 0x004E8CA5, 0x004F8CA5, 0x002E5160, 0x00000000, 0x000C1518, 0x004A8097, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x001F343C, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010203, 0x0041697A, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006299B0, 0x006299B0, 
        0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00669DB4, 0x00679DB3, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 
        0x006CA1B7, 0x006DA1B7, 0x006DA2B8, 0x00446472, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070A0B, 0x005F8A9C, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BC, 0x0072A3B8, 0x002F434B, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C1113, 0x004C6B78, 0x00719FB3, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BACBF, 0x007BACC0, 0x006D98AA, 0x00374C55, 0x0011191B, 
        0x00000000, 0x00000000, 0x00080C0D, 0x00040607, 0x00000101, 0x00597C89, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x0081AFC3, 0x0081AFC3, 0x0081B0C3, 0x0081B0C3, 0x003B515A, 0x00000000, 0x001A2327, 0x007EABBF, 
        0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x007198A9, 0x0053707C, 0x00374C53, 0x00212D32, 0x0007090A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000B0F10, 0x001D272B, 0x002D3D44, 0x003A4F57, 
        0x0049626D, 0x00526F7B, 0x005B7A87, 0x00618290, 0x00668897, 0x006A8D9C, 0x006C91A0, 0x006F95A5, 0x007197A7, 0x007197A7, 0x007096A6, 0x007096A6, 0x007298A8, 0x007096A6, 0x006F95A5, 0x006D92A2, 0x006B8F9E, 0x00678A98, 0x00638492, 0x005F7F8D, 
        0x00597784, 0x004F6975, 0x00425962, 0x0034464D, 0x00263339, 0x00131A1D, 0x00040506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x0012191B, 0x001E282C, 0x002C3C42, 0x00455E68, 0x00658998, 0x003F555F, 0x00000000, 0x00364951, 
        0x0084B2C5, 0x0084B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0082B1C4, 0x0082B0C4, 0x0082B0C3, 0x0082B0C4, 0x00182125, 0x00000000, 0x00557481, 0x0081B0C3, 0x0081B0C3, 0x0080AFC3, 0x0080AFC3, 0x0080AFC2, 0x0080AFC2, 0x006B93A4, 
        0x004B6773, 0x00161F22, 0x00000000, 0x00000000, 0x000C1112, 0x002C3D44, 0x00638998, 0x007DADC1, 0x007DADC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 
        0x0079A9BE, 0x0078A9BD, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BC, 0x0076A7BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 
        0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB4, 0x00689DB4, 0x00679DB4, 0x00679DB4, 
        0x00669DB3, 0x00669CB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00629AB1, 0x006299B0, 0x006299B0, 0x006199B0, 0x006099B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 
        0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005892AB, 0x005892AB, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00518DA6, 0x001F363F, 0x00000000, 0x001E353F, 
        0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004D8BA5, 0x004D8BA5, 0x004C8AA4, 0x0048849B, 0x001D353F, 0x00030507, 0x00000000, 0x00000000, 0x00223F4B, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A0, 0x004685A0, 0x004585A0, 0x0044859F, 
        0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387C98, 
        0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347996, 0x00347895, 0x00327895, 0x00327795,
  0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809B, 
        0x003F819C, 0x003F819D, 0x0040819D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x0046849E, 0x0014262E, 0x00000000, 0x00020506, 0x0038677B, 
        0x004A87A1, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x0025414C, 0x00000000, 0x001A2E36, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005691A9, 0x0046768B, 
        0x00070C0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x00385B69, 0x005B95AD, 0x005B95AD, 0x005D96AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199AF, 0x006299B0, 
        0x00629AB0, 0x00629AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006CA0B6, 
        0x006CA1B7, 0x006CA1B7, 0x006493A7, 0x00141E22, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0038525D, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BB, 0x0073A6BB, 0x0073A6BB, 0x006C9AAE, 0x000D1316, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00161F23, 0x00517380, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 0x007AAABF, 0x007AAABF, 0x007AABBF, 0x007BABBF, 0x007BABC0, 0x007BABC0, 0x006D98AA, 
        0x004E6D79, 0x001C272C, 0x00000000, 0x00000000, 0x00000000, 0x00212D32, 0x004A6571, 0x0078A5B8, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x0080AEC2, 0x0080AFC2, 0x0080AFC3, 0x0079A6B8, 0x001E292D, 0x00000000, 0x003C525B, 0x0081B0C3, 
        0x0081B0C3, 0x0082B0C3, 0x0082B0C3, 0x0082B0C3, 0x0082B0C4, 0x0082B1C4, 0x0082B1C4, 0x0083B1C4, 0x00759EAF, 0x00151C1F, 0x00000000, 0x004B6570, 0x00557481, 0x00425A63, 0x002F3F47, 0x001D272C, 0x000D1214, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020203, 0x00060809, 0x00080B0D, 0x000D1214, 0x000F1417, 0x000F1417, 0x000F1417, 0x000F1417, 0x00101618, 0x000F1416, 0x000E1315, 0x000B0F10, 0x00070A0B, 0x00060809, 0x00020203, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E1315, 0x003A4E57, 0x004B6570, 0x005B7B88, 0x00678B9A, 0x007199A9, 0x007EA9BC, 0x0083B1C5, 0x0083B1C5, 0x0083B1C4, 0x006E95A6, 0x00000000, 0x0011171A, 
        0x0083B1C4, 0x0083B1C4, 0x0082B0C4, 0x0082B0C4, 0x0082B0C4, 0x0082B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x004E6A76, 0x00000000, 0x002E3F46, 0x007EADC0, 0x0080AFC2, 0x0080AFC2, 0x007FAEC2, 0x00557482, 0x0029393F, 0x000D1315, 
        0x00000000, 0x00000000, 0x0011181B, 0x0045606B, 0x006890A1, 0x007DADC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACBF, 0x007BABBF, 0x007BABC0, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BD, 
        0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0076A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0073A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 
        0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00669CB3, 
        0x00669CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 
        0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AB, 0x005792AA, 0x005791AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00538FA8, 0x00528EA7, 0x00528EA7, 0x002A4855, 0x00000000, 0x00172830, 0x004E8AA2, 
        0x00508CA6, 0x004F8CA6, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00112026, 0x00000000, 0x0014262E, 0x0046849D, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 
        0x0043849F, 0x0043839E, 0x0042829E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00377B98, 
        0x00377B97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00347996, 0x00347895, 0x00337895, 0x00327894, 0x00327794,
  0x00317794, 0x00317794, 0x00337894, 0x00337895, 0x00337995, 0x00357996, 0x00357A96, 0x00367A96, 0x00367B97, 0x00377B97, 0x00377B98, 0x00397C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003B7D9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 
        0x003F819C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x003B6F84, 0x00070D10, 0x00000000, 0x00315A6C, 
        0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004E8BA5, 0x00172930, 0x00000000, 0x00284754, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691A9, 
        0x00243D48, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00263F4A, 0x005B94AC, 0x005B94AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006198B0, 
        0x006199B0, 0x006299B1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB5, 0x00699EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006B9FB6, 0x006BA0B6, 
        0x006CA0B6, 0x006CA1B6, 0x003F5F6C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D1316, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0043606D, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0011181B, 0x0039515B, 0x002B3D45, 0x00040506, 0x001E2B30, 0x006D9AAC, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABC0, 
        0x007BACC0, 0x0079A8BC, 0x00628898, 0x00202C31, 0x00000000, 0x00000000, 0x00000101, 0x00040607, 0x002D3F46, 0x006990A1, 0x007EAEC1, 0x007FAEC1, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x00678E9D, 0x000A0E0F, 0x00000000, 0x006A92A2, 0x0080AFC3, 
        0x0081AFC3, 0x0081AFC3, 0x0081B0C3, 0x0082B0C3, 0x0081B0C3, 0x0082B0C3, 0x0082B0C4, 0x0082B0C4, 0x006A90A0, 0x0007090A, 0x00000000, 0x007DAABD, 0x0083B1C4, 0x0081AFC2, 0x0081AEC1, 0x0080ADC0, 0x007FADBF, 0x007CA7BA, 0x00729AAB, 0x00658997, 
        0x00557380, 0x0011171A, 0x00000000, 0x00202B30, 0x00263439, 0x001A2428, 0x00141B1E, 0x0011171A, 0x000C1113, 0x00030405, 0x00000000, 0x00020203, 0x00090D0E, 0x00020203, 0x00000000, 0x000A0E10, 0x00192225, 0x00000000, 0x00000000, 0x0028363C, 
        0x003E535C, 0x004E6974, 0x005C7C8A, 0x006D93A3, 0x0079A4B5, 0x004D6773, 0x00000000, 0x001A2428, 0x0084B2C4, 0x0083B0C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x007AA5B7, 0x0007090A, 0x00000000, 
        0x007AA6B9, 0x0082B0C4, 0x0082B0C3, 0x0081B0C4, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x00739DAF, 0x00000000, 0x00030404, 0x0079A6B8, 0x0075A0B2, 0x003C535C, 0x00090D0F, 0x00010202, 0x00000000, 0x00000000, 
        0x00141C1F, 0x00567785, 0x0079A8BB, 0x007CABC0, 0x007CADC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007BABC0, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 
        0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 
        0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA2B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00669CB3, 
        0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005B95AD, 
        0x005B94AC, 0x005A93AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA7, 0x00365E6F, 0x00000000, 0x000B1316, 0x00457A90, 0x00508CA6, 
        0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004C8AA4, 0x004C8AA4, 0x004C89A3, 0x004B89A3, 0x00315B6C, 0x00000000, 0x00070E11, 0x003B6F86, 0x004887A1, 0x004787A1, 0x004686A0, 0x004685A0, 0x004685A0, 0x004585A0, 0x0044849F, 0x0044849F, 
        0x0043839E, 0x0042839E, 0x0042839D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00377B98, 0x00377B97, 
        0x00377B97, 0x00367A96, 0x00357996, 0x00357996, 0x00347895, 0x00337895, 0x00327895, 0x00327794, 0x00317794,
  0x00317794, 0x00317794, 0x00327895, 0x00337895, 0x00337895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387B98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 
        0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x002A505F, 0x00000101, 0x00060C0F, 
        0x003F758B, 0x004B89A3, 0x004B89A4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00477D95, 0x000C1519, 0x00000000, 0x00345C6C, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A9, 0x005591A9, 
        0x004D8299, 0x00070C0E, 0x00000000, 0x00000000, 0x00000000, 0x00152328, 0x005892AB, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005B95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006099B0, 
        0x006199B0, 0x006299B1, 0x006299B1, 0x00629AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB2, 0x00659CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 
        0x006BA0B6, 0x006395A9, 0x00050809, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0052798A, 0x006FA2B8, 0x006FA3B8, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x006B9BAF, 0x00010202, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x002C3F47, 0x0075A7BC, 0x0076A8BC, 0x0076A8BC, 0x006F9EB2, 0x0039515B, 0x006D9BAE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 
        0x007BABBF, 0x007BACC0, 0x007BACC0, 0x007CACC0, 0x006B95A7, 0x00354952, 0x0012191C, 0x00030506, 0x00000000, 0x00000000, 0x00172024, 0x0047626D, 0x006991A1, 0x0077A3B4, 0x007FAEC2, 0x004E6B77, 0x00000000, 0x0011181B, 0x0080AFC2, 0x0080AFC3, 
        0x0080AFC3, 0x0080AFC3, 0x0080AFC3, 0x0081AFC3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x00597986, 0x00000000, 0x00141B1E, 0x0082B0C4, 0x0082B0C4, 0x0082B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 
        0x0083B1C4, 0x00101619, 0x00000000, 0x006E95A6, 0x0083B1C4, 0x0083B1C5, 0x0084B1C4, 0x0083B1C5, 0x0084B2C5, 0x00364851, 0x00000000, 0x001E282C, 0x0084B1C5, 0x001B2529, 0x00000000, 0x00465F69, 0x0084B1C5, 0x00030404, 0x00000000, 0x00638695, 
        0x0084B1C5, 0x0084B1C4, 0x0084B1C5, 0x0083B1C4, 0x0083B1C5, 0x0054727E, 0x00020303, 0x00101618, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0083B1C4, 0x0082B1C4, 0x0082B1C4, 0x0082B0C4, 0x0082B1C4, 0x0082B1C4, 0x007DA9BC, 0x001E292D, 0x00000000, 
        0x00597986, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC3, 0x0080AFC2, 0x0080AFC2, 0x0079A6B8, 0x00172023, 0x00000000, 0x00172023, 0x00000000, 0x00000000, 0x00010202, 0x000F1517, 0x002A3A41, 0x00618695, 
        0x007DADC1, 0x007DADC1, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x006894A6, 0x0011191C, 
        0x00415C68, 0x0071A2B5, 0x0076A8BC, 0x0075A8BC, 0x0075A7BC, 0x0074A7BB, 0x0074A7BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 
        0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00679DB3, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 
        0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006198B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 
        0x005A94AC, 0x005A93AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005390A8, 0x00538FA8, 0x00538FA8, 0x00417286, 0x00030506, 0x00030607, 0x00376172, 0x00508DA6, 0x004F8CA5, 
        0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x003F758B, 0x00060C0F, 0x00000101, 0x002A505F, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849F, 
        0x0042839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003A7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387B98, 0x00377B98, 0x00377B97, 
        0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00337995, 0x00337895, 0x00327795, 0x00317794, 0x00317793,
  0x00317693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00367B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 
        0x003D809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041839D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x004887A1, 0x001D3741, 0x00000000, 
        0x0015262E, 0x004886A0, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x003D6B7E, 0x00020405, 0x00020405, 0x003B687A, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 
        0x005591A9, 0x00335766, 0x00000000, 0x00000000, 0x00000000, 0x004F849A, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 
        0x006098B0, 0x006099B0, 0x006299B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 
        0x006A9FB6, 0x0024373E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0024353D, 0x006B9EB4, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x0070A3B8, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0024353C, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00172125, 0x006B9AAD, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A7BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x007AABBF, 
        0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABC0, 0x007CACC0, 0x00729FB1, 0x00557684, 0x00344850, 0x000E1416, 0x00000000, 0x00000000, 0x00040606, 0x001E2A2E, 0x00394E57, 0x00212D32, 0x00000000, 0x004F6D79, 0x007FAEC2, 0x007FAEC2, 
        0x0080AEC2, 0x007FAEC2, 0x007FAFC2, 0x0080AFC2, 0x0080AFC2, 0x0081AFC3, 0x0080AFC3, 0x0080AFC3, 0x003F555F, 0x00000000, 0x00354851, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0082B0C3, 0x0082B0C3, 0x0082B0C3, 0x0083B0C3, 0x0083B0C4, 
        0x0082B0C4, 0x00020203, 0x00000000, 0x00729BAC, 0x0082B1C4, 0x0082B1C4, 0x0083B1C4, 0x0082B1C4, 0x0083B1C4, 0x0034464E, 0x00000000, 0x001D282C, 0x0083B1C4, 0x001B2428, 0x00000000, 0x00425A63, 0x0083B1C4, 0x00030405, 0x00000000, 0x0060818F, 
        0x0082B1C4, 0x0082B1C4, 0x0082B1C4, 0x0083B1C4, 0x0082B1C4, 0x00628595, 0x00080B0C, 0x00090D0E, 0x007EABBE, 0x0082B0C4, 0x0082B0C3, 0x0082B0C3, 0x0082B0C3, 0x0082B0C3, 0x0081B0C3, 0x0082B0C3, 0x0081B0C3, 0x007FACC0, 0x00394D56, 0x00000000, 
        0x0031434B, 0x0080AFC3, 0x0080AFC3, 0x0080AFC2, 0x0080AEC2, 0x0080AEC2, 0x007FAEC2, 0x007FAEC2, 0x00618595, 0x00415963, 0x00243238, 0x0006090A, 0x00000000, 0x00000000, 0x0006090A, 0x002C3D44, 0x004E6D79, 0x006D97A8, 0x007DADC0, 0x007DADC0, 
        0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BD, 0x0077A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x00638EA0, 0x00080B0D, 
        0x00000000, 0x00213036, 0x006590A2, 0x0075A7BB, 0x0074A6BC, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA1B7, 0x006BA0B6, 0x006B9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00689FB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 
        0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B1, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005D96AD, 0x005B96AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 
        0x005994AC, 0x005993AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005691A9, 0x005691AA, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x004A8197, 0x000D181C, 0x00000000, 0x002F5462, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 
        0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x0048869F, 0x0014262D, 0x00000000, 0x001E3843, 0x004887A2, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849F, 0x0043839E, 
        0x0042839E, 0x0041829E, 0x0041829D, 0x0040819D, 0x003F819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9B, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 
        0x00367A97, 0x00357A96, 0x00347996, 0x00347996, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317693,
  0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347895, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387B98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7F9A, 0x003C7F9B, 
        0x003E7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x0046849E, 0x00112127, 
        0x00000000, 0x00213E4A, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00386275, 0x00000000, 0x00091012, 0x00497F95, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 
        0x005590A9, 0x005691A9, 0x00132127, 0x00000000, 0x00192A31, 0x005892AB, 0x005892AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005B95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 
        0x006098AF, 0x006098B0, 0x006099B0, 0x006299B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 
        0x004C7383, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x00527A8B, 0x006DA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A4B9, 0x0070A4B9, 0x00517686, 0x00040607, 0x00000000, 0x00000000, 
        0x00000000, 0x00000101, 0x00527686, 0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 
        0x0079AABF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABC0, 0x007BACC0, 0x007AA9BC, 0x0074A1B3, 0x005B7E8D, 0x00293940, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00000000, 0x00222F34, 0x0053727F, 0x007AA7B9, 
        0x007EAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAFC2, 0x007FAEC2, 0x0080AFC2, 0x0080AFC2, 0x00202C31, 0x00000000, 0x00587987, 0x0081AFC3, 0x0081AFC3, 0x0081AFC3, 0x0081AFC3, 0x0081AFC3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 
        0x0079A5B7, 0x00000000, 0x000A0E10, 0x00749FB0, 0x0081B0C4, 0x0082B0C3, 0x0082B0C4, 0x0082B0C4, 0x0082B0C4, 0x0034474F, 0x00000000, 0x001D282C, 0x0082B0C4, 0x001B2428, 0x00000000, 0x00425963, 0x0082B0C3, 0x00030405, 0x00000000, 0x005F818F, 
        0x0082B0C3, 0x0082B0C4, 0x0082B0C4, 0x0082B0C3, 0x0082B0C3, 0x006D93A3, 0x000B0F11, 0x00060809, 0x0075A0B1, 0x0081AFC3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081AFC3, 0x0081AFC3, 0x0081AFC3, 0x0080AFC3, 0x0080AFC3, 0x004C6975, 0x00000000, 
        0x000A0D0F, 0x0080AFC2, 0x007FAEC2, 0x0080AFC2, 0x007FAEC2, 0x005D808F, 0x00304249, 0x000D1315, 0x00050809, 0x00000000, 0x00000000, 0x00000000, 0x001C272B, 0x0051717E, 0x00739FB1, 0x0079A8BB, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 
        0x007BABC0, 0x007BACC0, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BE, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0070A0B4, 0x000C1113, 
        0x00000000, 0x00000000, 0x00070A0B, 0x00527584, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B8, 
        0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 
        0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AB, 
        0x005993AC, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00121F25, 0x00000000, 0x002A4A57, 0x00508CA6, 0x00508DA6, 0x004E8CA5, 0x004E8BA5, 
        0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004A89A3, 0x00213E4A, 0x00000000, 0x00122128, 0x0046849F, 0x004887A1, 0x004786A1, 0x004786A0, 0x004685A0, 0x004685A0, 0x0044859F, 0x0044859F, 0x0044849F, 0x0043839E, 0x0042839E, 
        0x0042839E, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 
        0x00357A96, 0x00347996, 0x00347996, 0x00347895, 0x00327895, 0x00327894, 0x00317794, 0x00317693, 0x00307693,
  0x00307593, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 
        0x003D7F9B, 0x003D809B, 0x003E809C, 0x003E809B, 0x0040819C, 0x0040819D, 0x0040829D, 0x0042829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x003E758C, 
        0x00070E11, 0x00000000, 0x00305A6B, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x00508DA6, 0x002D505E, 0x00000000, 0x000E181D, 0x004F89A1, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x005590A9, 0x005590A9, 0x00447488, 0x00000000, 0x00243C46, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 
        0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x006599B0, 
        0x00162126, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0024373E, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x006A9CB1, 0x00202E34, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x0024343B, 0x0072A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BB, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 
        0x0079AABE, 0x0079AABF, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABC0, 0x007BABC0, 0x007BACC0, 0x007CACC0, 0x007CACC0, 0x0078A7BA, 0x004E6D79, 0x001F2B30, 0x00080C0D, 0x00040606, 0x00000000, 0x00000000, 0x00000000, 
        0x001B252A, 0x00425B66, 0x00668D9C, 0x00739FB2, 0x0079A6B9, 0x007EACC0, 0x007FAEC2, 0x007EACC0, 0x00050809, 0x00000000, 0x00709AAB, 0x0080AFC3, 0x0080AFC2, 0x0080AFC2, 0x0080AFC3, 0x0080AFC3, 0x0080AFC3, 0x0080AFC3, 0x0080AFC3, 0x0080AFC3, 
        0x006D94A5, 0x00000000, 0x00151D20, 0x0077A2B4, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0034474E, 0x00000000, 0x001D282C, 0x0081B0C3, 0x001B2428, 0x00000000, 0x00415963, 0x0082B0C3, 0x00030405, 0x00000000, 0x005E818F, 
        0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081B0C3, 0x0081AFC3, 0x0075A0B1, 0x000F1416, 0x00040506, 0x00678D9C, 0x0081AFC3, 0x0080AFC3, 0x0080AFC3, 0x0080AFC2, 0x0080AFC3, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x005D7F8D, 0x00050708, 
        0x00000000, 0x00608392, 0x004D6A76, 0x00243137, 0x00000101, 0x00000000, 0x00000000, 0x00020404, 0x00080B0C, 0x00182125, 0x00445E69, 0x00729EB1, 0x007DADC1, 0x007DACC0, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABC0, 0x007BABC0, 
        0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A8BC, 0x0075A7BC, 0x00121A1E, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00364E58, 0x006E9FB4, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA2B7, 
        0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699EB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00639BB2, 
        0x00639BB2, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AE, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 
        0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691A9, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528EA8, 0x001A2D35, 0x00000000, 0x001B3039, 0x004E88A2, 0x004F8CA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 
        0x004D8BA4, 0x004D8AA4, 0x004C8AA3, 0x004C8AA3, 0x004B89A3, 0x0030596A, 0x00000000, 0x00070E11, 0x003E768D, 0x004887A2, 0x004787A1, 0x004686A0, 0x004685A0, 0x004685A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 
        0x0041829E, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 
        0x00357A96, 0x00347995, 0x00347995, 0x00337895, 0x00327795, 0x00317794, 0x00317794, 0x00307693, 0x00307693,
  0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327795, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 
        0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 
        0x00305A6C, 0x00000101, 0x00030607, 0x00396A7D, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004E8CA5, 0x00213A45, 0x00000000, 0x0016282F, 0x004E879F, 0x00528EA7, 0x00538FA7, 0x00548FA8, 
        0x005490A8, 0x005590A9, 0x00538DA5, 0x001E343D, 0x00101B20, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005E97AE, 0x005E97AE, 
        0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB2, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00669DB3, 0x00669DB3, 0x00679DB4, 0x00689EB4, 0x00426472, 
        0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00040708, 0x006394A9, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x004D7181, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x0006090A, 0x006997AC, 0x0072A5BA, 0x0072A5BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0074A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0076A8BD, 0x0077A9BD, 0x0077A9BD, 0x0078A9BD, 
        0x0078A9BE, 0x0079AABE, 0x0078AABE, 0x0079AABE, 0x007AAABF, 0x007AAABF, 0x007AAABF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x00709CAE, 0x00537380, 0x00374D55, 0x00202D32, 0x00090D0F, 
        0x00000000, 0x00000000, 0x00000000, 0x000B0F11, 0x00233035, 0x00394F57, 0x004E6C78, 0x00547480, 0x00000000, 0x00141C1F, 0x007EADC1, 0x007FAEC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x007FAEC2, 0x0080AFC2, 0x0080AFC3, 0x0080AFC2, 0x0080AFC3, 
        0x005A7B89, 0x00000000, 0x001F2B30, 0x0079A5B8, 0x0081AFC2, 0x0080AFC3, 0x0081AFC3, 0x0081B0C3, 0x0081AFC3, 0x0034474F, 0x00000000, 0x001D282C, 0x0081B0C3, 0x001A2428, 0x00000000, 0x00415963, 0x0080B0C3, 0x00030405, 0x00000000, 0x005F818F, 
        0x0081AFC3, 0x0081AFC3, 0x0081AFC3, 0x0081AFC3, 0x0081AFC3, 0x007AA7BA, 0x0012181B, 0x00020303, 0x00567683, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x0080AFC2, 0x00739FB0, 0x00638998, 0x0051707D, 0x00344951, 0x00040607, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040607, 0x001B252A, 0x0032454D, 0x004E6B77, 0x006B94A5, 0x007DADC0, 0x007DADC1, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007BABBF, 0x007BABBF, 
        0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABE, 0x0079AABE, 0x0079A9BE, 0x0078A9BE, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x00223137, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00202F35, 0x005D8899, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 
        0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669CB2, 0x00659CB2, 0x00659BB2, 0x00659BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 
        0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C96AE, 0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 
        0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00518EA6, 0x0027434F, 0x00000000, 0x00101C21, 0x00498198, 0x00508DA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 
        0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x00396A7E, 0x00030607, 0x00000101, 0x00305B6C, 0x004887A2, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0041839D, 
        0x0041829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357996, 
        0x00357996, 0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x002F7593,
  0x002E7592, 0x00307693, 0x00307693, 0x00307694, 0x00317794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377C98, 0x00387C98, 0x00397C98, 0x00397D98, 0x003A7D99, 0x003A7E9A, 0x003B7E9A, 
        0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E7F9B, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0045849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 
        0x004887A2, 0x00254553, 0x00000000, 0x000C161B, 0x00447E96, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004D88A1, 0x0014232A, 0x00000000, 0x001E353E, 0x00508BA4, 0x00528EA8, 0x00538EA8, 
        0x00538FA8, 0x005490A9, 0x005490A9, 0x00447588, 0x000E171B, 0x00548EA5, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005994AC, 0x005B94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 
        0x005E97AE, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00669DB3, 0x00669DB3, 0x006398AE, 0x000F171A, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00456876, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 0x000C1114, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00446370, 0x0071A4B9, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 
        0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0079A9BE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BACC0, 0x007CACC0, 0x0075A2B5, 0x006B95A7, 
        0x005B7E8D, 0x003A505A, 0x00172024, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060809, 0x00000000, 0x0006090A, 0x0027353B, 0x003F5660, 0x00577885, 0x006E96A8, 0x007EAEC1, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 0x007FAEC2, 
        0x0049646F, 0x00000000, 0x0029393F, 0x007AA7BB, 0x007FAEC2, 0x0080AFC2, 0x0080AFC2, 0x0080AEC2, 0x007FAFC2, 0x0034474F, 0x00000000, 0x001D272C, 0x0080AFC2, 0x001A2428, 0x00000000, 0x00415962, 0x0080AFC2, 0x00030405, 0x00000000, 0x005E818F, 
        0x007FAFC2, 0x007FAEC2, 0x007FAFC2, 0x007FAFC2, 0x007FAEC2, 0x007FAEC2, 0x00172024, 0x00010202, 0x004A6672, 0x007FAEC2, 0x00739DAF, 0x005D7F8E, 0x00455F69, 0x002C3E45, 0x00192226, 0x00101619, 0x00090C0E, 0x00010202, 0x00000000, 0x00000000, 
        0x00000000, 0x000E1416, 0x0032454D, 0x00557684, 0x006A93A3, 0x0073A0B2, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BACC0, 0x007BACBF, 0x007BACBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 
        0x0079AABE, 0x0079AABF, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0074A6BB, 0x00344C55, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090E0F, 0x0043636F, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 
        0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 
        0x006299B1, 0x006299B0, 0x006099B0, 0x006098AF, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005B95AC, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005893AB, 0x005892AB, 
        0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA7, 0x00335968, 0x00000000, 0x00070D0F, 0x00488097, 0x00508DA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 
        0x004D8AA4, 0x004B89A4, 0x004B89A3, 0x00447E96, 0x000C161B, 0x00000000, 0x00264654, 0x004887A1, 0x004787A1, 0x004686A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 
        0x0041829D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7C99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00347996, 
        0x00347996, 0x00337895, 0x00327895, 0x00327895, 0x00317794, 0x00317694, 0x00307693, 0x00307593, 0x002F7592,
  0x002F7592, 0x002F7593, 0x00307693, 0x00307694, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 
        0x003B7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004685A0, 0x004686A1, 0x004786A1, 
        0x004887A1, 0x004887A1, 0x00192E37, 0x00000000, 0x00162830, 0x004A89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8BA4, 0x000A1114, 0x00000000, 0x002A4A57, 0x00518DA6, 0x00528EA8, 
        0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 
        0x005E97AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x0036535F, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x0018252A, 0x00669BB1, 0x006A9FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 0x006CA1B7, 0x006CA1B7, 0x006DA2B7, 0x00344E58, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00172226, 
        0x006796AB, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A7BC, 0x0076A8BD, 0x0076A8BC, 
        0x0077A8BD, 0x0077A8BD, 0x0075A7BA, 0x0073A3B7, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BACBF, 0x007CACC0, 0x007BACC0, 
        0x007CACC0, 0x007CACC0, 0x007CACC0, 0x0078A6B9, 0x005A7D8C, 0x00374C55, 0x00172024, 0x00040607, 0x00020404, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000F1517, 0x00243238, 0x00374C54, 0x004B6873, 0x00608593, 
        0x002F4249, 0x00000000, 0x0032454D, 0x0079A6B9, 0x007BA9BC, 0x007CA9BD, 0x007CAABE, 0x007CAABE, 0x007FAEC2, 0x0033464E, 0x00000000, 0x001C272C, 0x007FAEC2, 0x00192327, 0x00000000, 0x003F5761, 0x007FAEC2, 0x00020303, 0x00000000, 0x005B7C8B, 
        0x007BA9BC, 0x007BA8BB, 0x0077A3B5, 0x006F98A9, 0x005F8392, 0x00516F7C, 0x000F1518, 0x00000000, 0x00070A0B, 0x00030405, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00020404, 0x00030506, 0x0011171A, 0x0030424A, 0x0051717E, 
        0x0074A1B4, 0x007DADC1, 0x007DADC0, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007BABC0, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 
        0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x00486875, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00314852, 0x006B9DB2, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006DA2B8, 0x006DA2B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 
        0x006AA0B6, 0x006AA0B5, 0x00699FB5, 0x006A9FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00679DB3, 0x00669CB3, 0x00659DB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 
        0x006199B0, 0x006099B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D95AD, 0x005B95AD, 0x005B94AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AA, 
        0x005792AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x005490A8, 0x00538FA8, 0x00538EA8, 0x003B6779, 0x00000000, 0x00000000, 0x0044798E, 0x00508CA6, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004C8AA4, 
        0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x0015282F, 0x00000000, 0x00192F38, 0x004987A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 
        0x0040829D, 0x003F819C, 0x003F819C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003B7F9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 
        0x00347995, 0x00337895, 0x00327795, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7592, 0x002F7592,
  0x002E7492, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00367A97, 0x00367A97, 0x00367B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 
        0x003B7E9A, 0x003C7E9A, 0x003D7F9A, 0x003D7F9B, 0x003E7F9B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 
        0x004786A1, 0x004887A1, 0x0045819B, 0x00101E24, 0x00000000, 0x001F3A46, 0x004A89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x00417387, 0x00000000, 0x00000000, 0x002F5260, 0x00528EA7, 
        0x00528FA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005C96AE, 
        0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x0059889C, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00020404, 0x004B7281, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x005B889B, 0x00010102, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00466674, 
        0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0075A8BC, 0x0076A7BD, 
        0x0076A8BD, 0x0073A4B7, 0x00384F59, 0x00192428, 0x0077A9BD, 0x0078A9BD, 0x0078A9BD, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 0x0079AABE, 0x0079AABF, 0x007AAABF, 0x007AABBF, 0x007AAABF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 
        0x007BABC0, 0x007BABC0, 0x007BACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CADC0, 0x0079A7BB, 0x00628897, 0x004C6A76, 0x00394F58, 0x0028373E, 0x001D282D, 0x00141C1F, 0x000A0E10, 0x00010203, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00010202, 0x000B0F11, 0x0011171A, 0x001A2428, 0x001E2A2E, 0x00253339, 0x002C3D44, 0x0012191C, 0x00000000, 0x00090D0F, 0x0032454D, 0x00090C0E, 0x00000000, 0x00151E21, 0x0029383F, 0x00000000, 0x00000000, 0x000D1214, 
        0x000C1113, 0x00030405, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080C0D, 0x0012191C, 0x001C262B, 0x00253339, 0x00344951, 0x00496570, 0x005F8392, 0x0075A2B4, 0x007DADC1, 0x007DADC1, 0x007DACC0, 
        0x007CACC0, 0x007DACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x0079ABBF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 
        0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0078A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x00598191, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001C2A30, 0x00598496, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 
        0x006198B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005994AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AB, 0x005792AA, 
        0x005691AA, 0x005691AA, 0x005591AA, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x003C687B, 0x00000000, 0x00000000, 0x00000000, 0x001C323B, 0x00477E96, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 
        0x004B89A4, 0x004B89A3, 0x001F3A45, 0x00000000, 0x00101E24, 0x0046829C, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 
        0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347996, 
        0x00337895, 0x00337895, 0x00327895, 0x00317794, 0x00317693, 0x00307693, 0x00307593, 0x002E7592, 0x002E7592,
  0x002E7492, 0x002E7592, 0x002F7593, 0x002F7593, 0x00307693, 0x00307694, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00367A96, 0x00367B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D98, 0x003A7D99, 
        0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 
        0x004786A1, 0x004787A1, 0x004887A1, 0x003C7288, 0x00060C0E, 0x00000000, 0x00274856, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x003F7185, 0x000D181C, 0x00000000, 0x00000000, 0x00000101, 0x002D4D5B, 
        0x00528EA7, 0x00528FA7, 0x00538FA7, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005692AA, 0x005792AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005994AB, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 
        0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x001B2930, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x001D2D34, 0x00669BB2, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006BA0B6, 0x006BA0B6, 0x00699EB3, 0x0024353C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00182429, 0x006EA2B8, 
        0x006FA2B8, 0x006FA2B8, 0x006FA3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4B9, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0074A7BC, 0x0075A7BC, 
        0x0070A1B5, 0x00233238, 0x00000000, 0x001D2A2F, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007AABBF, 
        0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABC0, 0x007BACC0, 0x007BACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x0075A3B6, 0x006D98AA, 0x00668D9E, 0x005F8493, 0x00557784, 0x004A6673, 0x003C535C, 0x0030434A, 
        0x00212E33, 0x00182125, 0x000D1215, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00020303, 0x000C1113, 0x00151D21, 0x001E2A2F, 0x002E3F47, 0x00394F58, 0x0047636E, 0x00537380, 0x005E8291, 0x00648A9B, 0x006C96A8, 0x0074A1B3, 0x007CABBF, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 
        0x007BACC0, 0x007BACC0, 0x007BABC0, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x0079AABE, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 
        0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A7BC, 0x0074A7BB, 0x0073A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x006A9AAF, 
        0x00000000, 0x00000000, 0x001C292F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090D0F, 0x00405E6B, 0x006CA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006AA0B6, 0x00699FB5, 
        0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00679DB3, 0x00669DB4, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00639AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006099B0, 
        0x006098B0, 0x006098AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AA, 0x005792AA, 0x005691AA, 
        0x005691A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00528FA8, 0x003F6D80, 0x00060B0D, 0x00000000, 0x002A4A57, 0x00091114, 0x00000000, 0x00101C21, 0x00407389, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA3, 0x004B8AA3, 
        0x004B89A3, 0x00264755, 0x00000000, 0x00060C0E, 0x003D7289, 0x004887A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040819D, 0x0040819C, 
        0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00367B97, 0x00367A96, 0x00357A96, 0x00347996, 0x00347996, 0x00337895, 
        0x00337895, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x00307593, 0x002F7592, 0x002E7592, 0x002D7492,
  0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7593, 0x00317793, 0x00317794, 0x00317794, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00397C98, 0x00397C99, 0x00397D99, 
        0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003D7F9A, 0x003E7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 
        0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x0038697D, 0x00000000, 0x00020405, 0x00356376, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x003B6B7F, 0x00070C0E, 0x00000000, 0x000A1215, 0x00335A6A, 0x00000101, 0x00020304, 
        0x00375F70, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B94AD, 0x005B95AD, 
        0x005C95AD, 0x005C96AE, 0x005D96AD, 0x005E97AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x00629AB0, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00446A7A, 0x00030606, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00548294, 0x00679DB4, 0x00689DB4, 0x00679EB4, 0x00689EB5, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x00507889, 0x00030505, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x005B8799, 0x006DA2B7, 
        0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x006A97AA, 
        0x00141C20, 0x00000000, 0x00000000, 0x00344B54, 0x0076A7BC, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 
        0x007AAABF, 0x007AAABF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABC0, 0x007BABC0, 0x007BACC0, 0x007CABC0, 0x007BACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BABBF, 0x007BAABE, 
        0x007CAABE, 0x007AA9BD, 0x007AA9BD, 0x007BA9BD, 0x007AA9BC, 0x0075A1B3, 0x00709CAD, 0x006D96A8, 0x006890A0, 0x00628897, 0x005D808F, 0x005B7E8C, 0x005D808F, 0x005C7F8E, 0x00618695, 0x00678E9F, 0x006C95A7, 0x006F99AC, 0x0074A0B2, 0x0079A8BA, 
        0x007BAABD, 0x007BAABD, 0x007BAABD, 0x007CABBE, 0x007CAABE, 0x007BABBF, 0x007BACBF, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BABBF, 0x007BABBF, 0x007BABBF, 
        0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x0079AABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 
        0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A7BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 
        0x00020304, 0x00000000, 0x00476876, 0x00517787, 0x00020304, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00293E47, 0x006CA1B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 
        0x00699EB5, 0x00689EB5, 0x00689DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098AF, 
        0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AB, 0x005791AA, 0x005691AA, 0x005691A9, 
        0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538EA7, 0x004A8097, 0x00060A0C, 0x00000000, 0x00355E6F, 0x00508DA6, 0x00407186, 0x0004080A, 0x00000000, 0x00080F12, 0x0041768B, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 
        0x00356376, 0x00020304, 0x00000000, 0x0038687D, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x0045859F, 0x0045859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0041839E, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F819C, 
        0x003F809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00347895, 0x00337895, 
        0x00327895, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7492, 0x002D7492,
  0x002D7491, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307694, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397C98, 
        0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 
        0x004685A0, 0x004686A1, 0x004786A1, 0x004786A1, 0x004887A1, 0x002E5566, 0x00000000, 0x00030607, 0x003E7287, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x00386578, 0x00060A0C, 0x00000000, 0x000C161A, 0x00417387, 0x00508CA6, 0x003B697C, 0x00010303, 
        0x00010203, 0x003D6A7D, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005993AB, 0x005993AC, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005B95AC, 
        0x005B95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x005E92A8, 0x0019272D, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x002C444E, 0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x00689DB2, 0x001C2B30, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00304751, 0x006DA1B7, 0x006DA1B7, 
        0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BB, 0x0073A5BB, 0x0073A6BB, 0x005C8697, 0x00121A1D, 
        0x00000000, 0x00000000, 0x00000000, 0x00486774, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BD, 0x0078AABE, 0x0078AABE, 0x0078AABE, 0x0079AABE, 
        0x0079AABE, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x007AAABF, 0x007AABBF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BABC0, 0x007BABBF, 0x007BABC0, 0x007BACC0, 0x007BACC0, 0x007CACC0, 0x007CACC0, 
        0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 
        0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007CACC0, 0x007BACC0, 0x007BACC0, 0x007BACC0, 0x007BACC0, 0x007BABC0, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 
        0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AABBF, 0x007AAABF, 0x007AAABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 
        0x0076A8BC, 0x0076A7BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 
        0x00131C20, 0x00000000, 0x00334C55, 0x006FA3B8, 0x005F8B9E, 0x00182429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121A1E, 0x00578395, 0x006AA0B6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00689EB5, 
        0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00679DB4, 0x00669DB4, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x005F98AF, 
        0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AC, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005590A9, 
        0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00487D93, 0x00080D10, 0x00000000, 0x002D4F5D, 0x00508DA6, 0x004F8BA5, 0x004F8CA5, 0x00417287, 0x000B1317, 0x00000000, 0x00040809, 0x003A6A7E, 0x004B89A3, 0x004B89A3, 0x003E7288, 
        0x00030507, 0x00000000, 0x002E5667, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004584A0, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F809C, 
        0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00357A97, 0x00357996, 0x00357996, 0x00347995, 0x00337895, 0x00337895, 
        0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491,
  0x002C7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00347996, 0x00347996, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 
        0x003A7C99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 
        0x004585A0, 0x004685A0, 0x004686A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x00264755, 0x00000000, 0x00081013, 0x003E748A, 0x004B89A3, 0x002B505F, 0x00030607, 0x00000000, 0x00162830, 0x00447A90, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x00376172, 
        0x00020405, 0x00030607, 0x00376071, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005993AB, 0x005993AB, 0x005994AC, 0x005A94AC, 
        0x005B94AD, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006099B0, 0x006199B0, 0x006299B0, 0x003F6473, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x000C1316, 0x006196AD, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00689EB5, 0x00436574, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E1518, 0x006292A7, 0x006BA0B7, 0x006CA1B7, 
        0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x004B6C7A, 0x000A0F11, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00587E8E, 0x0074A7BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BE, 
        0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 0x0079AABE, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 
        0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007BABC0, 0x007BABC0, 0x007BABBF, 0x007BABBF, 0x007BABC0, 0x007BABC0, 0x007BABC0, 0x007BABC0, 0x007BABC0, 0x007BABBF, 0x007BACC0, 0x007BABC0, 0x007BABBF, 0x007CACBF, 0x007BACBF, 
        0x007BABBF, 0x007BABBF, 0x007BABC0, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AABBF, 0x0079ABBF, 0x0079AABF, 0x007AAABF, 0x0079AABF, 
        0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A7BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 
        0x0026383F, 0x00000000, 0x0022333A, 0x006EA2B8, 0x006EA2B8, 0x006697AB, 0x00354E59, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070A0C, 0x003C5A66, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00689DB4, 
        0x00679DB4, 0x00679DB4, 0x00679CB4, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 
        0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005A93AC, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005490A9, 
        0x005490A9, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x0045778C, 0x000C161A, 0x00000000, 0x00274551, 0x004F8BA4, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x0043798F, 0x00122127, 0x00000000, 0x0005090B, 0x002F5768, 0x003D7187, 0x00081013, 
        0x00000000, 0x00264755, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A1, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F819B, 0x003E809C, 
        0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347996, 0x00337895, 0x00327895, 0x00327794, 
        0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002E7492, 0x002E7492, 0x002D7492, 0x002C7391,
  0x002C7391, 0x002D7491, 0x002D7491, 0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00347995, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387B98, 0x00387C98, 
        0x00397C99, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0043849F, 0x0044849F, 
        0x004585A0, 0x004585A0, 0x004686A0, 0x004686A1, 0x004786A1, 0x004887A1, 0x004786A0, 0x001A3039, 0x00000000, 0x000D191E, 0x00203C47, 0x00020405, 0x00000000, 0x00192E36, 0x00488199, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 
        0x00345C6D, 0x00000000, 0x0005080A, 0x00396475, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00548FA8, 0x00548FA9, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A94AC, 
        0x005A94AC, 0x005B94AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x005F97AD, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00446979, 0x00649BB2, 0x00659BB2, 0x00659BB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x006498AD, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x003D5B68, 0x006BA0B6, 0x006BA0B6, 0x006CA0B7, 
        0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA3B8, 0x006FA3B8, 0x006FA3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x003E5A66, 0x00040506, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00090C0E, 0x00608B9C, 0x0074A6BB, 0x0074A6BB, 0x0074A7BC, 0x0074A6BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A7BD, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 
        0x0077A9BD, 0x0078A8BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABF, 0x007AAABE, 0x007AAABE, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x007AABBF, 
        0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007BABBF, 0x007BABBF, 0x007BABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 
        0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AABBF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x007AAABF, 0x0079AABF, 0x007AAABE, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079A9BE, 
        0x0078A9BE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A8BD, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0072A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B8, 0x006FA2B8, 
        0x0039535E, 0x00000000, 0x00121B1F, 0x006DA2B8, 0x006DA1B7, 0x006DA1B7, 0x006B9FB5, 0x00517889, 0x00080B0D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001E2D33, 0x00669CB1, 0x00689DB4, 0x00679DB4, 
        0x00679DB3, 0x00679DB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00649BB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AF, 
        0x005E97AE, 0x005D96AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005994AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A9, 
        0x00548FA8, 0x00538FA8, 0x00528FA8, 0x004B8299, 0x000C1519, 0x00000000, 0x0025414D, 0x00508DA6, 0x004F8CA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x00478199, 0x00122126, 0x00000000, 0x00030608, 0x0004090A, 0x00000000, 
        0x001A313A, 0x004786A0, 0x004887A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0043849F, 0x0043849F, 0x0042839E, 0x0042839D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 
        0x003D809B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003A7E99, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B97, 0x00367A97, 0x00367A96, 0x00357A97, 0x00347996, 0x00347996, 0x00347895, 0x00337895, 0x00327895, 0x00327794, 
        0x00317794, 0x00307694, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7492, 0x002C7491, 0x002C7391,
  0x002C7390, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7492, 0x002F7593, 0x002F7593, 0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A97, 0x00367A96, 0x00377B97, 0x00377B97, 0x00387C98, 
        0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003E7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 
        0x0045849F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A1, 0x004786A1, 0x004787A1, 0x004887A2, 0x000F1D22, 0x00000000, 0x00000000, 0x00010202, 0x00192D36, 0x0049879F, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 
        0x00508DA6, 0x00315767, 0x00000000, 0x00030607, 0x00406F82, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 
        0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005D97AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x00263C45, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0019272D, 
        0x005E92A7, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00283D46, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121C1F, 0x006395A9, 0x006AA0B6, 0x006B9FB6, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B7, 0x006CA1B6, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0070A4B9, 0x006C9FB3, 0x0039545F, 0x00000000, 0x00010202, 0x00010102, 0x00000000, 
        0x00000000, 0x00000000, 0x00131B1F, 0x006694A7, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0076A7BD, 0x0076A8BC, 0x0076A8BD, 0x0076A8BD, 
        0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BE, 0x0077A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 
        0x007AAABF, 0x007AAABE, 0x0079AABF, 0x007AAABF, 0x007AAABF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 
        0x007AAABF, 0x007AABBF, 0x007AAABF, 0x007AAABF, 0x007AAABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0078AABE, 0x0079AABE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 
        0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0074A6BB, 
        0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A4BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0071A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 
        0x004C707F, 0x00000000, 0x00020303, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006CA0B6, 0x005D8B9F, 0x00152025, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D1316, 0x00527E90, 0x00679DB3, 
        0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006199B0, 0x006199B0, 0x006198B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 
        0x005D96AE, 0x005C96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA8, 
        0x00538FA8, 0x00538FA8, 0x004B8299, 0x000B1316, 0x00000000, 0x0024404B, 0x00508DA6, 0x004F8CA5, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00162830, 0x00000000, 0x00000000, 0x000F1C22, 
        0x004987A2, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 
        0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00347996, 0x00347895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 
        0x00317794, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391,
  0x002B7390, 0x002C7391, 0x002C7491, 0x002D7492, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317694, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347895, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387C98, 
        0x00387B98, 0x00387C99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0042839E, 0x0043849E, 
        0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x0045819B, 0x00112026, 0x00000000, 0x00080F12, 0x004A89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 
        0x004E8BA4, 0x004F8CA6, 0x00345B6C, 0x00020304, 0x00030607, 0x00396475, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 
        0x005993AB, 0x005994AC, 0x005A94AC, 0x005A94AC, 0x005B94AD, 0x005C95AD, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x004A7688, 0x00010203, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00456C7C, 
        0x00629AB1, 0x00639AB1, 0x00649AB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00517C8E, 0x00060A0B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00476B7B, 0x00699EB5, 0x006A9FB5, 0x006A9FB6, 0x006A9FB6, 
        0x006A9FB6, 0x006BA0B6, 0x006CA0B6, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006EA1B7, 0x006EA2B7, 0x006DA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006798AB, 0x00293C44, 0x00000000, 0x00000000, 0x003C5763, 0x00030506, 0x00000000, 
        0x00000000, 0x00000000, 0x001D2B30, 0x006C9CB0, 0x0072A5BB, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0074A6BC, 0x0074A7BB, 0x0074A6BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A8BC, 0x0076A8BC, 0x0076A7BC, 
        0x0076A8BD, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 
        0x0078AABE, 0x0079AABE, 0x0078AABE, 0x0078AABE, 0x0079AABE, 0x0078AABE, 0x0078AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x007AAABE, 0x0079AABF, 0x0079AABF, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0079AABE, 
        0x0079AABE, 0x0079AABF, 0x0079AABE, 0x0079AABE, 0x0078A9BE, 0x0078AABE, 0x0079AABE, 0x0079A9BE, 0x0079A9BE, 0x0079AABE, 0x0079AABE, 0x0079AABE, 0x0079A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0077A9BE, 0x0077A9BE, 0x0078A9BD, 0x0077A9BD, 
        0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0075A7BD, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A6BC, 0x0074A7BB, 0x0074A7BC, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 
        0x0073A6BB, 0x0073A6BB, 0x0072A5BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A4BA, 0x0071A4B9, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA2B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006EA2B7, 
        0x005C889B, 0x00000000, 0x00000000, 0x006495AA, 0x006CA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x00679BB2, 0x00324C57, 0x00030405, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090A, 0x00385662, 
        0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 
        0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00548FA8, 
        0x00528FA8, 0x0045778C, 0x000C1519, 0x00000000, 0x0025414D, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B8AA3, 0x004B89A3, 0x001C343E, 0x00000000, 0x00112026, 0x0046829B, 
        0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043839F, 0x0043839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 
        0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00377C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 0x00327894, 0x00317794, 0x00317794, 
        0x00307693, 0x002F7693, 0x002F7693, 0x002E7592, 0x002E7592, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7390,
  0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7592, 0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00317794, 0x00327793, 0x00327794, 0x00337894, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 
        0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7E99, 0x003B7E99, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 
        0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x004887A1, 0x003F778E, 0x000C171B, 0x00000000, 0x00192E37, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA5, 
        0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00345C6C, 0x00000000, 0x0005080A, 0x00365F6F, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x00548FA8, 0x00548FA9, 0x005490A9, 0x005590A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 
        0x005993AB, 0x005993AC, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x005B94AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AD, 0x005D96AE, 0x005E97AE, 0x005B92A8, 0x001D2E36, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001C2D34, 0x006199B0, 
        0x006299B1, 0x00629AB0, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x006398AE, 0x00253841, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001F3037, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699EB5, 0x006A9FB5, 
        0x006A9FB6, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B8, 0x00618EA2, 0x00172226, 0x00000000, 0x00030405, 0x00486A77, 0x006897AB, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x002A3D45, 0x0071A4BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BC, 0x0074A7BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BC, 0x0076A8BC, 0x0076A7BC, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0076A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0078A9BD, 0x0078A9BD, 0x0078A9BE, 
        0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078AABE, 0x0078A9BE, 0x0078A9BE, 
        0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 0x0078A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 
        0x0076A8BD, 0x0076A8BC, 0x0076A8BD, 0x0076A8BC, 0x0075A8BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A5BB, 0x0072A5BA, 
        0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B7, 0x006EA2B8, 0x006DA2B7, 0x006DA2B7, 0x006DA1B7, 
        0x006395A9, 0x00000000, 0x00000000, 0x00517A8B, 0x006BA0B6, 0x006AA0B6, 0x006AA0B6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00689EB4, 0x004D7585, 0x00080D0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 
        0x001A282F, 0x005C8EA4, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D95AE, 0x005C95AD, 
        0x005C95AD, 0x005C95AD, 0x005B94AD, 0x005B94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528FA8, 
        0x00487D93, 0x000C161A, 0x00000000, 0x0024404C, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00182D36, 0x00000000, 0x000C181C, 0x003F778E, 0x004887A1, 
        0x004786A1, 0x004786A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 
        0x003C7E9A, 0x003B7E99, 0x003B7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A96, 0x00357996, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317693, 0x00307693, 
        0x00307693, 0x002F7592, 0x002F7592, 0x002E7592, 0x002D7491, 0x002D7391, 0x002C7391, 0x002C7391, 0x002A7290,
  0x002A7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7492, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00367A96, 0x00367A97, 0x00367B97, 
        0x00377B97, 0x00387C98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 
        0x0043839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x003C7188, 0x00060B0D, 0x00000000, 0x00213D4A, 0x004A87A1, 0x004B89A3, 0x004C89A3, 0x004D8AA4, 0x004D8AA4, 0x004D8BA5, 
        0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA6, 0x00325969, 0x00000000, 0x00020405, 0x003B6779, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005590A8, 0x005590A9, 0x005590A9, 0x005691A9, 0x005692AA, 0x005792AA, 0x005792AB, 
        0x005893AB, 0x005993AB, 0x005993AB, 0x005A93AC, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005B95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x00426B7B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x005A90A6, 0x006199B0, 
        0x006199B0, 0x006299B1, 0x006299B1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00517C8F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x005E8FA4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 
        0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x005F8DA0, 0x000E1619, 0x00000000, 0x00050809, 0x00507686, 0x006FA3B8, 0x004F7483, 0x00000000, 0x00000000, 
        0x00000000, 0x00000101, 0x0038525C, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BC, 0x0075A6BC, 
        0x0075A7BB, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0076A8BD, 0x0076A8BD, 0x0074A5B9, 0x0070A0B4, 0x0070A0B3, 0x0071A0B4, 0x0070A0B4, 0x0071A0B4, 0x0071A0B4, 0x0071A0B4, 0x0071A1B4, 0x0071A0B4, 
        0x0071A1B4, 0x0071A1B4, 0x0071A1B4, 0x0072A0B4, 0x0071A1B4, 0x0072A1B4, 0x0072A1B4, 0x0077A9BE, 0x0077A9BD, 0x0078A9BE, 0x0077A9BD, 0x0078A9BD, 0x0078A9BD, 0x0077A9BD, 0x0078A9BE, 0x0077A9BD, 0x0078A9BD, 0x0078A9BE, 0x0078A9BD, 0x0078A9BE, 
        0x0077A9BE, 0x0077A9BD, 0x0077A9BD, 0x0077A9BD, 0x006D9BAD, 0x0011181B, 0x005A7F8F, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0076A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 
        0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BC, 0x0075A6BB, 0x0074A7BC, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0072A5BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 
        0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x0070A3B8, 0x006FA3B9, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 
        0x006698AC, 0x000D1416, 0x00000000, 0x003E5C69, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00699EB4, 0x00689EB4, 0x006094A9, 0x00152025, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x000B1214, 0x00517E91, 0x006299B0, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006198B0, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 
        0x005C95AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528FA8, 0x004A8097, 
        0x00080D10, 0x00000000, 0x0025424E, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004A87A1, 0x00213E49, 0x00000000, 0x00060B0D, 0x003D7289, 0x004887A1, 0x004786A1, 
        0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0041839D, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F809C, 0x003E809C, 0x003E7F9B, 0x003D809B, 0x003C7F9A, 0x003C7E9A, 
        0x003C7E9A, 0x003A7D9A, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00307694, 0x00307693, 
        0x00307693, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002A7290,
  0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00317694, 0x00327794, 0x00327794, 0x00327895, 0x00337895, 0x00347996, 0x00347996, 0x00357996, 0x00367A96, 0x00367A97, 
        0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0041829E, 0x0042839D, 
        0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x003A6C80, 0x00060B0D, 0x00000000, 0x00274957, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 
        0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004E8BA4, 0x004F8DA6, 0x00355E6F, 0x00030607, 0x00000000, 0x00335969, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 
        0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x0054889E, 0x000A1114, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00365663, 0x006098AF, 0x006098B0, 
        0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x0010191D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0034505B, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 
        0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006AA0B6, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B6, 0x004C7181, 0x00060A0B, 0x00000000, 0x00121B1E, 0x00588496, 0x006EA2B8, 0x006EA2B8, 0x00354F59, 0x00000000, 0x00000000, 
        0x00000000, 0x00020304, 0x00476876, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A6BA, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 
        0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0074A7BC, 0x0075A7BB, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x00557A89, 0x00161F23, 0x00172125, 0x000B1012, 0x00080C0E, 0x000C1113, 0x000C1113, 0x000C1113, 0x000C1113, 0x000C1113, 
        0x000C1113, 0x000C1113, 0x000B0F11, 0x00070A0B, 0x0012191C, 0x00182226, 0x001C282D, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0077A9BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A9BD, 0x0077A9BD, 
        0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x0077A8BD, 0x004F707E, 0x00000000, 0x001D2A2F, 0x0077A8BD, 0x0076A8BD, 0x0077A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A5BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A5BA, 
        0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA3B8, 0x006EA2B8, 0x006EA2B7, 0x006EA2B8, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 
        0x006699AE, 0x0019262B, 0x00000000, 0x002A4049, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00679EB4, 0x00679DB3, 0x00679DB3, 0x00324D58, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00375663, 0x005E93AA, 0x006299B0, 0x006199B0, 0x006199B0, 0x006198B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 
        0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00528EA8, 0x003F6D80, 0x00060A0C, 
        0x00000000, 0x00274551, 0x00508DA6, 0x004F8CA5, 0x004F8CA6, 0x004E8CA5, 0x004E8CA5, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x00274957, 0x00000000, 0x00060C0E, 0x003A6C81, 0x004887A1, 0x004787A1, 0x004786A0, 
        0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839F, 0x0042839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F809C, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 
        0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D98, 0x00387C98, 0x00387C98, 0x00377C98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347996, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 
        0x002E7593, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7491, 0x002C7391, 0x002C7390, 0x002A7290, 0x002A7290,
  0x0029718F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7391, 0x002D7491, 0x002D7491, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 
        0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0041829D, 
        0x0042829E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x004887A1, 0x00386A7E, 0x00060B0D, 0x00000000, 0x00223F4C, 0x004B88A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 
        0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x00396577, 0x00040708, 0x00010202, 0x00294856, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005791AA, 
        0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005993AB, 0x0052889E, 0x001B2D34, 0x003C6373, 0x005B94AC, 0x005B95AD, 0x00508196, 0x00111C20, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121D21, 0x00588CA2, 0x005F98AF, 0x006098AF, 
        0x006098AF, 0x006098B0, 0x006198B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x00639AB1, 0x00324E5A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E1619, 0x00598A9F, 0x00659CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00689DB4, 
        0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006AA0B6, 0x006AA0B5, 0x003D5C68, 0x00040607, 0x00000000, 0x001D2C32, 0x00608FA2, 0x006CA1B7, 0x006DA1B7, 0x006DA2B7, 0x001F2E34, 0x00000000, 0x00000000, 
        0x00000000, 0x00040607, 0x00578191, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0072A4BA, 0x0072A5BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 
        0x0073A5BB, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BC, 0x006E9EB1, 0x00618C9D, 0x00618B9D, 0x00597F8F, 0x002C3F47, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00070B0C, 0x00466470, 0x005E8697, 0x00638C9D, 0x00638D9F, 0x0076A8BC, 0x0076A8BC, 0x0076A7BD, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BC, 0x0076A8BD, 0x0076A8BC, 0x0076A8BC, 
        0x0076A8BC, 0x0076A8BC, 0x0075A8BC, 0x0076A8BD, 0x0012191C, 0x00000000, 0x00000000, 0x005F8899, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A7BB, 0x0074A7BC, 0x0074A6BB, 
        0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A5BB, 0x0073A6BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4BA, 0x0070A4B9, 
        0x0070A4B9, 0x0070A4B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA1B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x00679BB1, 0x00253840, 0x00000000, 0x00172328, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00679DB4, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x004C7688, 0x000A1113, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001B2B31, 0x0057899E, 0x006098B0, 0x006098B0, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 
        0x005A94AC, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691A9, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00528FA7, 0x003C687B, 0x00060B0D, 0x00000000, 
        0x002D4F5D, 0x004F8BA4, 0x004F8CA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA4, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00223F4C, 0x00000000, 0x00060C0E, 0x00396A7F, 0x004887A1, 0x004787A1, 0x004686A1, 0x004686A1, 
        0x004686A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 
        0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x002F7693, 0x002F7592, 
        0x002E7592, 0x002E7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x0029718F,
  0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7592, 0x002F7592, 0x002F7693, 0x002F7693, 0x00307693, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 
        0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 0x0040819D, 0x0040819D, 0x0041829D, 
        0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00356477, 0x00040809, 0x00000101, 0x00254552, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 
        0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00407286, 0x00010303, 0x00000000, 0x00294855, 0x00518CA5, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 
        0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005791A8, 0x00365968, 0x0005080A, 0x0006090B, 0x000B1215, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x00365764, 0x005E97AE, 0x005F97AF, 0x005F97AF, 
        0x006098AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x00548498, 0x00070C0D, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00365461, 0x00659CB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB4, 
        0x00679DB4, 0x00679EB4, 0x00689DB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x0036515C, 0x00000000, 0x00000000, 0x001F2E34, 0x006A9FB5, 0x006CA0B6, 0x006CA0B7, 0x006CA1B7, 0x006DA1B7, 0x000B1113, 0x00000000, 0x00000000, 
        0x00000000, 0x00060A0B, 0x00689AAF, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 
        0x0072A5BA, 0x0072A5BA, 0x0073A5BB, 0x0073A5BA, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0074A6BB, 0x0074A6BB, 0x0074A7BB, 0x0073A4BA, 0x003F5B65, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00050809, 0x00537786, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0075A8BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0076A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x00598090, 0x00000000, 0x00000000, 0x00000000, 0x00212F35, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0074A7BC, 0x0074A7BC, 0x0074A6BC, 0x0074A7BC, 0x0074A6BC, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 
        0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BA, 0x0073A6BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 
        0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA2B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB5, 0x006A9FB5, 
        0x00699DB3, 0x00324C56, 0x00000000, 0x00070B0C, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659BB3, 0x00649BB2, 0x006196AD, 0x001E2F36, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0006090B, 0x004C788A, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E97AF, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 
        0x005A93AC, 0x005994AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00528FA7, 0x003B6779, 0x00000000, 0x00000000, 0x00355F6F, 
        0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x00254451, 0x00000101, 0x00040809, 0x00356478, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 
        0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003A7E99, 
        0x003A7D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00377B98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337895, 0x00337895, 0x00327895, 0x00317794, 0x00317794, 0x00307694, 0x00307693, 0x002F7593, 0x002F7592, 
        0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F,
  0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7290, 0x002C7391, 0x002C7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337995, 0x00347996, 0x00347996, 
        0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x0040819C, 0x0040829D, 
        0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00325D6F, 0x00040708, 0x00000000, 0x002B505F, 0x004A89A3, 0x004B89A3, 
        0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA6, 0x00508DA6, 0x0044778D, 0x000A1216, 0x00000000, 0x0026434F, 0x004E88A0, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005591A9, 
        0x005691A9, 0x005692AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005992AB, 0x0051869C, 0x00213741, 0x0005090A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000A1013, 0x0053879C, 0x005E97AE, 0x005E97AE, 0x005F97AF, 
        0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006097AE, 0x0029414B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000F181B, 0x00639BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB2, 0x00669CB3, 0x00669CB3, 0x00669DB3, 
        0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689DB4, 0x00689EB5, 0x00699EB5, 0x006294A9, 0x00253840, 0x00000000, 0x00020304, 0x002E4650, 0x006AA0B5, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006392A7, 0x00050708, 0x00000000, 0x00000000, 
        0x00000000, 0x000D1316, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A5BA, 
        0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0073A5BB, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x005F899A, 0x000B1013, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x0011181B, 0x0074A6BB, 0x0075A7BC, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 0x0075A7BC, 
        0x0075A7BC, 0x0075A7BC, 0x0074A7BC, 0x00202D33, 0x00000000, 0x00000000, 0x00000000, 0x00020303, 0x00628C9E, 0x0074A7BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 
        0x0073A6BB, 0x0073A5BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A4B9, 0x006FA3B8, 0x006FA3B8, 
        0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA1B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B5, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 
        0x00699FB5, 0x003D5C69, 0x00000000, 0x00000101, 0x006397AC, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649AB2, 0x00649AB2, 0x00639AB1, 0x00314E5A, 0x0005090A, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00314F5B, 0x005A90A7, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005A95AD, 0x005A94AC, 0x005A94AC, 
        0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005692AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00518EA6, 0x00335968, 0x00000000, 0x00000000, 0x00213B46, 0x00508DA6, 
        0x00508CA6, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x002B4F5E, 0x00000000, 0x00040809, 0x00325E70, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004585A0, 
        0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 
        0x00397D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x002F7593, 0x002F7592, 0x002F7592, 
        0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F,
  0x0028708E, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7390, 0x002C7390, 0x002D7491, 0x002D7491, 0x002D7492, 0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00337894, 0x00337895, 0x00337995, 0x00347996, 
        0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003E809C, 0x003F809C, 0x0040819D, 
        0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x004887A1, 0x00356477, 0x0004090A, 0x00000000, 0x00254551, 0x004B89A3, 
        0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA4, 0x004F8CA6, 0x0025424E, 0x00000000, 0x00000000, 0x00182B33, 0x004C839B, 0x00528FA7, 0x00538EA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 
        0x005590A9, 0x005590A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005893AB, 0x005993AB, 0x00467386, 0x001F333B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00162329, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005E97AE, 
        0x005E97AE, 0x005E97AE, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x00517E92, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004D798C, 0x00639AB1, 0x00639AB1, 0x00649BB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659BB2, 0x00659CB3, 
        0x00669CB3, 0x00669DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x005C8CA1, 0x001A282D, 0x00000000, 0x00010202, 0x0040616E, 0x00699FB5, 0x00699FB5, 0x006A9FB6, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x00517A8B, 0x00030505, 0x00000000, 0x00000000, 
        0x00000000, 0x00213138, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B9, 0x006FA3B8, 0x0070A4B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 
        0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0072A4BA, 0x0072A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BB, 0x0073A5BA, 0x0072A5BA, 0x006694A7, 0x0011181B, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x001C292E, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0073A6BB, 0x0074A6BB, 0x0073A6BB, 0x0073A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0074A6BB, 0x0073A6BB, 0x0074A6BB, 
        0x0074A6BB, 0x0074A6BB, 0x00618B9D, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00324852, 0x0073A6BB, 0x0073A5BB, 0x0073A5BB, 0x0073A5BB, 0x0073A6BB, 0x0072A5BB, 0x0073A5BB, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 
        0x0071A5BA, 0x0072A5BA, 0x0072A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 
        0x006EA2B8, 0x006EA2B8, 0x006DA2B8, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006AA0B5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00689EB4, 
        0x00689EB4, 0x00466A79, 0x00010202, 0x00010102, 0x00548093, 0x00679DB4, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x00629AB1, 0x00497384, 
        0x00121D21, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0019282F, 0x004F8095, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A95AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005993AB, 
        0x005993AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x0027434F, 0x00000000, 0x00010303, 0x00020405, 0x00020304, 0x002F5463, 
        0x004F8CA6, 0x004E8CA5, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x00254551, 0x00000000, 0x0004090A, 0x00356478, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A1, 0x004685A0, 0x004585A0, 0x0045859F, 
        0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x00397D99, 
        0x00397C99, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A96, 0x00357A96, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 
        0x002D7492, 0x002C7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028708E,
  0x0027708E, 0x0028708E, 0x0029718F, 0x0029728F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00337895, 
        0x00357996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003F809C, 0x003F819C, 
        0x0040819D, 0x0040829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004887A1, 0x004887A2, 0x00356478, 0x00040708, 0x00000101, 0x00223F4B, 
        0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8CA5, 0x00315767, 0x00000000, 0x00000000, 0x00080E11, 0x00000000, 0x000F1A1F, 0x004C849B, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00548FA8, 0x005490A8, 
        0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005891A9, 0x00447183, 0x000C1418, 0x00000000, 0x00000000, 0x000E171B, 0x005C95AD, 0x005C95AE, 0x005D96AE, 0x005D96AE, 
        0x005E97AE, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x001B2C33, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0029404A, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 
        0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x0059889B, 0x00090E10, 0x00000000, 0x00000000, 0x004E7687, 0x00689EB4, 0x00699EB4, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x00426371, 0x00020303, 0x00000000, 0x00000000, 
        0x00000000, 0x00395561, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B8, 0x006DA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 
        0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0072A5BA, 0x0071A4BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x006999AC, 0x00131C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x0026373E, 0x0073A5BB, 0x0073A5BB, 0x0073A6BA, 0x0073A5BB, 0x0073A6BB, 0x0073A5BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 0x0073A6BB, 
        0x0073A6BB, 0x0073A6BB, 0x0037505A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00131B1F, 0x006592A6, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A4BA, 0x0072A4BA, 0x0071A5BA, 
        0x0071A4B9, 0x0071A4BA, 0x0071A4B9, 0x0071A4BA, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 
        0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 
        0x00689EB4, 0x004E7687, 0x0006090B, 0x00000101, 0x00456A79, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 
        0x00598EA4, 0x0022363F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030506, 0x00375A68, 0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005B94AC, 0x00578FA6, 0x004F8398, 0x005994AB, 0x005993AB, 0x005893AB, 
        0x005892AB, 0x005892AA, 0x005791AA, 0x005791AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538EA7, 0x00528EA7, 0x001A2D35, 0x00000000, 0x00070D0F, 0x00457A90, 0x002D4F5D, 0x00000000, 0x00010202, 
        0x002F5564, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x00223F4C, 0x00000101, 0x00040809, 0x00356478, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 
        0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D98, 
        0x00397C98, 0x00387B98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00357996, 0x00337995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 
        0x002D7491, 0x002C7391, 0x002C7390, 0x002B7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0028708F, 0x0028708E,
  0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 
        0x00347995, 0x00357996, 0x00357A96, 0x00357A96, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397D98, 0x003A7C99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 
        0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041839E, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004685A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A2, 0x00315D6F, 0x00040809, 0x00000000, 
        0x00274957, 0x004A87A1, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x00376274, 0x00000000, 0x00000000, 0x00203A45, 0x00508DA6, 0x001A2E36, 0x00000000, 0x00070D0F, 0x0044768A, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x005490A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005791A9, 0x002C4954, 0x00080D10, 0x00010203, 0x00355866, 0x005C95AD, 0x005C95AD, 0x005C96AD, 
        0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AF, 0x00416879, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090E10, 0x00548498, 0x006299B0, 0x006299B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB1, 0x00649BB2, 
        0x00659CB2, 0x00659BB3, 0x00659CB2, 0x004C7486, 0x00010202, 0x00000000, 0x000D1417, 0x0058879B, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00304853, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00507788, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA3B8, 0x006FA3B8, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 
        0x0070A3B8, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A5BA, 0x006999AE, 0x00141D21, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00293C43, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0072A5BA, 0x0073A5BA, 0x0072A5BB, 0x0072A5BB, 0x0072A5BA, 0x0072A5BB, 0x0073A5BA, 0x0072A5BA, 0x0072A5BA, 
        0x0072A5BA, 0x006998AC, 0x00182227, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004D6F7E, 0x0072A5BA, 0x0072A4BA, 0x0071A5BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 
        0x0071A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA2B7, 0x006EA1B8, 0x006DA1B7, 
        0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00689DB4, 
        0x00679DB4, 0x00568395, 0x000B1113, 0x00000000, 0x00375460, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006098B0, 
        0x006098B0, 0x005F98AF, 0x002F4B57, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000F191D, 0x002C4853, 0x00304F5C, 0x001F343C, 0x00030506, 0x001E3139, 0x005993AB, 0x005892AB, 0x005892AB, 
        0x005792AB, 0x005791AA, 0x005791AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x004A8198, 0x00121F25, 0x00000000, 0x00101C21, 0x00488097, 0x00508DA6, 0x004E89A3, 0x001C313A, 0x00000000, 
        0x00030607, 0x00366375, 0x004D8AA4, 0x004D8AA4, 0x004C89A3, 0x004B89A3, 0x004A87A1, 0x00274957, 0x00000000, 0x00040809, 0x00325D70, 0x004887A1, 0x004887A1, 0x004787A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 
        0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D98, 0x00397C99, 
        0x00387C98, 0x00377B98, 0x00377B97, 0x00377A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00307794, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7492, 0x002E7492, 0x002D7491, 
        0x002D7391, 0x002B7391, 0x002B7390, 0x002B7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E,
  0x00276F8E, 0x0027708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 
        0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809C, 
        0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00356477, 0x00060C0E, 
        0x00000000, 0x00213D49, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x0039677B, 0x00050A0C, 0x00000000, 0x00192C35, 0x004A859D, 0x004F8DA5, 0x004F8BA5, 0x00284753, 0x00000000, 0x00040709, 0x00345B6C, 0x00528EA7, 0x00538FA7, 0x00538FA8, 
        0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x004B7C90, 0x00263E48, 0x00090F12, 0x002B4752, 0x0053889E, 0x005C95AD, 
        0x005D96AD, 0x005C96AE, 0x005D96AE, 0x004F8094, 0x00070B0D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002E4954, 0x006098B0, 0x006098B0, 0x006199B0, 0x006299B0, 0x006199B0, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639BB1, 0x00649BB2, 
        0x00649BB2, 0x00649CB2, 0x003A5A68, 0x00040708, 0x00000000, 0x0018242A, 0x0058879B, 0x00669CB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00699FB5, 0x0023353C, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x006394A8, 0x006AA0B6, 0x006BA0B6, 0x006CA0B6, 0x006BA1B7, 0x006CA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B7, 0x006EA2B7, 0x006EA2B7, 0x006FA2B8, 0x006EA2B8, 0x006FA2B8, 
        0x006EA2B8, 0x006FA2B9, 0x006FA3B8, 0x006FA3B8, 0x0070A3B9, 0x006FA3B8, 0x006FA3B9, 0x006FA4B8, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0071A4B9, 0x0070A4B9, 0x0070A4B9, 0x00699AAF, 0x00141D21, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00293C44, 0x0071A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0072A4B9, 0x0072A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 0x0071A5BA, 0x0071A4BA, 0x0071A4BA, 0x0071A4BA, 
        0x0071A4BA, 0x00557B8C, 0x00000000, 0x00000000, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001A262B, 0x0071A4B9, 0x0071A4B9, 0x0070A4BA, 0x0070A4B9, 0x0070A4B9, 0x0071A4B9, 0x0071A4B9, 0x0070A3B9, 0x0070A4B9, 0x006FA3B9, 
        0x006FA3B9, 0x0070A3B9, 0x006FA3B9, 0x006FA2B9, 0x006FA3B8, 0x006FA3B9, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B7, 0x006DA2B7, 0x006DA1B8, 0x006DA2B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 
        0x006CA0B6, 0x006CA0B6, 0x006CA1B7, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00689EB5, 0x00689EB4, 0x00689DB4, 0x00689DB4, 0x00679DB4, 0x00669DB3, 
        0x00679CB3, 0x005D8EA3, 0x000F181B, 0x00000000, 0x00283E47, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006199B0, 0x006098AF, 0x006098AF, 
        0x005F98AF, 0x005F97AF, 0x005F97AF, 0x00416879, 0x00080D0F, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E171B, 0x00375C6B, 0x00568FA8, 0x005893AB, 0x005892AB, 0x005792AA, 
        0x005791AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00538FA8, 0x00528EA7, 0x00538FA8, 0x00417286, 0x000D181C, 0x00000000, 0x001B3039, 0x00498198, 0x00508CA6, 0x004F8CA5, 0x004F8CA5, 0x004A839C, 0x00162931, 
        0x00000000, 0x00080F12, 0x003D6E83, 0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x00213D4A, 0x00000000, 0x00060C0E, 0x00366478, 0x004887A1, 0x004787A1, 0x004787A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 
        0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E99, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 
        0x00377B98, 0x00377B97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00327795, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391, 
        0x002C7391, 0x002B7390, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0027708E, 0x0027708E,
  0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002B7391, 0x002C7391, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327895, 
        0x00337895, 0x00337995, 0x00347995, 0x00357996, 0x00367A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387B97, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 
        0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x00386A7F, 
        0x00060B0D, 0x00000000, 0x00182D36, 0x004988A2, 0x004B89A3, 0x0042788F, 0x00070C0F, 0x00000000, 0x00101C22, 0x004A869F, 0x004E8BA5, 0x004F8BA5, 0x004F8CA5, 0x00508CA6, 0x00366071, 0x00000000, 0x00000000, 0x00284754, 0x00528EA7, 0x00528EA7, 
        0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005792AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005891A8, 0x0049788C, 0x0016242A, 0x00070C0E, 0x00385B6A, 
        0x005C95AD, 0x005C95AD, 0x0052869B, 0x00131F24, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00070C0E, 0x00588DA3, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 
        0x00639AB2, 0x0029414A, 0x00000101, 0x00000000, 0x00243840, 0x006195AB, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x006194A9, 0x0019262B, 0x00000000, 0x00000000, 0x00000000, 
        0x00070A0C, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B8, 
        0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006FA3B8, 0x006FA3B9, 0x006FA3B8, 0x006FA3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x006999AE, 0x00141D21, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00293C44, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4BA, 0x0071A4BA, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 0x0071A4B9, 
        0x0071A4B9, 0x00283A42, 0x00000000, 0x000E1518, 0x003F5B67, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x005A8496, 0x0070A3B9, 0x0070A4B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B8, 
        0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006EA1B8, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB6, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00669DB4, 0x00679DB3, 0x00669CB3, 
        0x00659CB3, 0x00659AB1, 0x00131E22, 0x00000000, 0x001D2C33, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x006097AF, 0x005F97AF, 
        0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005E96AE, 0x0041697A, 0x0005080A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010102, 0x00335462, 0x00548AA1, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005691AA, 
        0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005590A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00365E6F, 0x00030506, 0x00000000, 0x002A4A57, 0x004E89A2, 0x00508CA6, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004D8BA4, 0x0048839A, 
        0x00122228, 0x00000000, 0x00060C0E, 0x0041778E, 0x004A89A3, 0x00182D36, 0x00000000, 0x00060C0E, 0x00396A80, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839F, 0x0043839E, 
        0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00387B98, 
        0x00377B97, 0x00367A97, 0x00367A96, 0x00367A96, 0x00347996, 0x00347996, 0x00347995, 0x00337895, 0x00327795, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002D7592, 0x002D7491, 0x002C7491, 0x002C7391, 
        0x002B7390, 0x002A7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x00266F8E,
  0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7390, 0x002B7390, 0x002C7391, 0x002C7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 
        0x00327794, 0x00337895, 0x00337895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7E99, 0x003B7E99, 0x003B7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 
        0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 
        0x003A6C81, 0x00060B0D, 0x00000000, 0x001C333D, 0x00427991, 0x00080F11, 0x00000000, 0x000C171B, 0x0049849D, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x00508CA6, 0x00407388, 0x00060B0D, 0x00000000, 0x00192D35, 0x00508AA3, 
        0x00528FA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AA, 0x005893AB, 0x005993AB, 0x005993AC, 0x005993AC, 0x005A94AC, 0x003B6271, 0x00070C0E, 
        0x0006090B, 0x000C1417, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00345460, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x006299B1, 0x005E93AA, 
        0x0020323A, 0x00000000, 0x00000000, 0x002E4853, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00669DB3, 0x00669DB3, 0x00679DB3, 0x00679DB3, 0x00679DB3, 0x005A899E, 0x000F181B, 0x00000000, 0x00000000, 0x00000000, 
        0x001C2A30, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B7, 0x006BA0B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 
        0x006DA1B7, 0x006DA1B7, 0x006DA2B8, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA3B8, 0x006EA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B9, 0x006899AE, 0x00141D21, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00293C44, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A3B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 0x0070A4B9, 
        0x00699AAE, 0x00000000, 0x00000000, 0x0043626F, 0x006796AA, 0x00040707, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001E2C32, 0x0070A3B9, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA3B8, 0x006FA2B8, 0x006EA2B8, 
        0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA2B8, 0x006DA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006BA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006AA0B6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 
        0x00659CB3, 0x00659CB3, 0x001C2C32, 0x00000000, 0x00152227, 0x005E94AA, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006299B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005E97AF, 
        0x005E97AF, 0x005D97AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x001C2D34, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020405, 0x001B2D35, 0x0052889E, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AA, 0x005792AA, 0x005691AA, 0x005691AA, 
        0x005691A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x005490A9, 0x00538FA8, 0x00538FA8, 0x00518CA6, 0x002A4855, 0x00000000, 0x00030607, 0x002F5462, 0x00508DA6, 0x00508DA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8AA4, 0x004D8AA4, 
        0x00447B93, 0x000C171C, 0x00000000, 0x00081013, 0x00182C35, 0x00000000, 0x00060B0D, 0x003A6C81, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 
        0x0042839E, 0x0041829D, 0x0040829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7D9A, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 
        0x00377B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7390, 
        0x002B7290, 0x002A728F, 0x002A7290, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00266F8E, 0x00266F8D,
  0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0028708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002B7391, 0x002C7391, 0x002C7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317694, 0x00327794, 
        0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 
        0x003D7F9B, 0x003E809B, 0x003E819C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 
        0x004887A1, 0x003C7188, 0x000C181C, 0x00000000, 0x00060B0D, 0x00000000, 0x000C161A, 0x0040758B, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA6, 0x0043778C, 0x00142229, 0x00000000, 0x00101D22, 
        0x00437488, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x0053899F, 
        0x002A4550, 0x00080E10, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060A0B, 0x005E96AE, 0x005E97AE, 0x005F97AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x0056879B, 0x001A292F, 
        0x00000000, 0x00020404, 0x00365461, 0x00639BB1, 0x00649AB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669DB4, 0x00537F92, 0x00050809, 0x00000000, 0x00000000, 0x00000000, 
        0x002E4751, 0x00689EB5, 0x00699EB5, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006CA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 
        0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B7, 0x006DA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006899AD, 0x00141D21, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00283C43, 0x006FA3B8, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x006FA3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x0070A3B9, 0x006FA3B9, 0x0070A3B9, 0x006FA3B9, 0x0070A3B9, 0x006FA3B9, 
        0x00324953, 0x00000000, 0x00070A0C, 0x006898AD, 0x006C9FB4, 0x002A3E45, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x005D879A, 0x006FA2B8, 0x006FA2B8, 0x006EA3B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 
        0x006EA2B8, 0x006EA2B8, 0x006DA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006CA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006B9FB6, 0x006AA0B6, 0x006AA0B5, 
        0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00689EB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00679EB4, 0x00689DB4, 0x00679EB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 
        0x00649BB2, 0x00649BB2, 0x002A414B, 0x00000000, 0x000F181C, 0x0058899E, 0x00639AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F97AE, 0x005E97AE, 0x005E97AE, 
        0x005E96AE, 0x005D96AE, 0x005C96AD, 0x005C96AD, 0x005C95AD, 0x00213740, 0x00000000, 0x00000000, 0x00000000, 0x0017262D, 0x003E6778, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 
        0x005590A9, 0x005490A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x004B8399, 0x001F363F, 0x00000000, 0x000B1316, 0x00376172, 0x00508DA6, 0x004F8DA6, 0x004F8CA6, 0x004E8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 
        0x004C89A4, 0x003D6F84, 0x00080F12, 0x00000000, 0x00000000, 0x000C181C, 0x003D7289, 0x004887A1, 0x004787A1, 0x004787A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 
        0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003C7F9B, 0x003D7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x00397D99, 0x00397C99, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 
        0x00367A97, 0x00357A97, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7693, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7390, 
        0x002A7290, 0x002A7290, 0x0029728F, 0x0029718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D,
  0x00256E8C, 0x00266E8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307694, 
        0x00317794, 0x00327795, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 
        0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045849F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 
        0x004787A1, 0x004887A1, 0x003F778E, 0x00112026, 0x00000000, 0x00020304, 0x00305A6B, 0x004B89A3, 0x004B89A3, 0x004C89A3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004A839C, 0x0025414C, 0x00000000, 
        0x00060B0D, 0x00345A6B, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005490A8, 0x005591A9, 0x005691AA, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 
        0x005A94AC, 0x004C7D92, 0x00263E48, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001D3037, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005F97AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x004E7C90, 0x000D1518, 0x00000000, 
        0x00040607, 0x00487182, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639BB2, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x004B7384, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00436776, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B8, 0x006DA2B7, 0x006DA2B7, 0x006798AD, 0x00131D21, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00283B43, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006EA3B8, 0x006EA2B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006FA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006A9DB2, 
        0x00050809, 0x00000000, 0x002E434D, 0x006C9FB5, 0x006EA2B8, 0x004C7180, 0x00040607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00283B43, 0x006EA2B8, 0x006DA2B7, 0x006DA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 
        0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B7, 0x006CA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 
        0x00699FB5, 0x00699FB5, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00649BB1, 0x00639BB2, 0x00385764, 0x00000000, 0x00090F12, 0x00507E91, 0x006299B0, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 
        0x005D96AE, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x004E8195, 0x000B1114, 0x00000000, 0x00091012, 0x003B6273, 0x00548BA2, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591AA, 0x005590A9, 0x005490A9, 
        0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA7, 0x00538FA8, 0x00406F82, 0x000D171B, 0x00000000, 0x00172830, 0x00457A90, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 
        0x004B89A3, 0x003E748A, 0x00060C0F, 0x00000000, 0x00112026, 0x003F778E, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 
        0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9B, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B98, 0x00367B97, 0x00367B97, 
        0x00367A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317694, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7290, 0x002A7290, 
        0x002A7290, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00256E8C,
  0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002C7391, 0x002C7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x00307693, 0x00307693, 0x00307693, 
        0x00317694, 0x00327794, 0x00327894, 0x00327895, 0x00337995, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 
        0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 
        0x004786A1, 0x004786A1, 0x004887A1, 0x0044819B, 0x000F1C21, 0x00000000, 0x00081013, 0x003E7288, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x00508CA6, 0x00315767, 
        0x00020405, 0x00000000, 0x00223C47, 0x00518DA6, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AB, 0x005892AB, 0x005893AB, 0x005993AB, 
        0x005993AB, 0x005A94AC, 0x005A94AC, 0x00467487, 0x000E171A, 0x00000000, 0x00000000, 0x000D1519, 0x005C96AD, 0x005D96AD, 0x005D96AE, 0x005D97AE, 0x005E97AE, 0x005F97AE, 0x005F97AF, 0x005F97AF, 0x00436B7B, 0x00040708, 0x00000000, 0x000A1012, 
        0x00517F93, 0x006199B0, 0x006299B0, 0x006299B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x003B5C69, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00558294, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699FB5, 0x006A9FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB6, 0x006A9FB5, 0x006A9FB6, 0x006AA0B6, 0x006AA0B6, 0x006BA0B6, 
        0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006CA0B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006697AC, 0x00131D21, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00283B43, 0x006EA2B7, 0x006EA2B8, 0x006DA2B8, 0x006EA2B7, 0x006EA2B7, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B7, 0x006EA2B8, 0x006EA2B8, 0x006EA2B8, 0x00405F6C, 
        0x00000101, 0x00040607, 0x004E7383, 0x006EA2B8, 0x006EA2B8, 0x006CA0B6, 0x0011191C, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000E1417, 0x005E8B9E, 0x006DA1B7, 0x006DA1B7, 0x006CA1B7, 0x006DA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 
        0x006CA1B7, 0x006CA0B6, 0x006CA0B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006AA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 
        0x00689EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB3, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00639BB1, 
        0x00639AB1, 0x00639AB1, 0x00477081, 0x00000000, 0x00040607, 0x00497385, 0x006199B0, 0x006198B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C95AE, 0x005C96AD, 
        0x005C95AD, 0x005C95AD, 0x005B95AC, 0x0053889E, 0x000F191D, 0x00000000, 0x0029434E, 0x005891AA, 0x005993AB, 0x005893AB, 0x005893AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005692AA, 0x005691A9, 0x005691AA, 0x005590A9, 0x005590A9, 0x005490A9, 
        0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00518DA7, 0x00355C6D, 0x00030506, 0x00000101, 0x001E353F, 0x004E8AA2, 0x00508CA6, 0x004F8CA6, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 
        0x003E7288, 0x00081013, 0x00000000, 0x000F1C22, 0x0046819B, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043839F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 
        0x0040829D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387B97, 0x00377B97, 0x00367A97, 0x00367A96, 
        0x00357A96, 0x00347996, 0x00347995, 0x00347895, 0x00327895, 0x00327795, 0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 
        0x002A7290, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D,
  0x00246E8C, 0x00256E8C, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x002A718F, 0x002A728F, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 
        0x00317693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00347895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397D98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 
        0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x004485A0, 0x004585A0, 0x004685A0, 
        0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x004987A2, 0x001A3039, 0x00000000, 0x00030607, 0x00356376, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004E8BA4, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 
        0x00396577, 0x000C161A, 0x00000000, 0x00172931, 0x0045788E, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 
        0x005993AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x005A94AC, 0x00335361, 0x000D1518, 0x00000000, 0x0032515E, 0x005C95AD, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x00568BA1, 0x00345461, 0x00010203, 0x00000000, 0x000F191C, 0x004F7D90, 
        0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00283E47, 0x00000000, 0x00000000, 0x00000000, 0x00060A0B, 
        0x005B8CA0, 0x00669DB3, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 
        0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006BA1B6, 0x006CA0B6, 0x006CA1B7, 0x006CA0B7, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x006597AC, 0x00131D21, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00283B43, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x006DA1B7, 0x006DA2B7, 0x006DA2B7, 0x006DA2B7, 0x006DA2B7, 0x006DA2B7, 0x006DA2B7, 0x006DA2B7, 0x006DA1B7, 0x006A9DB3, 0x001A272D, 
        0x00000000, 0x00131D21, 0x006799AE, 0x006DA2B7, 0x006DA1B7, 0x006DA1B7, 0x003E5C68, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0040606D, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 
        0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 
        0x00689EB4, 0x00689DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00649BB1, 0x00639BB2, 0x00639AB2, 0x00639AB1, 0x00639AB1, 
        0x00639AB1, 0x00629AB1, 0x00548499, 0x00000000, 0x00000000, 0x00426878, 0x006198B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005E97AF, 0x005E97AF, 0x005D97AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 
        0x005C95AD, 0x005B95AC, 0x005992AA, 0x000B1316, 0x0019292F, 0x00497A8E, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005591A9, 0x005490A9, 0x005490A8, 0x00548FA8, 
        0x00538FA8, 0x00538FA8, 0x004B8299, 0x0026434F, 0x00000000, 0x0005090B, 0x002D4F5D, 0x00508DA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00366376, 
        0x00030506, 0x00000000, 0x001A313A, 0x004887A2, 0x004887A1, 0x004887A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040819D, 
        0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387B98, 0x00387C98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 
        0x00357996, 0x00347995, 0x00337995, 0x00337895, 0x00327795, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002E7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002A7290, 0x002A728F, 
        0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246D8C,
  0x00236D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x0029718F, 0x002B7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7593, 
        0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327795, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00367A97, 0x00367A97, 0x00367A97, 0x00387B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7D9A, 
        0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041839D, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 
        0x004685A0, 0x004686A0, 0x004686A0, 0x004787A1, 0x004787A1, 0x004786A0, 0x00264755, 0x00000000, 0x00020405, 0x00274855, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 
        0x004F8CA5, 0x00457B92, 0x001D333D, 0x00000000, 0x00091114, 0x00325868, 0x00528EA7, 0x00528FA7, 0x00538FA7, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005791AA, 0x005791AA, 0x005892AA, 
        0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005A94AC, 0x004F8398, 0x002F4C59, 0x0005080A, 0x00223841, 0x00477487, 0x00558BA1, 0x00518498, 0x00355664, 0x00142025, 0x00000000, 0x00000000, 0x000E1619, 0x00528499, 0x005F97AF, 
        0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00152227, 0x00000000, 0x00000000, 0x00000000, 0x00121C20, 
        0x005D90A4, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 
        0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006A9FB6, 0x006A9FB6, 0x006BA0B6, 0x006A9FB6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006496AB, 0x00131C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00273A43, 0x006CA1B6, 0x006CA0B7, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x006CA0B7, 0x006CA1B7, 0x006CA0B7, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B7, 0x006CA1B6, 0x00557F90, 0x0006090A, 
        0x00000000, 0x0036505B, 0x006CA1B7, 0x006CA1B6, 0x006CA1B7, 0x006CA1B7, 0x006B9FB5, 0x00050809, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00172328, 0x00689CB1, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006A9FB6, 
        0x006AA0B6, 0x006AA0B6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679EB4, 0x00679DB4, 0x00679DB4, 
        0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659BB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 
        0x006299B0, 0x006199B0, 0x006199B0, 0x00000000, 0x00000000, 0x00375865, 0x005F97AE, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E97AF, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AC, 
        0x005B94AC, 0x005A94AC, 0x005A94AC, 0x00457284, 0x00568FA7, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 
        0x00528EA8, 0x003F6E81, 0x00111E24, 0x00000000, 0x000F1B20, 0x003F6F82, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00264755, 0x00020304, 
        0x00000000, 0x00264655, 0x004786A0, 0x004887A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 
        0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A96, 0x00357A96, 0x00357996, 
        0x00347995, 0x00347995, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00307694, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7390, 0x002B7390, 0x002A7290, 0x002A728F, 0x0029718F, 
        0x0029718F, 0x0028708F, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00256E8C, 0x00246D8C,
  0x00236D8C, 0x00246D8C, 0x00246E8D, 0x00256E8C, 0x00256F8D, 0x00266F8E, 0x00276F8E, 0x0027708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7491, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7592, 
        0x00307693, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337995, 0x00347996, 0x00347996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 
        0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003D7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044859F, 
        0x004585A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x002E5666, 0x00000000, 0x00000000, 0x001F3B46, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004D8BA5, 0x004E8BA5, 
        0x004F8CA5, 0x004F8CA6, 0x004D89A3, 0x002C4D5B, 0x00000000, 0x00010203, 0x00213943, 0x00508BA3, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005792AA, 
        0x005792AB, 0x005892AB, 0x005892AB, 0x005993AB, 0x005993AB, 0x005994AB, 0x005A94AC, 0x005993AB, 0x00508499, 0x001A2A31, 0x00000000, 0x00020405, 0x00020405, 0x00010102, 0x00000000, 0x00000000, 0x00020405, 0x004F7F94, 0x005E97AE, 0x005E97AF, 
        0x005E97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006198B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x006299B0, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00050709, 0x00000000, 0x00000000, 0x00000000, 0x00203139, 
        0x006195AB, 0x00659CB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB5, 0x00699EB5, 
        0x00699EB5, 0x00699EB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB6, 0x006A9FB5, 0x006A9FB6, 0x006A9FB6, 0x006AA0B6, 0x006BA0B6, 0x006496AB, 0x00131C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00273A43, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA1B6, 0x006CA0B6, 0x006CA0B6, 0x006CA0B7, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006CA0B6, 0x006A9FB4, 0x00354F5A, 0x00000000, 
        0x00000000, 0x006598AD, 0x006CA0B6, 0x006CA0B6, 0x006CA0B6, 0x006BA0B6, 0x006BA0B6, 0x00395561, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00548091, 0x006B9FB6, 0x006AA0B5, 0x006A9FB6, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 
        0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699EB5, 0x00699EB5, 0x00699EB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00689DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 
        0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00649CB2, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006199B0, 
        0x006199B0, 0x006198B0, 0x006098B0, 0x00090F11, 0x00000000, 0x0029424C, 0x005D95AC, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 
        0x005A94AC, 0x005A93AB, 0x005993AC, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005590A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 
        0x00335968, 0x00020405, 0x00000000, 0x00101C21, 0x004F8BA4, 0x00508CA6, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x004A89A3, 0x001F3A45, 0x00000000, 0x00000000, 
        0x002E5667, 0x004887A1, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819C, 0x003F819C, 
        0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00357996, 0x00347996, 
        0x00347895, 0x00337895, 0x00337895, 0x00327894, 0x00317794, 0x00307694, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7290, 0x002A7290, 0x002A7190, 0x0029718F, 0x0029718F, 
        0x0028718F, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8C, 0x00256E8D, 0x00246D8C, 0x00236D8C,
  0x00236D8C, 0x00236D8C, 0x00246E8C, 0x00246E8D, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718E, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7592, 0x002F7592, 
        0x002F7592, 0x00307693, 0x00307693, 0x00307694, 0x00317794, 0x00327794, 0x00327795, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00367A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00387B97, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 
        0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043849E, 0x0044849F, 0x0044849F, 
        0x0045859F, 0x004585A0, 0x004585A0, 0x004786A0, 0x004786A1, 0x004786A0, 0x004787A1, 0x004887A1, 0x0038687D, 0x00060C0E, 0x00000000, 0x00162830, 0x00447E96, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 
        0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x002A4A57, 0x00000000, 0x00000000, 0x00111E23, 0x0044778C, 0x00528EA7, 0x00538FA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005691AA, 
        0x005792AA, 0x005792AA, 0x005792AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x003D6374, 0x000F191D, 0x00010102, 0x00000000, 0x00000000, 0x00000000, 0x001A2A31, 0x005990A7, 0x005D96AE, 0x005E96AE, 
        0x005E97AF, 0x005F97AE, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x006299B1, 0x00588BA0, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002C454F, 
        0x00639AB1, 0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB2, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 
        0x00689EB4, 0x00689EB5, 0x00689EB4, 0x00689EB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006395AB, 0x00131C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00273A43, 0x006BA0B6, 0x006AA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x00679AAF, 0x000B1113, 0x00000000, 
        0x00273B43, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006BA0B6, 0x006B9FB6, 0x006BA0B6, 0x006598AD, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001B292F, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00699FB5, 
        0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699FB5, 0x00699EB5, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669DB3, 
        0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB1, 0x00639AB1, 0x00639AB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006299B0, 0x006199B0, 0x006199B0, 
        0x006199B0, 0x006098B0, 0x006098AF, 0x001A2930, 0x00000000, 0x001B2B32, 0x005D94AB, 0x005E97AE, 0x005E96AE, 0x005E96AE, 0x005D96AE, 0x005C96AD, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A94AC, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AB, 0x005892AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x004A8197, 0x001C323A, 
        0x00000000, 0x0005090B, 0x00000101, 0x0005080A, 0x003E7084, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x00447E96, 0x0015282F, 0x00000000, 0x00060C0E, 0x0038697D, 
        0x004887A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003E809C, 
        0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A97, 0x00357996, 0x00347996, 0x00347995, 
        0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002B7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028718E, 
        0x0028718E, 0x00276F8E, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8C, 0x00236D8C, 0x00236D8B,
  0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246D8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0027708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7592, 
        0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 
        0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041839D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0044849F, 
        0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x003C7289, 0x00101E24, 0x00000000, 0x000C161B, 0x0039697E, 0x004A89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 
        0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x00457A90, 0x000A1316, 0x00000000, 0x000B1317, 0x00000000, 0x00030506, 0x002A4A57, 0x00508BA3, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005591A9, 
        0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005893AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005A93AC, 0x00568CA3, 0x00345462, 0x000B1316, 0x00000000, 0x00000000, 0x00101A1F, 0x00588FA6, 0x005D96AD, 0x005D96AE, 
        0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x00436A7A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00375663, 
        0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00649BB2, 0x00649CB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00659CB3, 0x00679CB3, 0x00669DB3, 0x00669DB3, 0x00669DB4, 0x00679DB4, 0x00679DB4, 
        0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00699FB4, 0x00699EB5, 0x00689EB5, 0x00689EB5, 0x00699EB5, 0x00699EB5, 0x00699EB5, 0x00699EB4, 0x006395AA, 0x00121C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00273A42, 0x006A9FB5, 0x00699FB5, 0x00699FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006AA0B5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006B9FB5, 0x006A9FB5, 0x00486B7A, 0x00000000, 0x00000000, 
        0x005B899C, 0x006A9FB5, 0x006A9FB6, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x006A9FB5, 0x00679DB2, 0x002E454E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00568395, 0x00689FB5, 0x00689EB5, 0x00689EB4, 0x00689EB5, 0x00689FB4, 
        0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00689EB4, 0x00679EB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00669DB3, 0x00669CB3, 0x00679CB4, 0x00679CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 
        0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x006299B1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F98AF, 
        0x005F98AF, 0x005F98AF, 0x005F97AF, 0x002A444E, 0x00000000, 0x00080E10, 0x005A92A9, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 
        0x005993AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00528EA7, 0x00355C6C, 0x000B1316, 0x00000000, 
        0x0016272E, 0x003F6F83, 0x00192D35, 0x00000000, 0x00101D22, 0x00478198, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00396A7E, 0x000C161B, 0x00000000, 0x00101E24, 0x003E7289, 0x004887A1, 
        0x004787A1, 0x004786A1, 0x004786A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 
        0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377A97, 0x00367A97, 0x00357996, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 
        0x00337895, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028718F, 0x0027708E, 
        0x0027708E, 0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8C, 0x00236D8C, 0x00236D8B, 0x00236D8B,
  0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00256E8D, 0x00256F8D, 0x00266F8D, 0x00276F8D, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A7190, 0x002B7290, 0x002B7390, 0x002C7390, 0x002D7391, 0x002D7491, 0x002D7492, 
        0x002E7592, 0x002F7592, 0x002F7593, 0x00307593, 0x00307693, 0x00317794, 0x00317794, 0x00327894, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 
        0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 
        0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004787A1, 0x0045829C, 0x00192F38, 0x00000000, 0x00030607, 0x0030596A, 0x004A89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 
        0x004D8BA4, 0x004D8BA5, 0x004B879F, 0x001A3038, 0x00000000, 0x00080E10, 0x00467C92, 0x003A6679, 0x00010303, 0x00000000, 0x000F1B20, 0x00497E95, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x00548FA9, 0x005490A9, 0x005590A9, 
        0x005690A9, 0x005691A9, 0x005691A9, 0x005791AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005993AC, 0x005A94AC, 0x0052889E, 0x002A4550, 0x00000000, 0x00000000, 0x00365765, 0x005C95AD, 0x005C96AD, 
        0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006099B0, 0x006198B0, 0x00304C57, 0x00000000, 0x00000000, 0x00000000, 0x00030606, 0x00436979, 
        0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB2, 0x00639AB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00669CB2, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 
        0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x006294A9, 0x00121C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00263A42, 0x00699FB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x000E1518, 0x00000000, 0x001D2C32, 
        0x00689CB3, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699FB5, 0x00699EB5, 0x00689EB5, 0x004E7687, 0x00050809, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00203037, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 
        0x00679DB4, 0x00679EB4, 0x00679DB4, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00659CB3, 0x00659CB2, 0x00659BB2, 0x00659BB2, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB0, 0x006299B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098AF, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F97AF, 
        0x005F97AF, 0x005F97AE, 0x005E97AE, 0x00395B6A, 0x00000000, 0x00000000, 0x004F7F94, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005993AB, 0x005993AB, 0x005893AB, 
        0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00508AA3, 0x00192B33, 0x00000101, 0x00000000, 0x002F5261, 
        0x004D89A1, 0x00508CA6, 0x004A849D, 0x00060A0C, 0x00000000, 0x001E3741, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x0030596A, 0x00030607, 0x00000000, 0x00192F38, 0x0046829C, 0x004887A1, 0x004787A1, 
        0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00327895, 
        0x00327795, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7492, 0x002D7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 
        0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B,
  0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7491, 0x002D7491, 
        0x002E7492, 0x002E7492, 0x002F7592, 0x002F7593, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00367A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 
        0x00387C99, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 
        0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A2, 0x00254653, 0x00000101, 0x00000000, 0x00213E4A, 0x004886A0, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 
        0x004C8AA4, 0x004D8BA4, 0x00315969, 0x00000000, 0x00000000, 0x00396577, 0x004F8CA5, 0x004F8CA6, 0x004B859D, 0x0015252B, 0x00000000, 0x00000000, 0x00315666, 0x00508BA3, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 
        0x005590A9, 0x005591A9, 0x005590A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x004B7C91, 0x00152329, 0x00000000, 0x003A606F, 0x005C95AD, 
        0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x005E97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x001A2930, 0x00000000, 0x00000000, 0x00000000, 0x00070C0E, 0x004F7C8F, 
        0x006299B1, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 0x00649BB1, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00649CB2, 0x00659CB2, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00669CB3, 
        0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00669DB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679EB4, 0x00679DB4, 0x00689EB4, 0x006194A9, 0x00121C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00263A42, 0x00689EB4, 0x00689EB4, 0x00699EB5, 0x00689EB5, 0x00699EB4, 0x00699EB5, 0x00699EB4, 0x00699EB5, 0x00699EB5, 0x00699EB5, 0x00689EB5, 0x00699EB5, 0x00699EB5, 0x00699EB4, 0x004F7788, 0x00000000, 0x00000000, 0x00466978, 
        0x00689EB5, 0x00699EB5, 0x00689EB5, 0x00699EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x006599AF, 0x00182429, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080D0E, 0x00578498, 0x00679DB4, 0x00689DB4, 0x00679DB4, 0x00679DB4, 
        0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00639BB2, 0x00639BB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 
        0x005E97AF, 0x005E97AE, 0x005E96AE, 0x00466F81, 0x00000000, 0x00000000, 0x00243A43, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005891A8, 0x00578EA5, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005994AB, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AB, 
        0x005892AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691A9, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528DA5, 0x003E6C7F, 0x00070C0F, 0x00000000, 0x000C1518, 0x003F7084, 0x00508DA6, 
        0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x003A687B, 0x00000000, 0x00000000, 0x00335C6C, 0x004D8BA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x0049869F, 0x00213D4A, 0x00000000, 0x00000101, 0x00264654, 0x004887A1, 0x004887A1, 0x004787A1, 0x004786A1, 
        0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 
        0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B98, 0x00367B97, 0x00367A97, 0x00367A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327895, 
        0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x0027708E, 
        0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246D8C, 0x00236D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B,
  0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x0029728F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7491, 
        0x002D7491, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327795, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00367A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00387B98, 
        0x00387C98, 0x00387C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0042829E, 0x0042839E, 
        0x0042839E, 0x0043849E, 0x0043849E, 0x0044849F, 0x0045849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x00305B6C, 0x00070E11, 0x00000000, 0x0014262D, 0x003F758B, 0x004B89A3, 0x004C89A3, 
        0x004C89A3, 0x003F7187, 0x00030507, 0x00000000, 0x00274755, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA6, 0x00508DA6, 0x002D505E, 0x00080E11, 0x00000000, 0x00182A32, 0x003F6E82, 0x00528EA8, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005692AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005994AC, 0x005A94AC, 0x005A94AC, 0x00375968, 0x003A5F6E, 0x005B94AD, 
        0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005C96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005F97AE, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x00060A0C, 0x00000000, 0x00000000, 0x00000000, 0x000A1114, 0x00598DA2, 
        0x006199B0, 0x006299B0, 0x006299B0, 0x006299B1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00659CB2, 0x00649CB2, 
        0x00669CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00669DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00669DB4, 0x00679DB4, 0x00679DB4, 0x006093A9, 0x00121C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00263A42, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00203037, 0x00000000, 0x000F161A, 0x005A8B9E, 
        0x00689EB4, 0x00689EB4, 0x00689EB4, 0x00679EB4, 0x00689EB4, 0x00689EB4, 0x00689DB4, 0x00689EB4, 0x00679EB4, 0x003D5E6B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0036535F, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00669DB3, 
        0x00679DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659BB3, 0x00659BB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB1, 0x00639AB1, 0x00639AB1, 
        0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006299B1, 0x006199B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006098AF, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 
        0x005E97AE, 0x005E96AE, 0x005D96AE, 0x00487689, 0x00000000, 0x00000000, 0x00000000, 0x00233943, 0x00385C6A, 0x00345664, 0x0020343D, 0x00223841, 0x00568DA4, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005892AB, 0x005892AA, 0x005792AA, 
        0x005692AA, 0x005791AA, 0x005691AA, 0x005591AA, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x005390A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00477B90, 0x00233E49, 0x00000000, 0x00020304, 0x00233D48, 0x004A839A, 0x00508DA6, 0x004F8CA6, 
        0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x0024414D, 0x00000000, 0x00030507, 0x003E7187, 0x004C8AA3, 0x004B89A3, 0x0040758B, 0x0014252D, 0x00000000, 0x00070E11, 0x00305A6C, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A0, 0x004786A0, 
        0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0040829C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9A, 
        0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00387C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367A97, 0x00357A97, 0x00357996, 0x00357996, 0x00347995, 0x00337895, 0x00327895, 0x00327895, 0x00327794, 
        0x00317794, 0x00317793, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00276F8D, 
        0x00266F8D, 0x00256E8D, 0x00246E8D, 0x00246D8C, 0x00246D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8B,
  0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00246D8C, 0x00246D8C, 0x00246E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002C7391, 0x002C7391, 
        0x002D7491, 0x002D7491, 0x002D7492, 0x002F7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327795, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 
        0x00387B98, 0x00387C98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 
        0x0042829E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004686A1, 0x004786A0, 0x004787A1, 0x004887A1, 0x003E758C, 0x00112127, 0x00000000, 0x00060C0F, 0x00315A6C, 0x004A89A3, 
        0x0048839C, 0x000A1417, 0x00000000, 0x00172A32, 0x004A859E, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA6, 0x00508CA6, 0x00457990, 0x001C313A, 0x00000000, 0x0005090B, 0x00223D48, 0x00508BA4, 0x00528EA7, 0x00528EA7, 0x00538FA8, 
        0x00538FA8, 0x00548FA8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005994AC, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E96AE, 0x005E97AE, 0x0055899E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00101A1E, 0x006098B0, 
        0x006098B0, 0x006098B0, 0x006099B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x006299B1, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00659CB2, 0x00659CB2, 0x00659CB2, 0x00659BB3, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x006092A8, 0x00121C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00253941, 0x00679DB4, 0x00679DB3, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00568497, 0x000A0F11, 0x00000000, 0x00273C45, 0x00679DB4, 
        0x00679DB4, 0x00679DB3, 0x00679DB4, 0x00679DB4, 0x00679DB4, 0x00679DB3, 0x00669DB3, 0x00679DB3, 0x00669DB3, 0x00669DB3, 0x00050809, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00141F24, 0x005F92A7, 0x00659CB3, 0x00669CB3, 0x00659CB3, 
        0x00659CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00649CB2, 0x00659BB2, 0x00649BB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00649BB2, 0x00639AB1, 0x00639AB2, 0x00639AB2, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 
        0x006299B1, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006099B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 
        0x005D96AE, 0x005C96AE, 0x005C95AD, 0x00426C7D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0016252B, 0x0047768A, 0x005791A8, 0x005893AB, 0x005893AB, 0x005892AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 
        0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00538EA8, 0x00528FA8, 0x00315665, 0x000A1215, 0x00000000, 0x000E191D, 0x003E6E81, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 
        0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x0047829A, 0x000F1B20, 0x00000000, 0x00112026, 0x0049859F, 0x00315B6C, 0x00060C0F, 0x00000000, 0x00122128, 0x003F768C, 0x004887A1, 0x004787A1, 0x004787A1, 0x004786A1, 0x004685A0, 0x004685A0, 
        0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 
        0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 
        0x00307694, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 
        0x00256E8D, 0x00256E8D, 0x00246D8C, 0x00236D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00206B8A,
  0x00206B8A, 0x00206B8A, 0x00216C8B, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246D8C, 0x00256E8D, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A728F, 0x002B7290, 0x002B7290, 0x002B7391, 
        0x002C7391, 0x002D7491, 0x002D7492, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327794, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00367A96, 0x00367A97, 0x00367B97, 
        0x00377B97, 0x00387B98, 0x00387B98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040829D, 
        0x0042829D, 0x0042839D, 0x0042839E, 0x0042839E, 0x0043839F, 0x0043849F, 0x0044849F, 0x0045849F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A1, 0x0046849E, 0x001D3843, 0x00000101, 0x00000000, 0x0023414D, 
        0x001B333C, 0x00000000, 0x00070E10, 0x003E7186, 0x004C8AA3, 0x004D8AA4, 0x004D8BA4, 0x004E8BA4, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00508CA6, 0x00335A6A, 0x00040709, 0x00000000, 0x000B1418, 0x00427388, 0x00518DA6, 0x00528EA7, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005791AA, 0x005791AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B94AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x00426A7A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0020343C, 0x005F98AF, 
        0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006198B0, 0x006198B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x00629AB1, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659BB2, 0x00659BB2, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00659CB3, 0x00659CB3, 0x00659CB3, 0x006092A8, 0x00121C20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00253941, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00669DB3, 0x00669DB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669DB3, 0x00669DB3, 0x00669DB3, 0x003A5965, 0x00000000, 0x00020303, 0x004D7788, 0x00669DB3, 
        0x00669DB3, 0x00669DB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669DB3, 0x00669CB3, 0x00669CB3, 0x00375460, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x004C7687, 0x00659CB2, 0x00659CB2, 0x00659BB2, 
        0x00659BB2, 0x00659BB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639AB1, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x006299B1, 0x006199B0, 
        0x006199B0, 0x006199B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005F97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C96AD, 
        0x005C96AD, 0x005C95AD, 0x005B95AD, 0x0031515E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00080D10, 0x003D6476, 0x005993AB, 0x005993AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 
        0x005591A9, 0x005591A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x004B839A, 0x0016272E, 0x00000000, 0x00000000, 0x0024404C, 0x00508DA6, 0x00508DA6, 0x004F8DA6, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 
        0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x003E7287, 0x00020304, 0x00000000, 0x000B161A, 0x00000000, 0x00000101, 0x001E3843, 0x0046859E, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004585A0, 0x004585A0, 
        0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 
        0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00387C98, 0x00387B98, 0x00387C98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A97, 0x00357996, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00307693, 
        0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00256F8D, 
        0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00216C8A, 0x00216B8A, 0x00206B8A,
  0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7390, 
        0x002B7390, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002F7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327894, 0x00327895, 0x00347895, 0x00347996, 0x00347996, 0x00357996, 0x00357A96, 0x00367A96, 
        0x00367B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397D98, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809B, 0x003F819C, 0x0040819C, 0x0040819D, 
        0x0040829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x002A4F5E, 0x00070D10, 0x00000000, 
        0x00000000, 0x00000000, 0x002F5566, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x00488097, 0x001C323B, 0x00010203, 0x00000000, 0x00223C46, 0x0046798F, 
        0x00528FA7, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005993AB, 0x005993AB, 0x005993AB, 
        0x005994AC, 0x005A93AC, 0x005A94AC, 0x005B94AC, 0x005A94AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005D96AD, 0x005C96AD, 0x005D96AE, 0x0027404A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0033515E, 0x005F97AF, 
        0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 
        0x00639AB2, 0x00639BB1, 0x00639AB1, 0x00639BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00659BB2, 0x00649CB2, 0x00659CB2, 0x005F91A7, 0x00121B20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00253941, 0x00659CB3, 0x00669CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00659CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x006195AB, 0x0018252A, 0x00000000, 0x0010191C, 0x00669CB3, 0x00669CB3, 
        0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB3, 0x00669CB2, 0x00669CB3, 0x00659CB3, 0x00659CB3, 0x00659CB2, 0x00659CB3, 0x006298AD, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x0018262B, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00649BB1, 0x00639BB1, 0x00639BB1, 0x00639AB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 
        0x006199B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C95AD, 0x005C95AD, 
        0x005C95AD, 0x005B95AD, 0x005B95AC, 0x00101B1F, 0x00000000, 0x00000000, 0x00090F12, 0x0027414C, 0x00538AA0, 0x005893AB, 0x005993AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691A9, 0x005691A9, 0x005590A9, 
        0x005590A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x004C849A, 0x002C4C5A, 0x00000101, 0x00000000, 0x0015252B, 0x00407185, 0x00508DA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004F8BA5, 0x004E8BA5, 0x004D8BA5, 
        0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x0023414C, 0x00000000, 0x00000000, 0x00070D10, 0x002A505F, 0x004887A1, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004585A0, 0x004585A0, 0x0045859F, 
        0x0044849F, 0x0043849F, 0x0043839E, 0x0043849E, 0x0042839E, 0x0042839D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 
        0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A96, 0x00357996, 0x00347996, 0x00347995, 0x00347895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 
        0x00307693, 0x002F7593, 0x002F7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002D7491, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708F, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 
        0x00246E8C, 0x00246D8C, 0x00236D8B, 0x00236D8B, 0x00226C8B, 0x00226B8B, 0x00216B8B, 0x00206B8A, 0x00206B8A,
  0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00246D8C, 0x00246D8C, 0x00256E8D, 0x00256F8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 
        0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337995, 0x00347996, 0x00357A96, 0x00357996, 
        0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397D98, 0x003A7D98, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x0040819C, 
        0x0040819D, 0x0040829D, 0x0041829D, 0x0041839E, 0x0042839D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0044849F, 0x0045849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x003B6F86, 0x0014262D, 
        0x00000000, 0x00000000, 0x00294C5A, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x003B697B, 0x000F1A1F, 0x00000000, 0x00080E11, 
        0x00294855, 0x00528EA7, 0x00528EA8, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005892AA, 0x005892AB, 0x005893AB, 
        0x005893AB, 0x005893AB, 0x005993AC, 0x005994AC, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B94AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x00558AA0, 0x00101A1E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00436D7E, 0x005E96AE, 
        0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005E97AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x006098B0, 0x006098AF, 0x006098B0, 0x006098B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B1, 0x00629AB1, 
        0x006299B1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB2, 0x00639AB1, 0x00639BB1, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x005E91A7, 0x00121B20, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00243941, 0x00649BB2, 0x00649BB2, 0x00659BB2, 0x00649BB2, 0x00659BB2, 0x00649CB2, 0x00649BB2, 0x00659CB2, 0x00659BB2, 0x00649BB2, 0x00659BB2, 0x00659CB2, 0x00517D90, 0x00000000, 0x00000000, 0x00446A79, 0x00659BB2, 0x00659BB2, 
        0x00649BB2, 0x00659BB2, 0x00659BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00304A55, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00507D91, 0x00639BB1, 0x00639AB1, 
        0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x00629AB1, 0x006299B0, 0x006299B0, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006198B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098AF, 
        0x006098AF, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AE, 0x005E96AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AC, 
        0x005B94AC, 0x005A94AC, 0x00325260, 0x00000000, 0x00000000, 0x00243D47, 0x0049798D, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 
        0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA7, 0x00335969, 0x000D171C, 0x00000000, 0x00000000, 0x00060C0E, 0x0045798F, 0x00508CA6, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 
        0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x004B89A3, 0x004A89A3, 0x00294C5B, 0x00080F12, 0x00000000, 0x0014262E, 0x003B6F85, 0x004887A2, 0x004887A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 
        0x0043849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D9A, 0x003A7D99, 
        0x00397D99, 0x00397C99, 0x00387C98, 0x00387C97, 0x00387B98, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00337996, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317793, 0x00307693, 0x00307693, 
        0x002F7593, 0x002F7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028718E, 0x0028708F, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x00256E8C, 0x00246D8C, 
        0x00246E8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8A, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89,
  0x001E6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00266F8D, 0x00266F8E, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7290, 
        0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002F7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 
        0x00367A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809C, 0x003F809C, 0x003F819C, 
        0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004685A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x004887A1, 0x0046849D, 
        0x00213E4A, 0x00000000, 0x00000000, 0x00172B33, 0x0047859E, 0x004B89A3, 0x004B89A4, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004E8CA5, 0x004E8CA5, 0x004F8CA6, 0x004F8CA6, 0x00111E23, 0x00000000, 0x00000000, 
        0x00000000, 0x00070D10, 0x003C697C, 0x00528EA7, 0x00538FA8, 0x00538FA7, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AA, 
        0x005892AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x00395E6D, 0x004C7C91, 0x005B94AC, 0x005B95AD, 0x002E4B57, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00568BA1, 0x005D96AE, 
        0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AF, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x006098AF, 0x006098B0, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006099B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 
        0x006199B0, 0x006199B0, 0x006299B0, 0x006299B1, 0x006299B0, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x005D90A6, 0x00111B1F, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00243941, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x0023373F, 0x00000000, 0x00080D0F, 0x00649BB2, 0x00649BB2, 0x00649BB2, 
        0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00649BB2, 0x00639BB2, 0x00639BB2, 0x00507D8F, 0x00050709, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x001B2A30, 0x00639AB1, 0x00629AB1, 
        0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006299B0, 0x00629AB1, 0x006299B0, 0x006299B1, 0x006199B0, 0x006199B0, 0x006199B0, 0x006198B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F98AF, 
        0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AC, 0x005B94AC, 0x005A94AC, 
        0x005A94AC, 0x003C6373, 0x00020304, 0x000D161A, 0x00477689, 0x005893AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00487D93, 0x00122025, 0x00000101, 0x00000101, 0x0016272E, 0x00010303, 0x00000000, 0x002A4A57, 0x004F8CA5, 0x004F8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x0048859E, 0x00172B33, 0x00000000, 0x00000000, 0x00223F4B, 0x0046849D, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043849E, 
        0x0043839E, 0x0042839E, 0x0042839E, 0x0041839E, 0x0041829D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D9A, 0x003A7D99, 0x003A7D99, 
        0x00397C98, 0x00387C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x00307693, 0x002F7593, 
        0x002F7592, 0x002E7592, 0x002E7492, 0x002D7492, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 
        0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89,
  0x001E6989, 0x001F6989, 0x00206A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x002A718F, 
        0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7491, 0x002D7492, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00317793, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347895, 0x00347996, 0x00347996, 
        0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397C98, 0x003A7D99, 0x00397D99, 0x003B7E99, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003D7F9A, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003E809C, 
        0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042829D, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004787A1, 
        0x004887A2, 0x00346073, 0x00091114, 0x00000000, 0x00060C0F, 0x00376779, 0x004987A1, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x00335B6B, 0x00020304, 0x00010303, 0x002A4A57, 
        0x00192C34, 0x00000000, 0x00000000, 0x001D323B, 0x0044768A, 0x00518DA6, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A8, 0x005490A8, 0x005490A9, 0x005591A9, 0x005590A9, 0x005690A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 
        0x005792AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005994AC, 0x00192930, 0x00000000, 0x00091012, 0x000A1013, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030506, 0x005C96AD, 0x005C96AE, 
        0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005F97AE, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 
        0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x006199B0, 0x006299B1, 0x006299B1, 0x00629AB0, 0x00629AB0, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x005C90A6, 0x00111B1F, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00243841, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB2, 0x00639AB2, 0x00639AB1, 0x00639AB2, 0x00649BB2, 0x00639BB2, 0x00639BB2, 0x00639AB2, 0x005D92A7, 0x00000000, 0x00000000, 0x00365361, 0x00639BB2, 0x00649BB1, 0x00639AB1, 
        0x00639BB2, 0x00639BB2, 0x00639AB1, 0x00639AB1, 0x00639BB1, 0x00639AB1, 0x00639AB2, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x00639AB1, 0x005F95AB, 0x001D2D34, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030405, 0x00528194, 0x006299B1, 
        0x00629AB1, 0x006299B1, 0x006199B0, 0x006199B1, 0x006199B1, 0x006199B0, 0x006199B0, 0x006198B0, 0x006198B0, 0x006198B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 
        0x005E97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005A95AD, 0x005A94AC, 0x005B94AC, 0x005A94AC, 0x005994AC, 
        0x005A94AC, 0x003F6879, 0x00325361, 0x005993AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 
        0x00538FA8, 0x00528FA8, 0x00487E94, 0x002A4855, 0x00000000, 0x00000000, 0x00000000, 0x00213B46, 0x00508DA6, 0x00223D48, 0x00000000, 0x00091114, 0x00457C92, 0x004E8BA5, 0x004E8BA4, 0x004D8BA5, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004B8AA4, 
        0x004B89A3, 0x004A87A1, 0x0037667A, 0x00060C0E, 0x00000000, 0x00091114, 0x00336074, 0x004887A2, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x004485A0, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 
        0x0043839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x0040819C, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 
        0x00397C98, 0x00387B98, 0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 
        0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 
        0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216C8B, 0x00206B8A, 0x00206B8A, 0x001F6A8A, 0x001F6A89, 0x001E6989,
  0x001E6988, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 
        0x0029728F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7492, 0x002F7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317693, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 
        0x00347996, 0x00357996, 0x00357A97, 0x00367A97, 0x00367A97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 
        0x003E809C, 0x003E819C, 0x003F819C, 0x003F819D, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839D, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044859F, 0x0045859F, 0x0045859F, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A1, 
        0x004787A1, 0x004887A1, 0x00417A92, 0x001D3843, 0x00000000, 0x00000000, 0x001D3540, 0x00447E96, 0x004A89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004A839C, 0x00101D23, 0x00000000, 0x0016282F, 0x004F8CA6, 
        0x00366071, 0x00000000, 0x00000000, 0x00000000, 0x00040709, 0x00203943, 0x0044778C, 0x00528EA7, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005691AA, 0x005691AA, 
        0x005691AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005892AA, 0x005892AB, 0x005893AB, 0x005892AB, 0x005993AB, 0x003F687A, 0x0016252B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000F191D, 0x005B95AD, 0x005C95AD, 
        0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005C96AD, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E96AE, 0x005E97AF, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x006098AF, 
        0x006098AF, 0x006098AF, 0x006098B0, 0x006198B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006198B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006299B0, 0x006199B0, 0x006199B1, 0x006199B0, 0x005C90A6, 0x00111B1F, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00243841, 0x006299B1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00639AB1, 0x00629AB1, 0x002B434E, 0x00000000, 0x0006090B, 0x00538397, 0x00629AB1, 0x00629AB1, 0x00629AB1, 
        0x00629AB1, 0x00629AB1, 0x00629AB1, 0x00629AB1, 0x006399B1, 0x00629AB1, 0x00629AB1, 0x006299B1, 0x00629AB1, 0x00619AB1, 0x006299B0, 0x006299B0, 0x003D606E, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x002C4550, 0x006199B0, 
        0x006199B0, 0x006099B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098B0, 0x006198B0, 0x006098AF, 0x006098AF, 0x006098AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 
        0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005D96AE, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AB, 0x005A93AB, 0x005993AB, 0x005993AB, 
        0x005893AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005892AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00548FA9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA8, 
        0x004D859D, 0x00284653, 0x00091114, 0x00000000, 0x00101D22, 0x001A2E36, 0x00000000, 0x000A1216, 0x00457A91, 0x004A849C, 0x00091114, 0x00000000, 0x00213B46, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 
        0x00447E96, 0x001D353F, 0x00000000, 0x00000000, 0x001E3843, 0x00417A93, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 
        0x0041829E, 0x0041829D, 0x0041829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 
        0x00387C98, 0x00387B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x002F7693, 0x002F7592, 0x002F7492, 0x002E7492, 
        0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x00297190, 0x0029718F, 0x0028718F, 0x0028708F, 0x0027708E, 0x00266F8E, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246D8C, 0x00236D8C, 0x00236D8C, 
        0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001D6988,
  0x001D6888, 0x001D6988, 0x001F6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028718E, 
        0x0029718F, 0x002A718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002F7592, 0x002F7593, 0x00307593, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00327895, 0x00337895, 0x00337895, 
        0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 
        0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 
        0x004786A1, 0x004786A1, 0x004787A1, 0x0047859F, 0x00366578, 0x00030608, 0x00000000, 0x00050A0C, 0x00335E6F, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x002F5564, 0x00000000, 0x00000000, 0x00477F96, 0x004B859D, 
        0x00101C21, 0x00000000, 0x00192C34, 0x00396577, 0x00091114, 0x00000000, 0x00030607, 0x00233D48, 0x00518CA5, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005691A9, 
        0x005691AA, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AB, 0x005892AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x00568EA5, 0x003C6474, 0x00070C0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00121E23, 0x005B94AC, 0x005B95AD, 
        0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005C96AE, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 
        0x005F98AF, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098AF, 0x006098B0, 0x006098B0, 0x006199B0, 0x006098B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x005B90A5, 0x00111B1F, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00233840, 0x006299B0, 0x006199B0, 0x006299B0, 0x006299B0, 0x006299B1, 0x006299B1, 0x006299B1, 0x006299B1, 0x006299B0, 0x006299B1, 0x005D91A8, 0x00090F11, 0x00000000, 0x001F3138, 0x005F94AC, 0x006299B0, 0x006299B0, 0x006299B1, 
        0x006199B1, 0x006299B0, 0x006199B0, 0x006299B1, 0x006199B0, 0x006199B0, 0x006299B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x00070C0E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00101A1E, 0x0056889E, 
        0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005E97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 
        0x005D96AE, 0x005D96AD, 0x005D96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 
        0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005691A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x002F5160, 
        0x00060B0D, 0x00000000, 0x00000000, 0x00020304, 0x003D6C80, 0x004F8AA4, 0x00050A0C, 0x00000000, 0x0025414E, 0x004D8AA4, 0x00386477, 0x00000000, 0x00000000, 0x003D7085, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00335E70, 
        0x00050A0C, 0x00000000, 0x00040708, 0x00356579, 0x004785A0, 0x004787A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 
        0x0041829D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 
        0x00377B98, 0x00367B97, 0x00367A97, 0x00367A96, 0x00367A96, 0x00357A96, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00317693, 0x00307593, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 
        0x002D7492, 0x002C7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A728F, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x00276F8E, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8B, 0x00236C8B, 
        0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 0x001F6989, 0x001D6989, 0x001D6988,
  0x001D6888, 0x001D6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B89, 0x00206B8A, 0x00206B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00246E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708E, 
        0x0029718F, 0x0029718F, 0x002A718F, 0x002A728F, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7391, 0x002D7492, 0x002D7491, 0x002E7592, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00327794, 0x00327795, 0x00337895, 
        0x00337895, 0x00347996, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 
        0x003D7F9B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004685A0, 
        0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x0045819B, 0x00162A32, 0x00010203, 0x00000000, 0x001B333D, 0x00437B93, 0x004B89A3, 0x004B89A3, 0x004C89A3, 0x0048829B, 0x00020304, 0x00000000, 0x00284956, 0x004E8BA5, 0x002F5363, 
        0x00000000, 0x00020405, 0x0044788E, 0x004E8AA4, 0x00091114, 0x00000000, 0x00030506, 0x00000000, 0x00010203, 0x00305463, 0x004C839B, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 
        0x005591A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005892AB, 0x005893AB, 0x00538BA2, 0x00223943, 0x0005080A, 0x00000000, 0x00000000, 0x00010202, 0x005993AB, 0x005B94AC, 
        0x005B94AC, 0x005B95AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005C95AD, 0x005C96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 
        0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x006098AF, 0x005F98AF, 0x006098AF, 0x005F98AF, 0x006098AF, 0x006098AF, 0x006098B0, 0x006098B0, 0x006098B0, 0x005A8FA5, 0x00111B1F, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00233840, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x003C606E, 0x00020304, 0x00020304, 0x003C606E, 0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 
        0x006199B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006198B0, 0x006198B0, 0x006199B0, 0x006199B0, 0x006199B0, 0x006099B0, 0x006199B0, 0x006098B0, 0x006098B0, 0x00345360, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00426979, 
        0x006098AF, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D97AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C96AD, 0x005C96AD, 
        0x005C95AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B94AD, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AA, 0x005792AA, 
        0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x004E88A0, 0x003C687B, 0x000B1316, 0x00000000, 
        0x0005080A, 0x001B3038, 0x00080F12, 0x00000000, 0x001E353F, 0x004F8CA6, 0x00376173, 0x00000000, 0x00020304, 0x00447990, 0x0049859C, 0x0015262D, 0x00000000, 0x000D181D, 0x004C8AA4, 0x004B89A3, 0x004B89A3, 0x00437B93, 0x001B333C, 0x00000000, 
        0x00010203, 0x00162A32, 0x0046819B, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 
        0x0041829D, 0x0040819C, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00377B97, 
        0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347995, 0x00347996, 0x00337895, 0x00337895, 0x00327895, 0x00327894, 0x00317794, 0x00317694, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7491, 
        0x002C7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A7190, 0x0029718F, 0x0028708F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00266E8D, 0x00256E8C, 0x00246D8C, 0x00246D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 
        0x00226C8A, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001D6988, 0x001D6888,
  0x001C6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001F6989, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00226C8A, 0x00226C8B, 0x00226D8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 
        0x0028708F, 0x0029718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002D7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002F7592, 0x002F7592, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 
        0x00337895, 0x00337995, 0x00347995, 0x00347995, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C98, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 
        0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 
        0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A2, 0x002E5566, 0x000C161B, 0x00000000, 0x000A1216, 0x002C5262, 0x0049869F, 0x004B89A3, 0x00192F37, 0x00000000, 0x000C161B, 0x00478098, 0x00488299, 0x000A1216, 
        0x00000000, 0x00274654, 0x004E8CA5, 0x00284855, 0x00000000, 0x0005090B, 0x00355E6E, 0x0025424E, 0x00080F12, 0x00000000, 0x000D171B, 0x002D4F5D, 0x00497E95, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A9, 0x005490A9, 
        0x005490A9, 0x005590A9, 0x005591A9, 0x005690A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x005892AB, 0x005893AB, 0x005893AB, 0x00457285, 0x001E323A, 0x00010202, 0x00000000, 0x002C4955, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AD, 0x005B95AC, 0x005B95AD, 0x005C94AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005D96AD, 0x005D95AD, 0x005C96AE, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E96AE, 0x005E97AE, 
        0x005D97AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005F97AE, 0x005F97AF, 0x005E97AE, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x006098AF, 0x006098AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 0x005A8FA4, 0x00111B1F, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00233840, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006099B0, 0x006099B0, 0x006198B0, 0x005D94AB, 0x001F3139, 0x00000000, 0x00080D0F, 0x005C90A7, 0x006198B0, 0x006199B0, 0x006098B0, 0x006098AF, 
        0x006199B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098B0, 0x006098AF, 0x006098AF, 0x005F98B0, 0x006098AF, 0x005F98AF, 0x005E95AC, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00152228, 
        0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AF, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005D97AE, 0x005D96AD, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005D96AD, 0x005C95AD, 0x005C96AD, 0x005B95AD, 0x005C95AD, 
        0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x005A94AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005792AB, 0x005892AA, 0x005792AA, 0x005792AA, 
        0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x00548FA9, 0x005390A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x004F8AA2, 0x00345B6B, 0x0015252B, 0x00000000, 0x00020405, 0x001E343E, 
        0x003F6E82, 0x00508DA6, 0x00305463, 0x00000000, 0x0004080A, 0x003D6C7F, 0x004E8CA5, 0x00182B33, 0x00000000, 0x0016272E, 0x004D8AA4, 0x00366376, 0x00020506, 0x00000101, 0x002D5363, 0x004A87A1, 0x002C5262, 0x000A1216, 0x00000000, 0x000C171B, 
        0x002E5666, 0x004887A2, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 
        0x0040819C, 0x0040819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 
        0x00367A97, 0x00367A97, 0x00367A97, 0x00347A96, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7592, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7492, 0x002C7391, 
        0x002C7391, 0x002C7390, 0x002B7290, 0x002A7290, 0x002A7190, 0x0029718F, 0x0029718F, 0x0028718E, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216C8A, 
        0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6888, 0x001D6888,
  0x001C6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00236D8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x00276F8E, 
        0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A7190, 0x002A7290, 0x002A7290, 0x002B7390, 0x002C7390, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 
        0x00327894, 0x00337795, 0x00337895, 0x00347995, 0x00347996, 0x00357996, 0x00357996, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 
        0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 
        0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A1, 0x00407991, 0x00213F4B, 0x00000000, 0x00000101, 0x00112127, 0x002A4D5C, 0x00020405, 0x00010303, 0x002E5463, 0x004C8AA4, 0x00223E49, 0x00000000, 
        0x000D171C, 0x004B87A0, 0x0043788E, 0x000A1115, 0x00000000, 0x00203A44, 0x004F8CA5, 0x004F8CA6, 0x00467A91, 0x00294956, 0x00000101, 0x00000000, 0x00091114, 0x0026434F, 0x00508BA4, 0x00528EA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 
        0x00548FA8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AA, 0x00558EA6, 0x00416D80, 0x000F1A1E, 0x00000000, 0x00355765, 
        0x005891A9, 0x005993AB, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005B94AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005C96AE, 0x005D96AE, 0x005D96AE, 
        0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E97AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005F97AF, 0x00598DA4, 0x00111B1F, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00233740, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x006097AF, 0x005F97AF, 0x005F98AF, 0x00518296, 0x00040708, 0x00000000, 0x00253B44, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x006098AF, 
        0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005F98AF, 0x005F97AF, 0x005F98AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x002B4550, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x004B788B, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B94AC, 
        0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005993AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005892AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005791AA, 0x005691A9, 
        0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A8, 0x00548FA8, 0x005490A9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00315564, 0x000D161A, 0x00000000, 0x00000000, 0x001E353E, 0x0042758A, 0x004F8AA4, 
        0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x000F1C21, 0x00000000, 0x00182B33, 0x004D8BA4, 0x003D6E82, 0x0004080A, 0x00000000, 0x0031596A, 0x004C8AA4, 0x00172B33, 0x00000000, 0x000A1215, 0x000E1B20, 0x00000101, 0x00000000, 0x0022404B, 0x00417992, 
        0x004887A1, 0x004887A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819C, 0x0040819C, 
        0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D9A, 0x003A7D99, 0x00397D99, 0x00397D98, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B98, 0x00377B97, 0x00367A97, 
        0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00337895, 0x00327895, 0x00317794, 0x00317794, 0x00317694, 0x00307693, 0x002F7693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002C7391, 0x002C7391, 
        0x002C7390, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x00276F8E, 0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00246D8B, 0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00216C8A, 0x00216B8A, 
        0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001D6888, 0x001D6988, 0x001C6888, 0x001C6887,
  0x001B6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001D6988, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8E, 
        0x00276F8E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7190, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002D7492, 0x002E7492, 0x002F7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00317694, 0x00317794, 
        0x00327794, 0x00327794, 0x00327895, 0x00337895, 0x00347995, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377A97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 
        0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D809B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849F, 0x0044849F, 
        0x0045849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x0038677C, 0x00080E11, 0x00000000, 0x00000000, 0x00000000, 0x000B1519, 0x004A88A2, 0x003F7389, 0x00000000, 0x00000000, 
        0x00366275, 0x004C89A3, 0x0024424E, 0x00000000, 0x00030708, 0x004C89A1, 0x004E8BA5, 0x004F8CA5, 0x004F8CA6, 0x00508CA6, 0x004B859D, 0x00203843, 0x00010303, 0x00000000, 0x00000101, 0x002B4B58, 0x004D859D, 0x00518DA5, 0x00528FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x0031515F, 0x0017272E, 
        0x0052899F, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005994AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005B95AC, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 
        0x005C96AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x005E96AE, 0x005E96AE, 0x005E97AE, 0x005E96AE, 0x005E97AE, 0x00568BA1, 0x00101A1E, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x0021343D, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x002F4B57, 0x00000000, 0x00000000, 0x004B788B, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005F97AF, 
        0x005F97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005F97AF, 0x005F97AF, 0x005E97AF, 0x005E97AF, 0x005E97AF, 0x005F97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x004E7D90, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x0018272D, 0x005D96AE, 0x005D96AD, 0x005D96AE, 0x005D96AD, 0x005C96AE, 0x005C96AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B94AD, 0x005B95AD, 0x005A94AD, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591A9, 
        0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x00548FA9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA7, 0x00518DA7, 0x004F88A1, 0x00376071, 0x00070D10, 0x00000000, 0x00010203, 0x0016272E, 0x00457A90, 0x00508DA6, 0x00508CA6, 0x004F8CA6, 
        0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x0042758B, 0x00000000, 0x00000000, 0x00356072, 0x004D8AA4, 0x001E3640, 0x00000000, 0x00091115, 0x0047829B, 0x0041788F, 0x00000000, 0x00000000, 0x00000000, 0x00080E11, 0x0037697D, 0x004887A1, 0x004887A1, 
        0x004787A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042829D, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F819C, 
        0x003F819C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397C98, 0x00397C99, 0x00397C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 
        0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317694, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 
        0x002B7390, 0x002A7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x00276F8D, 0x00266F8D, 0x00266F8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00216B8A, 
        0x001F6B8A, 0x001F6A89, 0x001F6A89, 0x001E6A89, 0x001D6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001B6787,
  0x001B6786, 0x001B6787, 0x001C6887, 0x001D6887, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8B, 0x00246E8C, 0x00246D8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 
        0x00266F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A7190, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7491, 0x002D7491, 0x002D7491, 0x002E7492, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307693, 
        0x00317794, 0x00327794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7E99, 
        0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F819C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 
        0x0044849F, 0x0044859F, 0x0045849F, 0x004585A0, 0x004686A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004787A1, 0x004787A1, 0x004887A1, 0x004786A1, 0x0023424F, 0x00060B0D, 0x00000000, 0x00091215, 0x00335F71, 0x00111F25, 0x00000000, 0x0015272E, 
        0x0049869E, 0x003F7388, 0x00000000, 0x00000000, 0x00325B6C, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8DA5, 0x00508CA6, 0x00457A91, 0x00223C46, 0x000B1316, 0x00000000, 0x0005080A, 0x00274551, 0x00417185, 0x00518CA5, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005792AA, 0x005792AB, 0x005892AA, 0x005792AB, 
        0x005892AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005A94AC, 0x005B94AD, 0x005B94AC, 0x005B94AD, 0x005B95AD, 0x005C95AD, 0x005B95AD, 
        0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005C96AD, 0x005C96AD, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005E96AE, 0x0052849A, 0x000D1519, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x001A2B31, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x0055899E, 0x00010203, 0x00000000, 0x00010202, 0x005E97AE, 0x005E97AE, 0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 
        0x005E97AF, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005E97AE, 0x005E97AE, 0x005E96AE, 0x005E96AE, 0x005E97AE, 0x005E96AE, 0x005D96AE, 0x005D96AE, 0x0054889E, 0x000D1519, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x004A798D, 0x005C96AE, 0x005C95AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B94AC, 0x005B94AC, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 
        0x005994AC, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 
        0x005590A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538EA8, 0x00538FA8, 0x0045788E, 0x002E515F, 0x000D161A, 0x00000000, 0x00060A0C, 0x001B2F38, 0x003D6B7E, 0x00508DA6, 0x00508DA6, 0x00508CA6, 0x004F8CA5, 0x004F8CA5, 
        0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004C8AA4, 0x00203944, 0x00000000, 0x00070C0F, 0x0049859D, 0x0041778D, 0x00050A0C, 0x00000101, 0x00192F38, 0x000C171B, 0x00000000, 0x00060B0D, 0x0023424E, 0x004786A1, 0x004887A1, 0x004787A1, 0x004787A1, 
        0x004786A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0040829D, 0x0040829C, 0x003F819C, 0x003F819C, 0x003F809C, 
        0x003F809B, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C99, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00357A96, 0x00357A96, 
        0x00347996, 0x00347996, 0x00347996, 0x00337995, 0x00337895, 0x00327795, 0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x002F7693, 0x002F7593, 0x002F7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 
        0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00206B8A, 0x00206B8A, 
        0x001F6A89, 0x001F6A89, 0x001E6A89, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6888, 0x001C6787, 0x001B6787,
  0x001A6686, 0x001B6787, 0x001B6787, 0x001C6787, 0x001C6888, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 
        0x00266F8D, 0x00266F8E, 0x0027708D, 0x0028708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A718F, 0x002A728F, 0x002A7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7693, 0x00307693, 
        0x00307694, 0x00317694, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00347895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B97, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 
        0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 
        0x0043849E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004886A1, 0x004887A1, 0x003C7288, 0x001B343E, 0x00000000, 0x00000000, 0x00000000, 0x00020506, 0x003C6E83, 
        0x004B89A3, 0x000F1D22, 0x00000000, 0x0015272E, 0x004A87A0, 0x004C8AA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x0045798F, 0x00305564, 0x00091013, 0x00000000, 0x00050A0B, 0x0017282F, 
        0x00376071, 0x00528EA7, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005390A8, 0x00548FA9, 0x005490A8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591AA, 0x005691AA, 0x005691A9, 0x005692AA, 0x005792AA, 
        0x005791AA, 0x005792AA, 0x005792AA, 0x005892AA, 0x005892AB, 0x005892AA, 0x005892AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005994AC, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 
        0x005B94AC, 0x005B95AC, 0x005B95AD, 0x005B95AD, 0x005B94AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005C95AD, 0x005D96AD, 0x004A798C, 0x00080D0F, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00101A1E, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x00162329, 0x00000000, 0x00000000, 0x00080D0F, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 
        0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AE, 0x005D96AD, 0x005C96AD, 0x005C95AD, 0x005C95AE, 0x00568BA2, 0x00152228, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x001D2F37, 0x005B95AD, 0x005B95AD, 0x005B94AD, 0x005B95AD, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005994AC, 0x005A93AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 
        0x005893AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005892AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A8, 
        0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA8, 0x00407084, 0x001D333C, 0x00080F12, 0x00000000, 0x00040709, 0x00274552, 0x00417388, 0x00508DA6, 0x00508CA6, 0x004F8CA6, 0x004F8CA5, 0x004F8BA5, 0x004E8CA5, 0x004E8BA5, 
        0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x003F7388, 0x00070E10, 0x00000000, 0x00203C47, 0x004B89A3, 0x001B323C, 0x00000000, 0x00000000, 0x00000000, 0x001C3540, 0x003D7289, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004686A0, 
        0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041839D, 0x0041829D, 0x0040829D, 0x0040829D, 0x003F819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 
        0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D9A, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A96, 0x00357996, 0x00347996, 
        0x00347995, 0x00337995, 0x00337895, 0x00327895, 0x00327894, 0x00317794, 0x00317694, 0x00307694, 0x00307693, 0x002F7593, 0x002F7593, 0x002F7592, 0x002D7592, 0x002D7492, 0x002D7492, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 
        0x002A7290, 0x0029718F, 0x0029718F, 0x0028718E, 0x0028708E, 0x00276F8E, 0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246E8D, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216B8B, 0x00216B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 
        0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6786,
  0x001A6686, 0x001A6686, 0x001B6787, 0x001C6887, 0x001C6887, 0x001D6888, 0x001D6988, 0x001D6989, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 
        0x00266F8D, 0x00266F8D, 0x00266F8E, 0x00276F8E, 0x0028708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 
        0x00307693, 0x00317693, 0x00317693, 0x00317794, 0x00327894, 0x00327894, 0x00337895, 0x00337995, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00397C98, 0x00397C98, 
        0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040819C, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839E, 
        0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004685A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x003A6D83, 0x000A1216, 0x00000000, 0x00000101, 0x001A313B, 
        0x00274856, 0x00000000, 0x00030607, 0x00376578, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x00508DA6, 0x00335B6B, 0x00040708, 0x00000000, 
        0x00000000, 0x00091012, 0x00355C6D, 0x00518CA5, 0x00528EA7, 0x00538EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005390A8, 0x005490A8, 0x005490A8, 0x005490A8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591AA, 0x005691A9, 0x005691AA, 0x005691AA, 
        0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AA, 0x005892AB, 0x005893AB, 0x005892AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005A94AC, 0x005994AC, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005B95AC, 0x005B94AC, 0x005B95AC, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x005C95AD, 0x005B95AD, 0x00355765, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00070B0D, 0x0049778B, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C96AD, 0x005D95AD, 0x005C96AD, 0x00274049, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00436C7E, 0x005C96AD, 0x005C96AE, 0x005C96AD, 0x005D96AE, 0x005D96AE, 
        0x005C96AD, 0x005D96AD, 0x005C95AD, 0x005C96AD, 0x005C96AD, 0x005C96AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x00508499, 0x0005090A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000101, 0x00365867, 0x005B94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AB, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005892AB, 0x005893AB, 
        0x005892AB, 0x005892AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x00548FA8, 0x005390A8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00528EA8, 0x00406F83, 0x00121F24, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00223C46, 0x00508DA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 0x004E8CA5, 0x004E8CA5, 0x004D8BA5, 0x004D8BA4, 
        0x004D8AA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x00213D49, 0x00000000, 0x00060B0E, 0x00122128, 0x00000101, 0x00000000, 0x00091215, 0x00396C81, 0x004887A2, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A0, 0x004685A0, 0x004686A0, 
        0x004585A0, 0x0045859F, 0x0045849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0041839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347995, 0x00347896, 
        0x00347995, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00317693, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7492, 0x002C7391, 0x002C7391, 0x002C7391, 0x002A7290, 0x002A7290, 0x002A718F, 
        0x0029718F, 0x0028718F, 0x0028718E, 0x0028708E, 0x0027708E, 0x00276F8D, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00216B8A, 0x00206A8A, 0x00206A89, 0x001F6A89, 
        0x001F6A89, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001C6887, 0x001B6787, 0x001A6786, 0x001A6686,
  0x00196686, 0x001A6686, 0x001B6786, 0x001B6787, 0x001B6787, 0x001C6888, 0x001D6888, 0x001D6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 
        0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 
        0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A96, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 
        0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E7F9B, 0x003E809B, 0x003F809B, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041839E, 
        0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004887A1, 0x004887A1, 0x004786A1, 0x00244350, 0x00091114, 0x00000000, 
        0x00000000, 0x00000000, 0x0014262D, 0x004B89A3, 0x004B8AA3, 0x004C89A4, 0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 0x004D8AA4, 0x004E8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004C879F, 0x00030506, 0x00010203, 
        0x000F1A1F, 0x0005090B, 0x00000000, 0x00070C0F, 0x002B4C59, 0x0043758A, 0x004F88A1, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005390A8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005591A9, 
        0x005691A9, 0x005691AA, 0x005691AA, 0x005692AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005993AB, 
        0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005B94AC, 0x005A94AC, 0x005890A6, 0x0052859C, 0x00518499, 0x004D7E92, 0x00345563, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x000C1317, 0x003E6575, 0x004F7F94, 0x0052869C, 0x00508297, 0x00467384, 0x001E3138, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00304E5A, 0x004A788B, 0x00518398, 0x005C95AD, 0x005C95AD, 
        0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005C95AD, 0x005B95AD, 0x005B95AD, 0x005B95AD, 0x00508398, 0x004B7B8F, 0x003F6778, 0x000E171B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00213740, 0x00467386, 0x004D7F93, 0x00568DA4, 0x005A94AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 
        0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x00548FA9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 
        0x00528DA6, 0x00467A90, 0x00335868, 0x000F1A1F, 0x00000000, 0x00010303, 0x000F1B20, 0x002C4D5B, 0x002F5362, 0x00020304, 0x00060B0D, 0x00477E95, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 
        0x004D8AA4, 0x004C8AA4, 0x004C8AA3, 0x004C89A3, 0x004B89A3, 0x003E7187, 0x00010203, 0x00000000, 0x00000000, 0x00091114, 0x00254552, 0x004786A1, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004585A0, 
        0x004585A0, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041839D, 0x0041829D, 0x0041829D, 0x0040829C, 0x0040819C, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003D809C, 0x003D7F9B, 0x003D7F9B, 
        0x003C7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00347995, 0x00337895, 
        0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317793, 0x00307694, 0x00307693, 0x002F7693, 0x002F7592, 0x002F7592, 0x002E7492, 0x002D7492, 0x002D7492, 0x002C7491, 0x002C7391, 0x002B7391, 0x002B7390, 0x002A7290, 0x002A728F, 0x0029728F, 
        0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246E8C, 0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00226C8A, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x001F6B89, 0x001F6A89, 0x001E6A89, 
        0x001E6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001C6787, 0x001B6787, 0x001B6787, 0x001A6686, 0x00196686,
  0x00196585, 0x00196686, 0x001A6686, 0x001A6786, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6989, 0x001E6988, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 
        0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A7190, 0x002A7290, 0x002B7290, 0x002B7390, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 
        0x002F7593, 0x002F7593, 0x002F7693, 0x00307693, 0x00317793, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B97, 0x00387C98, 
        0x00397C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0041829D, 
        0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004686A1, 0x004887A1, 0x004787A1, 0x004887A1, 0x003E768C, 0x00244451, 
        0x00030506, 0x00000000, 0x00091114, 0x00264755, 0x0047829C, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004D8BA5, 0x004D8BA5, 0x004E8BA5, 0x004E8CA5, 0x00233E49, 0x00000000, 0x00132228, 
        0x00498199, 0x003E6D80, 0x00274552, 0x00091114, 0x00000000, 0x00020405, 0x0017282F, 0x002E505E, 0x00498096, 0x00528EA7, 0x00528EA7, 0x00528FA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A8, 0x005490A9, 0x005490A9, 
        0x005490A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005791AA, 0x005792AA, 0x005692AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x005792AB, 0x005892AB, 0x005892AB, 0x005893AB, 0x005893AB, 
        0x005893AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AC, 0x005993AC, 0x005993AC, 0x005994AC, 0x00406A7C, 0x000D1519, 0x000E181C, 0x0006090B, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00090F11, 0x000F191D, 0x00070B0D, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x000F191D, 0x005B95AD, 0x005B95AC, 
        0x005B94AC, 0x005B94AC, 0x005B95AC, 0x005B94AC, 0x005A94AC, 0x005B94AC, 0x005B94AC, 0x005B94AC, 0x005B94AC, 0x005B94AC, 0x005A94AC, 0x000A1114, 0x00040608, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00060A0C, 0x00385D6C, 0x005993AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005892AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 
        0x005691AA, 0x005691A9, 0x005691A9, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x00558FA9, 0x005490A8, 0x00548FA9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00528EA7, 0x004F89A1, 0x00355B6C, 
        0x001B3139, 0x00070D0F, 0x00000000, 0x00030607, 0x00213943, 0x00396577, 0x004D88A0, 0x004F8CA6, 0x004D88A2, 0x000A1215, 0x00000101, 0x00284956, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A4, 
        0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x0047839C, 0x00264553, 0x000B1418, 0x00000000, 0x00030506, 0x00244451, 0x003E768C, 0x004887A1, 0x004887A1, 0x004787A1, 0x004786A0, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0044859F, 
        0x0044849F, 0x0044849F, 0x0043849E, 0x0043849E, 0x0042839E, 0x0042839E, 0x0041839E, 0x0041829E, 0x0041829D, 0x0040829D, 0x0040819C, 0x0040819C, 0x003F809C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 
        0x003C7E9A, 0x003B7E9A, 0x003A7D9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367A96, 0x00367A97, 0x00357A96, 0x00347996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 
        0x00327795, 0x00327794, 0x00317794, 0x00317793, 0x00307693, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002A7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0028718F, 
        0x0028708F, 0x0028708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00246E8C, 0x00236D8C, 0x00236D8B, 0x00236C8B, 0x00226C8B, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6989, 
        0x001D6988, 0x001D6888, 0x001C6887, 0x001C6787, 0x001B6787, 0x001A6686, 0x001A6686, 0x001A6686, 0x00196686,
  0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 0x001A6786, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 0x001D6888, 0x001D6988, 0x001F6989, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00216B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 
        0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002A7290, 0x002B7390, 0x002C7390, 0x002C7391, 0x002D7391, 0x002D7491, 0x002E7492, 
        0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327794, 0x00327895, 0x00337895, 0x00337995, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 
        0x00387C98, 0x00387C98, 0x00387C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003E819C, 0x003F819C, 0x0040819C, 0x0040829D, 
        0x0041829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004686A1, 0x004787A0, 0x004787A1, 0x004887A1, 0x004786A0, 
        0x00427B93, 0x001C3540, 0x00000000, 0x00000000, 0x0004080A, 0x002A4D5C, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA5, 0x004D8BA5, 0x00477F97, 0x00070D0F, 0x00010202, 0x002C4E5C, 
        0x004F8CA6, 0x004F8CA6, 0x004E8AA4, 0x004C879F, 0x00386475, 0x00101D23, 0x00000000, 0x00000000, 0x0005080A, 0x00192B33, 0x00406F82, 0x00528EA7, 0x00528EA7, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x00548FA9, 
        0x005490A8, 0x005490A9, 0x005590A8, 0x005590A9, 0x005590A9, 0x005590A9, 0x005691A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005791AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AB, 
        0x005892AB, 0x005892AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x00568FA6, 0x0052889E, 0x005389A0, 0x005389A0, 0x005389A0, 0x00538AA0, 0x00548AA0, 0x00548AA0, 0x005489A0, 0x00548AA0, 
        0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x0053899F, 0x0053889F, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x00548AA0, 0x005A94AC, 0x005A94AC, 
        0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A93AC, 0x0053889F, 0x0054899F, 0x00538A9F, 0x005389A0, 0x0053899F, 0x005389A0, 0x005389A0, 0x0053899F, 0x0053899F, 
        0x0053899F, 0x0053899F, 0x0052889F, 0x0052899F, 0x0052899F, 0x0051889E, 0x00558DA5, 0x005892AB, 0x005892AB, 0x005792AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 
        0x005691A9, 0x005591A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x00548FA9, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528EA7, 0x00477C92, 0x00233C47, 0x00070C0E, 0x00010202, 
        0x00000000, 0x00080F12, 0x00305463, 0x004A839A, 0x004E8AA3, 0x00508DA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x00274652, 0x00000000, 0x000F1B21, 0x00467F97, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A3, 0x004B8AA3, 
        0x004B89A3, 0x004B89A3, 0x002A4D5C, 0x0004080A, 0x00000000, 0x00000000, 0x001D3640, 0x00427C94, 0x004786A0, 0x004887A1, 0x004787A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 
        0x0044849F, 0x0043849E, 0x0042839E, 0x0043839E, 0x0042839E, 0x0041839D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9A, 0x003C7E9A, 0x003C7E9A, 
        0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x003A7D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00337895, 0x00327794, 
        0x00327794, 0x00317794, 0x00317793, 0x00317693, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7491, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7391, 0x002A7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028708E, 
        0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8D, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00216C8A, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001D6988, 
        0x001D6988, 0x001C6887, 0x001C6887, 0x001C6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00196685, 0x00186585,
  0x00186585, 0x00186585, 0x00196686, 0x00196686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00216B8B, 0x00226C8B, 0x00226C8B, 0x00236D8B, 
        0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002D7491, 0x002D7491, 
        0x002D7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307694, 0x00317794, 0x00317794, 0x00327795, 0x00327895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 
        0x00377B97, 0x00387C98, 0x00387C98, 0x00387C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x003F819C, 
        0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043849F, 0x0043839F, 0x0043849F, 0x0044849F, 0x0045849F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004787A1, 0x004786A1, 
        0x004887A1, 0x004887A1, 0x003C7087, 0x00122229, 0x00030607, 0x00000000, 0x00091215, 0x00346173, 0x00458098, 0x004B89A3, 0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x002B4F5D, 0x00010202, 0x00070E10, 0x00457C93, 
        0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x00508CA6, 0x0042758A, 0x001D333D, 0x00070D0F, 0x00000101, 0x00000000, 0x00080F12, 0x002D4E5C, 0x0046798F, 0x004D869E, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x005490A8, 0x00548FA8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005791AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AA, 
        0x005792AA, 0x005792AA, 0x005792AA, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005893AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AC, 0x005993AC, 0x005993AB, 
        0x005993AC, 0x005994AB, 0x005993AC, 0x005993AC, 0x005993AB, 0x005994AC, 0x005A93AC, 0x005A94AC, 0x005A94AC, 0x005994AC, 0x005994AC, 0x005A94AC, 0x005994AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 0x005A94AC, 
        0x005993AC, 0x005A93AC, 0x005A94AC, 0x005993AC, 0x005993AC, 0x005993AC, 0x005993AB, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005893AB, 
        0x005893AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591AA, 0x005691A9, 0x005590A9, 
        0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005089A2, 0x00487E94, 0x00365D6E, 0x00111D22, 0x00000000, 0x00000000, 0x00060A0C, 0x0016272E, 
        0x003A6577, 0x00508DA6, 0x00508DA6, 0x004F8DA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8BA5, 0x004B869F, 0x00020405, 0x00000000, 0x00376375, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C89A4, 0x004B89A3, 0x004B89A3, 0x00468098, 
        0x00346173, 0x00091215, 0x00000000, 0x00030607, 0x00122229, 0x003D7287, 0x004887A1, 0x004887A1, 0x004787A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0043849F, 
        0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 
        0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 
        0x00327794, 0x00317693, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A728F, 0x002A7290, 0x002A718F, 0x0029718F, 0x0028708F, 0x0027708E, 
        0x0027708E, 0x00276F8D, 0x00266F8E, 0x00266F8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236C8B, 0x00236C8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001D6988, 0x001D6988, 
        0x001D6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585,
  0x00176585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6786, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6888, 0x001D6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00226C8A, 0x00226C8B, 
        0x00236D8B, 0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256F8D, 0x00266F8D, 0x00276F8D, 0x00276F8E, 0x0028708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7491, 
        0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00357996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367A97, 
        0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003B7F9A, 0x003C7E9A, 0x003D7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F809C, 
        0x003F819C, 0x0040819D, 0x0040829D, 0x0040829D, 0x0041829D, 0x0042829E, 0x0042839D, 0x0042839E, 0x0043849E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004786A0, 
        0x004786A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x00336174, 0x00182E37, 0x00000000, 0x00000000, 0x000F1D23, 0x002A4E5D, 0x00467F98, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x0047819A, 0x00132228, 0x00000000, 0x00213C47, 0x004D8BA4, 
        0x004D8BA4, 0x004E8BA5, 0x004E8CA5, 0x004F8BA5, 0x004E8CA6, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x004A829A, 0x00335A6A, 0x001D333D, 0x00070D10, 0x00000000, 0x00000000, 0x0015252B, 0x002A4855, 0x003E6C7F, 0x00518CA5, 0x00538FA7, 0x00538FA8, 
        0x00528FA8, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x005490A9, 0x005490A8, 0x005590A9, 0x005590A8, 0x005590A9, 0x005490A9, 0x005591A9, 0x005591A9, 0x005590A9, 0x005691A9, 0x005691A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691AA, 
        0x005791AA, 0x005792AA, 0x005692AA, 0x005692AA, 0x005692AA, 0x005791AA, 0x005792AA, 0x005792AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005793AB, 0x005893AA, 0x005893AB, 0x005793AB, 0x005893AB, 0x005893AB, 0x005992AB, 0x005893AB, 0x005893AB, 
        0x005993AB, 0x005992AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005893AB, 0x005893AB, 0x005893AB, 0x005993AB, 0x005993AC, 0x005993AB, 0x005993AB, 0x005993AC, 0x005893AC, 0x005994AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005993AB, 
        0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005993AB, 0x005893AB, 0x005993AB, 0x005993AA, 0x005892AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005892AB, 0x005792AA, 0x005892AB, 0x005892AB, 
        0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005692AA, 0x005691AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005591AA, 0x005691A9, 0x005591A9, 0x005590A9, 0x005691A9, 0x005490A9, 0x005490A9, 0x005490A9, 
        0x00558FA8, 0x005490A9, 0x005490A9, 0x005490A8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00538FA8, 0x00538EA7, 0x00427488, 0x002E515F, 0x001A2E36, 0x00030607, 0x00000000, 0x00020505, 0x00182B33, 0x002E515F, 0x0045798F, 0x00508CA6, 
        0x004F8DA6, 0x004F8CA6, 0x004F8CA6, 0x004E8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8CA5, 0x004D8BA5, 0x004E8BA5, 0x004D8BA4, 0x00254451, 0x00000000, 0x00101D22, 0x004B8AA4, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00457F98, 0x002A4E5D, 0x000F1D22, 
        0x00000000, 0x00000000, 0x00182E37, 0x00336174, 0x004887A2, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045849F, 0x0044859F, 0x0043849F, 0x0043849F, 0x0043849E, 0x0043849E, 
        0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 
        0x00397D99, 0x003A7D99, 0x00387D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347995, 0x00347995, 0x00337895, 0x00327894, 0x00327894, 0x00327794, 0x00317794, 
        0x00317694, 0x00307693, 0x00307693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002D7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7390, 0x002B7290, 0x002B7290, 0x002A7190, 0x002A718F, 0x0029718F, 0x0028718F, 0x0028708F, 0x0028708E, 0x00276F8E, 
        0x00276F8D, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246E8C, 0x00236D8C, 0x00236D8B, 0x00236C8B, 0x00226C8B, 0x00216B8B, 0x00216B8A, 0x00216B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001D6988, 0x001D6988, 0x001C6887, 
        0x001C6887, 0x001B6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00186485,
  0x00176484, 0x00176485, 0x00186585, 0x00186585, 0x00196585, 0x001A6686, 0x001A6686, 0x001A6787, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x00206A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226B8B, 
        0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7390, 0x002B7390, 0x002C7391, 
        0x002C7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00337995, 0x00347996, 0x00357996, 0x00357A96, 0x00357A96, 
        0x00367A97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 
        0x003F819C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043839F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004686A0, 
        0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x0046839D, 0x003A6D83, 0x00162A32, 0x00000000, 0x00000000, 0x00070E11, 0x00254452, 0x0048859F, 0x004A89A3, 0x004B89A3, 0x0039687C, 0x00000000, 0x00000101, 0x00457E96, 0x004D8AA4, 
        0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004D89A2, 0x00477E95, 0x00386375, 0x00172930, 0x00000000, 0x00000000, 0x00040709, 0x000A1114, 0x00213B46, 0x00417185, 
        0x00528EA7, 0x00528EA7, 0x00528FA7, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA9, 0x005490A9, 0x005490A8, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 
        0x005691A9, 0x005691A9, 0x005691AA, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005692AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005892AB, 
        0x005792AB, 0x005792AB, 0x005892AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x005893AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005893AB, 0x005892AB, 0x005892AB, 0x005892AB, 
        0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005892AB, 0x005792AB, 0x005892AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 
        0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A8, 0x005490A9, 0x005490A8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00528FA7, 0x00528EA7, 0x00487D93, 0x002A4855, 0x000E191E, 0x00060B0D, 0x00000101, 0x00000000, 0x000F1B20, 0x00305665, 0x00457B91, 0x004C869F, 0x00508CA6, 0x004F8CA6, 0x004F8CA6, 
        0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x00437A91, 0x00030708, 0x00000000, 0x003B6C81, 0x004B89A3, 0x0048859F, 0x00254552, 0x00070E11, 0x00000000, 0x00000000, 
        0x00162A32, 0x003B6D83, 0x0046839D, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 
        0x0042839E, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F819C, 0x003E809B, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 
        0x003A7D99, 0x00397C99, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357996, 0x00347995, 0x00347995, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 
        0x00307693, 0x002F7693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7390, 0x002A7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0028708F, 0x0028708E, 0x0028708E, 0x00276F8E, 0x00266F8E, 
        0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00236D8C, 0x00236C8C, 0x00236C8B, 0x00216C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001E6A89, 0x001E6989, 0x001D6988, 0x001D6888, 0x001C6887, 0x001C6887, 
        0x001B6787, 0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00176585, 0x00176484,
  0x00166484, 0x00176484, 0x00176485, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001C6787, 0x001C6887, 0x001C6887, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A89, 0x00206B8A, 0x00216B8A, 0x00216C8A, 
        0x00216B8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00256E8C, 0x00256E8C, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x00297190, 0x002A7290, 0x002B7290, 0x002B7290, 0x002B7390, 
        0x002C7391, 0x002D7491, 0x002D7491, 0x002D7491, 0x002E7592, 0x002F7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327795, 0x00337895, 0x00337895, 0x00347895, 0x00347996, 0x00357996, 0x00357A96, 
        0x00367A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7D9A, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 
        0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829E, 0x0041829D, 0x0041839D, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004585A0, 
        0x004685A0, 0x004685A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x003B6E84, 0x00112026, 0x00020304, 0x00000000, 0x00030607, 0x00284A58, 0x0046829B, 0x00192E36, 0x00000000, 0x001E3741, 0x004C89A3, 0x004C8AA4, 
        0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x00508DA6, 0x004D88A0, 0x002D505E, 0x00070D0F, 0x00000000, 0x00000000, 0x00000000, 
        0x00060B0D, 0x00233D48, 0x00406F83, 0x004D869F, 0x00508AA3, 0x00528EA7, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x005490A8, 0x005490A8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 
        0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005791AA, 0x005791AA, 0x005791AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AA, 
        0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AB, 0x005792AA, 0x005792AB, 0x005892AA, 0x005792AA, 0x005792AB, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 
        0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005791AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005792AA, 0x005691AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005691AA, 
        0x005691AA, 0x005691A9, 0x005691A9, 0x005591A9, 0x005691A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00508CA4, 0x004E889F, 0x0046798E, 0x002B4B58, 0x000B1418, 0x00000000, 0x00000000, 0x00020405, 0x00030607, 0x00000000, 0x002A4B59, 0x00508DA6, 0x00508DA6, 0x00508CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004E8CA5, 
        0x004E8CA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA5, 0x004D8BA5, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x0049869F, 0x001E3741, 0x00000000, 0x00122228, 0x002B5160, 0x00030607, 0x00000000, 0x00020304, 0x00112026, 0x003B6F84, 
        0x004887A2, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 
        0x0041829D, 0x0040829D, 0x0040829D, 0x0040819C, 0x0040819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003C7E99, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397D98, 
        0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00357996, 0x00357996, 0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 
        0x00307693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7391, 0x002B7290, 0x002B7290, 0x002A728F, 0x002A7190, 0x0029718F, 0x0029718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 
        0x00266F8D, 0x00256E8C, 0x00246E8C, 0x00246E8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8A, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001E6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001B6787, 
        0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00166484,
  0x00166384, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6988, 0x001D6988, 0x001E6988, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 
        0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8B, 0x00246E8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 
        0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00337895, 0x00337895, 0x00337895, 0x00347995, 0x00347995, 0x00347996, 
        0x00357A96, 0x00367A97, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B97, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 
        0x003D809B, 0x003E809B, 0x003F809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x0045859F, 0x004585A0, 
        0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x00356376, 0x00192F38, 0x00050A0C, 0x00000000, 0x0005090B, 0x00020304, 0x00000101, 0x0040758B, 0x004B89A3, 0x004B8AA3, 
        0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x004A839A, 0x000F1B20, 0x00000000, 0x00203842, 0x001C3139, 
        0x000C1518, 0x00000000, 0x00000000, 0x00060A0C, 0x001C3139, 0x002F5260, 0x003D6A7D, 0x00497F95, 0x00528EA8, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A8, 0x00548FA9, 0x00548FA8, 
        0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005590A9, 0x005591A9, 0x005591A9, 0x005691A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691AA, 
        0x005791AA, 0x005692AA, 0x005691AA, 0x005691AA, 0x005792AA, 0x005791AA, 0x005791AA, 0x005791AA, 0x005791AA, 0x005791AA, 0x005792AA, 0x005791AA, 0x005792AA, 0x005692AA, 0x005791AA, 0x005791AA, 0x005791AA, 0x005792AA, 0x005791AA, 0x005791AA, 
        0x005792AA, 0x005791AA, 0x005791AA, 0x005691AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005791AA, 0x005691AA, 0x005691AA, 0x005691AA, 0x005691A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691A9, 0x005691AA, 0x005690A9, 0x005591A9, 0x005591A9, 
        0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x00548FA9, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x004D849C, 
        0x00406F82, 0x00335968, 0x00213943, 0x000B1316, 0x00000000, 0x00000000, 0x00080F11, 0x00172830, 0x00284653, 0x00407084, 0x003D6C80, 0x00000000, 0x00111E24, 0x004E8BA5, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8BA5, 
        0x004E8BA5, 0x004D8BA5, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x00294B59, 0x00010202, 0x00000000, 0x00000000, 0x00050A0C, 0x00192F38, 0x00356376, 0x004887A2, 0x004887A1, 
        0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004685A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0045859F, 0x0044859F, 0x0043849F, 0x0043849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 
        0x0040829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003F809C, 0x003E809C, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 
        0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357996, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 
        0x002F7593, 0x002E7592, 0x002E7492, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 
        0x00256E8D, 0x00256E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00216B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001D6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001C6787, 0x001B6787, 
        0x001A6686, 0x001A6686, 0x001A6686, 0x00186685, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166384,
  0x00156383, 0x00166484, 0x00166484, 0x00176484, 0x00176585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6786, 0x001B6787, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6989, 0x001E6989, 0x001F6A89, 0x001F6A8A, 0x00206B8A, 
        0x00206B8A, 0x00216B8A, 0x00226C8A, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 
        0x002B7290, 0x002B7390, 0x002B7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00337894, 0x00337895, 0x00337895, 0x00337895, 
        0x00347996, 0x00347996, 0x00357996, 0x00367A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B98, 0x00377B97, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 
        0x003C7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040829C, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0044849F, 
        0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004786A0, 0x004887A1, 0x004787A1, 0x004786A0, 0x003B7186, 0x00244350, 0x00020304, 0x00000000, 0x00000101, 0x00112127, 0x002F5869, 0x004A89A3, 
        0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA5, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8CA5, 0x003A697C, 0x00000101, 0x00010203, 0x004D89A3, 0x004F8BA5, 
        0x00467C93, 0x003C6B7E, 0x002A4A57, 0x00101D22, 0x00000000, 0x00000000, 0x00020405, 0x000C1519, 0x0015262D, 0x00294753, 0x003F6D80, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA9, 0x005490A9, 0x005490A9, 0x005490A8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005591A9, 0x005590A9, 0x005591A9, 
        0x005591A9, 0x005591A9, 0x005590A9, 0x005591A9, 0x005590A9, 0x005691A9, 0x005691A9, 0x005691A9, 0x005591A9, 0x005691A9, 0x005691A9, 0x005591AA, 0x005691A9, 0x005691A9, 0x005691A9, 0x005691AA, 0x005691A9, 0x005691AA, 0x005691A9, 0x005691A9, 
        0x005691A9, 0x005690A9, 0x005591AA, 0x005591A9, 0x005591A9, 0x005591A9, 0x005591A9, 0x005590A9, 0x005591A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 
        0x005490A8, 0x005490A9, 0x005490A8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x00528FA8, 0x00528EA8, 0x00528EA8, 0x0044768A, 0x002E505E, 0x001A2D35, 0x000E191D, 
        0x0005080A, 0x00000000, 0x00000000, 0x000A1216, 0x00243F4A, 0x00396577, 0x0044798E, 0x004D88A0, 0x00508CA6, 0x004F8CA6, 0x004B859D, 0x00080F12, 0x00000000, 0x0041758B, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8AA4, 
        0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004C89A3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004A89A3, 0x002F5868, 0x00112127, 0x0004090A, 0x00000000, 0x00020405, 0x0023424F, 0x003B7086, 0x004786A0, 0x004887A1, 0x004887A1, 0x004786A1, 
        0x004786A0, 0x004786A0, 0x004685A0, 0x004686A0, 0x004685A0, 0x0045859F, 0x0045859F, 0x0044859F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0043849F, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819D, 
        0x0040819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 0x003E7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00397C98, 0x00397C98, 0x00387C98, 
        0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 
        0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0028718F, 0x0028708F, 0x0028708E, 0x0028708E, 0x00276F8D, 0x00276F8D, 0x00266F8D, 0x00256E8D, 0x00256E8D, 
        0x00246E8C, 0x00246E8C, 0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00216C8B, 0x00216C8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001B6887, 0x001A6787, 0x001A6686, 
        0x001A6686, 0x00196685, 0x00196585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166484, 0x00156383,
  0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6786, 0x001B6786, 0x001B6787, 0x001C6887, 0x001C6888, 0x001D6988, 0x001E6988, 0x001E6988, 0x001F6A89, 0x001F6A89, 0x001F6A89, 
        0x00206B8A, 0x00216B8A, 0x00216B8B, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x0027708E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A7190, 
        0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 
        0x00347996, 0x00347996, 0x00357996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D9A, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 
        0x003C7F9B, 0x003C7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 
        0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x0045859F, 0x004685A0, 0x004686A0, 0x004686A1, 0x004786A1, 0x004787A1, 0x004886A1, 0x004787A1, 0x004887A2, 0x0046849E, 0x00264855, 0x00050A0C, 0x00000000, 0x00000000, 0x00060C0F, 
        0x002A4D5D, 0x0048859F, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004E8BA4, 0x004E8BA5, 0x00254350, 0x00000000, 0x001B3039, 0x004F8CA5, 0x004F8CA5, 
        0x004F8CA6, 0x004F8CA6, 0x00508CA6, 0x00508DA6, 0x004D88A0, 0x00325968, 0x0015262C, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00132127, 0x002C4C59, 0x0044768A, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA8, 0x00538EA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x005490A9, 0x005490A8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005590A9, 
        0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 
        0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005590A8, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 0x00548FA8, 0x005490A8, 0x005490A8, 0x005490A9, 0x00548FA8, 
        0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x00538FA8, 0x00528FA8, 0x00528FA8, 0x00518DA6, 0x00528EA7, 0x00487D94, 0x00325666, 0x00192B33, 0x00030607, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x000F1B20, 0x002B4C59, 0x00487F95, 0x00508DA6, 0x00508DA6, 0x00508CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004D89A1, 0x001C333C, 0x00000000, 0x00213B46, 0x004D8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004C8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x004C8AA4, 0x004C89A4, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x0049859F, 0x002A4D5C, 0x00060C0F, 0x00000000, 0x00000000, 0x00050A0C, 0x00274957, 0x0047849E, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A0, 
        0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839D, 0x0041829E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 
        0x003F819C, 0x003E809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00387B98, 0x00387C97, 0x00377B98, 
        0x00377B97, 0x00367B97, 0x00367A97, 0x00357A97, 0x00357A96, 0x00347996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00337895, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 
        0x002E7592, 0x002D7492, 0x002D7491, 0x002C7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002A7290, 0x002A718F, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256F8D, 0x00256E8C, 0x00246E8C, 
        0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001E6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001C6887, 0x001B6787, 0x001A6687, 0x001A6686, 
        0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166484, 0x00156383, 0x00156383,
  0x00146283, 0x00156383, 0x00166384, 0x00166484, 0x00166484, 0x00176485, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001D6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 
        0x00206A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 
        0x002A728F, 0x002A7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7491, 0x002C7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 
        0x00337895, 0x00347996, 0x00347996, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7D9A, 0x003B7E9A, 0x003B7E9A, 
        0x003C7E9A, 0x003C7F9B, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829E, 0x0041829E, 0x0042839E, 0x0042839E, 0x0043839E, 
        0x0043849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x004485A0, 0x0045859F, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004786A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x0046849F, 0x002B5161, 0x00101E24, 0x00030608, 
        0x00000000, 0x00010203, 0x00203C47, 0x0038687C, 0x00447E96, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA3, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004C89A2, 0x000B1418, 0x00000000, 0x00386477, 0x004E8BA5, 0x004E8CA5, 
        0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x00508CA6, 0x00508CA6, 0x00508DA6, 0x00508DA6, 0x003C6A7C, 0x00274551, 0x0016262D, 0x000D161A, 0x00040709, 0x00000000, 0x00000000, 0x00010202, 0x00132127, 0x0025414C, 0x00365E6E, 0x003F6E82, 
        0x0046798F, 0x004C839B, 0x00518CA5, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00548FA9, 0x005490A8, 0x00548FA9, 0x00548FA8, 
        0x005490A9, 0x005490A8, 0x005490A8, 0x005590A8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005490A8, 0x005490A9, 0x005490A9, 0x005490A9, 0x005590A9, 0x005490A9, 0x005590A9, 0x005590A9, 0x005490A9, 0x005590A9, 0x005490A9, 0x005490A9, 0x005490A9, 
        0x005490A9, 0x005490A8, 0x005490A9, 0x005490A9, 0x005490A8, 0x005490A9, 0x005490A9, 0x005490A8, 0x005490A8, 0x005490A8, 0x00548FA9, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00528FA8, 0x004D869D, 0x00477B91, 0x00417184, 0x00396374, 0x002A4855, 0x00172930, 0x00040809, 0x00000000, 0x00000000, 0x00020304, 0x000B1316, 0x00132127, 0x00223C46, 0x00376172, 0x004D88A0, 
        0x00508DA6, 0x00508CA6, 0x00508CA6, 0x00508CA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8CA5, 0x004E8CA5, 0x00315869, 0x00000000, 0x00060C0E, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 
        0x004C89A3, 0x004B89A3, 0x004B89A3, 0x00457E96, 0x0038677B, 0x00203B46, 0x00010202, 0x00000000, 0x00030608, 0x00101E24, 0x002B5161, 0x0046849D, 0x004887A1, 0x004887A1, 0x004787A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 
        0x004685A0, 0x004585A0, 0x0045859F, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0041829E, 0x0040829D, 0x0040829D, 0x0040829D, 0x0040819C, 0x003F819C, 0x003F809C, 
        0x003F819C, 0x003E809B, 0x003E7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 
        0x00367B97, 0x00367A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347996, 0x00347895, 0x00337895, 0x00337895, 0x00327894, 0x00327894, 0x00317794, 0x00317794, 0x00307694, 0x00307693, 0x00307693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002E7492, 
        0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00256F8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 
        0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6887, 0x001C6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x001A6686, 
        0x00196685, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166484, 0x00166384, 0x00156383, 0x00146283,
  0x00136282, 0x00146283, 0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 0x00186485, 0x00186585, 0x00186585, 0x00196586, 0x00196686, 0x001A6786, 0x001B6787, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6988, 0x001D6988, 0x001E6988, 0x001E6989, 
        0x001F6A89, 0x00206A89, 0x00206B8A, 0x00216B8A, 0x00216B8B, 0x00216B8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029708F, 
        0x0029718F, 0x0029718F, 0x002A728F, 0x002B7290, 0x002B7390, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00327894, 
        0x00327895, 0x00337895, 0x00337895, 0x00347996, 0x00347996, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B98, 0x00377B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D98, 0x003A7D99, 0x003A7D99, 0x003B7E99, 
        0x003B7E9A, 0x003B7E9A, 0x003B7F9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9A, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041839E, 0x0042839E, 
        0x0042839E, 0x0042839E, 0x0043839E, 0x0043839F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004786A0, 0x004787A1, 0x004787A1, 0x004787A1, 0x0046849E, 0x0037677C, 
        0x0022404C, 0x00070D10, 0x00000000, 0x00000101, 0x000F1D22, 0x0022404C, 0x003C7086, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x003E7186, 0x00000000, 0x00070E10, 0x0048839A, 0x004D8BA4, 0x004D8BA5, 
        0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8CA5, 0x004E8CA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x00508CA6, 0x00487E96, 0x003E6E82, 0x00345C6D, 0x0025424E, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00080E11, 0x00111F24, 0x00182B33, 0x00223D48, 0x002F5261, 0x003B6678, 0x00477B91, 0x00518CA5, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00538EA8, 0x00538FA7, 0x00528EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00548FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 
        0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538EA8, 0x00528EA8, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 
        0x00498096, 0x003E6C7F, 0x00325766, 0x0025424D, 0x001A2E37, 0x00132127, 0x000A1216, 0x00010202, 0x00000000, 0x00000000, 0x00010303, 0x000D171C, 0x00020304, 0x00020405, 0x003C6A7D, 0x00467B91, 0x004F8CA5, 0x00508CA6, 0x004F8CA6, 0x004F8CA6, 
        0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8BA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x003F7387, 0x00080E11, 0x00000000, 0x003A6A7E, 0x004C8AA3, 0x004C8AA3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 
        0x004A89A3, 0x003C7086, 0x00223F4C, 0x000F1D22, 0x00000101, 0x00000000, 0x00070E11, 0x0022404D, 0x0037677C, 0x0046849E, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 
        0x0044859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003F809C, 0x003E809B, 
        0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9B, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 
        0x00367A96, 0x00357A96, 0x00347996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00337895, 0x00327894, 0x00317794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x002F7693, 0x002F7592, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 
        0x002D7391, 0x002C7391, 0x002C7390, 0x002B7290, 0x002B7290, 0x002A7290, 0x0029728F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8D, 0x00246E8C, 0x00246D8C, 0x00236D8C, 
        0x00236D8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196585, 0x00196585, 
        0x00186585, 0x00186585, 0x00176485, 0x00176484, 0x00166484, 0x00156384, 0x00156383, 0x00146283, 0x00146283,
  0x00136182, 0x00146282, 0x00146283, 0x00156383, 0x00156383, 0x00166484, 0x00176484, 0x00176484, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6787, 0x001B6786, 0x001C6787, 0x001C6887, 0x001C6887, 0x001D6988, 0x001E6988, 0x001E6989, 
        0x001F6A89, 0x001F6A89, 0x001F6A8A, 0x00206A8A, 0x00216B8A, 0x00216B8A, 0x00216B8B, 0x00226C8B, 0x00236C8B, 0x00236C8B, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0028708E, 0x0028708F, 
        0x0029718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002B7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7693, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 
        0x00327794, 0x00327894, 0x00327895, 0x00337895, 0x00347895, 0x00347996, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x00397D99, 0x003A7D99, 
        0x003A7D99, 0x003B7E9A, 0x003B7E99, 0x003C7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F809C, 0x003F819C, 0x0040819D, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 
        0x0042839E, 0x0042839E, 0x0042839E, 0x0043849E, 0x0043839F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 
        0x004785A0, 0x0044819A, 0x00315D70, 0x000C171B, 0x00000000, 0x00000000, 0x00010303, 0x000D191D, 0x002F5667, 0x004987A1, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x001E3842, 0x00000000, 0x001D353F, 0x004A87A0, 0x004D8AA4, 0x004D8BA4, 
        0x004D8AA5, 0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8BA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA5, 0x004F8CA6, 0x00467A91, 0x00000000, 0x00070D10, 0x0044788D, 0x00365F70, 0x00223C47, 
        0x000E191E, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x00010203, 0x00020505, 0x00040708, 0x000C1519, 0x00192B33, 0x0025404B, 0x00345A6A, 0x003F6E82, 0x00498096, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528FA8, 0x00528FA7, 
        0x00528FA7, 0x00528EA8, 0x00528FA8, 0x00538FA7, 0x00538FA8, 0x00538FA7, 0x00538EA8, 0x00538EA8, 0x00538FA8, 0x00528FA8, 0x00538FA8, 0x00538FA8, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA8, 0x00538FA7, 0x00538FA8, 
        0x00538FA8, 0x00538EA8, 0x00538FA8, 0x00538FA8, 0x00538EA7, 0x00528FA7, 0x00538EA7, 0x00528EA8, 0x00528FA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x00528EA7, 0x004B839A, 0x00437489, 0x00365E6F, 0x00284653, 0x001D323B, 0x000E191D, 0x0005090B, 
        0x00030506, 0x00010303, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000A1216, 0x001D333D, 0x00315766, 0x0043768B, 0x004C869E, 0x0043778C, 0x000B1418, 0x00000000, 0x00457A91, 0x004F8CA5, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 
        0x004E8CA5, 0x004F8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004C8AA4, 0x004B89A3, 0x00132229, 0x00000000, 0x001E3741, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004A87A1, 0x002F5767, 
        0x000D181D, 0x00010303, 0x00000000, 0x00000000, 0x000C181C, 0x00325D70, 0x0044819A, 0x004785A0, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 
        0x0044849F, 0x0044849F, 0x0043849F, 0x0043839E, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F809C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D7F9B, 
        0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A97, 
        0x00357A96, 0x00347996, 0x00347995, 0x00347996, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00317694, 0x00307693, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002E7492, 0x002D7491, 0x002C7391, 
        0x002C7391, 0x002B7391, 0x002B7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00276F8D, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246E8C, 0x00246D8C, 0x00236D8B, 0x00236D8B, 
        0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001E6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001B6787, 0x001B6786, 0x001A6786, 0x001A6686, 0x001A6685, 0x00196686, 0x00186585, 
        0x00186585, 0x00176485, 0x00176484, 0x00166484, 0x00156384, 0x00156383, 0x00146283, 0x00146282, 0x00136182,
  0x00136182, 0x00136282, 0x00146283, 0x00146283, 0x00156383, 0x00166384, 0x00166484, 0x00176484, 0x00176485, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001C6887, 0x001D6888, 0x001D6988, 
        0x001E6989, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0027708E, 
        0x0028708F, 0x0029718E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7593, 0x002F7693, 0x00307693, 0x00307793, 0x00317694, 
        0x00327794, 0x00327794, 0x00327894, 0x00327895, 0x00337895, 0x00337995, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00377B98, 0x00387C98, 0x00397C98, 0x00397C99, 0x00397D99, 
        0x003A7D99, 0x003A7D99, 0x003B7D9A, 0x003B7E99, 0x003B7E9A, 0x003C7F9A, 0x003C7E9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 0x0040829D, 0x0041829D, 
        0x0041839E, 0x0041829E, 0x0042829E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043839E, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004786A1, 
        0x004787A1, 0x004887A1, 0x004887A1, 0x004887A2, 0x003A6E84, 0x001C343E, 0x00081013, 0x00010303, 0x00000000, 0x00010203, 0x001D353F, 0x0039697D, 0x00437D94, 0x004A87A1, 0x0005090B, 0x00000000, 0x0031596A, 0x004C8AA3, 0x004C8AA3, 0x004C8AA4, 
        0x004C8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x00345C6C, 0x00000000, 0x0016272E, 0x004F8AA4, 0x00508CA6, 0x00508DA6, 
        0x00508CA6, 0x00508DA6, 0x00457B91, 0x00355D6E, 0x00274552, 0x00172930, 0x000D181C, 0x00091114, 0x00060C0E, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00040708, 0x000F1A1E, 0x0016262D, 0x00213943, 0x0026424E, 
        0x00305462, 0x00355C6C, 0x003A6476, 0x00417184, 0x0044768B, 0x0044778C, 0x0046798F, 0x00477B91, 0x00487C92, 0x00487C92, 0x00487C92, 0x00487C92, 0x00487D93, 0x00487C92, 0x00487C92, 0x00487D93, 0x00487D93, 0x00487C92, 0x00477C92, 0x00477B91, 
        0x00467A90, 0x0045788D, 0x0044768B, 0x00427387, 0x003C687A, 0x00355C6D, 0x00315666, 0x00284652, 0x00213A44, 0x00192B33, 0x00101C22, 0x00080D10, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020304, 0x00060A0C, 0x00091012, 
        0x000C1519, 0x0014232A, 0x00233F4A, 0x00315666, 0x00417387, 0x00508DA6, 0x00508DA6, 0x00508DA6, 0x00508CA6, 0x004F8CA6, 0x00508CA6, 0x004B859E, 0x00122026, 0x00000000, 0x002E5261, 0x004F8CA5, 0x004E8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 
        0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004C8AA4, 0x004C8AA3, 0x00274855, 0x00000000, 0x000D191E, 0x0040758B, 0x0039697D, 0x001D353F, 0x00010202, 0x00000000, 
        0x00010303, 0x00081013, 0x001C343E, 0x003A6E84, 0x004887A2, 0x004887A1, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 
        0x0043849F, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829E, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 
        0x003D7F9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 
        0x00347996, 0x00347995, 0x00347995, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x002F7693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7491, 0x002D7491, 0x002C7391, 0x002C7391, 
        0x002C7391, 0x002B7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00256F8D, 0x00266F8D, 0x00256E8D, 0x00246D8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 
        0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001C6887, 0x001B6787, 0x001A6786, 0x001A6686, 0x001A6686, 0x00196585, 0x00186585, 0x00186585, 
        0x00176484, 0x00176484, 0x00166484, 0x00166384, 0x00156383, 0x00156383, 0x00146283, 0x00136282, 0x00136182,
  0x00126182, 0x00136182, 0x00136182, 0x00136283, 0x00146283, 0x00156383, 0x00156384, 0x00166484, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001C6887, 0x001D6888, 
        0x001D6988, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246D8C, 0x00256E8C, 0x00256E8C, 0x00256F8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 
        0x0028708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 
        0x00307793, 0x00317794, 0x00327794, 0x00327794, 0x00327894, 0x00337895, 0x00347895, 0x00347895, 0x00347995, 0x00347996, 0x00357996, 0x00367A96, 0x00367A97, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387B98, 0x00397C98, 
        0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003E7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040829D, 
        0x0040819D, 0x0040829D, 0x0042829D, 0x0041829D, 0x0041839E, 0x0042839E, 0x0043839E, 0x0042839E, 0x0043839F, 0x0043849F, 0x0044849F, 0x0044849E, 0x0045859F, 0x0044849F, 0x0044859F, 0x004585A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004686A1, 
        0x004686A0, 0x004786A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x00437D95, 0x00305B6D, 0x001D3742, 0x00091215, 0x00000000, 0x00000000, 0x000B1519, 0x00172B33, 0x00000000, 0x00081013, 0x00427990, 0x004B89A3, 0x004B89A3, 0x004B8AA4, 
        0x004B89A3, 0x004B8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x001D333D, 0x00000000, 0x00274552, 0x004D8AA4, 0x004E8CA5, 0x004F8CA5, 
        0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x00508CA6, 0x00508DA6, 0x00508DA6, 0x00488198, 0x0043758B, 0x003A677A, 0x00345B6C, 0x002D4F5D, 0x0026434F, 0x001E363F, 0x00000000, 0x00000000, 0x00070D0F, 0x00040809, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010303, 0x00030607, 0x00050A0B, 0x00060B0D, 0x0005090B, 0x00050A0B, 0x00060B0D, 0x00060B0D, 0x00060A0C, 0x0005080A, 0x00060A0C, 0x0005090B, 0x00020505, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00030607, 0x00080F12, 0x00101D22, 0x00101C21, 0x00000101, 0x0005090B, 0x00294855, 0x00335968, 0x00396577, 0x00407286, 0x00487F95, 
        0x00508CA6, 0x00508DA6, 0x00508CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004E8BA5, 0x004F8BA5, 0x001A2F38, 0x00000000, 0x001B3039, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 
        0x004D8AA4, 0x004D8AA4, 0x004C8BA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B89A4, 0x004B8AA3, 0x004C89A3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x00376578, 0x00000000, 0x00020405, 0x00070E11, 0x00000000, 0x00000000, 0x00091215, 0x001E3842, 
        0x00305B6C, 0x00427D95, 0x004887A1, 0x004887A1, 0x004786A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004786A0, 0x004786A0, 0x004685A0, 0x004686A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043849F, 
        0x0043839E, 0x0042839E, 0x0042839D, 0x0042839E, 0x0042829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040829C, 0x003F819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 
        0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00397C99, 0x00387C98, 0x00387B98, 0x00387C98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00357996, 0x00347996, 
        0x00347995, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00327794, 0x00317794, 0x00317694, 0x00317693, 0x00307693, 0x002F7593, 0x002F7592, 0x002F7592, 0x002D7592, 0x002E7492, 0x002D7492, 0x002C7491, 0x002C7391, 0x002C7391, 0x002B7290, 
        0x002B7290, 0x002A7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0029718F, 0x0027708E, 0x0028708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00246E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00226D8B, 0x00226C8B, 0x00216C8A, 
        0x00216B8A, 0x00216B8A, 0x00206A8A, 0x001F6A8A, 0x001F6A89, 0x001E6A89, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6888, 0x001C6887, 0x001B6887, 0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00196585, 0x00186585, 0x00186585, 0x00176484, 
        0x00166484, 0x00166484, 0x00156383, 0x00156383, 0x00156383, 0x00146282, 0x00136282, 0x00136182, 0x00126182,
  0x00126181, 0x00126082, 0x00136182, 0x00136282, 0x00146282, 0x00146283, 0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 0x00176585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6786, 0x001B6787, 0x001C6787, 0x001C6787, 0x001C6888, 
        0x001D6988, 0x001D6988, 0x001E6989, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00246D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256F8D, 0x00266F8D, 0x00266F8D, 
        0x0027708E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A728F, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002C7491, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002F7592, 0x002F7593, 0x002F7593, 
        0x00307693, 0x00317694, 0x00317793, 0x00317794, 0x00327794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347995, 0x00357996, 0x00347996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367A97, 0x00377A97, 0x00377B97, 0x00377B97, 0x00387B98, 
        0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9B, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 
        0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004685A0, 
        0x004686A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x0047859F, 0x00427C95, 0x0037667B, 0x001A313B, 0x00000101, 0x00000000, 0x00000000, 0x00010202, 0x00101D23, 0x002B505F, 0x00457F98, 0x004A89A3, 
        0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x00091013, 0x00000000, 0x00335D6E, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 
        0x004E8CA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x00508CA6, 0x004F8CA6, 0x004A839B, 0x00000000, 0x00060B0D, 0x003D6C7F, 0x00487F96, 0x00477D93, 0x00457B91, 
        0x00427489, 0x00396577, 0x00335B6B, 0x00305564, 0x00294855, 0x00223C47, 0x00213B45, 0x001F3640, 0x001C323B, 0x00091114, 0x00000000, 0x00060C0E, 0x00122025, 0x00030607, 0x00000000, 0x00091013, 0x0015252C, 0x00040809, 0x00000000, 0x0016272E, 
        0x00213A45, 0x00223C46, 0x00274551, 0x002E5260, 0x00335A6A, 0x00376172, 0x00407185, 0x00457A90, 0x00467C93, 0x00487F95, 0x00498198, 0x004B859D, 0x003D6C7F, 0x00020405, 0x00091013, 0x00498299, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 
        0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004E8CA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x00294A58, 0x00000101, 0x000F1B20, 0x004B88A1, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 
        0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00467F98, 0x002A4F5E, 0x00111F25, 0x00050A0C, 0x00000000, 0x00000000, 0x00000000, 0x001A313B, 0x0037677B, 0x00427C95, 0x0047859F, 
        0x004887A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0043839E, 0x0043839E, 0x0042839E, 
        0x0042839E, 0x0042839E, 0x0041829E, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003B7E9A, 
        0x003B7E9A, 0x003B7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B97, 0x00377B98, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357996, 0x00357996, 0x00347895, 0x00337895, 
        0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00327794, 0x00317794, 0x00317693, 0x00307693, 0x002F7693, 0x002F7593, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7491, 0x002C7391, 0x002C7391, 0x002B7290, 0x002B7290, 
        0x002A728F, 0x0029718F, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246E8C, 0x00246E8C, 0x00246D8C, 0x00236D8B, 0x00236C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 
        0x00206B8A, 0x00206B89, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6988, 0x001E6988, 0x001D6888, 0x001C6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6787, 0x001A6686, 0x00196686, 0x00196585, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 
        0x00166384, 0x00156384, 0x00156383, 0x00156383, 0x00146283, 0x00136182, 0x00136282, 0x00126082, 0x00126081,
  0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136282, 0x00146282, 0x00156283, 0x00156383, 0x00166383, 0x00166384, 0x00176484, 0x00176484, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 
        0x001C6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256F8D, 0x00266F8D, 
        0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x0029728F, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7592, 
        0x00307693, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00327794, 0x00327894, 0x00327895, 0x00337895, 0x00337895, 0x00347996, 0x00347996, 0x00357996, 0x00357996, 0x00367A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00387B98, 
        0x00387C98, 0x00387C98, 0x00387C98, 0x00397D99, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9A, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F809C, 
        0x003F819C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x0045859F, 
        0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A0, 0x004786A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x004887A2, 0x0047859F, 0x002F596A, 0x00112127, 0x00030608, 0x00010203, 0x00000000, 0x00000000, 0x000F1B21, 
        0x002A4E5D, 0x00417990, 0x0047829B, 0x004986A0, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C89A3, 0x004C8AA4, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x00478099, 0x00000000, 0x0005090B, 0x003D6F83, 0x004D8BA5, 0x004D8BA5, 0x004D8BA5, 
        0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x004E8BA5, 0x004E8CA5, 0x004E8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x0043788D, 0x00000000, 0x000A1216, 0x0044798F, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 
        0x00508CA6, 0x00508DA6, 0x00508CA6, 0x00508DA6, 0x00508CA6, 0x00508CA6, 0x00508DA6, 0x00508DA6, 0x00508DA6, 0x00203843, 0x00000000, 0x00223C46, 0x00508DA6, 0x00111E24, 0x00000000, 0x002A4A57, 0x00508DA6, 0x00122026, 0x00000000, 0x003B697B, 
        0x00508DA6, 0x00508DA6, 0x00508DA6, 0x00508CA6, 0x00508CA6, 0x004F8DA6, 0x004F8CA6, 0x004F8CA6, 0x00508CA6, 0x004F8CA6, 0x00508CA6, 0x004F8CA6, 0x00457A91, 0x00030607, 0x00050A0C, 0x003F7185, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 
        0x004F8CA5, 0x004E8BA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x00386578, 0x00010202, 0x00080F12, 0x0041758C, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 
        0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004986A0, 0x0047829B, 0x0041788F, 0x002A4E5D, 0x000E1B20, 0x00000000, 0x00000000, 0x00010203, 0x00030608, 0x00122228, 0x0030596A, 0x0047859F, 0x004887A1, 0x004887A1, 0x004887A1, 0x004787A1, 
        0x004887A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0045849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 
        0x0042839D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 
        0x003B7E99, 0x003A7D99, 0x003A7D99, 0x003A7C99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 
        0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7391, 0x002A7290, 0x002A7290, 
        0x002A7290, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00266F8D, 0x00266F8D, 0x00266E8D, 0x00256E8D, 0x00246D8C, 0x00246D8C, 0x00236D8C, 0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00216C8B, 0x00216B8A, 0x00206B8A, 
        0x00206A8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6887, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166484, 
        0x00166384, 0x00156383, 0x00156283, 0x00146283, 0x00136282, 0x00136182, 0x00136182, 0x00126081, 0x00116081,
  0x00116081, 0x00116081, 0x00126181, 0x00126182, 0x00136182, 0x00136282, 0x00146283, 0x00146383, 0x00156383, 0x00166384, 0x00166484, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 
        0x001C6787, 0x001C6887, 0x001D6988, 0x001D6988, 0x001E6988, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00256E8D, 0x00256E8D, 
        0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0028708F, 0x0028718E, 0x0029718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002D7492, 0x002E7592, 0x002E7592, 
        0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317693, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00347A96, 0x00357A96, 0x00367A96, 0x00367A97, 0x00367B97, 0x00377B97, 
        0x00377B97, 0x00377C98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9A, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 
        0x003F809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 
        0x0045859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004686A1, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x004887A2, 0x00417C93, 0x002E5667, 0x001C353F, 0x000E1B21, 0x00010202, 
        0x00000000, 0x00000000, 0x000C171B, 0x001F3944, 0x002E5666, 0x003B6C81, 0x0046819A, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x00356072, 0x00000000, 0x000C171B, 0x00437B92, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 
        0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x00386477, 0x00000000, 0x000F1B20, 0x00477F96, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 
        0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8BA6, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x004F8CA6, 0x001E3640, 0x00000000, 0x00213A45, 0x004F8CA6, 0x00101D23, 0x00000000, 0x00284754, 0x004F8CA6, 0x00111F25, 0x00000000, 0x00396679, 
        0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA6, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x004F8CA5, 0x0049829A, 0x0004080A, 0x00030708, 0x00386477, 0x004E8BA5, 0x004E8CA5, 0x004E8BA5, 0x004E8BA5, 
        0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x0047819A, 0x00020405, 0x00030607, 0x00376476, 0x004C8AA3, 0x004C8AA4, 0x004B89A3, 0x004B8AA3, 
        0x004B89A3, 0x0046819A, 0x003B6C81, 0x002E5666, 0x001F3944, 0x000C171B, 0x00000000, 0x00000000, 0x00010202, 0x000E1B21, 0x001C353F, 0x002E5667, 0x00427C94, 0x004887A2, 0x004787A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 
        0x004686A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839D, 0x0041839D, 0x0041829D, 
        0x0041829D, 0x0040829D, 0x0040829D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003D809B, 0x003D809B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7E99, 0x003A7D99, 
        0x00397D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A96, 0x00357A96, 0x00357A96, 0x00347996, 0x00347996, 0x00347996, 0x00337895, 0x00337895, 0x00337895, 
        0x00327794, 0x00317794, 0x00317794, 0x00307694, 0x00307693, 0x00307693, 0x00307693, 0x002F7592, 0x002F7592, 0x002E7592, 0x002D7492, 0x002D7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7391, 0x002B7391, 0x002A7290, 0x002A7290, 0x002A7190, 
        0x0029718F, 0x0029718F, 0x0028708F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00276F8E, 0x00266F8D, 0x00266E8D, 0x00256E8D, 0x00246E8C, 0x00246D8C, 0x00246D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00216B8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 
        0x001F6A89, 0x001F6A89, 0x001F6989, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6888, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00196585, 0x00186585, 0x00186585, 0x00176485, 0x00176484, 0x00166484, 0x00166384, 
        0x00156383, 0x00156283, 0x00146283, 0x00136282, 0x00136182, 0x00136182, 0x00126181, 0x00116081, 0x00116081,
  0x00105F80, 0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136282, 0x00146283, 0x00156283, 0x00156383, 0x00156383, 0x00166484, 0x00176484, 0x00176484, 0x00186585, 0x00186585, 0x00196585, 0x00196686, 0x001A6686, 0x001A6686, 0x001A6786, 
        0x001B6787, 0x001C6887, 0x001C6887, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6989, 0x001F6A89, 0x00206A89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236C8B, 0x00246D8C, 0x00246D8C, 0x00246E8D, 
        0x00256E8D, 0x00256F8D, 0x00266F8D, 0x00276F8D, 0x00276F8E, 0x0027708E, 0x0027708E, 0x0028708F, 0x0029718F, 0x0029718F, 0x002A7190, 0x002A7290, 0x002A7290, 0x002B7390, 0x002C7390, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7492, 0x002E7492, 
        0x002E7592, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00347895, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00357A96, 0x00367A97, 
        0x00367B97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003A7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 
        0x003E809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849F, 0x0044849F, 
        0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004886A1, 0x004887A1, 0x004887A1, 0x00417B94, 0x003A6E83, 
        0x002C5161, 0x0015282F, 0x00000000, 0x00000000, 0x00000000, 0x00050A0C, 0x000C161A, 0x00162A32, 0x002A4E5D, 0x003E7389, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x00223F4B, 0x00000000, 0x0014242B, 0x004987A0, 0x004C8AA3, 0x004C8AA3, 0x004C8AA3, 
        0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004D8BA5, 0x002E5363, 0x00000000, 0x00132229, 0x0049839A, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 
        0x004E8BA4, 0x004D8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8CA5, 0x001E3640, 0x00000000, 0x00203A45, 0x004E8CA5, 0x00101C22, 0x00000000, 0x00274654, 0x004E8BA5, 0x00111F25, 0x00000000, 0x00386477, 
        0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA4, 0x004D8BA5, 0x004D8BA5, 0x00080E11, 0x00010303, 0x0031596A, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 
        0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004B8AA3, 0x004B8AA3, 0x004B89A3, 0x000C161A, 0x00000000, 0x002C5161, 0x004A89A3, 0x004B89A3, 0x003E7389, 0x002A4E5D, 
        0x00162A32, 0x000C161A, 0x00050A0C, 0x00000000, 0x00000000, 0x00000101, 0x0015282F, 0x002B5261, 0x003A6E84, 0x00417B93, 0x004887A1, 0x004887A1, 0x004887A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A1, 0x004686A1, 0x004686A0, 0x004686A0, 
        0x004685A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0045859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0044839F, 0x0043849E, 0x0043849E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041819D, 0x0040829D, 
        0x0040819D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 
        0x00397C99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00337894, 0x00327794, 0x00327794, 
        0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002C7391, 0x002B7390, 0x002A7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 
        0x0029718F, 0x0028708E, 0x0027708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266F8D, 0x00256F8D, 0x00246E8C, 0x00246E8C, 0x00246D8C, 0x00246D8C, 0x00236C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00216B8A, 0x00206A89, 0x001F6A89, 
        0x001F6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6887, 0x001C6887, 0x001B6787, 0x001A6786, 0x001A6786, 0x001A6686, 0x00196686, 0x00186586, 0x00186585, 0x00186584, 0x00176485, 0x00166484, 0x00166484, 0x00156383, 0x00156383, 
        0x00156383, 0x00146283, 0x00136282, 0x00136182, 0x00136182, 0x00126181, 0x00116081, 0x00116081, 0x00105F80,
  0x00105F80, 0x00105F80, 0x00116080, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136282, 0x00146283, 0x00156283, 0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 0x001A6686, 
        0x001A6786, 0x001B6787, 0x001C6887, 0x001C6887, 0x001D6888, 0x001D6888, 0x001D6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00236D8C, 0x00236D8C, 0x00246D8C, 
        0x00256E8D, 0x00256E8D, 0x00266E8D, 0x00266F8D, 0x00266F8E, 0x00276F8E, 0x0027708E, 0x0028708F, 0x0028708E, 0x0028718F, 0x0029718F, 0x002A7290, 0x002A7290, 0x002A7290, 0x002B7290, 0x002B7391, 0x002C7391, 0x002C7491, 0x002D7491, 0x002D7491, 
        0x002E7492, 0x002E7592, 0x002E7592, 0x002F7693, 0x002F7693, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 0x00337995, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00357A96, 
        0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 
        0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003F819C, 0x003F819C, 0x003F819C, 0x0040819D, 0x0040819D, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829E, 0x0042829E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 
        0x0043849F, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004686A1, 0x004786A1, 0x004786A1, 0x004787A1, 0x004787A1, 0x004887A1, 
        0x004887A1, 0x004887A2, 0x0047849E, 0x00346376, 0x001C343E, 0x00060C0E, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00030608, 0x00172B34, 0x002F5668, 0x000F1C21, 0x00000000, 0x001F3944, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 
        0x004B89A3, 0x004B8AA3, 0x004B8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x0024424E, 0x00000000, 0x00182B33, 0x004B88A1, 0x004D8AA4, 0x004D8BA4, 0x004D8BA5, 
        0x004D8BA4, 0x004D8BA4, 0x004E8BA5, 0x004D8BA5, 0x004D8BA4, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x004E8BA5, 0x001E3540, 0x00000000, 0x00203A45, 0x004D8BA5, 0x00101C22, 0x00000000, 0x00274653, 0x004E8BA5, 0x00111F25, 0x00000000, 0x00386477, 
        0x004E8BA5, 0x004D8BA5, 0x004E8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x004D8BA5, 0x004D8BA4, 0x004D8BA4, 0x004D8BA4, 0x000D191D, 0x00000000, 0x002A4C5B, 0x004D8BA4, 0x004C8BA4, 0x004C8AA4, 0x004C8AA4, 
        0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004B8AA3, 0x004C8AA3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004A88A2, 0x004B89A3, 0x001E3742, 0x00000000, 0x00112026, 0x00172A32, 0x00030608, 0x00000000, 0x00000000, 
        0x00000000, 0x00000101, 0x00060C0E, 0x001C343E, 0x00356376, 0x0046849D, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A0, 0x004786A1, 0x004786A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 
        0x004585A0, 0x0045859F, 0x0044859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0043849E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829E, 0x0041839D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819C, 
        0x003F819C, 0x003F819C, 0x003F809C, 0x003E809B, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 
        0x00387C98, 0x00387C98, 0x00387B98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00367B97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347996, 0x00347996, 0x00347895, 0x00337895, 0x00337895, 0x00327894, 0x00327794, 0x00317794, 0x00317794, 
        0x00317793, 0x00307693, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002E7592, 0x002D7492, 0x002D7491, 0x002D7391, 0x002C7391, 0x002B7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A7190, 0x0029718F, 0x0029718F, 0x0028718F, 
        0x0028708F, 0x0027708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00266E8D, 0x00256E8D, 0x00256E8D, 0x00246D8C, 0x00246D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 
        0x001E6A89, 0x001E6988, 0x001D6988, 0x001D6988, 0x001C6887, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00196585, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166384, 0x00156383, 0x00156383, 0x00156283, 
        0x00146283, 0x00146282, 0x00136182, 0x00136182, 0x00126081, 0x00116081, 0x00116081, 0x00105F80, 0x00105F80,
  0x000F5E80, 0x00105F80, 0x00106080, 0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136282, 0x00146283, 0x00146283, 0x00156383, 0x00156384, 0x00166484, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 0x00186585, 0x00196686, 0x001A6686, 
        0x001A6786, 0x001B6787, 0x001B6787, 0x001C6787, 0x001C6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6989, 0x001F6989, 0x001F6A89, 0x00206B89, 0x00206B8A, 0x00216B8A, 0x00216B8A, 0x00226C8B, 0x00226C8B, 0x00226C8C, 0x00236D8B, 0x00246D8C, 
        0x00246D8C, 0x00256E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00276F8E, 0x00276F8E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A718F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002B7290, 0x002C7391, 0x002C7391, 0x002C7491, 
        0x002D7491, 0x002E7492, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7593, 0x002F7693, 0x00307693, 0x00317693, 0x00317793, 0x00317794, 0x00327794, 0x00327894, 0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00347996, 0x00347996, 0x00357996, 
        0x00357A97, 0x00367A96, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7E9A, 
        0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042839E, 0x0042839E, 0x0042839E, 
        0x0042839E, 0x0043839E, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x004585A0, 0x004585A0, 0x004685A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004786A1, 
        0x004787A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A2, 0x004887A2, 0x003C7389, 0x002A505F, 0x001A3039, 0x000F1C22, 0x00070E11, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000D181D, 0x00244350, 0x0030596A, 0x0039697D, 0x003F758B, 
        0x00457F97, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004C8AA3, 0x004B8AA4, 0x004C8AA3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x001A3039, 0x00000000, 0x001C343E, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004D8AA4, 
        0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8BA4, 0x004D8AA4, 0x001D353F, 0x00000000, 0x00203A44, 0x004D8BA4, 0x00101D22, 0x00000000, 0x00274653, 0x004D8AA4, 0x00111F25, 0x00000000, 0x00386577, 
        0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004D8BA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004D8AA4, 0x004C8AA4, 0x004D8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x00162931, 0x00000000, 0x00233F4B, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 
        0x004B8AA3, 0x004C89A3, 0x004B89A3, 0x004B8AA3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00457F97, 0x003F758B, 0x0039697D, 0x0030596A, 0x0023424F, 0x0014252C, 0x00030607, 0x00000000, 0x00000000, 0x00000000, 0x00070E11, 0x000F1C22, 0x001A3039, 
        0x002A4F5F, 0x003D7289, 0x004887A2, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004787A1, 0x004786A1, 0x004787A1, 0x004786A1, 0x004686A0, 0x004786A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004685A0, 0x0045859F, 0x004585A0, 0x004585A0, 
        0x0044859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849E, 0x0043839E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F819C, 
        0x003F819C, 0x003E809C, 0x003E809B, 0x003E809C, 0x003E809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C98, 0x00397C98, 0x00387C98, 
        0x00387C98, 0x00387B98, 0x00377B97, 0x00377B98, 0x00367B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00337895, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00317694, 
        0x00307693, 0x00307693, 0x002F7693, 0x002F7593, 0x002E7592, 0x002E7592, 0x002E7592, 0x002D7491, 0x002D7491, 0x002D7491, 0x002C7391, 0x002B7390, 0x002B7390, 0x002B7290, 0x002A728F, 0x0029728F, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 
        0x0027708E, 0x00276F8E, 0x00266F8E, 0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246D8C, 0x00246D8C, 0x00236D8C, 0x00236C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6989, 0x001F6A89, 
        0x001E6988, 0x001D6988, 0x001D6988, 0x001C6887, 0x001C6887, 0x001B6787, 0x001B6787, 0x001A6786, 0x00196686, 0x001A6686, 0x00186585, 0x00186585, 0x00186585, 0x00176584, 0x00176484, 0x00166484, 0x00166384, 0x00156383, 0x00146283, 0x00146283, 
        0x00136282, 0x00136182, 0x00136182, 0x00126081, 0x00116081, 0x00116081, 0x00106081, 0x00105F80, 0x000F5F80,
  0x000E5E7F, 0x000F5E80, 0x00105F80, 0x00105F80, 0x00116081, 0x00116081, 0x00126181, 0x00126181, 0x00136182, 0x00136282, 0x00146282, 0x00146283, 0x00156383, 0x00156383, 0x00166484, 0x00176384, 0x00176484, 0x00186485, 0x00186585, 0x00186585, 0x00196685, 
        0x001A6686, 0x001A6686, 0x001B6686, 0x001B6787, 0x001C6787, 0x001C6887, 0x001D6888, 0x001D6988, 0x001D6988, 0x001E6988, 0x001F6989, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00226C8B, 0x00236D8B, 
        0x00236D8B, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266E8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0027708E, 0x0028708F, 0x0028718F, 0x0029718F, 0x0029718F, 0x002A728F, 0x002A7290, 0x002B7290, 0x002B7290, 0x002B7390, 0x002C7391, 
        0x002C7491, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7593, 0x00307693, 0x00307693, 0x00317794, 0x00317794, 0x00317794, 0x00327794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00337995, 0x00347996, 
        0x00347996, 0x00357996, 0x00357A96, 0x00357A97, 0x00367A97, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397C98, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 0x003B7E9A, 0x003B7E9A, 
        0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809C, 0x003E809B, 0x003E819C, 0x003F819C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040819C, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 
        0x0042829D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0044849F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004685A0, 0x004686A0, 0x004686A0, 
        0x004686A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x004787A1, 0x004887A1, 0x00448098, 0x003C7087, 0x00336174, 0x00294C5B, 0x001A3039, 0x000A1317, 0x00000000, 0x00000000, 0x00000000, 0x00010202, 0x00091114, 
        0x000F1C22, 0x00162931, 0x00203B46, 0x002B515F, 0x00366478, 0x00417991, 0x004B89A3, 0x004A89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x00112026, 0x00000000, 0x00223E4A, 0x004B89A3, 0x004B89A3, 0x004B8AA3, 0x004B89A3, 
        0x004B8AA3, 0x004B8AA3, 0x004C8AA3, 0x004C8AA4, 0x004B8AA3, 0x004C8AA3, 0x004C8AA4, 0x004C89A4, 0x004C8AA4, 0x001D3640, 0x00000000, 0x001F3944, 0x004C8AA4, 0x000F1C22, 0x00000000, 0x00264653, 0x004C8AA4, 0x00111F25, 0x00000000, 0x00376477, 
        0x004C8AA3, 0x004C8AA3, 0x004C8AA4, 0x004C89A3, 0x004C8AA4, 0x004C8AA4, 0x004C8AA4, 0x004C8AA3, 0x004C89A3, 0x004B89A3, 0x004B8AA3, 0x004C89A3, 0x004B89A3, 0x001F3A45, 0x00000000, 0x001F3843, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 
        0x004B89A3, 0x004A89A3, 0x00417991, 0x00366578, 0x002B5060, 0x00203B46, 0x00162930, 0x000F1C22, 0x00091114, 0x00010202, 0x00000000, 0x00000000, 0x00000000, 0x000A1418, 0x001A3039, 0x00284B5A, 0x00336174, 0x003C7086, 0x00448098, 0x004887A1, 
        0x004887A1, 0x004787A1, 0x004787A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x004585A0, 0x004585A0, 0x0044859F, 0x0044849F, 0x0044849F, 0x0044849F, 
        0x0043849F, 0x0043849F, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042829E, 0x0042839E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040819D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003E809C, 0x003E809C, 
        0x003E809B, 0x003E7F9B, 0x003D7F9B, 0x003D7F9A, 0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 
        0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A97, 0x00357A97, 0x00357996, 0x00357996, 0x00347996, 0x00347895, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 
        0x002F7693, 0x002F7592, 0x002E7592, 0x002E7492, 0x002D7492, 0x002D7491, 0x002D7491, 0x002C7491, 0x002C7391, 0x002B7390, 0x002B7390, 0x002B7290, 0x002A728F, 0x002A728F, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0028708E, 0x0027708E, 
        0x00276F8E, 0x00266F8D, 0x00256F8D, 0x00256E8D, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00246D8C, 0x00226C8C, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001E6988, 
        0x001D6988, 0x001D6888, 0x001C6887, 0x001B6887, 0x001B6787, 0x001B6786, 0x001A6686, 0x00196686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166484, 0x00156384, 0x00156383, 0x00156283, 0x00146282, 0x00136182, 
        0x00136182, 0x00136182, 0x00126181, 0x00116081, 0x00116081, 0x00105F81, 0x00105F80, 0x000F5F80, 0x000E5E7F,
  0x000E5E7F, 0x000E5E7F, 0x000F5F80, 0x00105F80, 0x00105F80, 0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136182, 0x00136283, 0x00146282, 0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 0x00186485, 0x00186585, 0x00186585, 
        0x00196686, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6887, 0x001D6888, 0x001D6888, 0x001D6988, 0x001E6988, 0x001E6A89, 0x001F6A89, 0x001F6A89, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216C8B, 0x00226C8B, 0x00226C8B, 
        0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246D8C, 0x00246E8C, 0x00256E8D, 0x00256E8D, 0x00266F8D, 0x00276F8E, 0x00276F8E, 0x0028708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x002A718F, 0x002A7190, 0x002B7290, 0x002B7290, 0x002B7390, 
        0x002C7391, 0x002C7391, 0x002C7491, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002F7593, 0x002F7593, 0x002F7693, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 0x00337895, 0x00337895, 0x00337895, 
        0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00357A96, 0x00367A97, 0x00367B97, 0x00377A97, 0x00377B97, 0x00377B97, 0x00387B98, 0x00387C98, 0x00387C98, 0x00397C98, 0x00397D99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E99, 
        0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003C7F9A, 0x003C7F9A, 0x003C7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E809B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 
        0x0041829D, 0x0041829D, 0x0041829E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043839F, 0x0043849E, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x004585A0, 0x0045859F, 0x004585A0, 0x004585A0, 0x004685A0, 
        0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004786A1, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004786A0, 0x0047859F, 0x0046839E, 0x00447E96, 0x00366579, 0x00244451, 0x00122128, 0x00030607, 
        0x00000000, 0x00000000, 0x00000000, 0x00000101, 0x00010203, 0x00010303, 0x00030607, 0x000D181D, 0x00182C35, 0x00254451, 0x00325C6E, 0x003C6F84, 0x0048859F, 0x000C161A, 0x00000101, 0x00294D5C, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 
        0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x001D353F, 0x00000000, 0x001F3843, 0x004B89A3, 0x000F1C21, 0x00000000, 0x00264653, 0x004B89A3, 0x00111F25, 0x00000000, 0x00366376, 
        0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x004B89A3, 0x002A4E5D, 0x00000000, 0x00182C35, 0x00396A7E, 0x00325C6E, 0x00254451, 0x00182C35, 
        0x000D181D, 0x00030507, 0x00010303, 0x00010203, 0x00000101, 0x00000000, 0x00000000, 0x00000000, 0x00030607, 0x00122128, 0x00244451, 0x00366579, 0x00437E96, 0x0046839E, 0x004785A0, 0x004786A0, 0x004887A1, 0x004787A1, 0x004887A1, 0x004787A1, 
        0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004685A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x0045849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 
        0x0043839F, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003F809B, 0x003E809C, 0x003E809B, 0x003E809B, 
        0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7E9A, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 
        0x00377B97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357A96, 0x00347996, 0x00347996, 0x00347996, 0x00337995, 0x00337895, 0x00337895, 0x00327794, 0x00327794, 0x00327794, 0x00317794, 0x00317793, 0x00317694, 0x00307693, 0x002F7693, 0x002F7693, 
        0x002F7592, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7492, 0x002C7491, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0028718F, 0x0028708E, 0x0027708E, 0x00276F8E, 0x00276F8D, 
        0x00266F8D, 0x00266F8D, 0x00256E8D, 0x00256E8D, 0x00246D8C, 0x00246D8C, 0x00246D8B, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x001F6A89, 0x001F6A89, 0x001F6A89, 0x001E6988, 0x001D6988, 0x001D6988, 
        0x001C6888, 0x001C6887, 0x001C6887, 0x001B6787, 0x001A6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166484, 0x00156383, 0x00156383, 0x00146383, 0x00146283, 0x00146282, 0x00136182, 
        0x00126182, 0x00126082, 0x00116081, 0x00116081, 0x00105F80, 0x00105F80, 0x000F5F80, 0x000F5E7F, 0x000E5E7F,
  0x000D5E7F, 0x000E5E7F, 0x000F5E80, 0x000F5E80, 0x00105F80, 0x00105F80, 0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136182, 0x00146283, 0x00146283, 0x00156383, 0x00156384, 0x00166384, 0x00166484, 0x00176484, 0x00186585, 0x00186585, 
        0x00186585, 0x00196586, 0x00196686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6787, 0x001C6888, 0x001C6888, 0x001D6888, 0x001D6988, 0x001E6989, 0x001F6989, 0x001F6A89, 0x001F6A8A, 0x00206B8A, 0x00206B8A, 0x00216B8A, 0x00216C8A, 0x00226C8B, 
        0x00226C8B, 0x00236D8B, 0x00236D8C, 0x00236D8C, 0x00246E8C, 0x00256E8C, 0x00256E8C, 0x00266F8D, 0x00266F8D, 0x00266F8D, 0x00276F8E, 0x0027708E, 0x0027708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x0029718F, 0x002A7290, 0x002B7290, 0x002B7290, 
        0x002B7291, 0x002C7390, 0x002C7391, 0x002D7391, 0x002D7491, 0x002D7492, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7593, 0x00307693, 0x00307693, 0x00307693, 0x00317694, 0x00317794, 0x00317794, 0x00327794, 0x00327895, 0x00337895, 0x00337895, 
        0x00337995, 0x00347995, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00367A96, 0x00367A97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387B97, 0x00387C98, 0x00397C98, 0x00397C99, 0x00397C99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 
        0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003E809B, 0x003E809C, 0x003F809C, 0x003F819C, 0x003F809C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040819D, 
        0x0040829D, 0x0041829D, 0x0041829D, 0x0042829D, 0x0041839E, 0x0042829E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x0045859F, 
        0x004585A0, 0x004685A0, 0x004585A0, 0x004686A0, 0x004685A0, 0x004686A0, 0x004786A0, 0x004686A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A1, 
        0x00417B92, 0x00335F72, 0x00264856, 0x00182D36, 0x000F1C21, 0x000A1316, 0x00070D10, 0x00040708, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x000C171B, 0x00182D35, 0x00213D4A, 0x00274957, 0x002D5464, 
        0x00356376, 0x0038697D, 0x003B6D82, 0x003D7288, 0x003E748A, 0x0040758B, 0x0041778E, 0x00427990, 0x00457F97, 0x001A303A, 0x00000000, 0x001C333D, 0x004A88A2, 0x000E191E, 0x00000000, 0x00223F4B, 0x0048849D, 0x000F1B21, 0x00000000, 0x0030596A, 
        0x00427991, 0x0041778E, 0x003F758B, 0x003E748A, 0x003D7288, 0x003B6D82, 0x0038697D, 0x00356376, 0x002D5464, 0x00274957, 0x00213E4A, 0x00182C35, 0x00112127, 0x0004090A, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00040708, 0x00070D10, 0x000A1317, 0x000F1C21, 0x00182D36, 0x00264856, 0x00335F72, 0x00427A92, 0x004887A2, 0x004887A2, 0x004887A1, 0x004887A2, 0x004887A1, 0x004887A1, 0x004887A1, 0x004787A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004786A0, 
        0x004686A0, 0x004686A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004585A0, 0x004585A0, 0x0045859F, 0x004585A0, 0x0045859F, 0x0045859F, 0x0045849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043839F, 0x0043839E, 0x0043839E, 
        0x0042839E, 0x0042839E, 0x0042839E, 0x0042829D, 0x0041829E, 0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x003F819C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003E7F9B, 0x003D7F9B, 0x003D7F9B, 
        0x003D7F9B, 0x003C7F9B, 0x003C7E9A, 0x003C7F9A, 0x003C7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7E99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397C99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B98, 0x00377B97, 0x00377B97, 0x00367B97, 
        0x00367A97, 0x00357A97, 0x00357A96, 0x00357996, 0x00347996, 0x00347995, 0x00347995, 0x00347995, 0x00337895, 0x00327895, 0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 0x00307593, 0x002F7592, 0x002F7592, 
        0x002E7592, 0x002E7492, 0x002D7492, 0x002D7492, 0x002C7391, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x0027708D, 0x00276F8E, 0x00266F8D, 
        0x00266F8D, 0x00256E8C, 0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8B, 0x00226C8B, 0x00226C8B, 0x00226C8B, 0x00216B8B, 0x00206B8A, 0x00206B8A, 0x00206A8A, 0x001F6A89, 0x001E6A89, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6888, 
        0x001C6888, 0x001B6787, 0x001B6787, 0x001B6786, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00176484, 0x00166384, 0x00166384, 0x00156383, 0x00156283, 0x00146283, 0x00136282, 0x00136182, 0x00136182, 
        0x00126081, 0x00126081, 0x00116081, 0x00116080, 0x00105F80, 0x000F5F80, 0x000F5E7F, 0x000E5E7F, 0x000E5E7F,
  0x000D5D7E, 0x000D5D7F, 0x000E5E7F, 0x000F5E7F, 0x000F5F80, 0x00105F80, 0x00105F80, 0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136182, 0x00136282, 0x00146283, 0x00156383, 0x00156383, 0x00166384, 0x00166484, 0x00166484, 0x00176585, 
        0x00186585, 0x00186585, 0x00196686, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6787, 0x001C6888, 0x001D6888, 0x001D6988, 0x001E6989, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A8A, 0x00206B8A, 0x00206B8A, 0x00216C8A, 
        0x00216C8B, 0x00226C8B, 0x00236C8B, 0x00236D8B, 0x00236D8C, 0x00246D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0027708E, 0x0028708E, 0x0028718F, 0x0029718F, 0x0029718F, 0x0029718F, 0x002A7290, 
        0x002A7290, 0x002A7290, 0x002B7391, 0x002C7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7491, 0x002E7592, 0x002F7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00307694, 0x00317794, 0x00317794, 0x00327794, 0x00327894, 
        0x00327895, 0x00337895, 0x00337895, 0x00347995, 0x00347995, 0x00347996, 0x00357996, 0x00357A96, 0x00357A96, 0x00367A96, 0x00367B97, 0x00367B97, 0x00377B97, 0x00377B97, 0x00377B98, 0x00387C97, 0x00387C98, 0x00397C98, 0x00397C99, 0x003A7D99, 
        0x003A7D99, 0x003A7D99, 0x003B7D99, 0x003B7E99, 0x003B7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7E9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003D809B, 0x003D809B, 0x003E809C, 0x003E809C, 0x003F809C, 0x0040819C, 0x003F819C, 
        0x0040819C, 0x0040819C, 0x0040819D, 0x0040819D, 0x0040829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041839D, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043839E, 0x0043839E, 0x0043849E, 0x0043849F, 0x0043849F, 0x0044849F, 0x0044849F, 
        0x0044849F, 0x0044849F, 0x0045859F, 0x0045859F, 0x0045859F, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x004685A0, 0x004686A0, 0x004686A0, 0x004786A0, 0x004686A0, 0x004786A1, 0x004786A1, 0x004786A1, 0x004787A1, 0x004887A1, 0x004787A1, 
        0x004787A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x004887A1, 0x00437E96, 0x003C7288, 0x00376679, 0x00305A6C, 0x002A4E5E, 0x0023414E, 0x001C3540, 0x00152830, 0x000F1D22, 0x00070E11, 0x00030506, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 
        0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00010303, 0x00030506, 0x00060B0D, 0x00081013, 0x000B1418, 0x00040809, 0x00000000, 0x0005090B, 0x000E1A1F, 0x00020405, 0x00000000, 0x00060C0E, 0x000D191D, 0x00020405, 0x00000000, 0x00070D10, 
        0x00081013, 0x00060B0D, 0x00030506, 0x00010303, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00000000, 0x00020506, 0x00080E11, 0x000F1D22, 0x0015272F, 0x001C3540, 0x0023424E, 0x002A4E5E, 0x00305A6C, 
        0x00366679, 0x003C7288, 0x00447E96, 0x004887A1, 0x004887A1, 0x004787A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A0, 0x004686A0, 0x004786A0, 0x004686A0, 0x004685A0, 0x004685A0, 
        0x004685A0, 0x004585A0, 0x004685A0, 0x004585A0, 0x0045859F, 0x0045859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849E, 0x0044849E, 0x0043839E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0041829E, 
        0x0041829D, 0x0041829D, 0x0041829D, 0x0040829D, 0x0040819D, 0x0041819D, 0x0040819C, 0x003F819C, 0x003F819C, 0x0040819C, 0x003F819C, 0x003F809C, 0x003F809B, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9A, 
        0x003C7E9A, 0x003C7F9A, 0x003B7E9A, 0x003B7E99, 0x003B7D9A, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397C99, 0x00397C98, 0x00387C98, 0x00387C98, 0x00377B97, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367B97, 0x00367A97, 0x00357A96, 
        0x00357A96, 0x00357996, 0x00347995, 0x00347996, 0x00347995, 0x00337995, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00317794, 0x00317794, 0x00317794, 0x00307693, 0x00307693, 0x00307693, 0x002F7593, 0x002F7592, 0x002E7592, 0x002E7492, 
        0x002D7492, 0x002D7491, 0x002C7391, 0x002C7391, 0x002C7391, 0x002B7390, 0x002B7290, 0x002A7290, 0x002A7290, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028718E, 0x0028708F, 0x0028708E, 0x0027708E, 0x00266F8E, 0x00266F8D, 0x00256F8D, 0x00266E8D, 
        0x00256E8C, 0x00246E8C, 0x00246D8C, 0x00246D8C, 0x00236D8B, 0x00236C8B, 0x00226C8B, 0x00226C8B, 0x00216B8A, 0x00216B8A, 0x00206B8A, 0x00206A89, 0x001F6A89, 0x001F6A89, 0x001E6989, 0x001E6989, 0x001D6888, 0x001D6888, 0x001C6887, 0x001C6887, 
        0x001B6787, 0x001B6787, 0x001A6786, 0x001A6686, 0x00196686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176484, 0x00166484, 0x00166384, 0x00156383, 0x00156383, 0x00146283, 0x00146283, 0x00136282, 0x00136182, 0x00126182, 0x00126081, 
        0x00116081, 0x00116081, 0x00105F80, 0x00105F80, 0x000F5F80, 0x000E5E7F, 0x000E5E7F, 0x000E5E7F, 0x000D5D7F,
  0x000C5D7E, 0x000D5D7E, 0x000E5E7F, 0x000E5E7F, 0x000E5E7F, 0x000F5F80, 0x00105F80, 0x00105F80, 0x00116081, 0x00116081, 0x00126081, 0x00126182, 0x00136182, 0x00136182, 0x00146283, 0x00156283, 0x00156383, 0x00156383, 0x00166484, 0x00166484, 0x00176484, 
        0x00176584, 0x00186585, 0x00186585, 0x00186586, 0x00196686, 0x001A6686, 0x001A6686, 0x001B6787, 0x001B6787, 0x001C6787, 0x001C6888, 0x001D6888, 0x001D6888, 0x001E6988, 0x001E6989, 0x001F6A89, 0x001F6A89, 0x00206A89, 0x00206B8A, 0x00206B8A, 
        0x00216B8B, 0x00226C8B, 0x00226C8B, 0x00236C8B, 0x00236D8C, 0x00236D8C, 0x00236D8C, 0x00246E8C, 0x00256E8C, 0x00256E8D, 0x00266F8D, 0x00266F8D, 0x00266F8E, 0x0027708E, 0x0027708E, 0x0028708E, 0x0028708E, 0x0029718F, 0x0029718F, 0x0029718F, 
        0x002A7290, 0x002A7290, 0x002B7290, 0x002B7390, 0x002B7391, 0x002C7391, 0x002C7391, 0x002D7491, 0x002D7491, 0x002E7492, 0x002E7592, 0x002E7592, 0x002F7592, 0x002F7693, 0x00307693, 0x00307693, 0x00307694, 0x00317794, 0x00317794, 0x00317794, 
        0x00327795, 0x00327895, 0x00337895, 0x00337895, 0x00337995, 0x00337995, 0x00347996, 0x00357996, 0x00357A96, 0x00357996, 0x00367A97, 0x00367A96, 0x00367A97, 0x00377B97, 0x00377B97, 0x00377B97, 0x00387C98, 0x00387C98, 0x00387C98, 0x00387C98, 
        0x00397C98, 0x00397D99, 0x00397D99, 0x003A7D99, 0x003A7D99, 0x003A7D99, 0x003B7E9A, 0x003B7E9A, 0x003B7E9A, 0x003C7E9A, 0x003C7F9A, 0x003C7F9A, 0x003D7F9B, 0x003D7F9B, 0x003D7F9B, 0x003E7F9B, 0x003E809B, 0x003E809C, 0x003E809C, 0x003F809C, 
        0x003F809C, 0x003F819C, 0x003F819C, 0x0040819C, 0x0040819D, 0x0040819D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0041829D, 0x0042829E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0043839E, 0x0043849E, 0x0043839E, 0x0043849F, 
        0x0043849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044859F, 0x0044859F, 0x0045859F, 0x0045859F, 0x0045859F, 0x004585A0, 0x004585A0, 0x004685A0, 0x004585A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004786A1, 
        0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004787A1, 0x004787A1, 0x004887A1, 0x004787A1, 0x004887A1, 0x004887A1, 0x004786A0, 0x0046849D, 0x0045819B, 0x00447F98, 0x00427C95, 0x00427B93, 0x00407992, 0x003E748B, 0x00356579, 0x00305A6C, 
        0x002B5161, 0x0023414E, 0x001F3B46, 0x001C333E, 0x00162931, 0x00101E24, 0x000F1C21, 0x000D181D, 0x000A1316, 0x00070E11, 0x0004080A, 0x00010203, 0x00000101, 0x00000000, 0x00000000, 0x00000101, 0x00020405, 0x00040809, 0x00070E11, 0x000A1317, 
        0x000D181D, 0x000F1C21, 0x00101E24, 0x00162931, 0x001C333E, 0x001F3B46, 0x0023424E, 0x002B5160, 0x00305A6C, 0x00366579, 0x003E758B, 0x00407992, 0x00427B94, 0x00427D95, 0x00447F98, 0x0045819A, 0x0046849D, 0x004786A0, 0x004887A1, 0x004887A1, 
        0x004887A1, 0x004886A1, 0x004887A1, 0x004787A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004786A1, 0x004686A1, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004686A0, 0x004685A0, 0x004585A0, 0x004585A0, 0x004585A0, 0x0045859F, 
        0x0045859F, 0x0045859F, 0x0044859F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0044849F, 0x0043849F, 0x0043849F, 0x0043839E, 0x0043839E, 0x0043839E, 0x0042839E, 0x0042839E, 0x0042839E, 0x0042839D, 0x0042839E, 0x0042829E, 0x0041829E, 0x0041829D, 
        0x0041829D, 0x0041829D, 0x0040819D, 0x0040819D, 0x0040819D, 0x003F819C, 0x003F819C, 0x003F809C, 0x003F809C, 0x003E809C, 0x003E809B, 0x003E809B, 0x003D809B, 0x003D7F9B, 0x003D7F9B, 0x003D7F9A, 0x003C7F9B, 0x003C7F9A, 0x003C7E9A, 0x003C7E9A, 
        0x003B7E9A, 0x003B7E9A, 0x003B7E99, 0x003A7D99, 0x003A7D99, 0x00397D99, 0x00397D99, 0x00397C99, 0x00397C98, 0x00397C98, 0x00387C98, 0x00387B98, 0x00377B97, 0x00377B97, 0x00377B97, 0x00367A97, 0x00367A97, 0x00367A97, 0x00357A96, 0x00357A96, 
        0x00357996, 0x00347996, 0x00347995, 0x00347996, 0x00337895, 0x00337895, 0x00327895, 0x00327794, 0x00327794, 0x00317794, 0x00317794, 0x00307794, 0x00307693, 0x00307693, 0x00307693, 0x002F7592, 0x002E7592, 0x002E7592, 0x002E7492, 0x002D7492, 
        0x002D7492, 0x002C7391, 0x002C7391, 0x002C7390, 0x002B7390, 0x002B7290, 0x002B7290, 0x002A728F, 0x0029718F, 0x0029718F, 0x0029718F, 0x0028708E, 0x0028708E, 0x0027708E, 0x0027708E, 0x00276F8E, 0x00266F8D, 0x00256F8D, 0x00256E8D, 0x00246E8C, 
        0x00246E8C, 0x00246D8C, 0x00236D8C, 0x00236D8C, 0x00226C8B, 0x00226C8B, 0x00216C8B, 0x00216C8A, 0x00206B8A, 0x00206B8A, 0x00206B8A, 0x001F6A89, 0x001F6989, 0x001E6989, 0x001E6988, 0x001D6988, 0x001D6888, 0x001C6888, 0x001C6887, 0x001B6787, 
        0x001B6787, 0x001A6686, 0x001A6686, 0x00196686, 0x00186585, 0x00186585, 0x00186585, 0x00176585, 0x00176484, 0x00166484, 0x00166484, 0x00156383, 0x00156383, 0x00156283, 0x00136283, 0x00136282, 0x00136182, 0x00126182, 0x00126181, 0x00116081, 
        0x00116081, 0x00105F80, 0x00105F80, 0x000F5F80, 0x000E5E7F, 0x000E5E7F, 0x000E5E7F, 0x000D5D7F, 0x000C5D7E
#endif
};

GUI_CONST_STORAGE GUI_BITMAP bmClockFace_Classic_390x390 = {
  390, // xSize
  390, // ySize
  1560, // BytesPerLine
  32, // BitsPerPixel
  (unsigned char *)_acClockFace_Classic_390x390,  // Pointer to picture data
  NULL,  // Pointer to palette
#if (GUI_USE_ARGB == 1)
  GUI_DRAW_BMPM8888I
#else
  GUI_DRAW_BMP8888
#endif
};

static GUI_POINT _aSecPos[3600];
static GUI_POINT _aMinPos[3600];
static GUI_POINT _aHourPos[3600];

/*********************************************************************
*
*       Static code
*
**********************************************************************
*/
/*********************************************************************
*
*       _SetupHand
*/
static void _SetupHand(int xSize, int ySize, GUI_POINT * pPoint, int Length, int NumItems) {
  I32 Alpha;
  int i;
  int r;
  int xPos;
  int yPos;
  I32 AlphaAdd;

  xPos = (xSize >> 1) * AA_FACTOR;
  yPos = (ySize >> 1) * AA_FACTOR;
  r = Length * AA_FACTOR;
  AlphaAdd = (360L * 1000L) / NumItems;
  for (Alpha = -90000, i = 0; i < NumItems; Alpha += AlphaAdd, i++) {
    pPoint->x = xPos + ((GUI__CosHQ(Alpha) * r) >> 16);
    pPoint->y = yPos + ((GUI__SinHQ(Alpha) * r) >> 16);
    pPoint++;
  }
}

/*********************************************************************
*
*       _DrawIndicator
*/
static void _DrawIndicator(GUI_POINT Point, GUI_COLOR Color, int PenSize) {
  int AAFactorOld;
  
  AAFactorOld = GUI_AA_GetFactor();
  GUI_AA_EnableHiRes();
  GUI_AA_SetFactor(AA_FACTOR);
  GUI_SetColor(Color);
  GUI_SetPenSize(PenSize);
  GUI_AA_DrawLine((LCD_GetXSize() >> 1) * AA_FACTOR, (LCD_GetYSize() >> 1) * AA_FACTOR, Point.x, Point.y);
  GUI_SetColor(COLOR_LIGHTBROWN);
  if (PenSize > 3) {
    GUI_SetPenSize(2);
    GUI_AA_DrawLine((LCD_GetXSize() >> 1) * AA_FACTOR, (LCD_GetYSize() >> 1) * AA_FACTOR, Point.x, Point.y);
  }
  GUI_AA_DisableHiRes();
  GUI_AA_SetFactor(AAFactorOld);
}

/*********************************************************************
*
*       _AnimateSecond
*/
static void _AnimateSecond(GUI_ANIM_INFO * pInfo, void * pVoid) {
  ANIM_DATA * pData;
  WM_MESSAGE Msg = {0};
  
  pData  = (ANIM_DATA *)pVoid;
  pData->Index = pData->LastIndex + (pData->Destination * pInfo->Pos) / GUI_ANIM_RANGE;
  pData->Time = pData->Index / 60;
  WM_InvalidateWindow(pData->hWin);
  if (pInfo->State == GUI_ANIM_END) {
    pData->LastIndex = pData->Index;
  }
  if (pData->Index >= pData->NumItems) {
    Msg.MsgId = MSG_ANIM_MINUTE;
    WM_BroadcastMessage(&Msg);
    pData->Index = 0;
    pData->LastIndex = 0;
  }
}

/*********************************************************************
*
*       _AnimateMinute
*/
static void _AnimateMinute(GUI_ANIM_INFO * pInfo, void * pVoid) {
  ANIM_DATA * pData;
  WM_MESSAGE Msg = {0};
  
  pData  = (ANIM_DATA *)pVoid;
  pData->Index = pData->LastIndex + (pData->Destination * pInfo->Pos) / GUI_ANIM_RANGE;
  pData->Time = pData->Index / 60;
  if (pData->Time == 60) {
    Msg.MsgId = MSG_ANIM_HOUR;
    WM_BroadcastMessage(&Msg);
  }
  WM_InvalidateWindow(pData->hWin);
  if (pInfo->State == GUI_ANIM_END) {
    pData->LastIndex = pData->Index;
  }
  if (pData->Index >= pData->NumItems) {
    pData->Index = 0;
    pData->LastIndex = 0;
  }
}

/*********************************************************************
*
*       _OnDelete
*/
static void _OnDelete(void * pVoid) {
  ANIM_DATA * pData;

  pData = (ANIM_DATA *)pVoid;
  pData->AnimInProgress = 0;
}

/*********************************************************************
*
*       _AnimateHour
*/
static void _AnimateHour(GUI_ANIM_INFO * pInfo, void * pVoid) {
  ANIM_DATA * pData;
  
  pData  = (ANIM_DATA *)pVoid;
  pData->Index = pData->LastIndex + (pData->Destination * pInfo->Pos) / GUI_ANIM_RANGE;
  pData->Time = pData->Index / 300;
  
  WM_InvalidateWindow(pData->hWin);
  if (pInfo->State == GUI_ANIM_END) {
    pData->LastIndex = pData->Index;
  }
  if (pData->Index >= pData->NumItems) {
    pData->Index = 0;
    pData->LastIndex = 0;
  }
}

/*********************************************************************
*
*       _cbClock
*/
static void _cbClock(WM_MESSAGE * pMsg) {
  static ANIM_DATA         aAnimData[3];
  static GUI_ANIM_HANDLE   ahAnim[3];
  int                      xSize;
  int                      ySize;
  int                      AAFactorOld;
#ifdef GUI_USE_EMCC
  EMCC_DATE                Date;
#endif

  switch (pMsg->MsgId) {
  case WM_CREATE:
    xSize = LCD_GetXSize();
    ySize = LCD_GetYSize();
    _SetupHand(xSize, ySize, _aSecPos,  (xSize >> 1),  GUI_COUNTOF(_aSecPos));
    _SetupHand(xSize, ySize, _aMinPos,  (xSize >> 1) - 70,  GUI_COUNTOF(_aMinPos));
    _SetupHand(xSize, ySize, _aHourPos, (xSize >> 1) - 94, GUI_COUNTOF(_aHourPos));

#ifdef GUI_USE_EMCC
    EMCC_GetNow(&Date);
#endif

    aAnimData[SECOND].hWin        = pMsg->hWin;
    aAnimData[SECOND].Index       = TIME_START_S(TIME_S);
    aAnimData[SECOND].NumItems    = GUI_COUNTOF(_aSecPos);
    aAnimData[SECOND].Destination = 60;
    aAnimData[SECOND].LastIndex   = TIME_START_S(TIME_S);
    
    aAnimData[MINUTE].hWin        = pMsg->hWin;
    aAnimData[MINUTE].Index       = TIME_START_M(TIME_M);
    aAnimData[MINUTE].Destination = 60;
    aAnimData[MINUTE].NumItems    = GUI_COUNTOF(_aMinPos);
    aAnimData[MINUTE].LastIndex   = TIME_START_M(TIME_M);

    aAnimData[HOUR].hWin        = pMsg->hWin;
    aAnimData[HOUR].Index       = TIME_START_H(TIME_H);
    aAnimData[HOUR].Destination = 6;
    aAnimData[HOUR].NumItems    = GUI_COUNTOF(_aHourPos);
    aAnimData[HOUR].LastIndex   = TIME_START_H(TIME_H);

    ahAnim[SECOND] = GUI_ANIM_Create(TIME_ANIM, 10, (void *)&aAnimData[SECOND], NULL);
    GUI_ANIM_AddItem(ahAnim[SECOND], 0, TIME_ANIM, ANIM_LINEAR, (void *)&aAnimData[SECOND], _AnimateSecond);
    GUI_ANIM_StartEx(ahAnim[SECOND], -1, NULL);
    break;
  case WM_PAINT:
    GUI_DrawBitmap(&BM_FACE, 0, 0);
    _DrawIndicator(_aHourPos[aAnimData[HOUR].Index],   GUI_BLACK, 8);
    _DrawIndicator(_aMinPos [aAnimData[MINUTE].Index], GUI_BLACK, 7);
    _DrawIndicator(_aSecPos [aAnimData[SECOND].Index], GUI_BLACK, 3);
    xSize = (LCD_GetXSize() >> 1) * AA_FACTOR;
    ySize = (LCD_GetYSize() >> 1) * AA_FACTOR;
    AAFactorOld = GUI_AA_GetFactor();
    GUI_AA_EnableHiRes();
    GUI_AA_SetFactor(AA_FACTOR);
    GUI_SetColor(GUI_BLACK);
    GUI_AA_FillCircle(xSize, ySize, 10 * AA_FACTOR);
    GUI_AA_SetFactor(AAFactorOld);
    GUI_AA_DisableHiRes();

    break;
  case MSG_ANIM_MINUTE:
    ahAnim[MINUTE] = GUI_ANIM_Create(300, 10, (void *)&aAnimData[MINUTE], NULL);
    GUI_ANIM_AddItem(ahAnim[MINUTE], 0, 300, ANIM_ACCELDECEL, (void *)&aAnimData[MINUTE], _AnimateMinute);
    GUI_ANIM_StartEx(ahAnim[MINUTE], 1, NULL);
    break;
  case MSG_ANIM_HOUR:
    ahAnim[HOUR] = GUI_ANIM_Create(1000, 10, (void *)&aAnimData[HOUR], NULL);
    GUI_ANIM_AddItem(ahAnim[HOUR], 0, 1000, ANIM_ACCELDECEL, (void *)&aAnimData[HOUR], _AnimateHour);
    GUI_ANIM_StartEx(ahAnim[HOUR], 1, _OnDelete);
    break;
  default:
    WM_DefaultProc(pMsg);
    break;
  }
}

/*********************************************************************
*
*       Public code
*
**********************************************************************
*/
/*********************************************************************
*
*       MainTask
*/
void MainTask(void);
void MainTask(void) {
  int xSize;
  int ySize;

  GUI_Init();
  WM_MULTIBUF_Enable(1);
  xSize = LCD_GetXSize();
  ySize = LCD_GetYSize();
  WM_SetSize(WM_HBKWIN, xSize, ySize);
  WM_CreateWindowAsChild(0, 0, xSize, ySize, WM_HBKWIN, WM_CF_SHOW, _cbClock, 0);
  while (1) {
    GUI_Delay(100);
  }
}

/****** End of File *************************************************/
